(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    373707,       9525]*)
(*NotebookOutlinePosition[    374389,       9549]*)
(*  CellTagsIndexPosition[    374345,       9545]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["CurvesGraphics", "Title"],

Cell[TextData[{
  "By ",
  ButtonBox["Gianluca Gorni",
    ButtonData:>{
      URL[ "http://www.dimi.uniud.it/~gorni"], None},
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["Department of Mathematics and Computer Science",
    ButtonData:>{
      URL[ "http://www.dimi.uniud.it"], None},
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["University of Udine",
    ButtonData:>{
      URL[ "http://web.uniud.it"], None},
    ButtonStyle->"Hyperlink"],
  ", Italy. Latest revision: April 18, 2005."
}], "Text"],

Cell[TextData[{
  "The package defined in this notebook adds the following capabilities to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics:"
}], "Text"],

Cell[TextData[{
  StyleBox["easily",
    FontSlant->"Italic"],
  " placing ",
  StyleBox["arrows along curves",
    FontWeight->"Bold"],
  " in 2D or 3D space: along the curves produced by  ",
  ButtonBox["Plot",
    ButtonStyle->"RefGuideLink"],
  ", ",
  ButtonBox["ParametricPlot",
    ButtonStyle->"RefGuideLink"],
  ", ",
  ButtonBox["ParametricPlot3D",
    ButtonStyle->"RefGuideLink"],
  ", and ",
  ButtonBox["ContourPlot",
    ButtonStyle->"RefGuideLink"],
  ", and along the solutions to differential equations given by ",
  ButtonBox["NDSolve",
    ButtonStyle->"RefGuideLink"],
  ";"
}], "Text",
  CellDingbat->"\[FilledCircle]",
  CellMargins->{{100, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "drawing ",
  StyleBox["parametric or contour ",
    FontWeight->"Bold"],
  StyleBox["curves on a surface in 3D space",
    FontWeight->"Bold"],
  ", all curves with optional arrows along them."
}], "Text",
  CellDingbat->"\[FilledCircle]",
  CellMargins->{{100, Inherited}, {Inherited, Inherited}}],

Cell["\<\
Number, positions, size, shape, style, color of the arrows and of \
the curves are customizable through options. The default values of the \
options have been chosen to give pleasing results in most typical cases that \
I could think of, with hardly any tweaking.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Before you start:",
    FontWeight->"Bold"],
  " if you have not done it already, install ",
  ButtonBox["David Park",
    ButtonData:>{
      URL[ "http://home.earthlink.net/~djmp/"], None},
    ButtonStyle->"Hyperlink"],
  "'s ",
  StyleBox["DrawGraphics", "Input"],
  " package, available for download from the page ",
  ButtonBox["http://home.earthlink.net/~djmp/Mathematica.html",
    ButtonData:>{
      URL[ "http://home.earthlink.net/~djmp/Mathematica.html"], None},
    ButtonStyle->"Hyperlink"],
  " (scroll down to the section on ",
  StyleBox["the DrawGraphics Paradigm",
    FontSlant->"Italic"],
  "). ",
  StyleBox["DrawGraphics", "Input"],
  " is must for anyone making serious pictures with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". ",
  StyleBox["CurvesGraphics", "Input"],
  " uses internally and is integrated with ",
  StyleBox["DrawGraphics", "Input"],
  ". However, once you have it properly installed, you can proceed to ",
  StyleBox["CurvesGraphics", "Input"],
  " and don't need to learn ",
  StyleBox["DrawGraphics", "Input"],
  " usage first, for most purposes."
}], "Text"],

Cell[TextData[{
  StyleBox["Instructions",
    FontWeight->"Bold"],
  ": The package is embedded in this notebook file. You load the package by \
clicking on the following button (whose effect is the same as the menu \
command \"Evaluate Initialization\"), and then you can evaluate the tutorial \
examples, and make your own variations. Read on for instruction on how to \
make a more permanent installation."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Button[
      StyleForm["\<Click here to load package!\>", 
        FontColor \[Rule] RGBColor[1, 0, 0], FontSize \[Rule] 16, 
        FontWeight -> "\<Bold\>"], 
      ButtonFunction \[RuleDelayed] 
        FrontEndExecute[FrontEndToken["\<EvaluateInitialization\>"]], 
      ButtonEvaluator \[Rule] None, Active \[Rule] True]\)], "Input",
  CellOpen->False],

Cell[BoxData[
    ButtonBox[
      TagBox[
        StyleBox["\<\"Click here to load package!\"\>",
          FontSize->16,
          FontWeight->"Bold",
          FontColor->RGBColor[1, 0, 0]],
        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0], FontSize -> 16, 
          FontWeight -> "Bold"]&)],
      ButtonFunction:>FrontEndExecute[ 
          FrontEndToken[ "EvaluateInitialization"]],
      ButtonEvaluator->None,
      Active->True]], "Output",
  TextAlignment->Center]
}, Open  ]],

Cell[CellGroupData[{

Cell["Installation instructions and disclaimers", "Subsubtitle"],

Cell[TextData[{
  "This notebook is not meant for absolute beginners of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". It assumes some familiarity with notebooks and with the syntax of basic \
standard Mathematica commands such as ",
  ButtonBox["Plot",
    ButtonStyle->"RefGuideLink"],
  " and ",
  ButtonBox["ParametricPlot",
    ButtonStyle->"RefGuideLink"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Instructions for permanent installation of the package.",
    FontWeight->"Bold"],
  " If you like this package and wish to be able to load it the same way as \
with standard packages, do as follows: with the help of the ",
  ButtonBox["Option Inspector",
    ButtonStyle->"RefGuideLink"],
  " reset the notebook option  ",
  ButtonBox["AutoGeneratedPackage",
    ButtonStyle->"RefGuideLink"],
  " to ",
  StyleBox["Automatic", "Input"],
  ". Alternatively, evaluate the following cell:"
}], "Text"],

Cell[BoxData[
    \(SetOptions[InputNotebook[], 
      AutoGeneratedPackage \[Rule] Automatic]\)], "Input"],

Cell[TextData[{
  "Then save the notebook. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will generate a new package file called ",
  StyleBox["CurvesGraphics.m", "Input"],
  " inside the same directory as this notebook file. Then you should place \
this new ",
  StyleBox["CurvesGraphics.m", "Input"],
  " file somewhere ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will find it, for example in the directory that you will get from \
evaluating the following command:"
}], "Text"],

Cell[BoxData[
    \(ToFileName[{$UserAddOnsDirectory, "\<Applications\>"}]\)], "Input"],

Cell[TextData[{
  "See also the section ",
  ButtonBox["Installing New Add-ons",
    ButtonStyle->"AddOnsLink"],
  " in the on-line help. If the installation is done correctly you will be \
able to load the package with the command"
}], "Text"],

Cell[BoxData[
    \(Needs["\<CurvesGraphics`\>"]\)], "Input"],

Cell[TextData[{
  StyleBox["Disclaimers",
    FontWeight->"Bold"],
  ". I wrote the package for myself and for anybody interested. I make no \
guarantee of any kind. For example, I tried to make the program correct and \
easy to use,  but I gave only marginal concern to speed. I doubt whether the \
program may be practical in a large-scale graphics project, and I never tried \
anyway. Also, bad-input handling and error messages would deserve more work.\n\
This package adds new options to the following built-in commands: ",
  ButtonBox["Plot",
    ButtonStyle->"RefGuideLink"],
  ", ",
  ButtonBox["ParametricPlot",
    ButtonStyle->"RefGuideLink"],
  ", ",
  ButtonBox["ParametricPlot3D",
    ButtonStyle->"RefGuideLink"],
  ", ",
  ButtonBox["ContourPlot",
    ButtonStyle->"RefGuideLink"],
  ". Their new functionality is triggered by setting ",
  StyleBox["Oriented\[Rule]True", "Input"],
  ". Similarly, the existing  ",
  ButtonBox["NDSolve",
    ButtonStyle->"RefGuideLink"],
  "  will plot the solution when given the new option ",
  StyleBox["PlotSolution\[Rule]True", "Input"],
  ". This design choice makes the package easier to use, in my opinion, but \
it may break pre-existing code. However, as far as I understand the behaviour \
of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ",  I think that you are unlikely to have trouble if your old code only \
relies on built-in commands and options."
}], "Text"],

Cell[TextData[{
  StyleBox["Obsolete versions:",
    FontWeight->"Bold"],
  " the forbears of ",
  StyleBox["CurvesGraphics", "Input"],
  " are still available for download: ",
  ButtonBox["ODEplot",
    ButtonData:>{
      URL[ "http://www.dimi.uniud.it/gorni/Mma/ODEplot.nb"], None},
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["LevelPlot3D",
    ButtonData:>{
      URL[ "http://www.dimi.uniud.it/gorni/Mma/LevelPlot3D.nb"], None},
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["CurveOnSurface",
    ButtonData:>{
      URL[ "http://www.dimi.uniud.it/gorni/Mma/CurveOnSurface.nb"], None},
    ButtonStyle->"Hyperlink"],
  ". They don't need ",
  StyleBox["DrawGraphics", "Input"],
  ". They have no 3D-arrow capability, and the user interface is different. I \
tried to make ",
  StyleBox["DrawGraphics", "Input"],
  " backward compatible with the older syntax, but I make no guarantee."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Versions History", "Subsubtitle"],

Cell[TextData[{
  "January 9, 2005: rules added to ",
  StyleBox["LinearClipPlot3D", "Input"],
  " so that it now accepts combinations of inequalities, such as ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x \[LessEqual] 1\)]],
  ", or ",
  Cell[BoxData[
      \(TraditionalForm\`x < y < x + z \[And] z \[LessEqual] 1\)]],
  ", as input. Extended the documentation on ",
  StyleBox["PlotCurveOnSurface3D", "Input"],
  " for contour plots. LinearPhasePlot renamed as ",
  StyleBox["LinearPhasePlot2D", "Input"],
  ", for more consistency, and retouched to allow for column vector field as \
input.\nApril 18, 2005: retouched the installation instructions."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package"
}], "Subtitle"],

Cell[TextData[{
  "This is the program. It is meant to be read only by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " programmers."
}], "Text"],

Cell[CellGroupData[{

Cell["Preliminaries and usage documentation", "Subsubtitle"],

Cell[BoxData[
    \(Off[General::"\<spell\>"]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Off[General::"\<spell1\>"]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(BeginPackage["\<CurvesGraphics`\>", "\<Utilities`FilterOptions`\>", "\
\<Graphics`Arrow`\>", "\<Graphics`FilledPlot`\>", "\<Graphics`PlotField`\>", \
"\<DrawGraphics`DrawingMaster`\>"];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Unprotect["\<`*\>"];\)\), "\[IndentingNewLine]", 
    \(\(ClearAll["\<`*\>"];\)\)}], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Oriented", "Input"],
  ", and its ancillary options"
}], "Subsection"],

Cell[BoxData[
    \(\(Oriented::usage = "\<Oriented is an option for Plot, ParametricPlot, \
Plot3D, ParametricPlot3D, ContourPlot, PlotCurveOnSurface, \
TrigInterpolationPlot, TrigInterpolationParametricPlot, NDSolve, PhasePlot, \
LinearPhasePlot2D, LevelPlot3D, SliceSurfacePlot, and their Draw couterparts. \
With Oriented->True the curves will come out with arrows along them\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(HowManyArrows::usage = "\<HowManyArrows is an option for Plot, \
ParametricPlot, ParametricPlot3D, and other functions that accept the \
Oriented option, that directs how many arrows to add along the curve. The \
default is HowManyArrows->Automatic, which is based on the ratio of the \
length of the curve(s) to the longest side of the smallest Rectangle (or \
Cuboid) that contains the curve(s) (see also ArrowDensity). When more than \
one curve is drawn at the same time, HowManyArrows accepts a list of values, \
that will be applied cyclically to the curves.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ArrowPositions::usage = "\<ArrowPositions->{p1,p2,...} is an option \
for Plot, ParametricPlot, ParametricPlot3D, and other functions that accept \
the Oriented option (ContourPlot not included), that directs where to draw \
the arrows heads along the curve. The values p1,p2,... are supposed to be \
numbers between 0 and 1 (otherwise they are normalized automatically), and \
refer to the curve parameterized by arc length. The default is \
ArrowPositions->Automatic, under which the lengths of the arcs between the \
first or last arrow and the end point is d, while the arcs between successive \
arrow heads are 2d. This arrangement is best for closed cuves, as all \
successive arrows are separated by arcs of the same length.\>";\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(ReverseOrientation::usage = "\<ReverseOrientation is an option for \
Plot, ParametricPlot, ParametricPlot3D, and other functions that accept the \
Oriented option. When set to True, the orientation of the arrows gets \
reversed. The default is ReverseOrientation->False.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ArrowDensity::usage = "\<ArrowDensity is an option for Plot, \
ParametricPlot, ParametricPlot3D, and other functions that accept the \
Oriented option, influencing how many arrows to draw along the lines. The \
number of arrows increases with the value of ArrowDensity. The default value \
is ArrowDensity->1.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ArrowShaftLength::usage = "\<ArrowShaftLength is an option for Plot, \
ParametricPlot, ParametricPlot3D, and other functions that accept the \
Oriented option. It sets how long the arrow shafts should be, in the original \
coordinates of the graph (not scaled). Do not confuse this with the arrow \
head length. You may need to tweak ArrowShaftLength if your lines have hight \
curvature, or the AspectRatio is far from Automatic.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ArrowsAcrossSubdivisions::usage = "\<ArrowsAcrossSubdivisions is an \
option for Plot, ParametricPlot, ParametricPlot3D, and other functions that \
accept the Oriented option. The default is ArrowsAcrossSubdivisions->True. \
When set to False, each arrow shaft placed along the curve will be contained \
in a single one of the straight line segments the Line is made of. This may \
help improve the look of a picture. Try also ArrowShaftLength.\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Arrow3DColor::usage = "\<Arrow3DColor is an option for \
ParametricPlot3D, LevelPlot3D and other functions that draw 3D arrows. The \
default is Arrow3DColor->Automatic,which means the same color as the curve \
along which the arrow is placed, typically black. Arrow3DColor->{} will make \
3D arrows with no intrinsic color, just like any other surface.\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Arrow3DEdgeForm::usage = "\<Arrow3DEdgeForm is an option for \
ParametricPlot3D, LevelPlot3D and other functions that draw 3D arrows. It \
instructs how to draw the edges of the triangles the 3D arrows are made of. \
The default is Arrow3DEdgeForm\[Rule]EdgeForm[], that is, edges are not \
drawn.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "The \"engines\" that power the ",
  StyleBox["Oriented", "Input"],
  " options in the various situations:"
}], "Subsection"],

Cell[BoxData[
    \(\(OrientedPlot::usage = "\<OrientedPlot[f[x],{x,xMin,xMax},opts] makes \
a Plot and then adds arrows along the curve. Specific options are \
HowManyArrows, ArrowPositions, ReverseOrientation. It also accepts options \
from Plot and Graphics`Arrow`. By default HeadScaling->Automatic and \
HeadLength->1/20.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OrientedParametricPlot::usage = \
"\<OrientedParametricPlot[{x[t],y[t]},{t,tMin,tMax},opts] makes a \
ParametricPlot and then adds arrows along the curve. Specific options are \
HowManyArrows, ArrowPositions, ReverseOrientation. It also accepts options \
from ParametricPlot and Graphics`Arrow`. By default HeadScaling->Automatic \
and HeadLength->1/20.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OrientedParametricPlot3D::usage = \
"\<OrientedParametricPlot3D[{x[t],y[t],z[t]},{t,tMin,tMax},opts] makes a \
ParametricPlot3D and then adds arrows along the curve. Specific options \
include HowManyArrows, ArrowPositions, ReverseOrientation. It also accepts \
options from ParametricPlot3D. DrawGraphics`DrawingArrows`. \
HeadScaling3D->Absolute by default and HeadLength3D->1/20.
OrientedParametricPlot3D[{x[t,u],y[t,u],z[t,u]},{t,tMin,tMax},{u,uMin,uMax},\
opts] makes a ParametricPlot3D of the surface, and then adds arrows along its \
boundary, in a counterclockwise (in the t-u space) direction.\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OrientedPlot3D::usage = \
"\<OrientedParametricPlot3D[f[x,y],{x,xMin,xMax},{y,yMin,yMax},opts] makes a \
Plot3D of the surface, and then adds arrows along its boundary, in a \
counterclockwise (in the t-u space) direction.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(HamiltonianPlot::usage = \
"\<HamiltonianPlot[f[x,y],{x,xMin,xMax},{y,yMin,yMax},opts] is the function \
that takes over ContourPlot when this has the option Oriented->True\>";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["TrigInterpolation", "Subsection"],

Cell[BoxData[
    \(\(TrigInterpolation::usage = "\<TrigInterpolation[data,var] attempts to \
find a trigonometric function that interpolates exactly between the data. The \
data format is the same as for InterpolatingPolynomial. Options are \
EvaluateOnCoefficients and Period\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(EvaluateOnCoefficients::usage = "\<EvaluateOnCoefficients is an \
option for TrigInterpolation, TrigInterpolationPlot and similar. It specifies \
what transformation to make on the coefficients of the trigonometric \
expression. A typical value may be \
EvaluateOnCoefficients->Simplify.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Period::usage = "\<Period is an option for TrigInterpolation, \
TrigInterpolationPlot and similar. It specifies the (joint) period of the \
trigonometric functions that will make up the interpolation. The default is \
Period->Automatic\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ParametricTrigInterpolation::usage = \
"\<ParametricTrigInterpolation[data,t] attempts to find a trigonometric \
function that interpolates exactly between the data. The data structure is a \
list, of which each element is either a pair (or triplet) of numbers or a \
list of pairs (or triplets)\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(TrigInterpolationPlot::usage = \
"\<TrigInterpolationPlot[data,xMin,xMax,opts] attempts to find a \
trigonometric function that interpolates exactly between the data and then \
plots its graph between xMin and xMax. The data have the same syntax as for \
InterpolatingPolynomial. It takes the options from Plot and from \
TrigInterpolation, plus ShowFormula, ShowListPlot, ListPlotStyle.\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(TrigInterpolationDraw::usage = \
"\<TrigInterpolationDraw[data,xMin,xMax,opts] is the DrawGraphics companion \
to TrigInterpolationPlot\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(TrigInterpolationParametricPlot::usage = \
"\<TrigInterpolationParametricPlot[data] is attempts to find a trigonometric \
function that interpolates exactly between the data and then plot its \
parametric graph. The data structure is a list, of which each element is \
either a pair (or triplet) of numbers or a list of pairs (or triplets). In \
case of pairs the plot will be 2-dimensional, otherwise it will be \
3-dimensional. With the option ClosedCurve->True the plot will be a closed \
curve (a loop). It takes also the options from Plot and from \
TrigInterpolation, plus ShowFormula, ShowListPlot, ListPlotStyle.\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(TrigInterpolationParametricDraw::usage = \
"\<TrigInterpolationParametricDraw[data] is the DrawGraphics companion to \
TrigInterpolationParametricPlot\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(TrigInterpolationParametricPlot3D::usage = \
"\<TrigInterpolationParametricPlot3D[3Ddata,opts] is just \
TrigInterpolationParametricPlot but for 3D curves only. It is provided only \
for naming symmetry.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(TrigInterpolationParametricDraw3D::usage = \
"\<TrigInterpolationParametricDraw[data] is the DrawGraphics companion to \
TrigInterpolationParametricPlot3D\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PolynomialLevelSetTrigInterpolation::usage = \
"\<PolynomialLevelSetTrigInterpolation[2Ddata,t,x,y,opts] attempts to find a \
two-variable polynomial whose 0-level set interpolates the given data. The \
output will be a couple: the first element is the output of \
ParametricTrigInterpolation[2Ddata,t,opts], while the second element will be \
a polynomial in x and y.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ShowListPlot::usage = "\<ShowListPlot is an option for \
TrigInterpolationPlot and TrigInterpolationParametricPlot. When \
ShowListPlot->True, the data points will be displayed along the \
curve.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ListPlotStyle::usage = "\<ListPlotStyle is an option for \
TrigInterpolationPlot and TrigInterpolationParametricPlot. It specifies the \
style of the data points that are drawn when ShowListPlot is set to \
True\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ClosedCurve::usage = "\<ClosedCurve is an option for \
TrigInterpolationParametricPlot. The default is \
TrigInterpolationParametricPlot->False. When \
TrigInterpolationParametricPlot->True the curve will be closed (a \
loop).\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(FilledClosedCurve::usage = "\<FilledClosedCurve is an option for \
TrigInterpolationParametricPlot, in the 2D case. The default is \
FilledClosedCurve->False. When FilledClosedCurve->True the curve will be \
closed (a loop) and it will be shown filled. The color is specified with the \
option Fills from Graphics`FilledPlot`\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ShowFormula::usage = "\<ShowFormula is an option for \
TrigInterpolationPlot and TrigInterpolationParametricPlot. The default is \
ShowFormula->False. If ShowFormula->True, the output will be a couple with \
first the graphics output and then the output of TrigInterpolation or \
ParametricTrigInterpolation.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["LevelPlot3D", "Input"],
  " and its companions:"
}], "Subsection"],

Cell[BoxData[
    \(\(LevelPlot3D::usage = \
\[IndentingNewLine]"\<LevelPlot3D[f,{x,x0,x1},{y,y0,y1}] draws a 3D plot of \
the function f with the level sets emphasized. You can control the number (or \
precise position) of level sets to be drawn with the option Contours. \
Example: LevelPlot3D[x^2+y^2,{x,-1,1},{y,-1,1},PlotPoints->11,Contours->5}].\>\
";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LevelDraw3D::usage = \
\[IndentingNewLine]"\<LevelDraw3D[f,{x,x0,x1},{y,y0,y1}] extract the Graphics \
primitives from LevelPlot3D, suppressing the display.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SliceSurfacePlot3D::usage = "\<SliceSurfacePlot3D[3DSurface, \
LinearForm,variables] draws on the surface the level sets of the LinearForm. \
You can control how many level sets (or their precise values) with the option \
Contours. Example: \
SliceSurfacePlot3D[Plot3D[Sin[x*y],{x,0,Pi},{y,0,Pi}],x+y,x,y,z].\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SliceSurface::usage = "\<SliceSurface[3DSurface, \
LinearForm,variables] is an obsolete name for SliceSurfacePlot3D, retained \
for backward compatibility.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SliceSurface = SliceSurfacePlot3D;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SliceSurfaceDraw3D::usage = "\<SliceSurfaceDraw3D[3DSurface, \
LinearForm,variables] is the DrawGraphics companion to \
SliceSurfacePlot3D.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LinearClipPlot3D::usage = "\<LinearClipPlot3D[3DSurface, \
LinearInequality,variables] shows the part of the surface that lies in the \
half-plane defined by the linear inequality. Example: \
LinearClipPlot3D[Plot3D[Sin[x*y],{x,0,Pi},{y,0,Pi}],x+y>=8z,x,y,z].\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LinearClip::usage = "\<LinearClip[3DSurface, \
LinearInequality,variables] is an obsolete name for LinearClipPlot3D, \
retained for backward compatibility.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LinearClip = LinearClipPlot3D;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LinearClipDraw3D::usage = "\<LinearClipDraw3D[3DSurface, \
LinearInequality,variables] is the DrawGraphics companion to \
LinearPlot3D].\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PrepareForSlices::usage = "\<PrepareForSlices is an option for \
LinearClipPlot3D, specifying whether to keep both the two parts of the \
surface when cutting with a plane. It can take the values True or \
False.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SurfaceStyle::usage = "\<SurfaceStyle is an option for \
SliceSurfacePlot3D and LevelPlot3D, containing the Graphis3D directives to \
affect the appearance of the surface.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ShowProjectedLevelSets::usage = "\<ShowProjectedLevelSets is an \
option for LevelPlot3D and SliceSurfacePlot3D. When set to True, the level \
sets will be shown both on the 3D surface and as orthogonally projected onto \
a horizontal plane (or onto a level plane of the linear form in the \
SliceSurfacePlot3D case). The z-level of the plane is controlled with \
ProjectAt. The default is ShowProjectedLevelSets->False\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ProjectAt::usage = "\<ProjectAt is an option for LevelPlot3D and \
SliceSurfacePlot3D. ProjectAt->realNumber tells at what z-level (or linear \
form level) to draw the projected level sets. The default is ProjectAt->0\>";\
\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PlotCurveOnSurface", "Input"],
  " and its ",
  StyleBox["Draw", "Input"],
  " companion:"
}], "Subsection"],

Cell[BoxData[
    \(\(PlotCurveOnSurface3D::usage = \
\[IndentingNewLine]"\<PlotCurveOnSurface3D[surface,curve1,curve2,...,options] \
draws the curves on the surface adding plot points to the curve as to avoid \
disappearance of the curves behind the surface. The surface can be specified \
as in either Plot3D or ParametricPlot3D. The curves are expressed in the \
parameter space of the surface. Example: \
PlotCurveOnSurface3D[{x^2+y^2,{x,-1,1},{y,-1,1}},{{Cos[t],Sin[t]},{t,0,2Pi},\
PlotPoints->41}].\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(CurveOnSurface::usage = \
\[IndentingNewLine]"\<CurveOnSurface[surface,curve1,curve2,...,options] is an \
obsolete name for PlotCurveOnSurface3D. It is retained for backward \
compatibility.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(CurveOnSurface = PlotCurveOnSurface3D;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DrawCurveOnSurface3D::usage = \
\[IndentingNewLine]"\<DrawCurveOnSurface3D[surface,curve1,curve2,...,options] \
is the DrawGraphics companion to PlotCurveOnSurface3D.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ContourPlotOnSurface3D::usage = \
\[IndentingNewLine]"\<ContourPlotOnSurface3D[surface,contourPlot1,...,options]\
 .\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PlotSolution for NDSolve", "Subsection"],

Cell[BoxData[
    \(\(NDSolvePlot::usage = "\<NDSolvePlot[differential equations,options] \
is the engine of NDSolve when given the option PlotSolution->True. It solves \
the equations with NDSolve and then draws a plot of the solution. For a \
planar system the plot has arrows on it. The output is a couple \
{Graphics,NDSolve output}. It takes all options of NDSolve and \
OrientedParametricPlot.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PlotSolution::usage = "\<PlotSolution is a new option for NDSolve. If \
it is set to True and the unknown functions are at most 3, then the output of \
NDSolve becomes a list of the form {solution, graph of the \
solution}\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DrawSolution::usage = "\<DrawSolution is a new option for NDSolve, \
the DrawGraphics companion to PlotSolution. If it is set to True and the \
unknown functions are at most 3, then the output of NDSolve becomes a list of \
the form {solution, graphics primitives of the graph of the \
solution}\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "LinearPhasePlot2D",
  " and ",
  StyleBox["PhasePlot", "Input"]
}], "Subsection"],

Cell[BoxData[
    \(\(LinearPhasePlot2D::usage = \
\[IndentingNewLine]"\<LinearPhasePlot2D[matrix,options] plots a phase \
portrait of the system of two differential equations \
{x'[t],y'[t]}==mat.{x[t],y[t]}. The matrix must be numeric and exact. The \
curves are drawn from the exact symbolic solutions of the system. Options are \
NotableLineStyle, NumberOfTrajectories, WriteReport, ShowField, Oriented, \
ArrowDensity. LinearPhasePlot2D also accepts all options for Graphics`Arrow` \
and Graphics. Example: LinearPhasePlot2D[{{1,2}},{-2,1}}].\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LinearPhasePlot::usage = \[IndentingNewLine]"\<LinearPhasePlot is the \
older name of LinearPhasePlot2D, retained for backward \
compatibility.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NotableLineStyle::usage = "\<NotableLineStyle is an option for \
LinearPhasePlot2D specifying how to highlight the straight lines that are of \
special significance for the system (either eigenspaces or principal \
directions). The default value is \
NotableLineStyle->RGBColor[1,0,0].\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NumberOfTrajectories::usage = "\<NumberOfTrajectories is an option \
for LinearPhasePlot2D that helps control how many trajectories to (attempt \
to) draw, approximately. The default value is NotableLineStyle->5.\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(WriteReport::usage = "\<WriteReport is an option for \
LinearPhasePlot2D specifying whether to write the classification of the given \
system. The default value is WriteReport->True.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ShowField::usage = "\<ShowField is an option for PhasePlot, \
LinearPhasePlot2D and ContourPlot specifying whether to draw the direction \
field of the system (by means of the package Graphics`PlotField`) together \
with the trajectories. The default value is ShowField->False.\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PhasePlot::usage = \
"\<PhasePlot[{f[x,y],g[x,y]},{x,xMin,xMax},{y,yMin,yMax},{tMin,tMax},options] \
makes a phase portrait of the system \
{x'[t]==f[x[t],y[t]],y'[t]==g[x[t],y[t]]}. Specific options are PlotPoints \
(that controls how many points there are in the initial values grid), \
InitialPoints, Oriented. It also accepts NDSolve, Graphics`Arrow` and \
Graphics options.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PhaseDraw::usage = \
"\<PhaseDraw[{f[x,y],g[x,y]},{x,xMin,xMax},{y,yMin,yMax},{tMin,tMax},options] \
is the DrawGraphics companion to PhasePlot.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(InitialPoints::usage = "\<InitialPoints is an option for PhasePlot: \
it takes as value a list of points in 2D or 3D that are to be the starting \
points for the trajectories.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GridPoints::usage = "\<GridPoints is an option for PhasePlot: it \
takes as value an integer or a list of two or three integers, stating the \
dimensions of the grid of starting points for the trajectories.\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(Remove[GridPoints]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["tail", "Subsection"],

Cell[BoxData[
    \(\(Begin["\<`Private`\>"];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(OrientedCurve = Oriented;\)\), "\[IndentingNewLine]", 
    \(\(OrientedContour = Oriented;\)\)}], "Input",
  InitializationCell->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Arrow stuff", "Subsubtitle"],

Cell["Finding the length of a path:", "Text"],

Cell[BoxData[
    \(\(lineLength[pts_List] := 
        Apply[Plus, 
          Sqrt[Apply[Plus, Rest[pts - RotateRight[pts]]^2, 1]]];\)\)], "Input",\

  InitializationCell->True],

Cell["\<\
Finding the lengths of the subpaths obtained by taking the first \
1,2,3,... points of the given path:\
\>", "Text"],

Cell[BoxData[
    \(\(successiveLengths[pts_List] := 
        Map[lineLength, Rest[FoldList[Append, {}, pts]]];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "Parameterizing a path by arc length, taking some care not to get ",
  ButtonBox["Interpolation",
    ButtonStyle->"RefGuideLink"],
  " error messages because of duplicate parameter values:"
}], "Text"],

Cell[BoxData[
    \(\(byArcLength[pts_List] := 
        Module[{withoutDuplicates = 
              pts //. {a___, b_List, b_, c___} \[RuleDelayed] {a, b, c}, 
            divisionPointsNo}, \[IndentingNewLine]divisionPointsNo = 
            Length[successiveLengths[
                  withoutDuplicates] //. {a___, b_List, b_, 
                    c___} \[RuleDelayed] {a, b, 
                    c}]; \[IndentingNewLine]Function[{t}, 
            Evaluate[
              Through[\(Map[
                    Interpolation[
                        Transpose[{successiveLengths[
                                withoutDuplicates], #}] //. \(({a___List, {b_?
                                    NumericQ, c_}, {b_, d_}, 
                                e___})\) \[RuleDelayed] {a, {b, c}, e}, 
                        InterpolationOrder \[Rule] 
                          If[divisionPointsNo > 1, 1, 0]] &, 
                    Transpose[withoutDuplicates]]\)[t]]]]];\)\)], "Input",
  InitializationCell->True],

Cell["Color functions:", "Text"],

Cell[BoxData[
    \(\(colorSpecPattern = _CMYColor | _CMYKColor | _GrayLevel | _Hue | \
_RGBColor;\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Inserting arrow heads along a path in given positions (represented \
by fractions of the total arc length of the path):\
\>", "Text"],

Cell[BoxData[
    \(\(Options[insertArrows] = {ArrowShaftLength \[Rule] 1/1000, 
          Arrow3DColor \[Rule] Automatic, Arrow3DEdgeForm \[Rule] EdgeForm[], 
          ReverseOrientation \[Rule] False, 
          ArrowsAcrossSubdivisions \[Rule] True, 
          PlotStyle \[Rule] Automatic};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(insertArrows[pts_List, {}, opts___?OptionQ] := 
        Sequence @@ {};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(insertArrows[pts_List /; lineLength[pts] > $MachineEpsilon, 
          positions_List, 
          opts___?OptionQ] := \[IndentingNewLine]Module[{dim = 
              Length@\(First@pts\), el = lineLength[N@pts], revQ, acrossQ, 
            arw3Dedgfrm, arwDelta, pltSty, arw3Dclr, ptsFinal, par, 
            normalizedPlotPts, subdivisionInterval, arw, delta, arrowBase, 
            arrowTip}, \[IndentingNewLine]{revQ, acrossQ} = 
            Map[TrueQ, \({ReverseOrientation, 
                    ArrowsAcrossSubdivisions} /. {opts}\) /. 
                Options[insertArrows]]; \[IndentingNewLine]{arw3Dedgfrm, 
              arwDelta, pltSty, 
              arw3Dclr} = \({Arrow3DEdgeForm, ArrowShaftLength, PlotStyle, 
                  Arrow3DColor} /. {opts}\) /. 
              Options[insertArrows]; \[IndentingNewLine]pltSty = 
            Cases[pltSty, colorSpecPattern, {0, 1}]; \[IndentingNewLine]If[
            arw3Dclr === Automatic, 
            If[pltSty === {}, arw3Dclr = GrayLevel[0], 
              arw3Dclr = Last[pltSty]]]; \[IndentingNewLine]If[
            Not[TrueQ[arwDelta > 0]], 
            arwDelta = 
              ArrowShaftLength /. 
                Options[insertArrows]]; \[IndentingNewLine]ptsFinal = 
            If[TrueQ[revQ], Reverse[pts], pts]; \[IndentingNewLine]par = 
            byArcLength[N@ptsFinal]; \[IndentingNewLine]normalizedPlotPts = 
            Flatten@Cases[
                  par /. InterpolatingFunction \[Rule] 
                      intFunc, \(intFunc[_, _, {s_}, ___]\)[___] \
\[RuleDelayed] s, {0, Infinity}, 1]/
              el; \[IndentingNewLine]subdivisionInterval[t_] := 
            First@Cases[
                Partition[normalizedPlotPts, 2, 1], {a_, b_} /; 
                  a \[LessEqual] t \[LessEqual] b, 
                1]; \[IndentingNewLine]arw = 
            Which[dim \[Equal] 2, Arrow, dim \[Equal] 3, 
              DrawGraphics`DrawingArrows`Arrow3D]; \
\[IndentingNewLine]halfDelta = 
            If[dim \[Equal] 2, 
              arwDelta/
                2, \[IndentingNewLine]\(DrawGraphics`DrawingArrows`\
HeadLength3D*DrawGraphics`DrawingArrows`HeadScaling3D/2 /. {opts}\) /. 
                Options[
                  DrawGraphics`DrawingArrows`Arrow3D]]; \
\[IndentingNewLine]arrowBase[t_ /; acrossQ] := 
            Max[el*t - halfDelta, 0]; \[IndentingNewLine]arrowBase[
              t_ /; Not@acrossQ] := 
            el*Max[First@subdivisionInterval[t], 
                t - halfDelta/el]; \[IndentingNewLine]arrowTip[
              t_ /; acrossQ] := 
            Min[el*t + halfDelta, el]; \[IndentingNewLine]arrowTip[
              t_ /; Not@acrossQ] := 
            el*Min[t + halfDelta/el, 
                Last@subdivisionInterval[t]]; \[IndentingNewLine]{If[
              dim \[Equal] 3, 
              Sequence @@ {If[arw3Dclr === None, Sequence @@ {}, 
                    SurfaceColor[Sequence @@ Flatten[{arw3Dclr}]]], 
                  arw3Dedgfrm}, Sequence @@ {}], 
            Map[\((arw[par[arrowBase[#]], par[arrowTip[#]], 
                    FilterOptions[arw, HeadScaling \[Rule] Automatic, 
                      opts]])\) &, positions]}];\)\)], "Input",
  InitializationCell->True],

Cell["Ignoring arrows when the path is too short:", "Text"],

Cell[BoxData[
    \(\(insertArrows[
          pts_List /; lineLength[pts] \[LessEqual] \ $MachineEpsilon, 
          positions_List, opts___?OptionQ] := Sequence @@ {};\)\)], "Input",
  InitializationCell->True],

Cell["Co\[ODoubleDot]rdinating the various ways to assign the arrow \
positions:", "Text"],

Cell[BoxData[{
    \(\(normalizedArrowPositions[
          pos_ /; And[pos =!= Automatic, 
              MatchQ[pos, \(({u__ /; Element[{u}, Reals]})\) | \((v_ /; 
                      Element[v, Reals])\)]], _] := 
        Flatten[{\((pos - Min[pos, 0])\)/\((Max[pos, 1] - 
                  Min[pos, 0])\)}];\)\), "\[IndentingNewLine]", 
    \(\(normalizedArrowPositions[Automatic, howMany_Integer] := 
        Range[1, 2  howMany - 1, 
            2]/\((2  Max[howMany, 1])\);\)\), "\[IndentingNewLine]", 
    \(\(normalizedArrowPositions[Automatic, 
          howMany_] := {};\)\), "\[IndentingNewLine]", 
    \(normalizedArrowPositions[
        pos_ /; And[pos =!= Automatic, 
            Not@MatchQ[
                pos, \(({u__ /; Element[{u}, Reals]})\) | \((v_ /; 
                      Element[v, Reals])\)]], _] := {}\)}], "Input",
  InitializationCell->True],

Cell[TextData[{
  "Choosing ",
  StyleBox["HeadScaling3D", "Input"],
  " as the length of the longest side of the smallest ",
  ButtonBox["Rectangle",
    ButtonStyle->"RefGuideLink"],
  " or ",
  ButtonBox["Cuboid",
    ButtonStyle->"RefGuideLink"],
  " that encloses all the ",
  StyleBox["Line", "Input"],
  "s in a ",
  StyleBox["Graphics", "Input"],
  " or ",
  StyleBox["Graphics3D", "Input"],
  " object:"
}], "Text"],

Cell[BoxData[
    \(\(maxLineExcursion[gr_] := 
        Max[0, Max @@ 
            Cases[gr, 
              Line[pts_] \[RuleDelayed] 
                Max@Map[Max[#] - Min[#] &, Transpose[pts]], {0, 
                Infinity}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Options[
          automaticHeadScaling3D] = {DrawGraphics`DrawingArrows`HeadScaling3D \
\[Rule] Automatic};\)\), "\[IndentingNewLine]", 
    \(\(automaticHeadScaling3D[gr_, 
          opts___?OptionQ] := \[IndentingNewLine]Module[{maxExcursion, 
            scalingFromOpts}, \[IndentingNewLine]maxExcursion = 
            maxLineExcursion[
              gr]; \[IndentingNewLine]scalingFromOpts = \
\(DrawGraphics`DrawingArrows`HeadScaling3D /. {opts}\) /. 
              Options[automaticHeadScaling3D]; \
\[IndentingNewLine]DrawGraphics`DrawingArrows`HeadScaling3D \[Rule] 
            If[TrueQ[scalingFromOpts \[GreaterEqual] 0], scalingFromOpts, 
              maxExcursion]];\)\)}], "Input",
  InitializationCell->True],

Cell["\<\
A utility to estimate automatically how many arrows to draw along \
curves, based on the ratio of their length with a reference dimension:\
\>", \
"Text"],

Cell[BoxData[
    \(\(sortOutHowManyArrows[graf_, declaredHowMany_, referenceDimension_, 
          arrowDensityParameter_] := 
        Module[{automaticHowMany, 
            howMany}, \[IndentingNewLine]automaticHowMany := 
            Cases[graf, 
              Line[pts_List] \[RuleDelayed] 
                Ceiling[
                  If[TrueQ[arrowDensityParameter \[GreaterEqual] 0], 
                      arrowDensityParameter, 1]*
                    lineLength[pts]/referenceDimension], {1, 
                Infinity}]; \[IndentingNewLine]Which[
            declaredHowMany === Automatic, 
            howMany = 
              automaticHowMany, \[IndentingNewLine]Length[
                declaredHowMany] \[Equal] 0, 
            howMany = {declaredHowMany}, \[IndentingNewLine]True, 
            howMany = declaredHowMany]; \[IndentingNewLine]If[
            Not@FreeQ[howMany, Automatic], 
            howMany = 
              MapIndexed[#1 /. 
                    Automatic \[Rule] cyclicPart[automaticHowMany, #2] &, 
                howMany]]; \[IndentingNewLine]howMany];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["OrientedPlot", "Subsubtitle"],

Cell[BoxData[{
    \(\(cyclicPart[obj_ /; Length[obj] \[Equal] 0, _] = 
        obj;\)\), "\[IndentingNewLine]", 
    \(\(cyclicPart[obj_, i_Integer] := 
        obj[\([Mod[i, Length[obj], 1]]\)];\)\), "\[IndentingNewLine]", 
    \(\(cyclicPart[obj_, {i_Integer}] := cyclicPart[obj, i];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(SetAttributes[OrientedPlot, HoldAll]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[OrientedPlot] = 
        Join[{Oriented \[Rule] True, HowManyArrows\  \[Rule] \ Automatic, 
            ArrowPositions \[Rule] Automatic, 
            ReverseOrientation \[Rule] False, 
            Graphics`Arrow`HeadScaling \[Rule] Automatic, 
            Graphics`Arrow`HeadLength \[Rule] 1/20, 
            ArrowShaftLength \[Rule] Automatic, 
            ArrowsAcrossSubdivisions \[Rule] True, ArrowDensity \[Rule] 1}, 
          Options[Plot], 
          DeleteCases[
            Options[Arrow], \((Graphics`Arrow`HeadScaling | 
                  Graphics`Arrow`HeadLength)\) \[Rule] _]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OrientedPlot[f_, it_List, opts___?OptionQ] := 
        Module[{howMany, pos, revQ, c, 
            referenceDimension}, \[IndentingNewLine]{howMany, 
              arrowDensityParameter, pos, revQ, 
              arwShftLngth} = \({HowManyArrows, ArrowDensity, ArrowPositions, 
                  ReverseOrientation, ArrowShaftLength} /. {opts}\) /. 
              Options[OrientedPlot]; \[IndentingNewLine]If[NumericQ[pos], 
            pos = {{pos}}]; \[IndentingNewLine]If[pos === Automatic, 
            pos = {Automatic}]; \[IndentingNewLine]If[
            MatchQ[pos, {x__} /; Element[{x}, Reals]], 
            pos = {pos}]; \[IndentingNewLine]If[Length[revQ] === 0, 
            revQ = {revQ}]; \[IndentingNewLine]c = 
            DrawGraphics`DrawingPaper`Draw[f, it, 
              Evaluate[
                FilterOptions[Plot, 
                  opts]]]; \[IndentingNewLine]referenceDimension = 
            maxLineExcursion[c]; \[IndentingNewLine]howMany = 
            sortOutHowManyArrows[c, howMany, referenceDimension, 
              arrowDensityParameter]; \[IndentingNewLine]arwShftLngth = 
            If[TrueQ[arwShftLngth \[GreaterEqual] 0], 
              arwShftLngth, \(referenceDimension*
                    Graphics`Arrow`HeadLength /. {opts}\) /. 
                Options[
                  OrientedPlot]]; \
\[IndentingNewLine]DrawGraphics`DrawingPaper`Draw2D[{c, \
\[IndentingNewLine]MapIndexed[#1 /. 
                    Line[pts_List] \[RuleDelayed] \
\[IndentingNewLine]insertArrows[
                        pts, \[IndentingNewLine]normalizedArrowPositions[
                          cyclicPart[pos, #2], cyclicPart[howMany, #2]], 
                        ReverseOrientation \[Rule] 
                          TrueQ[cyclicPart[revQ, #2]], 
                        ArrowShaftLength \[Rule] arwShftLngth, 
                        opts] &, \[IndentingNewLine]c]}, \
\[IndentingNewLine]FilterOptions[Graphics, opts, 
              Options[Plot]]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["OrientedParametricPlot", "Subsubtitle"],

Cell[BoxData[
    \(SetAttributes[OrientedParametricPlot, HoldAll]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[OrientedParametricPlot] = 
        Join[{Oriented \[Rule] True, HowManyArrows \[Rule] Automatic, 
            ArrowPositions \[Rule] Automatic, 
            ReverseOrientation \[Rule] False, 
            Graphics`Arrow`HeadScaling \[Rule] Automatic, 
            Graphics`Arrow`HeadLength \[Rule] 1/20, 
            ArrowShaftLength \[Rule] Automatic, 
            ArrowsAcrossSubdivisions \[Rule] True, ArrowDensity \[Rule] 1}, 
          Options[ParametricPlot], 
          DeleteCases[
            Options[Arrow], \((Graphics`Arrow`HeadScaling | 
                  Graphics`Arrow`HeadLength)\) \[Rule] _]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OrientedParametricPlot[f_, it_List, opts___?OptionQ] := 
        Module[{howMany, pos, revQ, c, referenceDimension, 
            arwShftLngth}, \[IndentingNewLine]{howMany, 
              arrowDensityParameter, pos, 
              revQ} = \({HowManyArrows, ArrowDensity, ArrowPositions, 
                  ReverseOrientation} /. {opts}\) /. 
              Options[OrientedParametricPlot]; \[IndentingNewLine]If[
            NumericQ[pos], pos = {{pos}}]; \[IndentingNewLine]If[
            pos === Automatic, pos = {Automatic}]; \[IndentingNewLine]If[
            MatchQ[pos, {x__} /; Element[{x}, Reals]], 
            pos = {pos}]; \[IndentingNewLine]If[Length[revQ] === 0, 
            revQ = {revQ}]; \[IndentingNewLine]c = 
            DrawGraphics`DrawingPaper`ParametricDraw[f, it, 
              Evaluate[
                FilterOptions[ParametricPlot, 
                  opts]]]; \[IndentingNewLine]referenceDimension = 
            maxLineExcursion[c]; \[IndentingNewLine]howMany = 
            sortOutHowManyArrows[c, howMany, referenceDimension, 
              arrowDensityParameter]; \[IndentingNewLine]arwShftLngth = 
            If[TrueQ[arwShftLngth \[GreaterEqual] 0], 
              arwShftLngth, \(referenceDimension*
                    Graphics`Arrow`HeadLength /. {opts}\) /. 
                Options[
                  OrientedPlot]]; \
\[IndentingNewLine]DrawGraphics`DrawingPaper`Draw2D[{c, \
\[IndentingNewLine]MapIndexed[#1 /. 
                    Line[pts_List] \[RuleDelayed] \
\[IndentingNewLine]insertArrows[
                        pts, \[IndentingNewLine]normalizedArrowPositions[
                          cyclicPart[pos, #2], cyclicPart[howMany, #2]], 
                        ReverseOrientation \[Rule] 
                          TrueQ[cyclicPart[revQ, #2]], 
                        ArrowShaftLength \[Rule] arwShftLngth, 
                        opts] &, \[IndentingNewLine]c]}, \
\[IndentingNewLine]FilterOptions[Graphics, opts, Options[ParametricPlot], 
              DisplayFunction \[Rule] $DisplayFunction]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["OrientedParametricPlot3D (curve)", "Subsubtitle"],

Cell[BoxData[
    \(SetAttributes[OrientedParametricPlot3D, HoldAll]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[OrientedParametricPlot3D] = 
        Join[{Oriented \[Rule] True, HowManyArrows \[Rule] Automatic, 
            ArrowPositions \[Rule] Automatic, 
            ReverseOrientation \[Rule] False, 
            DrawGraphics`DrawingArrows`HeadScaling3D \[Rule] Automatic, 
            DrawGraphics`DrawingArrows`HeadLength3D \[Rule] 1/10, 
            Arrow3DColor \[Rule] Automatic, ContourStyle \[Rule] Automatic, 
            PlotStyle \[Rule] Automatic, 
            ArrowsAcrossSubdivisions \[Rule] True, 
            ArrowDensity \[Rule] 1}, \[IndentingNewLine]Options[
            insertArrows], \[IndentingNewLine]DeleteCases[
            Options[DrawGraphics`DrawingArrows`Arrow3D], 
            DrawGraphics`DrawingArrows`HeadScaling3D \[Rule] _], \
\[IndentingNewLine]Options[ParametricPlot3D]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(joinChain[obj_] := 
      obj //. \[IndentingNewLine]{{primitive___, Line[{a__, b_}], 
              Line[{b_, c__}], d___} \[RuleDelayed] {primitive, 
              Line[{a, b, c}], 
              d}, {primitives0___, {primitives1___, 
                Line[{a__, b_}]}, {primitives2___, Line[{b_, c__}]}, 
              d___} \[RuleDelayed] {primitives0, {primitives1, 
                Line[{a, b, c}]}, d}}\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(makeStandardStyle[sty_] := 
        Which[\[IndentingNewLine]sty === 
            None, {{None}}, \[IndentingNewLine]sty === 
            Automatic, {Automatic}, \[IndentingNewLine]sty === {}, {{}}, \
\[IndentingNewLine]sty === {{}}, {Automatic}, \[IndentingNewLine]Head[sty] =!= 
            List, {{sty}}, \[IndentingNewLine]MatchQ[
            sty, {___, 
              prim_ /; Not[
                  Head[prim] === 
                    List], ___}], {sty}, \[IndentingNewLine]True, 
          sty];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OrientedParametricPlot3D[f_, it_List, opts___?OptionQ] := 
        Module[{howMany, pos, revQ, arw3Dcolor, pltStyle, pltStyle2, c, 
            cStyled, joinedLine, 
            hdscl3D}, \[IndentingNewLine]{ortdQ, howMany, 
              arrowDensityParameter, pos, revQ, arw3Dcolor, 
              pltStyle} = \({OrientedCurve, HowManyArrows, ArrowDensity, 
                  ArrowPositions, ReverseOrientation, Arrow3DColor, 
                  PlotStyle} /. {opts}\) /. 
              Options[OrientedParametricPlot3D]; \[IndentingNewLine]If[
            Not@TrueQ[ortdQ], howMany = 0]; \[IndentingNewLine]If[
            NumericQ[pos], pos = {{pos}}]; \[IndentingNewLine]If[
            pos === Automatic, pos = {Automatic}]; \[IndentingNewLine]If[
            MatchQ[pos, {x__} /; Element[{x}, Reals]], 
            pos = {pos}]; \[IndentingNewLine]If[Length[revQ] === 0, 
            revQ = {revQ}]; \[IndentingNewLine]arw3Dcolor = 
            makeStandardStyle[arw3Dcolor]; \[IndentingNewLine]pltStyle = 
            makeStandardStyle[pltStyle]; \[IndentingNewLine]pltStyle2 = 
            makeStandardStyle[pltStyle] /. 
              Automatic \[Rule] {}; \[IndentingNewLine]c = 
            DrawGraphics`ParametricDrawing3D`ParametricDraw3D[f, it, 
              Evaluate[
                FilterOptions[ParametricPlot3D, 
                  opts]]]; \[IndentingNewLine]cStyled = 
            If[MatchQ[c, {__Line}], 
              Join[pltStyle2[\([1]\)], c], \[IndentingNewLine]Replace[
                Transpose[{Table[cyclicPart[pltStyle2, i], {i, Length[c]}], 
                    c}], {{x___}, y_} \[RuleDelayed] {x, 
                    y}, {1}]]; \[IndentingNewLine]joinedLine = 
            c // joinChain; \[IndentingNewLine]referenceDimension = 
            maxLineExcursion[joinedLine]; \[IndentingNewLine]howMany = 
            sortOutHowManyArrows[joinedLine, howMany, referenceDimension, 
              arrowDensityParameter]; \[IndentingNewLine]hdscl3D = 
            automaticHeadScaling3D[joinedLine, opts, 
              Sequence @@ 
                Options[
                  OrientedParametricPlot3D]]; \
\[IndentingNewLine]DrawGraphics`DrawingCube`Draw3DItems[{cStyled, 
              MapIndexed[#1 /. 
                    Line[pts_List] \[RuleDelayed] \
\[IndentingNewLine]insertArrows[
                        pts, \[IndentingNewLine]normalizedArrowPositions[
                          cyclicPart[pos, #2], cyclicPart[howMany, #2]], 
                        ReverseOrientation \[Rule] 
                          TrueQ[cyclicPart[
                              revQ, #2]], \[IndentingNewLine]Arrow3DColor \
\[Rule] cyclicPart[arw3Dcolor, #2], \[IndentingNewLine]PlotStyle \[Rule] 
                          cyclicPart[
                            pltStyle, #2], \[IndentingNewLine]hdscl3D, opts, 
                        FilterOptions[DrawGraphics`DrawingArrows`Arrow3D, 
                          Options[
                            OrientedParametricPlot3D]]] &, \
\[IndentingNewLine]joinedLine]}, \[IndentingNewLine]FilterOptions[Graphics3D, 
              opts, Options[ParametricPlot3D], 
              DisplayFunction \[Rule] $DisplayFunction]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PlotCurveOnSurface3D", "Subsubtitle"],

Cell[CellGroupData[{

Cell["insertion of points along a line", "Section"],

Cell[TextData[{
  "The function to",
  StyleBox["SplitQ[1,pt1,pt2]", "Input"],
  " decides whether the line between the two points ",
  StyleBox["pt1", "Input"],
  " and ",
  StyleBox["pt2", "Input"],
  " crosses over a vertical line with integer abscissa, and gives a list of \
the integer abscissas that are crossed. ",
  StyleBox["SplitQ[2,pt1,pt2]", "Input"],
  " does the same with crossing with horizontal lines."
}], "Text"],

Cell[BoxData[
    \(\(toSplitQ[n_Integer /; n < 3, pt0_List /; NumericQ[pt0[\([1]\)]], 
            pt1_List] /; 
          MatrixQ[{pt0, 
              pt1}] := \[IndentingNewLine]Module[{coord = \(Transpose[{pt0, 
                    pt1}]\)[\([n]\)], med1, 
            med2}, \[IndentingNewLine]{med1, 
              med2} = \({Floor[Min[#]] + 1, Ceiling[Max[#]] - 1} &\)[
              coord]; \[IndentingNewLine]{med1 \[LessEqual] 
              med2, \(If[OrderedQ[coord], Identity, Reverse]\)[
              Range[med1, med2]]}];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "The function ",
  StyleBox["makeSplit[1][{pt1,pt2}]", "Input"],
  " inserts new points along the line segment between ",
  StyleBox["pt1", "Input"],
  " and ",
  StyleBox["pt2", "Input"],
  " at all crossings with vertical lines of integer abscissa. So does",
  StyleBox[" makeSplit[2][{pt1,pt2}]", "Input"],
  " with horizontal lines."
}], "Text"],

Cell[BoxData[
    \(\(\(makeSplit[
            n_Integer /; n < 3]\)[{pt0_List /; NumericQ[pt0[\([1]\)]], 
            pt1_List}] := \[IndentingNewLine]Module[{}, \
\[IndentingNewLine]{answer, divisions} = 
            toSplitQ[n, pt0, pt1]; \[IndentingNewLine]If[
            answer, \[IndentingNewLine]Join[{pt0}, 
              t*pt1 + \((1 - t)\)*pt0 /. 
                Map[\(Solve[\((t*pt1 + \((1 - t)\)*
                                  pt0)\)[\([n]\)] \[Equal] #, 
                        t]\)[\([1]\)] &, divisions], {pt1}], {pt0, 
              pt1}]];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "The function ",
  StyleBox["toSplitQ[3,pt0,pt1]", "Input"],
  " decides whether the line segment between the two points ",
  StyleBox["pt0", "Input"],
  " and ",
  StyleBox["pt1 ", "Input"],
  "crosses",
  " the diagonal of the integer cell the two points are in, and gives the \
coordinates of the crossing point."
}], "Text"],

Cell[BoxData[
    \(toSplitQ[3, pt0_List, pt1_List] := 
      Module[{v, c}, \[IndentingNewLine]v = 
          Floor[Map[Min, 
              Transpose[{pt0, pt1}]]]; \[IndentingNewLine]c = {pt0 - v, 
            pt1 - v}; \[IndentingNewLine]{Subtract @@ c[\([1]\)]*
              Subtract @@ c[\([2]\)] < 0, c}]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "The function make",
  StyleBox["Split[3][{pt0,pt1}]", "Input"],
  " adds to the line between the points ",
  StyleBox["pt0", "Input"],
  " and ",
  StyleBox["pt1", "Input"],
  " the crossing (if any) between the line and the diagonal of the integer \
cell the two points are in."
}], "Text"],

Cell[BoxData[
    \(\(\(makeSplit[3]\)[{pt0_List /; NumericQ[pt0[\([1]\)]], pt1_List}] := 
        Module[{answer, c0, c1}, \[IndentingNewLine]{answer, {c0, c1}} = 
            toSplitQ[3, pt0, pt1]; \[IndentingNewLine]If[answer, 
            Join[{pt0}, 
              t*pt1 + \((1 - t)\) pt0 /. 
                Solve[Equal @@ \((t*c1 + \((1 - t)\) c0)\), t], {pt1}], {pt0, 
              pt1}]];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "The function ",
  StyleBox["divideLine[ptsList]", "Input"],
  " takes the list of points ",
  StyleBox["ptsList", "Input"],
  " and inserts points at all crossings with vertical or horizontal or \
diagonal lines."
}], "Text"],

Cell[BoxData[
    \(\(divideLine[ptsList_List] := 
        Fold[Flatten[Map[makeSplit[#2], Partition[#1, 2, 1]], 1] &, 
            ptsList, {1, 2, 3}] //. {a___, b_List, b_, 
              c___} \[RuleDelayed] {a, b, c};\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["making the 3D curves", "Section"],

Cell[TextData[{
  "The function ",
  StyleBox["weight[pt]", "Input"],
  " expresses the 2D point ",
  StyleBox["pt", "Input"],
  " as a convex combination of the four vertices of the integer cell the \
point is in, and gives the coefficients."
}], "Text"],

Cell[BoxData[
    \(\(weight[pt_List /; NumericQ[pt[\([1]\)]]] := 
        Module[{vert, loc, belowDiagQ}, \[IndentingNewLine]vert = 
            Floor[pt]; \[IndentingNewLine]loc = 
            pt - vert; \[IndentingNewLine]belowDiagQ = \((Subtract @@ 
                  loc \[GreaterEqual] 0)\); \[IndentingNewLine]Map[Flatten, 
            Cases[\({{vert, w00}, {vert + {1, 0}, w10}, {vert + {1, 1}, 
                      w11}, {vert + {0, 1}, w01}} /. \(Solve[
                      Thread[loc \[Equal] 
                            w00 {0, 0} + 
                              If[belowDiagQ, w10 {1, 0}, w01 {0, 1}] + 
                              w11 {1, 1}]~
                        Join~{w00 + If[belowDiagQ, w10, w01] + w11 \[Equal] 
                            1}, {w00, If[belowDiagQ, w10, w01], 
                        w11}]\)[\([1]\)]\) /. {w10 \[Rule] 0, 
                  w01 \[Rule] 0}, {_, w_ /; w =!= 0}]]];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "The function ",
  StyleBox["polygonVerticesCoordinates", "Input"],
  " makes a matrix of the coordinates of the vertices of the surface."
}], "Text"],

Cell[BoxData[
    \(\(SetAttributes[polygonVerticesCoordinates, HoldAll];\)\)], "Input"],

Cell[BoxData[
    \(\(polygonVerticesCoordinates[
          f_ /; Not[Head[f] === List], {u_, uMin_, uMax_}, {v_, vMin_, 
            vMax_}, optsS___?
            OptionQ] := \[IndentingNewLine]Block[{$DisplayFunction = 
              Identity}, 
          Transpose[{\(Plot3D[u, {u, uMin, uMax}, {v, vMin, vMax}, 
                  optsS]\)[\([1]\)], \(Plot3D[
                  v, {u, uMin, uMax}, {v, vMin, vMax}, 
                  optsS]\)[\([1]\)], \(Plot3D[
                  f, {u, uMin, uMax}, {v, vMin, vMax}, 
                  optsS]\)[\([1]\)]}, {3, 1, 2}]];\)\)], "Input"],

Cell[BoxData[
    \(\(polygonVerticesCoordinates[{fx_, fy_, fz_, ___}, {u_, uMin_, 
            uMax_}, {v_, vMin_, vMax_}, 
          optsS___?
            OptionQ] := \[IndentingNewLine]Block[{$DisplayFunction = 
              Identity}, 
          Transpose[{\(Plot3D[fx, {u, uMin, uMax}, {v, vMin, vMax}, 
                  optsS]\)[\([1]\)], \(Plot3D[
                  fy, {u, uMin, uMax}, {v, vMin, vMax}, 
                  optsS]\)[\([1]\)], \(Plot3D[
                  fz, {u, uMin, uMax}, {v, vMin, vMax}, 
                  optsS]\)[\([1]\)]}, {3, 1, 2}]];\)\)], "Input"],

Cell[TextData[{
  "The function ",
  StyleBox["normalizeCoordinates[pt,xMin,", "Input"],
  "stepX",
  StyleBox[",yMin,", "Input"],
  "stepY",
  StyleBox["]", "Input"],
  " takes the grid with vertex at ",
  StyleBox["{xMin,yMin}", "Input"],
  " and takes it to the integer grid starting at the origin."
}], "Text"],

Cell[BoxData[
    \(\(normalizeCoordinates[pt_List /; NumericQ[pt[\([1]\)]], xMin_, stepX_, 
          yMin_, stepY_] := 
        Rationalize[\((pt - {xMin, yMin})\)/{stepX, 
              stepY},  .00001];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "The function ",
  StyleBox["originalCoordinates[nrmPt,xMin,", "Input"],
  "stepX",
  StyleBox[",yMin,", "Input"],
  "stepY",
  StyleBox["]", "Input"],
  " takes back a point in the integer grid to the original grid."
}], "Text"],

Cell[BoxData[
    \(\(originalCoordinates[nrmPt_List /; NumericQ[nrmPt[\([1]\)]], xMin_, 
          stepX_, yMin_, stepY_] := 
        nrmPt*{stepX, stepY} + {xMin, yMin};\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "The function ",
  StyleBox["basicCurvePoints[{gu,gv},{t,tMin,tMax}] ", "Input"],
  "effectively calculates the values of ",
  StyleBox["{gu,gv}", "Input"],
  " for ",
  StyleBox["t", "Input"],
  " from ",
  StyleBox["tMin", "Input"],
  " to ",
  StyleBox["tMax", "Input"],
  " at uniform increments of ",
  StyleBox["t", "Input"],
  ". It uses ",
  StyleBox["ParametricPlot3D", "Input"],
  ", and not ",
  StyleBox["Table", "Input"],
  " or such, because we want the evaluation of our function to behave like \
the built-in ",
  StyleBox["Plot3D", "Input"],
  " and ",
  StyleBox["ParametricPlot3D", "Input"],
  "."
}], "Text"],

Cell[BoxData[
    \(\(SetAttributes[basicCurvePoints, HoldAll];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(basicCurvePoints[{gu_, gv_}, {t_, tMin_, tMax_}, optsC___?OptionQ] := 
        Transpose[
            Drop[Transpose[\(ParametricPlot3D[{gu, gv, 0}, {t, tMin, tMax}, 
                      Evaluate[FilterOptions[ParametricPlot3D, optsC]], 
                      PlotPoints \[Rule] 15, 
                      DisplayFunction \[Rule] Identity]\)[\([1]\)] /. 
                  Line[{a__}] \[RuleDelayed] 
                    Sequence @@ {a}], \(-1\)]] //. {x___, y_List, y_, 
              z___} \[RuleDelayed] {x, y, z};\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Final", "Section"],

Cell["\<\
Combining the surface and the curve(s), possibly with arrows:\
\>", \
"Text"],

Cell[BoxData[
    \(\(SetAttributes[PlotCurveOnSurface3D, HoldAll];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "Handling the ",
  StyleBox["Oriented", "Input"],
  " option in the surface itself when it occurs twice or is set to ",
  StyleBox["False", "Input"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(PlotCurveOnSurface3D[{f_ /; Not[MatchQ[f, {__List}]], {u_Symbol, 
              uMin_, uMax_}, {v_Symbol, vMin_, vMax_}, optsS1___?OptionQ, 
            Oriented \[Rule] a_, optsS2___?OptionQ, Oriented \[Rule] _, 
            optsS3___?
              OptionQ}, \[IndentingNewLine]curves : \((\(({_, {_Symbol, _, \
_}, {_Symbol, _, _}, ___?OptionQ} | {{_, _}, {_Symbol, _, _}, ___?
                        OptionQ})\) ... )\), optsGen___?OptionQ] := 
        PlotCurveOnSurface3D[{f, {u, uMin, uMax}, {v, vMin, vMax}, optsS1, 
            Oriented \[Rule] a, optsS2, optsS3}, curves, 
          optsGen];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PlotCurveOnSurface3D[{f_ /; Not[MatchQ[f, {__List}]], {u_Symbol, 
              uMin_, uMax_}, {v_Symbol, vMin_, vMax_}, optsS1___?OptionQ, 
            Oriented \[Rule] \((a_ /; Not[TrueQ[a]])\), optsS2___?OptionQ, 
            Oriented \[Rule] _, optsS3___?OptionQ}, 
          curves : \((\(({_, {_Symbol, _, _}, {_Symbol, _, _}, ___?
                        OptionQ} | {{_, _}, {_Symbol, _, _}, ___?
                        OptionQ})\) ... )\), optsGen___?OptionQ] := 
        PlotCurveOnSurface3D[{f, {u, uMin, uMax}, {v, vMin, vMax}, optsS1, 
            optsS2, optsS3}, curves, optsGen];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PlotCurveOnSurface3D[{f_ /; Not[MatchQ[f, {__List}]], {u_Symbol, 
              uMin_, uMax_}, {v_Symbol, vMin_, vMax_}, 
            optsS___?OptionQ /; Not[True === \((Oriented /. {optsS})\)]}, 
          curves : \(({{_, _}, {_Symbol, _, _}, ___?OptionQ} ... )\), 
          optsGen___?OptionQ] := \[IndentingNewLine]Module[{basic2Dcurves, 
            xMin, xMax, yMin, yMax, dr, pdr, testSurface, n1, n2, stepX, 
            stepY, gridInfo, normalizedbasic2Dcurves, curveXMin, curveXMax, 
            curveYMin, curveYMax, subdividedCur, weightsList, fCoordinates, 
            verticesData, weightedCoord, cur3D, curveOpts, statedHowMany, 
            referenceDimension, howMany, sty, adaptedCurvesWithOpts, 
            srfVertices, plg, srface, srfSty, sr, hdscl3D, 
            pos}, \[IndentingNewLine]basic2Dcurves = 
            Apply[basicCurvePoints, {curves}, 1]; \[IndentingNewLine]{xMin, 
              xMax, yMin, yMax} = 
            Rationalize[Evaluate[{uMin, uMax, vMin, vMax}], 
              1/10^6]; \[IndentingNewLine]dr = 
            DrawGraphics`DrawingCube`Draw3D; \[IndentingNewLine]pdr = 
            DrawGraphics`ParametricDrawing3D`ParametricDraw3D; \
\[IndentingNewLine]testSurface = 
            If[MatchQ[f, {_, _, _, ___}], 
              pdr[{x, y, 0}, {x, 0, 1}, {y, 2, 3}, 
                Evaluate@
                  FilterOptions[ParametricPlot3D, optsS, 
                    optsGen]], \[IndentingNewLine]dr[0, {x, 0, 1}, {y, 2, 3}, 
                  Evaluate@FilterOptions[Plot3D, optsS, optsGen]] /. 
                Polygon[pts_] \[RuleDelayed] 
                  Polygon[RotateLeft[pts]]]; \[IndentingNewLine]n1 = 
            1 + Count[testSurface, 
                Polygon[{{_, 2. , _}, __}], {1, 
                  Infinity}]; \[IndentingNewLine]n2 = 
            1 + Count[testSurface, 
                Polygon[{{0. , __}, __}], {1, 
                  Infinity}]; \[IndentingNewLine]{stepX, 
              stepY} = \(({xMax, yMax} - {xMin, yMin})\)/\(({n1, n2} - 
                  1)\); \[IndentingNewLine]gridInfo = {xMin, stepX, yMin, 
              stepY}; \[IndentingNewLine]normalizedbasic2Dcurves = 
            Map[normalizeCoordinates[#, Sequence @@ gridInfo] &, 
              basic2Dcurves, {2}]; \[IndentingNewLine]{{curveXMin, 
                curveXMax}, {curveYMin, curveYMax}} = 
            Map[{Min[Floor[#]], Max[Ceiling[#]]} &, 
              Transpose[
                Flatten[normalizedbasic2Dcurves, 1]~
                  Join~{{xMin, yMin}, {xMax, 
                      yMax}}]]; \[IndentingNewLine]subdividedCur = 
            Map[divideLine, 
              normalizedbasic2Dcurves]; \[IndentingNewLine]weightsList = 
            Map[weight, 
              subdividedCur, {2}]; \[IndentingNewLine]fCoordinates = 
            Which[Head[Evaluate[f]] =!= 
                List, {u, v, f} /. Thread[{u, v} \[Rule] #] &, 
              MatchQ[f, {_, _, _, ___}], 
              Take[f /. Thread[{u, v} \[Rule] #], 
                  3] &, \[IndentingNewLine]MatchQ[
                f, {_, _}], {u, v, First[f]} /. 
                  Thread[{u, 
                        v} \[Rule] #] &]; \[IndentingNewLine]verticesData = 
            Map[fCoordinates, \[IndentingNewLine]N@
                  Table[{x, y}, {y, yMin + curveYMin*stepY, 
                      yMin + curveYMax*stepY, stepY}, {x, 
                      xMin + curveXMin*stepX, xMin + curveXMax*stepX, 
                      stepX}], {2}] // \((Rationalize[#, 
                    1/10^6] &)\); \[IndentingNewLine]weightedCoord = 
            Apply[#3*
                  verticesData[\([#2 - curveYMin + 1, #1 - curveXMin + 
                        1]\)] &, 
              weightsList, {3}]; \[IndentingNewLine]cur3D = 
            Map[Line[Apply[Plus, #, 1]] &, 
              weightedCoord]; \[IndentingNewLine]curveOpts = 
            Map[Drop[#, 
                  2] &, {curves}]; \[IndentingNewLine]statedHowMany = \
\(HowManyArrows /. curveOpts\) /. 
              Options[OrientedParametricPlot3D]; \
\[IndentingNewLine]referenceDimension = 
            maxLineExcursion[
              cur3D]; \[IndentingNewLine]arrowDensityParameter = \
\(ArrowDensity /. {optsGen}\) /. 
              Options[OrientedParametricPlot3D]; \[IndentingNewLine]howMany = 
            sortOutHowManyArrows[cur3D, statedHowMany, referenceDimension, 
              arrowDensityParameter]; \[IndentingNewLine]curveOpts = 
            Apply[Prepend, 
              Transpose[{curveOpts, Thread[HowManyArrows \[Rule] howMany]}], 
              1]; \[IndentingNewLine]sty = 
            If[{curves} === {}, {}, 
              Map[Flatten[#, 2] &, \({PlotStyle} /. 
                    curveOpts\) /. {Automatic \[Rule] {}, 
                    PlotStyle \[Rule] {}}]]; \[IndentingNewLine]cur3D = 
            Map[Flatten[#, 1] &, 
              Transpose[{sty, 
                  cur3D}]]; \[IndentingNewLine]adaptedCurvesWithOpts = 
            Transpose[{cur3D, curveOpts}]; \[IndentingNewLine]srfVertices = 
            Map[fCoordinates, 
                N@Table[{x, y}, {y, yMin, yMax, stepY}, {x, xMin, xMax, 
                      stepX}], {2}] // \((Rationalize[#, 
                    1/10^6] &)\); \[IndentingNewLine]plg[i_, j_] := 
            Polygon[Apply[srfVertices[\([##]\)] &, 
                Map[{i, j} + # &, {{0, 0}, {0, 1}, {1, 1}, {1, 0}}], 
                1]]; \[IndentingNewLine]srface = 
            Flatten@Table[
                plg[i, j], {i, n2 - 1}, {j, 
                  n1 - 1}]; \[IndentingNewLine]Which[MatchQ[f, {_, _, _, _}], 
            srfSty = 
              Map[Drop[#, \(-1\)] &, 
                pdr[f, {u, uMin, uMax}, {v, vMin, vMax}, 
                  PlotPoints \[Rule] {n1, n2}]]; \[IndentingNewLine]srface = 
              Map[Flatten[#, 1] &, 
                Transpose[{srfSty, srface}]], \[IndentingNewLine]Or[
              Head[f] =!= List, 
              Length[f] \[Equal] 2], \[IndentingNewLine]sr = 
              dr[f, {u, uMin, uMax}, {v, vMin, vMax}, 
                  PlotPoints \[Rule] {n1, n2}, 
                  Evaluate[
                    FilterOptions[Plot3D, optsS]]] /. _Polygon \[RuleDelayed] 
                  Sequence @@ {}; \[IndentingNewLine]srfSty = 
              Which[MatchQ[sr, {__, {__}}], 
                Map[Join[Drop[sr, \(-1\)], {#}] &, 
                  Last[sr]], \[IndentingNewLine]MatchQ[sr, {__, {}}], 
                Table[Drop[
                    sr, \(-1\)], {\((n1 - 1)\) \((n2 - 
                          1)\)}], \[IndentingNewLine]MatchQ[sr, {__}], 
                Map[List, sr], \[IndentingNewLine]MatchQ[sr, {}], 
                Table[{}, {\((n1 - 1)\) \((n2 - 
                          1)\)}]\[IndentingNewLine]]; \
\[IndentingNewLine]srface = 
              Map[Flatten[#, 1] &, 
                Transpose[{srfSty, srface}]]]; \[IndentingNewLine]hdscl3D = 
            automaticHeadScaling3D[cur3D // N, optsGen, 
              Sequence @@ 
                Options[OrientedParametricPlot3D]]; \[IndentingNewLine]Show[
            Graphics3D[{{EdgeForm[], srface}, 
                adaptedCurvesWithOpts /. {{sty___, 
                        Line[pts_List]}, {opt___}} \[RuleDelayed] \
\(({howMany, pos} = \({HowManyArrows, ArrowPositions} /. {opt, optsGen}\) /. 
                          Options[
                            OrientedParametricPlot3D]; \[IndentingNewLine]If[
                        Not@TrueQ[OrientedCurve /. {opt}], 
                        pos = {}]; \[IndentingNewLine]{If[
                          MemberQ[{None, {None}}, PlotStyle /. {opt}], 
                          Sequence @@ {}, Sequence @@ {sty, Line[pts]}], 
                        insertArrows[pts, 
                          normalizedArrowPositions[pos, howMany], opt, 
                          optsGen, hdscl3D, 
                          Sequence @@ 
                            Options[OrientedParametricPlot3D]]})\)}], 
            FilterOptions[Graphics3D, optsGen, 
              If[MatchQ[f, {_, _}], Lighting \[Rule] False, {}], 
              Options[OrientedParametricPlot3D]]]];\)\)], "Input"],

Cell["The case when the surface itself is not oriented:", "Text"],

Cell[BoxData[
    \(\(PlotCurveOnSurface3D[{f_ /; Not[MatchQ[f, {__List}]], {u_Symbol, 
              uMin_, uMax_}, {v_Symbol, vMin_, vMax_}, 
            optsS___?OptionQ /; Not[True === \((Oriented /. {optsS})\)]}, 
          curves : \((\(({_, {_Symbol, _, _}, {_Symbol, _, _}, ___?
                        OptionQ} | {{_, _}, {_Symbol, _, _}, ___?
                        OptionQ})\) ... )\), 
          optsGen___?
            OptionQ] := \[IndentingNewLine]Module[{parametric2DCurves, 
            contour2DCurves, raw2DContours, basic2DContoursAndStyles, 
            howManyContourArrows, basic2DContours, contoursStyles, 
            basic2DParametricCurves, basic2Dcurves, xMin, xMax, yMin, yMax, 
            dr, pdr, testSurface, n1, n2, stepX, stepY, gridInfo, 
            normalizedbasic2Dcurves, curveXMin, curveXMax, curveYMin, 
            curveYMax, subdividedCur, weightsList, fCoordinates, 
            verticesData, weightedCoord, cur3D, parametricCur3D, 
            contourCur3D, parametric2DCurveOptions, 
            statedHowManyParametricArrows, referenceDimension, 
            arrowDensityParameter, howManyParametricArrows, 
            parametricCurveOpts, contourCurveOpts, curveOpts, 
            parametricStyles, sty, adaptedCurvesWithOpts, srfVertices, plg, 
            srface, srfSty, sr, hdscl3D, howMany, 
            pos}, \[IndentingNewLine]parametric2DCurves = 
            Cases[{curves}, {{_, _}, {_Symbol, _, _}, ___?
                  OptionQ}]; \[IndentingNewLine]contour2DCurves = 
            Cases[{curves}, {_, {_Symbol, _, _}, {_Symbol, _, _}, ___?
                  OptionQ}]; \[IndentingNewLine]raw2DContours = 
            Apply[DrawGraphics`DrawingPaper`ContourDraw, contour2DCurves, 
              1]; \[IndentingNewLine]basic2DContoursAndStyles = 
            Cases[raw2DContours, {___, {_Line, ___}} | {__, _Line, ___}, {1, 
                Infinity}]; \[IndentingNewLine]howManyContourArrows = 
            Map[Count[#, _Arrow, {1, Infinity}] &, 
              basic2DContoursAndStyles]; \[IndentingNewLine]basic2DContours = 
            Cases[basic2DContoursAndStyles, 
              Line[pts_] \[RuleDelayed] pts, {1, 
                Infinity}]; \[IndentingNewLine]contoursStyles = \
\(basic2DContoursAndStyles /. {_Line, ___} \[RuleDelayed] Sequence @@ {}\) /. 
              Line[_] \[RuleDelayed] 
                Sequence @@ {}; \[IndentingNewLine]basic2DParametricCurves = 
            Apply[basicCurvePoints, parametric2DCurves, 
              1]; \[IndentingNewLine]basic2Dcurves = 
            Join[basic2DContours, 
              basic2DParametricCurves]; \[IndentingNewLine]{xMin, xMax, yMin, 
              yMax} = Rationalize[Evaluate[{uMin, uMax, vMin, vMax}], 
              1/10^6]; \[IndentingNewLine]dr = 
            DrawGraphics`DrawingCube`Draw3D; \[IndentingNewLine]pdr = 
            DrawGraphics`ParametricDrawing3D`ParametricDraw3D; \
\[IndentingNewLine]testSurface = 
            If[MatchQ[f, {_, _, _, ___}], 
              pdr[{x, y, 0}, {x, 0, 1}, {y, 2, 3}, 
                Evaluate@
                  FilterOptions[ParametricPlot3D, optsS, 
                    optsGen]], \[IndentingNewLine]dr[0, {x, 0, 1}, {y, 2, 3}, 
                  Evaluate@FilterOptions[Plot3D, optsS, optsGen]] /. 
                Polygon[pts_] \[RuleDelayed] 
                  Polygon[RotateLeft[pts]]]; \[IndentingNewLine]n1 = 
            1 + Count[testSurface, 
                Polygon[{{_, 2. , _}, __}], {1, 
                  Infinity}]; \[IndentingNewLine]n2 = 
            1 + Count[testSurface, 
                Polygon[{{0. , __}, __}], {1, 
                  Infinity}]; \[IndentingNewLine]{stepX, 
              stepY} = \(({xMax, yMax} - {xMin, yMin})\)/\(({n1, n2} - 
                  1)\); \[IndentingNewLine]gridInfo = {xMin, stepX, yMin, 
              stepY}; \[IndentingNewLine]normalizedbasic2Dcurves = 
            Map[normalizeCoordinates[#, Sequence @@ gridInfo] &, 
              basic2Dcurves, {2}]; \[IndentingNewLine]{{curveXMin, 
                curveXMax}, {curveYMin, curveYMax}} = 
            Map[{Min[Floor[#]], Max[Ceiling[#]]} &, 
              Transpose[
                Flatten[normalizedbasic2Dcurves, 1]~
                  Join~{{xMin, yMin}, {xMax, 
                      yMax}}]]; \[IndentingNewLine]subdividedCur = 
            Map[divideLine, 
              normalizedbasic2Dcurves]; \[IndentingNewLine]weightsList = 
            Map[weight, 
              subdividedCur, {2}]; \[IndentingNewLine]fCoordinates = 
            Which[Head[Evaluate[f]] =!= 
                List, {u, v, f} /. Thread[{u, v} \[Rule] #] &, 
              MatchQ[f, {_, _, _, ___}], 
              Take[f /. Thread[{u, v} \[Rule] #], 
                  3] &, \[IndentingNewLine]MatchQ[
                f, {_, _}], {u, v, First[f]} /. 
                  Thread[{u, 
                        v} \[Rule] #] &]; \[IndentingNewLine]verticesData = 
            Map[fCoordinates, \[IndentingNewLine]N@
                  Table[{x, y}, {y, yMin + curveYMin*stepY, 
                      yMin + curveYMax*stepY, stepY}, {x, 
                      xMin + curveXMin*stepX, xMin + curveXMax*stepX, 
                      stepX}], {2}] // \((Rationalize[#, 
                    1/10^6] &)\); \[IndentingNewLine]weightedCoord = 
            Apply[#3*
                  verticesData[\([#2 - curveYMin + 1, #1 - curveXMin + 
                        1]\)] &, 
              weightsList, {3}]; \[IndentingNewLine]cur3D = 
            Map[Line[Apply[Plus, #, 1]] &, 
              weightedCoord]; \[IndentingNewLine]parametricCur3D = 
            Take[cur3D, \(-Length[
                  basic2DParametricCurves]\)]; \
\[IndentingNewLine]contourCur3D = 
            Take[cur3D, 
              Length[basic2DContoursAndStyles]]; \
\[IndentingNewLine]parametric2DCurveOptions = 
            Map[Drop[#, 2] &, 
              parametric2DCurves]; \
\[IndentingNewLine]statedHowManyParametricArrows = \(HowManyArrows /. 
                parametric2DCurveOptions\) /. 
              Options[OrientedParametricPlot3D]; \
\[IndentingNewLine]referenceDimension = 
            maxLineExcursion[
              cur3D]; \[IndentingNewLine]arrowDensityParameter = \
\(ArrowDensity /. {optsGen}\) /. 
              Options[OrientedParametricPlot3D]; \
\[IndentingNewLine]howManyParametricArrows = 
            sortOutHowManyArrows[parametricCur3D, 
              statedHowManyParametricArrows, referenceDimension, 
              arrowDensityParameter]; \[IndentingNewLine]parametricCurveOpts \
= Apply[Prepend, 
              Transpose[{parametric2DCurveOptions, 
                  Thread[HowManyArrows \[Rule] howManyParametricArrows]}], 
              1]; \[IndentingNewLine]contourCurveOpts = 
            Map[List, 
                Thread[HowManyArrows \[Rule] 
                    howManyContourArrows]] /. {HowManyArrows \[Rule] 
                    n_?Positive} \[RuleDelayed] {HowManyArrows \[Rule] n, 
                  Oriented \[Rule] True}; \[IndentingNewLine]{contoursStyles, 
              contourCurveOpts} = 
            If[contoursStyles === {}, {{}, {}}, 
              Transpose[
                Transpose[{contoursStyles, 
                      contourCurveOpts}] /. {{a___, col : colorSpecPattern, 
                        c___}, {d___}} \[RuleDelayed] {{a, col, c}, {d, 
                        Arrow3DColor \[Rule] 
                          col}}]]; \[IndentingNewLine]curveOpts = 
            Join[contourCurveOpts, 
              parametricCurveOpts]; \[IndentingNewLine]parametricStyles = 
            If[parametric2DCurves === {}, {}, 
              Map[Flatten[#, 2] &, \({PlotStyle} /. 
                    parametricCurveOpts\) /. {Automatic \[Rule] {}, 
                    PlotStyle \[Rule] {}}]]; \[IndentingNewLine]sty = 
            Join[contoursStyles, 
              parametricStyles]; \[IndentingNewLine]cur3D = 
            Map[Flatten[#, 1] &, 
              Transpose[{sty, 
                  cur3D}]]; \[IndentingNewLine]adaptedCurvesWithOpts = 
            Transpose[{cur3D, curveOpts}]; \[IndentingNewLine]srfVertices = 
            Map[fCoordinates, 
                N@Table[{x, y}, {y, yMin, yMax, stepY}, {x, xMin, xMax, 
                      stepX}], {2}] // \((Rationalize[#, 
                    1/10^6] &)\); \[IndentingNewLine]plg[i_, j_] := 
            Polygon[Apply[srfVertices[\([##]\)] &, 
                Map[{i, j} + # &, {{0, 0}, {0, 1}, {1, 1}, {1, 0}}], 
                1]]; \[IndentingNewLine]srface = 
            Flatten@Table[
                plg[i, j], {i, n2 - 1}, {j, 
                  n1 - 1}]; \[IndentingNewLine]Which[MatchQ[f, {_, _, _, _}], 
            srfSty = 
              Map[Drop[#, \(-1\)] &, 
                pdr[f, {u, uMin, uMax}, {v, vMin, vMax}, 
                  PlotPoints \[Rule] {n1, n2}]]; \[IndentingNewLine]srface = 
              Map[Flatten[#, 1] &, 
                Transpose[{srfSty, srface}]], \[IndentingNewLine]Or[
              Head[f] =!= List, 
              Length[f] \[Equal] 2], \[IndentingNewLine]sr = 
              dr[f, {u, uMin, uMax}, {v, vMin, vMax}, 
                  PlotPoints \[Rule] {n1, n2}, 
                  Evaluate[
                    FilterOptions[Plot3D, optsS]]] /. _Polygon \[RuleDelayed] 
                  Sequence @@ {}; \[IndentingNewLine]srfSty = 
              Which[MatchQ[sr, {__, {__}}], 
                Map[Join[Drop[sr, \(-1\)], {#}] &, 
                  Last[sr]], \[IndentingNewLine]MatchQ[sr, {__, {}}], 
                Table[Drop[
                    sr, \(-1\)], {\((n1 - 1)\) \((n2 - 
                          1)\)}], \[IndentingNewLine]MatchQ[sr, {__}], 
                Map[List, sr], \[IndentingNewLine]MatchQ[sr, {}], 
                Table[{}, {\((n1 - 1)\) \((n2 - 
                          1)\)}]\[IndentingNewLine]]; \
\[IndentingNewLine]srface = 
              Map[Flatten[#, 1] &, 
                Transpose[{srfSty, srface}]]]; \[IndentingNewLine]hdscl3D = 
            automaticHeadScaling3D[cur3D // N, optsGen, 
              Sequence @@ 
                Options[OrientedParametricPlot3D]]; \[IndentingNewLine]Show[
            Graphics3D[{{EdgeForm[], srface}, 
                adaptedCurvesWithOpts /. {{sty___, 
                        Line[pts_List]}, {opt___}} \[RuleDelayed] \
\(({howMany, pos} = \({HowManyArrows, ArrowPositions} /. {opt, optsGen}\) /. 
                          Options[
                            OrientedParametricPlot3D]; \[IndentingNewLine]If[
                        Not@TrueQ[OrientedCurve /. {opt}], 
                        pos = {}]; \[IndentingNewLine]{If[
                          MemberQ[{None, {None}}, PlotStyle /. {opt}], 
                          Sequence @@ {}, Sequence @@ {sty, Line[pts]}], 
                        insertArrows[pts, 
                          normalizedArrowPositions[pos, howMany], opt, 
                          optsGen, hdscl3D, 
                          Sequence @@ 
                            Options[OrientedParametricPlot3D]]})\)}], 
            FilterOptions[Graphics3D, optsGen, 
              If[MatchQ[f, {_, _}], Lighting \[Rule] False, {}], 
              Options[OrientedParametricPlot3D]]]];\)\)], "Input",
  InitializationCell->True],

Cell["The case when the surface is itself oriented:", "Text"],

Cell[BoxData[
    \(\(PlotCurveOnSurface3D[{f_ /; Not[MatchQ[f, {__List}]], {u_Symbol, 
              uMin_, uMax_}, {v_Symbol, vMin_, vMax_}, optsS1___?OptionQ, 
            Oriented \[Rule] True, optsS2___?OptionQ}, 
          curves : \((\(({_, {_Symbol, _, _}, {_Symbol, _, _}, ___?
                        OptionQ} | {{_, _}, {_Symbol, _, _}, ___?
                        OptionQ})\) ... )\), 
          optsGen___?OptionQ] := \[IndentingNewLine]Module[{howMany, pos, 
            revQ, hdlngh3D, cntrstyle, arwColor, 
            bdrOpts}, \[IndentingNewLine]{howMany, pos, revQ, hdlngh3D, 
              cntrstyle, 
              arwColor} = \(\({HowManyArrows, ArrowPositions, 
                    ReverseOrientation, 
                    DrawGraphics`DrawingArrows`HeadLength3D, ContourStyle, 
                    Arrow3DColor} /. {optsS1, optsS2, optsGen}\) /. 
                Options[OrientedParametricPlot]\) /. 
              Options[OrientedParametricPlot3D]; \[IndentingNewLine]If[
            Head[howMany] =!= List, 
            howMany = {howMany}]; \[IndentingNewLine]If[
            MatchQ[pos, {__?NumericQ} | Automatic], 
            pos = {pos}]; \[IndentingNewLine]If[Length[revQ] === 0, 
            revQ = {revQ}]; \[IndentingNewLine]cntrstyle = 
            makeStandardStyle[cntrstyle]; \[IndentingNewLine]arwColor = 
            makeStandardStyle[arwColor]; \[IndentingNewLine]bdrOpts[
              i_] := {HowManyArrows \[Rule] cyclicPart[howMany, i], 
              ArrowPositions \[Rule] 
                cyclicPart[pos, 
                  i], \[IndentingNewLine]ReverseOrientation \[Rule] 
                cyclicPart[revQ, i], \[IndentingNewLine]PlotStyle \[Rule] 
                cyclicPart[cntrstyle, 
                  i], \[IndentingNewLine]Arrow3DColor \[Rule] 
                cyclicPart[arwColor, i], 
              DrawGraphics`DrawingArrows`HeadLength3D \[Rule] 
                hdlngh3D}; \[IndentingNewLine]PlotCurveOnSurface3D[{f, {u, 
                uMin, uMax}, {v, vMin, vMax}, optsS1, 
              optsS2}, \[IndentingNewLine]Evaluate[{{u, vMin}, {u, uMin, 
                  uMax}, Oriented \[Rule] True, PlotPoints \[Rule] 2, 
                Sequence @@ bdrOpts[1]}], \[IndentingNewLine]Evaluate[{{uMax, 
                  v}, {v, vMin, vMax}, Oriented \[Rule] True, 
                PlotPoints \[Rule] 2, 
                Sequence @@ 
                  bdrOpts[2]}], \[IndentingNewLine]Evaluate[{{uMax - u, 
                  vMax}, {u, 0, uMax - uMin}, Oriented \[Rule] True, 
                PlotPoints \[Rule] 2, 
                Sequence @@ bdrOpts[3]}], \[IndentingNewLine]Evaluate[{{uMin, 
                  vMax - v}, {v, 0, vMax - vMin}, Oriented \[Rule] True, 
                PlotPoints \[Rule] 2, 
                Sequence @@ bdrOpts[4]}], \[IndentingNewLine]curves, 
            optsGen]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SetAttributes[DrawCurveOnSurface3D, HoldAll];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DrawCurveOnSurface3D[
          surf : {f_ /; Not[MatchQ[f, {__List}]], {u_Symbol, uMin_, 
                uMax_}, {v_Symbol, vMin_, vMax_}, optsS___?OptionQ}, 
          curves : \((\(({_, {_Symbol, _, _}, {_Symbol, _, _}, ___?
                        OptionQ} | {{_, _}, {_Symbol, _, _}, ___?
                        OptionQ})\) ... )\), optsGen___?OptionQ] := 
        Block[{$DisplayFunction = 
              Identity}, \[IndentingNewLine]\(PlotCurveOnSurface3D[surf, 
              curves, optsGen]\)[\([1]\)]];\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["OrientedParametricPlot3D (surface)", "Subsubtitle"],

Cell[BoxData[
    \(\(OrientedParametricPlot3D[f_, it1_List, it2_List, opts___?OptionQ] := 
        PlotCurveOnSurface3D[{f, it1, it2, Oriented \[Rule] True, opts}, 
          Evaluate@FilterOptions[Graphics3D, opts]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["OrientedPlot3D", "Subsubtitle"],

Cell[BoxData[
    \(SetAttributes[OrientedPlot3D, HoldAll]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OrientedPlot3D[f_, it1_List, it2_List, opts___?OptionQ] := 
        PlotCurveOnSurface3D[{f, it1, it2, Oriented \[Rule] True, opts}, 
          Evaluate@FilterOptions[Graphics3D, opts]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["The Oriented option", "Subsubtitle"],

Cell[BoxData[{
    \(\(Unprotect[Plot];\)\), "\[IndentingNewLine]", 
    \(Plot[f_, x_, opts1___?OptionQ, Oriented \[Rule] a_, opts2___?OptionQ, 
        Oriented \[Rule] _, opts3___?OptionQ] := 
      Plot[f, x, opts1, Oriented \[Rule] a, opts2, opts3]; 
    Plot[f_, x_, opts1___?OptionQ, Oriented \[Rule] True, opts2___?OptionQ] := 
      OrientedPlot[f, x, opts1, opts2];\), "\[IndentingNewLine]", 
    \(\(Plot[f_, x_, opts1___?OptionQ, 
          Oriented \[Rule] \((smthng_ /; Not[TrueQ[smthng]])\), 
          opts2___?OptionQ] := 
        Plot[f, x, opts1, opts2];\)\), "\[IndentingNewLine]", 
    \(\(Protect[Plot];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Unprotect[ParametricPlot];\)\), "\[IndentingNewLine]", 
    \(\(ParametricPlot[f_, x_, opts1___?OptionQ, Oriented \[Rule] a_, 
          opts2___?OptionQ, Oriented \[Rule] _, opts3___?OptionQ] := 
        ParametricPlot[f, x, opts1, Oriented \[Rule] a, opts2, 
          opts3];\)\), "\[IndentingNewLine]", 
    \(\(ParametricPlot[f_, x_, opts1___?OptionQ, Oriented \[Rule] True, 
          opts2___?OptionQ] := 
        OrientedParametricPlot[f, x, opts1, 
          opts2];\)\), "\[IndentingNewLine]", 
    \(\(ParametricPlot[f_, x_, opts1___?OptionQ, 
          Oriented \[Rule] \((smthng_ /; Not[TrueQ[smthng]])\), 
          opts2___?OptionQ] := 
        ParametricPlot[f, x, opts1, opts2];\)\), "\[IndentingNewLine]", 
    \(\(Protect[ParametricPlot];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Unprotect[Plot3D];\)\), "\[IndentingNewLine]", 
    \(\(Plot3D[f_, x_List, y_List, opts1___?OptionQ, Oriented \[Rule] a_, 
          opts2___?OptionQ, Oriented \[Rule] _, opts3___?OptionQ] := 
        Plot3D[f, x, y, opts1, Oriented \[Rule] a, opts2, 
          opts3];\)\), "\[IndentingNewLine]", 
    \(\(Plot3D[f_, x_List, y_List, opts1___?OptionQ, Oriented \[Rule] True, 
          opts2___?OptionQ] := 
        OrientedPlot3D[f, x, y, opts1, opts2];\)\), "\[IndentingNewLine]", 
    \(\(Plot3D[f_, x_List, y_List, opts1___?OptionQ, 
          Oriented \[Rule] \((smthng_ /; Not[TrueQ[smthng]])\), 
          opts2___?OptionQ] := 
        Plot3D[f, x, y, opts1, opts2];\)\), "\[IndentingNewLine]", 
    \(\(Protect[Plot3D];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(Unprotect[DrawGraphics`DrawingCube`Draw3D]; 
    DrawGraphics`DrawingCube`Draw3D[data1__, Oriented \[Rule] True, 
        data2___] := 
      First[Plot3D[data1, Oriented \[Rule] True, data2, 
          DisplayFunction \[Rule] Identity]];\), "\[IndentingNewLine]", 
    \(\(Protect[DrawGraphics`DrawingCube`Draw3D];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Unprotect[ParametricPlot3D];\)\), "\[IndentingNewLine]", 
    \(\(ParametricPlot3D[f_, x_, opts1___?OptionQ, Oriented \[Rule] a_, 
          opts2___?OptionQ, Oriented \[Rule] _, opts3___?OptionQ] := 
        ParametricPlot3D[f, x, opts1, Oriented \[Rule] a, opts2, 
          opts3];\)\), "\[IndentingNewLine]", 
    \(\(ParametricPlot3D[f_, x_List, opts1___?OptionQ, Oriented \[Rule] True, 
          opts2___?OptionQ] := 
        OrientedParametricPlot3D[f, x, opts1, 
          opts2];\)\), "\[IndentingNewLine]", 
    \(\(\(ParametricPlot3D[f_, x_List, opts1___?OptionQ, 
          Oriented \[Rule] \((smthng_ /; Not[TrueQ[smthng]])\), 
          opts2___?OptionQ] := 
        ParametricPlot3D[f, x, opts1, opts2];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(ParametricPlot3D[f_, x_, y_List, opts1___?OptionQ, 
          Oriented \[Rule] a_, opts2___?OptionQ, Oriented \[Rule] _, 
          opts3___?OptionQ] := 
        ParametricPlot3D[f, x, y, opts1, Oriented \[Rule] a, opts2, 
          opts3];\)\), "\[IndentingNewLine]", 
    \(\(ParametricPlot3D[f_, x_List, y_List, opts1___?OptionQ, 
          Oriented \[Rule] True, opts2___?OptionQ] := 
        OrientedParametricPlot3D[f, x, y, opts1, 
          opts2];\)\), "\[IndentingNewLine]", 
    \(\(ParametricPlot3D[f_, x_List, y_List, opts1___?OptionQ, 
          Oriented \[Rule] \((smthng_ /; Not[TrueQ[smthng]])\), 
          opts2___?OptionQ] := 
        ParametricPlot3D[f, x, y, opts1, opts2];\)\), "\[IndentingNewLine]", 
    \(\(Protect[ParametricPlot3D];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Clipping lines and adapting arrows to the display area", "Subsubtitle"],

Cell[TextData[{
  "Determining whether two points are not in the same (weak) side of the \
plane with respect to at least one of the straight lines ",
  Cell[BoxData[
      \(TraditionalForm\`x = xMin\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x = xMax\)\(,\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`y = yMin\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`y = yMax\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(\(crossingQ[{xMin_, xMax_}, {yMin_, yMax_}]\)[{{x1_?NumericQ, 
              y1_}, {x2_?NumericQ, y2_}}] := 
        Or[x1 < xMin < x2, x2 < xMin < x1, x1 < xMax < x2, x2 < xMax < x1, 
          y1 < yMin < y2, y2 < yMin < y1, y1 < yMax < y2, 
          y2 < yMax < y1];\)\)], "Input",
  InitializationCell->True],

Cell["Three-dimensional case:", "Text"],

Cell[BoxData[
    \(\(\(crossingQ[{xMin_, xMax_}, {yMin_, yMax_}, {zMin_, 
              zMax_}]\)[{{x1_?NumericQ, y1_, z1_}, {x2_?NumericQ, y2_, 
              z2_}}] := Or[x1 < xMin < x2, x2 < xMin < x1, x1 < xMax < x2, 
          x2 < xMax < x1, y1 < yMin < y2, y2 < yMin < y1, y1 < yMax < y2, 
          y2 < yMax < y1, z1 < zMin < z2, z2 < zMin < z1, z1 < zMax < z2, 
          z2 < zMax < z1];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "When two points make ",
  StyleBox["crossingQ", "Input"],
  " true, find the intersection between the earliest found crossed straight \
line and the segment joining the two points:"
}], "Text"],

Cell[BoxData[
    \(\(addCrossingPoint[{{x1_, y1_}, {x2_, y2_}}, {_, xMax_}, _] /; 
          Or[x1 < xMax < x2, x2 < xMax < x1] := 
        With[{t = \(-\((\((x2 - xMax)\)/\((x1 - 
                        x2)\))\)\)}, \[IndentingNewLine]{{xMax, 
              t*y1 + \((1 - t)\) y2}, {x2, y2}}];\)\)], "Input"],

Cell[BoxData[
    \(\(addCrossingPoint[{pt1 : {x1_?NumericQ, __}, pt2 : {x2_, __}}, {_, 
              xMax_}, __] /; 
          Or[x1 < xMax < x2, 
            x2 < xMax < x1] := \[IndentingNewLine]{t*pt1 + \((1 - t)\) pt2, 
            pt2} /. t \[Rule] \(-\((\((x2 - xMax)\)/\((x1 - 
                      x2)\))\)\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(addCrossingPoint[{{x1_, y1_}, {x2_, y2_}}, {xMin_, _}, _] /; 
          Or[x1 < xMin < \ x2, x2 < xMin < x1] := 
        With[{t = \(-\((\((x2 - xMin)\)/\((x1 - 
                        x2)\))\)\)}, \[IndentingNewLine]{{xMin, 
              t*y1 + \((1 - t)\) y2}, {x2, y2}}];\)\)], "Input"],

Cell[BoxData[
    \(\(addCrossingPoint[{pt1 : {x1_?NumericQ, __}, 
              pt2 : {x2_, __}}, {xMin_, _}, __] /; 
          Or[x1 < xMin < \ x2, 
            x2 < xMin < x1] := \[IndentingNewLine]{t*pt1 + \((1 - t)\) pt2, 
            pt2} /. t \[Rule] \(-\((\((x2 - xMin)\)/\((x1 - 
                      x2)\))\)\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(addCrossingPoint[{{x1_, y1_}, {x2_, y2_}}, _, {_, yMax_}] /; 
          Or[y1 < yMax < y2, y2 < yMax < y1] := 
        With[{t = \(-\((\((y2 - yMax)\)/\((y1 - 
                        y2)\))\)\)}, \[IndentingNewLine]{{t*x1 + \((1 - t)\) 
                  x2, yMax}, {x2, y2}}];\)\)], "Input"],

Cell[BoxData[
    \(\(addCrossingPoint[{pt1 : {_, y1_?NumericQ, ___}, 
              pt2 : {_, y2_, ___}}, _, {_, yMax_}, ___] /; 
          Or[y1 < yMax < y2, 
            y2 < yMax < y1] := \[IndentingNewLine]{t*pt1 + \((1 - t)\) pt2, 
            pt2} /. t \[Rule] \(-\((\((y2 - yMax)\)/\((y1 - 
                      y2)\))\)\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(addCrossingPoint[{{x1_, y1_}, {x2_, y2_}}, _, {yMin_, _}] /; 
          Or[y1 < yMin < \ y2, y2 < yMin < y1] := 
        With[{t = \(-\((\((y2 - yMin)\)/\((y1 - 
                        y2)\))\)\)}, \[IndentingNewLine]{{t*x1 + \((1 - t)\) 
                  x2, yMin}, {x2, y2}}];\)\)], "Input"],

Cell[BoxData[
    \(\(addCrossingPoint[{pt1 : {_, y1_?NumericQ, ___}, 
              pt2 : {_, y2_, ___}}, _, {yMin_, _}, ___] /; 
          Or[y1 < yMin < \ y2, 
            y2 < yMin < y1] := \[IndentingNewLine]{t*pt1 + \((1 - t)\) pt2, 
            pt2} /. t \[Rule] \(-\((\((y2 - yMin)\)/\((y1 - 
                      y2)\))\)\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(addCrossingPoint[{pt1 : {_, _, z1_?NumericQ}, 
              pt2 : {_, _, z2_}}, _, _, {_, zMax_}] /; 
          Or[z1 < zMax < z2, 
            z2 < zMax < z1] := \[IndentingNewLine]{t*pt1 + \((1 - t)\) pt2, 
            pt2} /. t \[Rule] \(-\((\((z2 - zMax)\)/\((z1 - 
                      z2)\))\)\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(addCrossingPoint[{pt1 : {_, _, z1_?NumericQ}, 
              pt2 : {_, _, z2_}}, _, _, {zMin_, _}] /; 
          Or[z1 < zMin < z2, 
            z2 < zMin < z1] := \[IndentingNewLine]{t*pt1 + \((1 - t)\) pt2, 
            pt2} /. t \[Rule] \(-\((\((z2 - zMin)\)/\((z1 - 
                      z2)\))\)\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(addCrossingPoint[cplpts_, lts__] /; 
          Not[\(crossingQ[lts]\)[cplpts]] := {Last[cplpts]};\)\)], "Input",
  InitializationCell->True],

Cell["Determining where a point is with respect to a rectangle:", "Text"],

Cell[BoxData[
    \(\(\(strictlyInsideQ[{xMin_, xMax_}, {yMin_, yMax_}]\)[{x_?NumericQ, 
            y_}] := And[xMin < x < xMax, yMin < y < yMax];\)\)], "Input"],

Cell[BoxData[
    \(\(\(strictlyInsideQ[varRange__]\)[pt_] := 
        And @@ \(Less @@@ 
            Transpose@Insert[Transpose[{varRange}], pt, 2]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(weaklyInsideQ[{xMin_, xMax_}, {yMin_, yMax_}]\)[{x_?NumericQ, y_}] := 
        And[xMin \[LessEqual] \ x \[LessEqual] xMax, 
          yMin \[LessEqual] y \[LessEqual] yMax];\)\)], "Input"],

Cell[BoxData[
    \(\(\(weaklyInsideQ[varRange__]\)[pt_] := 
        And @@ \(LessEqual @@@ 
            Transpose@Insert[Transpose[{varRange}], pt, 2]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(weaklyOutsideQ[varRange__]\)[pt_] := 
        Not[\(strictlyInsideQ[varRange]\)[pt]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(strictlyOutsideQ[varRange__]\)[pt_] := 
        Not[\(weaklyInsideQ[varRange]\)[pt]];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Clipping the part of a curve lying outside a rectangle, and then \
placing arrow heads along it:\
\>", "Text"],

Cell[BoxData[
    \(\(clipAndPlaceArrows[gr_, lts__List, inversionCriterion_, 
          arrowDensityParameter_?NonNegative, opts___?OptionQ] := 
        Module[{strOuts, wklIn, adjClosedPaths, provisional, subdivided, 
            clipped, wrongDirectionQ, directedTraj, 
            r}, \[IndentingNewLine]strOuts[a_] := 
            PatternTest[a, 
              Evaluate[strictlyOutsideQ[lts]]]; \[IndentingNewLine]wklIn[a_] := 
            PatternTest[a, 
              Evaluate[
                weaklyInsideQ[
                  lts]]]; \[IndentingNewLine]adjClosedPaths = \(\(gr /. 
                  Line[{a_, b___, a_}] \[RuleDelayed] 
                    provisional[{a, b, a}]\) /. 
                provisional[{a___, strOuts[b_], c___}] \[RuleDelayed] 
                  provisional[{b, c, a}]\) /. 
              provisional \[Rule] Line; \[IndentingNewLine]subdivided = 
            adjClosedPaths //. 
              Line[pts_] \[RuleDelayed] 
                Line[Join[{First[pts]}, 
                    Flatten[
                      Map[addCrossingPoint[#, lts] &, Partition[pts, 2, 1]], 
                      1]]]; \[IndentingNewLine]tst = 
            Or[And[\(strictlyOutsideQ[lts]\)[#1], \(strictlyOutsideQ[
                      lts]\)[#2]], 
                And[\(weaklyInsideQ[lts]\)[#1], \(weaklyInsideQ[
                      lts]\)[#2]]] &; \[IndentingNewLine]clipped = \
\(subdivided /. Line[pts_] \[RuleDelayed] 
                  Map[Line, 
                    Split[pts, tst]]\) /. {Line[{strOuts[__]}] \[RuleDelayed] 
                  Sequence @@ {}, 
                Line[{a_}] \[RuleDelayed] 
                  Sequence @@ {}}; \[IndentingNewLine]r[pts_] /; 
              lineLength[pts] > $MachineEpsilon := \(r[pts] = 
              Ceiling[arrowDensityParameter*\((lineLength[pts]/
                        Sqrt[Apply[Plus, Apply[Subtract, {lts}, 1]^2]] - 
                      1/15)\)]\); \[IndentingNewLine]r[pts_] /; 
              lineLength[pts] \[LessEqual] $MachineEpsilon := 
            1; \[IndentingNewLine]arwShftLngth = \(ArrowShaftLength /. {opts}\
\) /. ArrowShaftLength \[Rule] Automatic; \[IndentingNewLine]arwShftLngth = 
            If[TrueQ[arwShftLngth \[GreaterEqual] 0], 
              arwShftLngth, \(maxLineExcursion[clipped]*
                    Graphics`Arrow`HeadLength /. {opts}\) /. 
                Options[HamiltonianPlot]]; \[IndentingNewLine]clipped /. 
            Line[pts_List] \[RuleDelayed] 
              Sequence @@ {Line[
                    If[TrueQ@inversionCriterion[pts], Reverse@pts, pts]], 
                  insertArrows[pts, 
                    normalizedArrowPositions[Automatic, r[pts]], 
                    ReverseOrientation \[Rule] inversionCriterion[pts], 
                    ArrowShaftLength \[Rule] arwShftLngth, 
                    opts]}];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["The Oriented option for ContourPlot", "Subsubtitle"],

Cell[BoxData[
    \(\(Options[HamiltonianPlot] = {ReverseOrientation \[Rule] False, 
          ShowField \[Rule] False, ArrowDensity \[Rule] 1, 
          Graphics`Arrow`HeadScaling \[Rule] Automatic, 
          Graphics`Arrow`HeadLength \[Rule] 1/20, 
          ArrowShaftLength \[Rule] Automatic, 
          ArrowsAcrossSubdivisions \[Rule] True};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(HamiltonianPlot[
          h_, {x_Symbol, xMin_, xMax_}, {y_Symbol, yMin_, yMax_}, 
          opts___?OptionQ] := 
        Module[{levelData, showFieldQ, arwDnsty, revDirQ, approx, grad, a, b, 
            sympMat, wrongDirectionQ, allTrajs, lateralMargin, 
            topBottomMargin, fld}, \[IndentingNewLine]levelData = 
            ContourPlot[h, {x, xMin, xMax}, {y, yMin, yMax}, 
              DisplayFunction \[Rule] Identity, 
              Evaluate[FilterOptions[ContourPlot, opts]], 
              ContourShading \[Rule] False]; \[IndentingNewLine]{showFieldQ, 
              arwDnsty, 
              revDirQ} = \({ShowField, ArrowDensity, 
                  ReverseOrientation} /. {opts}\) /. 
              Options[HamiltonianPlot]; \[IndentingNewLine]approx = 
            ListInterpolation[
              Transpose[
                levelData[\([1]\)]], {{xMin, xMax}, {yMin, 
                  yMax}}]; \[IndentingNewLine]grad[{a_, b_}] := 
            Through[{\(Derivative[1, 0]\)[approx], \(Derivative[0, 1]\)[
                    approx]}[a, b]]; \[IndentingNewLine]sympMat = {{0, 
                1}, {\(-1\), 0}}; \[IndentingNewLine]wrongDirectionQ[
              pts_List] := \((If[TrueQ[revDirQ], \(-1\), 
                    1]*\(byArcLength[pts]'\)[
                      0] . \((sympMat . grad[First[pts]])\) < 
                0)\); \[IndentingNewLine]allTrajs = 
            clipAndPlaceArrows[
              Graphics[levelData], {xMin, xMax}, {yMin, yMax}, 
              wrongDirectionQ, arwDnsty, opts, 
              Sequence @@ 
                Options[HamiltonianPlot]]; \[IndentingNewLine]{lateralMargin, 
              topBottomMargin} = {xMax - xMin, yMax - yMin}/
              40; \[IndentingNewLine]fld := 
            PlotVectorField[
              sympMat . grad[{a, b}], {a, xMin + lateralMargin, 
                xMax - lateralMargin}, {b, yMin + topBottomMargin, 
                yMax - topBottomMargin}, 
              DisplayFunction \[Rule] 
                Identity]; \[IndentingNewLine]Show[{allTrajs, 
              If[showFieldQ, fld, Sequence @@ {}]}, 
            FilterOptions[Graphics, opts], 
            DisplayFunction \[Rule] $DisplayFunction]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Unprotect[ContourPlot];\)\), "\[IndentingNewLine]", 
    \(\(ContourPlot[h_, {x_Symbol, xMin_, xMax_}, {y_Symbol, yMin_, yMax_}, 
          opts1___?OptionQ, Oriented \[Rule] a_, opts2___?OptionQ, 
          Oriented \[Rule] _, opts3___?OptionQ] := 
        ContourPlot[h, {x, xMin, xMax}, {y, yMin, yMax}, opts1, 
          Oriented \[Rule] a, opts2, opts3];\)\), "\[IndentingNewLine]", 
    \(\(ContourPlot[h_, {x_Symbol, xMin_, xMax_}, {y_Symbol, yMin_, yMax_}, 
          opts1___?OptionQ, Oriented \[Rule] True, opts2___?OptionQ] := 
        HamiltonianPlot[h, {x, xMin, xMax}, {y, yMin, yMax}, opts1, 
          opts2];\)\), "\[IndentingNewLine]", 
    \(\(ContourPlot[h_, {x_Symbol, xMin_, xMax_}, {y_Symbol, yMin_, yMax_}, 
          opts1___?OptionQ, 
          Oriented \[Rule] \((smthg_ /; Not[TrueQ[smthg]])\), 
          opts2___?OptionQ] := 
        ContourPlot[h, {x, xMin, xMax}, {y, yMin, yMax}, opts1, 
          opts2];\)\), "\[IndentingNewLine]", 
    \(\(Protect[ContourPlot];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NDSolvePlot", "Subsubtitle"],

Cell[BoxData[
    \(\(Options[NDSolvePlot] = {PlotStyle \[Rule] Automatic};\)\)], "Input",
  InitializationCell->True],

Cell["The case of a system with two unknown functions:", "Text"],

Cell[BoxData[
    \(\(NDSolvePlot[eqs_, {x1_, x2_}, {t_, tMin_, tMax_}, opts___?OptionQ] := 
        Module[{solRule, sol, f, ortdQ}, \[IndentingNewLine]solRule = 
            NDSolve[eqs, {x1, x2}, {t, tMin, tMax}, 
              FilterOptions[NDSolve, opts]]; \[IndentingNewLine]sol = {x1, 
                x2} /. solRule[\([1]\)]; \[IndentingNewLine]f = 
            If[Head[sol[\([1]\)]] === InterpolatingFunction, Through[sol[t]], 
              sol]; \[IndentingNewLine]ortdQ = 
            TrueQ[\(Oriented /. {opts}\) /. 
                Oriented \[Rule] True]; \[IndentingNewLine]{solRule, 
            ParametricPlot[Evaluate[f], {t, tMin, tMax}, 
              Evaluate[
                FilterOptions[
                  If[ortdQ, OrientedParametricPlot, ParametricPlot], opts, 
                  Oriented \[Rule] True]]]}];\)\)], "Input",
  InitializationCell->True],

Cell["The case of a system with three unknown functions:", "Text"],

Cell[BoxData[
    \(\(NDSolvePlot[eqs_, {x1_, x2_, x3_}, {t_, tMin_, tMax_}, 
          opts___?OptionQ] := 
        Module[{solRule, sol, f, ortdQ}, \[IndentingNewLine]solRule = 
            NDSolve[eqs, {x1, x2, x3}, {t, tMin, tMax}, 
              FilterOptions[NDSolve, opts]]; \[IndentingNewLine]sol = {x1, 
                x2, x3} /. solRule[\([1]\)]; \[IndentingNewLine]ortdQ = 
            TrueQ[\(Oriented /. {opts}\) /. 
                Oriented \[Rule] True]; \[IndentingNewLine]f = 
            If[Head[sol[\([1]\)]] === InterpolatingFunction, Through[sol[t]], 
              sol]; \[IndentingNewLine]{solRule, 
            OrientedParametricPlot3D[Evaluate[f], {t, tMin, tMax}, opts, 
              Oriented \[Rule] True]}];\)\)], "Input",
  InitializationCell->True],

Cell["The case of a single unknown function:", "Text"],

Cell[BoxData[
    \(\(NDSolvePlot[eqs_, x_ /; Head[x] =!= List, {t_, tMin_, tMax_}, 
          opts___?OptionQ] := 
        Module[{solRule, sol, f}, 
          solRule = 
            NDSolve[eqs, x, {t, tMin, tMax}, 
              FilterOptions[NDSolve, opts]]; \[IndentingNewLine]sol = 
            x /. solRule[\([1]\)]; \[IndentingNewLine]f = 
            If[Head[sol] === InterpolatingFunction, sol[t], 
              sol]; \[IndentingNewLine]ortdQ = 
            TrueQ[\(Oriented /. {opts}\) /. 
                Oriented \[Rule] False]; \[IndentingNewLine]{solRule, 
            ParametricPlot[Evaluate[{t, f}], {t, tMin, tMax}, 
              Evaluate[
                FilterOptions[
                  If[ortdQ, OrientedParametricPlot, ParametricPlot], 
                  opts]]]}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NDSolvePlot[eqs_, {x_}, {t_, tMin_, tMax_}, opts___?OptionQ] := 
        NDSolvePlot[eqs, x, {t, tMin, tMax}, opts];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NDSolveDraw[x__] := 
        Block[{$DisplayFunction = Identity, sol, plt}, {sol, plt} = 
            NDSolvePlot[x]; \[IndentingNewLine]{sol, 
            First[plt]}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(\(Unprotect[NDSolve];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(NDSolve[eqs_, x_ /; Head[x] =!= List, {t_, tMin_, tMax_}, 
          opts1___?OptionQ, PlotSolution \[Rule] True, 
          opts2___?OptionQ] := \[IndentingNewLine]NDSolvePlot[eqs, 
          x, {t, tMin, tMax}, opts1, opts2];\)\), "\[IndentingNewLine]", 
    \(\(NDSolve[eqs_, 
          x_List /; 1 \[LessEqual] Length[x] \[LessEqual] 3, {t_, tMin_, 
            tMax_}, opts1___?OptionQ, PlotSolution \[Rule] True, 
          opts2___?OptionQ] := \[IndentingNewLine]NDSolvePlot[eqs, 
          x, {t, tMin, tMax}, opts1, opts2];\)\), "\[IndentingNewLine]", 
    \(\(\(NDSolve[eqs_, x_, t_List, opts1___?OptionQ, 
          PlotSolution \[Rule] value /; Not@TrueQ[value], opts2___?OptionQ] := 
        NDSolve[eqs, x, t, opts1, opts2];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(NDSolve[eqs_, x_ /; Head[x] =!= List, {t_, tMin_, tMax_}, 
          opts1___?OptionQ, DrawSolution \[Rule] True, 
          opts2___?OptionQ] := \[IndentingNewLine]NDSolveDraw[eqs, 
          x, {t, tMin, tMax}, opts1, opts2];\)\), "\[IndentingNewLine]", 
    \(\(NDSolve[eqs_, 
          x_List /; 1 \[LessEqual] Length[x] \[LessEqual] 3, {t_, tMin_, 
            tMax_}, opts1___?OptionQ, DrawSolution \[Rule] True, 
          opts2___?OptionQ] := \[IndentingNewLine]NDSolveDraw[eqs, 
          x, {t, tMin, tMax}, opts1, opts2];\)\), "\[IndentingNewLine]", 
    \(\(\(NDSolve[eqs_, x_, t_List, opts1___?OptionQ, 
          DrawSolution \[Rule] value /; Not@TrueQ[value], opts2___?OptionQ] := 
        NDSolve[eqs, x, t, opts1, opts2];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Protect[NDSolve];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PhasePlot", "Subsubtitle"],

Cell[BoxData[
    \(\(Options[PhasePlot] = {GridPoints \[Rule] 5, 
          InitialPoints \[Rule] Automatic, OrientedCurve \[Rule] True, 
          Frame \[Rule] True, \ ArrowDensity \[Rule] 1, 
          ShowField \[Rule] False, 
          Graphics`Arrow`HeadScaling \[Rule] Automatic, 
          Graphics`Arrow`HeadLength \[Rule] 1/20, 
          DrawGraphics`DrawingArrows`HeadScaling3D \[Rule] Automatic, 
          DrawGraphics`DrawingArrows`HeadLength3D \[Rule] 1/20, 
          PlotStyle \[Rule] Automatic, ColorFunctionScaling \[Rule] True, 
          ShowListPlot \[Rule] False, ListPlotStyle \[Rule] PointSize[ .02], 
          Arrow3DColor \[Rule] Automatic};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PhasePlot::"\<BadPlotPoints\>" = "\<Bad PlotPoints\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(PhasePlot[{{xComponent_}, {yComponent_}}, \
\[IndentingNewLine]{x_Symbol, xMin_?NumericQ, 
            xMax_?NumericQ}, \[IndentingNewLine]{y_Symbol, yMin_?NumericQ, 
            yMax_?NumericQ}, \[IndentingNewLine]{tMin_?NonPositive, 
            tMax_?NonNegative}, \[IndentingNewLine]opts___?
            OptionQ] := \[IndentingNewLine]PhasePlot[{xComponent, 
            yComponent}, {x, xMin, xMax}, {y, yMin, yMax}, {tMin, tMax}, 
          opts];\)\), "\[IndentingNewLine]", 
    \(\(PhasePlot[{{xComponent_}, {yComponent_}, {zComponent_}}, \
\[IndentingNewLine]{x_Symbol, xMin_?NumericQ, 
            xMax_?NumericQ}, \[IndentingNewLine]{y_Symbol, yMin_?NumericQ, 
            yMax_?NumericQ}, \[IndentingNewLine]{z_Symbol, zMin_?NumericQ, 
            zMax_?NumericQ}, \[IndentingNewLine]{tMin_?NonPositive, 
            tMax_?NonNegative}, \[IndentingNewLine]opts___?
            OptionQ] := \[IndentingNewLine]PhasePlot[{xComponent, yComponent, 
            zComponent}, {x, xMin, xMax}, {y, yMin, yMax}, {z, zMin, 
            zMax}, {tMin, tMax}, opts];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PhasePlot[field_List /; Head[field[\([1]\)]] =!= List, 
            variableLimits : {_Symbol, _?NumericQ, _?NumericQ} ..  /; 
              And @@ Map[Less @@ Rest[#] &, {variableLimits}], {tMin_?
                NonPositive, tMax_?NonNegative}, opts___?OptionQ] /; 
          2 \[LessEqual] Length[field] === 
            Length[{variableLimits}] \[LessEqual] 3 := 
        Module[{dim, var, lmts, howManyPts, shwArrsQ, arwDnsty, colorSclng, 
            arwColor, shwLstPlt, lstPltSty, margins, pts, intlPts, strtPts, 
            eq, t, u, v, w, x0, sol, allSols, hdscl3D, allTrajs, 
            gr}, \[IndentingNewLine]dim = 
            Length[field]; \[IndentingNewLine]var = {variableLimits}[\([All, 
                1]\)]; \[IndentingNewLine]lmts = 
            Map[Rest, {variableLimits}]; \[IndentingNewLine]{howManyPts, 
              intlPts, shwArrsQ, arwDnsty, sty, colorSclng, arwColor, 
              shwLstPlt, 
              lstPltSty} = \({GridPoints, InitialPoints, OrientedCurve, 
                  ArrowDensity, PlotStyle, ColorFunctionScaling, 
                  Arrow3DColor, ShowListPlot, ListPlotStyle} /. {opts}\) /. 
              Options[PhasePlot]; \[IndentingNewLine]margins = \(-Subtract @@@ 
                  lmts\)/40; \[IndentingNewLine]pts = 
            Which[\[IndentingNewLine]MatchQ[howManyPts, 
                l : {__Integer?\((# \[GreaterEqual] 2 &)\)} /; 
                  Length[l] \[Equal] dim], 
              howManyPts, \[IndentingNewLine]MatchQ[
                howManyPts, _Integer?\((# \[GreaterEqual] 2 &)\)], 
              Table[howManyPts, {dim}], \[IndentingNewLine]True, 
              Message[PhasePlot::BadPlotPoints]; 
              Abort[]]; \[IndentingNewLine]strtPts = 
            If[\[IndentingNewLine]intlPts === Automatic, 
              Flatten[Outer[
                  List, \[IndentingNewLine]Sequence @@ \((Apply[
                        Range[#1, #2, \((#2 - #1)\)/\((#3 - 1)\)] &, 
                        Transpose[
                          Append[Transpose[lmts] + {margins, \(-margins\)}, 
                            pts]], 1])\)], 
                dim - 1], \[IndentingNewLine]intlPts]; \
\[IndentingNewLine]scaledStrtPts := 
            Map[\((# - lmts[\([All, 1]\)])\)/\((lmts[\([All, 2]\)] - 
                        lmts[\([All, 1]\)])\) &, strtPts] /. 
              x_?NumericQ \[RuleDelayed] 
                Min[Max[x, 0], 1]; \[IndentingNewLine]Which[
            sty === Automatic, 
            sty = {{}}, \[IndentingNewLine]Or[Head[sty] === Function, 
              dim === 3 && MemberQ[{CMYColor, RGBColor}, sty]], 
            sty = Apply[Flatten[{sty[##]}] &, 
                If[TrueQ@colorSclng, scaledStrtPts, strtPts], 
                1], \[IndentingNewLine]Not@MatchQ[sty, {__List}], 
            sty = {sty}]; \[IndentingNewLine]If[
            dim === 3, \[IndentingNewLine]Which[arwColor === Automatic, 
              sty = sty /. \((col : colorSpecPattern)\) \[RuleDelayed] 
                    Sequence @@ {col, 
                        SurfaceColor[col]}, \[IndentingNewLine]Or[
                Head[arwColor] === Function, 
                MemberQ[{CMYColor, RGBColor}, arwColor]], 
              arwColor = 
                Apply[SurfaceColor[arwColor[##]] &, 
                  If[TrueQ@colorSclng, scaledStrtPts, strtPts], 
                  1], \[IndentingNewLine]Not@MatchQ[arwColor, {__List}], 
              arwColor = {arwColor}]]; \[IndentingNewLine]If[
            arwColor =!= Automatic, 
            arwColor = 
              arwColor /. \((col : colorSpecPattern)\) \[RuleDelayed] 
                  SurfaceColor[col]]; \[IndentingNewLine]Which[
            lstPltSty === Automatic, 
            lstPltSty = {{}}, \[IndentingNewLine]Or[
              Head[lstPltSty] === Function, 
              dim === 3 && MemberQ[{CMYColor, RGBColor}, lstPltSty]], 
            lstPltSty = 
              lstPltSty @@@ 
                If[TrueQ@colorSclng, scaledStrtPts, 
                  strtPts], \[IndentingNewLine]Not@
              MatchQ[lstPltSty, {__List}], 
            lstPltSty = {lstPltSty}]; \[IndentingNewLine]lstPlt := 
            MapIndexed[
                Flatten@{cyclicPart[sty, #2], cyclicPart[lstPltSty, #2], 
                      Point[#1]} &, strtPts] /. 
              Automatic \[RuleDelayed] Sequence @@ {}; \[IndentingNewLine]eq[
              x0_List, {i_Integer}] := {Flatten[{Thread[
                      Take[{\(u'\)[t], \(v'\)[t], \(w'\)[t]}, dim] \[Equal] 
                        field] /. 
                    Thread[var \[Rule] Take[{u[t], v[t], w[t]}, dim]], 
                  Thread[Take[{u[0], v[0], w[0]}, dim] \[Equal] x0]}], 
              Take[{u, v, w}, dim], {t, tMin, tMax}, HowManyArrows \[Rule] 0, 
              DisplayFunction \[Rule] Identity, 
              PlotStyle \[Rule] 
                If[Or[dim === 2, arwColor === Automatic], cyclicPart[sty, i], 
                  Flatten[{cyclicPart[sty, i], cyclicPart[arwColor, i]}]], 
              opts}; \[IndentingNewLine]sol[x0_List, {i_Integer}] := 
            joinChain[\(Apply[NDSolvePlot, eq[x0, {i}]]\)[\([2, 
                    1]\)] /. {} \[Rule] 
                  Sequence @@ {}]; \[IndentingNewLine]allSols = 
            MapIndexed[sol, strtPts] /. 
              Automatic \[RuleDelayed] 
                Sequence @@ {}; \[IndentingNewLine]hdscl3D = 
            automaticHeadScaling3D[Line[lmts // Transpose], opts, 
              Sequence @@ 
                Options[
                  OrientedParametricPlot3D]]; \[IndentingNewLine]allTrajs = 
            If[shwArrsQ, 
              clipAndPlaceArrows[allSols, Sequence @@ lmts, False &, 
                arwDnsty, Arrow3DColor \[Rule] None, 
                Sequence @@ DeleteCases[{opts}, PlotStyle \[Rule] _], 
                hdscl3D, Sequence @@ Options[PhasePlot]], 
              allSols]; \[IndentingNewLine]gr = 
            If[dim \[Equal] 2, Graphics, 
              Graphics3D]; \[IndentingNewLine]Show[{gr[
                If[dim \[Equal] 2, 
                  allTrajs, {SurfaceColor[GrayLevel[0]], allTrajs}]], 
              If[TrueQ@shwLstPlt, gr[lstPlt], Sequence @@ {}]}, 
            FilterOptions[gr, opts], PlotRange \[Rule] lmts, 
            FilterOptions[gr, Sequence @@ Options[PhasePlot]]]];\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(PhaseDraw[field_List, 
            variableLimits : {_Symbol, _?NumericQ, _?NumericQ} ..  /; 
              And @@ Map[Less @@ Rest[#] &, {variableLimits}], {tMin_?
                NonPositive, tMax_?NonNegative}, opts___?OptionQ] /; 
          2 \[LessEqual] Length[field] === 
            Length[{variableLimits}] \[LessEqual] 3 := \(PhasePlot[field, 
            variableLimits, {tMin, tMax}, DisplayFunction \[Rule] Identity, 
            opts]\)[\([1]\)];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["LinearPhasePlot2D", "Subsubtitle"],

Cell[CellGroupData[{

Cell["LinearPhasePlot2D basic tests", "Section"],

Cell["Error messages when a bad matrix is given:", "Text"],

Cell[BoxData[
    \(\(admissibleMatrixQ::"\<notMatrix\>" = "\<Not a 2 by 2 matrix\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(admissibleMatrixQ::"\<nonNumeric\>" = "\<Not a numeric \
matrix\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(admissibleMatrixQ::"\<complex\>" = "\<Complex matrix\>";\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(admissibleMatrixQ::"\<inexactMatrix\>" = "\<Not an exact numeric \
matrix\>";\)\)], "Input",
  InitializationCell->True],

Cell["Determining whether the given matrix is good:", "Text"],

Cell[BoxData[
    \(\(admissibleMatrixQ[mat_?MatrixQ] := \(admissibleMatrixQ[mat] = 
          And[\[IndentingNewLine]If[
              MatrixQ[mat] && Length[mat] === 2 && TensorRank[mat] === 2, 
              True, Message[admissibleMatrixQ::"\<notMatrix\>"]; 
              False], \[IndentingNewLine]If[
              And @@ Map[NumericQ, Flatten[mat]], True, 
              Message[admissibleMatrixQ::"\<nonNumeric\>"]; 
              False], \[IndentingNewLine]If[
              And @@ Map[FreeQ[Chop[N[#]], Complex] &, Flatten[mat]], True, 
              Message[admissibleMatrixQ::"\<complex\>"]; False], 
            If[Precision[mat] === Infinity, True, 
              Message[admissibleMatrixQ::"\<inexactMatrix\>"]; 
              False]]\);\)\)], "Input",
  InitializationCell->True],

Cell["The simplest matrix structure tests:", "Text"],

Cell[BoxData[
    \(\(diagonalQ[mat_?MatrixQ] := 
        Simplify[mat[\([1, 2]\)]] === 0 && 
          Simplify[mat[\([2, 1]\)]] === 0;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(nonNullQ[mat_] := 
        Apply[Or, Map[# =!= 0 &, Simplify[Flatten[{mat}]]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(nullMatrixQ[mat_] := 
        Union[Flatten[Simplify[mat]]] === {0};\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["LinearPhasePlot2D basic matrix functions", "Section"],

Cell[TextData[{
  "The trace of a matrix requires to test what ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " version is running:"
}], "Text"],

Cell[BoxData[
    \(\(matrixTrace = 
        If[$VersionNumber < 4, \((#[\([1, 1]\)] + #[\([2, 2]\)])\) &, 
          Tr];\)\)], "Input",
  InitializationCell->True],

Cell["The discriminant of a 2 by 2 real matrix:", "Text"],

Cell[BoxData[
    \(\(discriminant[mat_] := 
        Simplify[matrixTrace[mat]^2 - 4  Det[mat]];\)\)], "Input",
  InitializationCell->True],

Cell["The real canonical form of a real 2 by 2 matrix:", "Text"],

Cell[BoxData[
    \(\(realCanonicalForm[mat_ /; discriminant[mat] \[GreaterEqual] 0] := 
        JordanDecomposition[m];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(realCanonicalForm[mat_ /; discriminant[mat] < 0] := 
        Module[{complexSim, complexJordan, 
            realSim}, \[IndentingNewLine]{complexSim, complexJordan} = 
            JordanDecomposition[mat]; \[IndentingNewLine]realSim = 
            Transpose[\({Re[#], Im[#]} &\)[\(complexSim // Transpose\) // 
                  First]]; \[IndentingNewLine]{realSim, 
            Inverse[realSim] . mat . realSim}];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["LinearPhasePlot2D spectral analysis", "Section"],

Cell["The spectral classification of 2 by 2 matrices:", "Text"],

Cell[BoxData[
    \(\(saddleQ[mat_?admissibleMatrixQ] := 
        discriminant[mat] > 0 && Simplify[Det[mat]] < 0;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(nodeQ[mat_?admissibleMatrixQ] := 
        discriminant[mat] > 0 && Simplify[Det[mat]] > 0;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(singularDistinctEigenvaluesQ[mat_?admissibleMatrixQ] := 
        discriminant[mat] > 0 && Simplify[Det[mat]] === 0;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(improperNodeQ[mat_?admissibleMatrixQ] := 
        discriminant[mat] === 0 && 
          Simplify[matrixTrace[mat]] =!= 
            0 && \(! diagonalQ[mat]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(nonNullMultipleOfIdentity[mat_?admissibleMatrixQ] := 
        discriminant[mat] === 0 && diagonalQ[mat] && 
          nonNullQ[mat];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(nonNullNilpotentQ[mat_?admissibleMatrixQ] := 
        discriminant[mat] === 0 && Simplify[matrixTrace[mat]] === 0 && 
          nonNullQ[mat];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(centerQ[mat_?admissibleMatrixQ] := 
        discriminant[mat] < 0 && 
          Simplify[matrixTrace[mat]] === 0;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(spiralQ[mat_?admissibleMatrixQ] := 
        discriminant[mat] < 0 && 
          Simplify[matrixTrace[mat]] =!= 0;\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["LinearPhasePlot2D main", "Section"],

Cell[CellGroupData[{

Cell["preamble", "Subsection",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \(\(Options[
          LinearPhasePlot2D] = {PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}}, 
          AspectRatio \[Rule] Automatic, Frame \[Rule] True, 
          FrameTicks \[Rule] {{0}, {0}}, 
          NotableLineStyle \[Rule] RGBColor[1, 0, 0], 
          NumberOfTrajectories \[Rule] 5, WriteReport \[Rule] True, 
          ShowField \[Rule] False, Oriented \[Rule] True, \ 
          ArrowDensity \[Rule] 1, 
          ArrowsAcrossSubdivisions \[Rule] True};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(inverseRange[s_?MatrixQ] := 
        Map[Max, 
          Inverse[s] . {{1, \(-1\), \(-1\), 1}, {1, 
                1, \(-1\), \(-1\)}}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(equil = {PointSize[ .03], Point[{0, 0}], GrayLevel[1], 
          PointSize[ .02], Point[{0, 0}]};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(\(wrongDirectionQ[mat_?MatrixQ]\)[{pt1_List, 
            pt2_, ___}] := \((\((pt2 - pt1)\) . \((mat . \((pt1 + pt2)\)/
                  2)\) < 0)\);\)\(\[IndentingNewLine]\)
    \)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Node (two nonvanishing real eigenvalues of the same sign)", "Subsection",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \(\(LinearPhasePlot2D[mat_?nodeQ, opts___Rule] := 
        Module[{sim, diag, \[Lambda]1, \[Lambda]2, wrtRptQ, shwFldQ, 
            shwArrsQ, arwDnsty, n, style, fld, xmax, ymax, sol, vert, orizz, 
            r, coeffList, basicTrajs, 
            allTrajs}, \[IndentingNewLine]{sim, diag} = 
            JordanDecomposition[
              mat]; \[IndentingNewLine]{\[Lambda]1, \[Lambda]2} = 
            Transpose[diag, {1, 1}]; \[IndentingNewLine]{wrtRptQ, shwFldQ, 
              shwArrsQ, arwDnsty, n, 
              style} = \({WriteReport, ShowField, Oriented, \ ArrowDensity, 
                  NumberOfTrajectories + 1, NotableLineStyle} /. {opts}\) /. 
              Options[LinearPhasePlot2D]; \[IndentingNewLine]If[wrtRptQ, 
            Print[If[\[Lambda]1 > 
                    0, "\<Repulsive\>", "\<Attractive\>"] <> "\< node\>"], 
            Null]; \[IndentingNewLine]fld := 
            PlotVectorField[
              mat . {x, y}, {x, \(- .9\),  .9}, {y, \(- .9\),  .9}, 
              DisplayFunction \[Rule] Identity]; \[IndentingNewLine]{xmax, 
              ymax} = N[inverseRange[sim]]; \[IndentingNewLine]sol[c_] := 
            Map[N[sim] . # &, \(Plot[c*Abs[x]^\((\[Lambda]2/\[Lambda]1)\), 
                    Evaluate[{x, \(-Min[xmax, r]\), Min[xmax, r]} /. 
                        r \[RuleDelayed] \((ymax/
                                Abs[c])\)^\((\[Lambda]1/\[Lambda]2)\)], 
                    DisplayFunction \[Rule] Identity]\)[\([1, 1, 1]\)] /. 
                Line[{a___, {x1_?NonPositive, y1_}, {x2_?NonNegative, y2_}, 
                      b___}] \[RuleDelayed] {Line[{a, {x1, y1}, {0, 0}}], 
                    Line[{{0, 0}, {x2, y2}, 
                        b}]}, {3}]; \[IndentingNewLine]vert = {style, 
                Map[N[sim] . # &, {Line[{{0, \(-ymax\)}, \(-{0, 0}\)/10^3}], 
                    Line[{{0, 0}/10^3, {0, ymax}}]}, {3}]} // 
              Flatten; \[IndentingNewLine]orizz = {style, 
                Map[N[sim] . # &, {Line[{{\(-xmax\), 0}, { .01,  .01}}], 
                    Line[{{0, 0}/10^3, {xmax, 0}}]}, {3}]} // 
              Flatten; \[IndentingNewLine]coeffList = \(Join[#, \(-#\)] &\)[
              Table[\((1 - r)\)*
                  ymax/\((r*xmax)\)^\((\[Lambda]2/\[Lambda]1)\), {r, 1/n, 
                  1 - 1/n, 1/n}]]; \[IndentingNewLine]basicTrajs = {Map[sol, 
                coeffList], vert, orizz, 
              equil}; \[IndentingNewLine]allTrajs = 
            If[shwArrsQ, 
              clipAndPlaceArrows[basicTrajs, {\(-1\), 1}, {\(-1\), 1}, 
                wrongDirectionQ[mat], arwDnsty, opts], 
              basicTrajs]; \[IndentingNewLine]Show[{If[shwFldQ, fld, 
                Sequence @@ {}], Graphics[allTrajs]}, 
            PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}}, 
            FilterOptions[Plot, opts], 
            FilterOptions[Plot, Options[LinearPhasePlot2D]], 
            DisplayFunction \[Rule] $DisplayFunction]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Saddle (two nonvanishing real eigenvalues with opposite \
signs)\
\>", "Subsection",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \(\(LinearPhasePlot2D[mat_?saddleQ, opts___Rule] := 
        Module[{sim, diag, \[Lambda]1, \[Lambda]2, wrtRptQ, shwFldQ, 
            shwArrsQ, arwDnsty, n, style, fld, xmax, ymax, sol0, sol, 
            coeffList, vert, orizz, basicTrajs, 
            allTrajs}, \[IndentingNewLine]{sim, diag} = 
            JordanDecomposition[
              mat]; \[IndentingNewLine]{\[Lambda]1, \[Lambda]2} = {diag[\([1, 
                  1]\)], diag[\([2, 2]\)]}; \[IndentingNewLine]{wrtRptQ, 
              shwFldQ, shwArrsQ, arwDnsty, n, 
              style} = \({WriteReport, ShowField, Oriented, \ ArrowDensity, 
                  NumberOfTrajectories + 1, NotableLineStyle} /. {opts}\) /. 
              Options[LinearPhasePlot2D]; \[IndentingNewLine]If[wrtRptQ, 
            Print["\<Saddle\>"], Null]; \[IndentingNewLine]fld := 
            PlotVectorField[
              mat . {x, y}, {x, \(- .9\),  .9}, {y, \(- .9\),  .9}, 
              DisplayFunction \[Rule] Identity]; \[IndentingNewLine]{xmax, 
              ymax} = N[inverseRange[sim]]; \[IndentingNewLine]sol0[
              c_] := \(Plot[c*Abs[x]^\((\[Lambda]2/\[Lambda]1)\), 
                Evaluate[{x, Abs[ymax/c]^\((\[Lambda]1/\[Lambda]2)\), 
                    Min[xmax, 1]}], DisplayFunction \[Rule] Identity]\)[\([1, 
                1, 1]\)]; \[IndentingNewLine]sol[
              c_] := {Map[N[sim] . # &, sol0[c], {2}], 
              Map[N[sim] . {{\(-1\), 0}, {0, 1}} . # &, 
                sol0[c], {2}]}; \[IndentingNewLine]coeffList = \(Join[#, \(-#\
\)] &\)[Table[r*ymax/\((r*xmax)\)^\((\[Lambda]2/\[Lambda]1)\), {r, 1/n, 
                  1 - 1/n, 1/n}]]; \[IndentingNewLine]vert = {style, 
                Map[N[sim] . # &, {Line[{{0, \(-ymax\)}, {0, 0}}], 
                    Line[{{0, 0}, {0, ymax}}]}, {3}]} // 
              Flatten; \[IndentingNewLine]orizz = {style, 
                Map[N[sim] . # &, {Line[{{\(-xmax\), 0}, {0, 0}}], 
                    Line[{{0, 0}, {xmax, 0}}]}, {3}]} // 
              Flatten; \[IndentingNewLine]basicTrajs = {Map[sol, coeffList], 
              vert, orizz, equil}; \[IndentingNewLine]allTrajs = 
            If[shwArrsQ, 
              clipAndPlaceArrows[basicTrajs, {\(-1\), 1}, {\(-1\), 1}, 
                wrongDirectionQ[mat], arwDnsty, opts], basicTrajs]; 
          Show[{If[shwFldQ, fld, Sequence @@ {}], Graphics[allTrajs]}, 
            PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}}, 
            FilterOptions[Plot, opts], 
            FilterOptions[Plot, Options[LinearPhasePlot2D]], 
            DisplayFunction \[Rule] $DisplayFunction]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Two distinct real eigenvalues, one vanishing", "Subsection",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \(\(LinearPhasePlot2D[mat_?singularDistinctEigenvaluesQ, 
          opts___?OptionQ] := 
        Module[{sim, canon, \[Lambda], wrtRptQ, shwFldQ, shwArrsQ, arwDnsty, 
            n, style, fld, trasf, xmax, ymax, sol, vert, coeffList, 
            basicTrajs, allTrajs}, \[IndentingNewLine]{sim, canon} = 
            JordanDecomposition[
              mat]; \[IndentingNewLine]\[Lambda] = \(Select[
                Flatten[canon], # =!= 0 &, 
                1]\)[\([1]\)]; \[IndentingNewLine]{wrtRptQ, shwFldQ, 
              shwArrsQ, arwDnsty, n, 
              style} = \({WriteReport, ShowField, Oriented, \ ArrowDensity, 
                  NumberOfTrajectories, NotableLineStyle} /. {opts}\) /. 
              Options[LinearPhasePlot2D]; \[IndentingNewLine]If[wrtRptQ, 
            Print["\<One null eigenvalue, the other one \>" <> 
                If[\[Lambda] > 0, "\<positive\>", "\<negative\>"]], 
            Null]; \[IndentingNewLine]fld := 
            PlotVectorField[
              mat . {x, y}, {x, \(- .9\),  .9}, {y, \(- .9\),  .9}, 
              DisplayFunction \[Rule] Identity]; \[IndentingNewLine]trasf = 
            N[sim] . 
                If[canon[\([1, 1]\)] === \[Lambda], 
                  IdentityMatrix[
                    2], {{0, 1}, {1, 0}}] . # &; \[IndentingNewLine]{xmax, 
              ymax} = N[inverseRange[sim]]; \[IndentingNewLine]sol[c_] := 
            Map[trasf, {Line[{{\(-xmax\), c}, {0, c}}], 
                Line[{{0, c}, {xmax, 
                      c}}]}, {3}]; \[IndentingNewLine]vert = {{GrayLevel[1], 
                Thickness[ .04], 
                Line[trasf /@ {{0, \(-ymax\)}, {0, ymax}}]}, {RGBColor[1, 0, 
                    0], Dashing[{ .02,  .02}], Thickness[ .01], style, 
                  Line[trasf /@ {{0, \(-ymax\)}, {0, ymax}}]} // 
                Flatten}; \[IndentingNewLine]coeffList = 
            ymax*Range[\(-n\), n]/n; \[IndentingNewLine]basicTrajs = 
            Map[sol, coeffList]; \[IndentingNewLine]allTrajs = 
            If[shwArrsQ, 
              clipAndPlaceArrows[basicTrajs, {\(-1\), 1}, {\(-1\), 1}, 
                wrongDirectionQ[mat], arwDnsty, opts], basicTrajs]; 
          Show[{If[shwFldQ, fld, Sequence @@ {}], 
              Graphics[{allTrajs, vert, equil}]}, 
            PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}}, 
            FilterOptions[Plot, opts], 
            FilterOptions[Plot, Options[LinearPhasePlot2D]], 
            DisplayFunction \[Rule] $DisplayFunction]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Improper node (two real coincident eigenvalues, but the matrix is \
not diagonal)\
\>", "Subsection",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \(\(LinearPhasePlot2D[mat_?improperNodeQ, opts___Rule] := 
        Module[{sim, canon, \[Lambda], wrtRptQ, shwFldQ, shwArrsQ, arwDnsty, 
            n, style, fld, xmax, ymax, sol, u, coeffList, orizz, basicTrajs, 
            allTrajs}, \[IndentingNewLine]{sim, canon} = 
            N[JordanDecomposition[mat]]; \[IndentingNewLine]\[Lambda] = 
            canon[\([1, 1]\)]; \[IndentingNewLine]{wrtRptQ, shwFldQ, 
              shwArrsQ, arwDnsty, n, 
              style} = \({WriteReport, ShowField, Oriented, \ ArrowDensity, 
                  2  NumberOfTrajectories, NotableLineStyle} /. {opts}\) /. 
              Options[LinearPhasePlot2D]; \[IndentingNewLine]If[wrtRptQ, 
            Print[If[\[Lambda] > 
                    0, "\<Repulsive\>", "\<Attractive\>"] <> "\< improper \
node\>"], Null]; \[IndentingNewLine]fld := 
            PlotVectorField[
              mat . {x, y}, {x, \(- .9\),  .9}, {y, \(- .9\),  .9}, 
              DisplayFunction \[Rule] Identity]; \[IndentingNewLine]{xmax, 
              ymax} = N[inverseRange[sim]]; \[IndentingNewLine]sol[c_] := 
            Map[N[sim] . 
                  Reverse[#] &, \(Plot[
                    c*y + y*
                        Log[Max[
                              Abs[y],  .000001  
                                ymax]]/\[Lambda], {y, \(-ymax\), ymax}, 
                    DisplayFunction \[Rule] Identity]\)[\([1, 1, 1]\)] /. 
                Line[{a___, {y1_?NonPositive, x1_}, {y2_?NonNegative, x2_}, 
                      b___}] \[RuleDelayed] {Line[{a, {y1, x1}, {0, 0}}], 
                    Line[{{0, 0}, {y2, x2}, 
                        b}]}, {3}]; \[IndentingNewLine]u = 
            Min[xmax, ymax]; \[IndentingNewLine]coeffList = 
            Table[\((Sin[r]*u - Cos[r]*u*Log[Cos[r]*u]/\[Lambda])\)/\((Cos[r]*
                    u)\), {r, \(-Pi\)/2 + Pi/n, Pi/2 - Pi/n, 
                Pi/n}]; \[IndentingNewLine]orizz = {style, 
                Map[N[sim] . # &, {Line[{{\(-xmax\), 0}, {0, 0}}], 
                    Line[{{0, 0}, {xmax, 0}}]}, {3}]} // 
              Flatten; \[IndentingNewLine]basicTrajs = {Map[sol, coeffList], 
              orizz, equil}; \[IndentingNewLine]allTrajs = 
            If[shwArrsQ, 
              clipAndPlaceArrows[basicTrajs, {\(-1\), 1}, {\(-1\), 1}, 
                wrongDirectionQ[mat], arwDnsty, opts], basicTrajs]; 
          Show[{If[shwFldQ, fld, Sequence @@ {}], Graphics[allTrajs]}, 
            PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}}, 
            FilterOptions[Plot, opts], 
            FilterOptions[Plot, Options[LinearPhasePlot2D]], 
            DisplayFunction \[Rule] $DisplayFunction]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Nonvanishing multiple of the identity matrix", "Subsection",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \(\(LinearPhasePlot2D[mat_?nonNullMultipleOfIdentity, opts___Rule] := 
        Module[{\[Lambda], wrtRptQ, shwFldQ, shwArrsQ, arwDnsty, n, fld, sol, 
            coeffList, basicTrajs, allTrajs}, \[IndentingNewLine]\[Lambda] = 
            mat[\([1, 1]\)]; \[IndentingNewLine]{wrtRptQ, shwFldQ, shwArrsQ, 
              arwDnsty, 
              n} = \({WriteReport, ShowField, Oriented, \ ArrowDensity, 
                  NumberOfTrajectories} /. {opts}\) /. 
              Options[LinearPhasePlot2D]; \[IndentingNewLine]If[wrtRptQ, 
            Print[If[\[Lambda] > 
                    0, "\<Repulsive\>", "\<Attractive\>"] <> "\< node with \
coincident eigenvalues\>"]]; \[IndentingNewLine]fld := 
            PlotVectorField[
              mat . {x, y}, {x, \(- .9\),  .9}, {y, \(- .9\),  .9}, 
              DisplayFunction \[Rule] Identity]; \[IndentingNewLine]sol[
              c_] := {Line[2 {\(-{Cos[c], Sin[c]}\), {0, 0}}], 
              Line[2 {{0, 0}, {Cos[c], 
                      Sin[c]}}]}; \[IndentingNewLine]coeffList = 
            N[Pi*Range[
                    2  n]/\((2  n)\)]; \[IndentingNewLine]basicTrajs = {Map[
                sol, coeffList], equil}; \[IndentingNewLine]allTrajs = 
            If[shwArrsQ, 
              clipAndPlaceArrows[basicTrajs, {\(-1\), 1}, {\(-1\), 1}, 
                wrongDirectionQ[mat], arwDnsty, opts], basicTrajs]; 
          Show[{If[shwFldQ, fld, Sequence @@ {}], Graphics[allTrajs]}, 
            PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}}, 
            FilterOptions[Plot, opts], 
            FilterOptions[Plot, Options[LinearPhasePlot2D]], 
            DisplayFunction \[Rule] $DisplayFunction]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Two null eigenvalues but the matrix is not null", "Subsection",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \(\(LinearPhasePlot2D[mat_?nonNullNilpotentQ, opts___Rule] := 
        Module[{sim, canon, xmax, ymax, wrtRptQ, shwFldQ, shwArrsQ, arwDnsty, 
            n, style, fld, sol, orizz, provisional, coeffList, basicTrajs, 
            allTrajs}, \[IndentingNewLine]{sim, canon} = 
            JordanDecomposition[mat]; \[IndentingNewLine]{xmax, ymax} = 
            N[inverseRange[sim]]; \[IndentingNewLine]{wrtRptQ, shwFldQ, 
              shwArrsQ, arwDnsty, n, 
              style} = \({WriteReport, ShowField, Oriented, \ ArrowDensity, 
                  NumberOfTrajectories, NotableLineStyle} /. {opts}\) /. 
              Options[LinearPhasePlot2D]; \[IndentingNewLine]If[wrtRptQ, 
            Print["\<Two null eigenvalues\>"], Null]; \[IndentingNewLine]fld := 
            PlotVectorField[
              mat . {x, y}, {x, \(- .9\),  .9}, {y, \(- .9\),  .9}, 
              DisplayFunction \[Rule] Identity]; \[IndentingNewLine]sol[c_] := 
            Map[N[sim] . # &, {Line[{{\(-xmax\), c}, {0, c}}], 
                Line[{{0, c}, {xmax, 
                      c}}]}, {3}]; \[IndentingNewLine]orizz = {{GrayLevel[1], 
                Thickness[ .04], 
                provisional[\((N[sim] . # &)\) /@ {{\(-xmax\), 0}, {xmax, 
                        0}}]}, {RGBColor[1, 0, 0], Dashing[{ .02,  .02}], 
                  Thickness[ .01], style, 
                  provisional[\((N[sim] . # &)\) /@ {{\(-xmax\), 0}, {xmax, 
                          0}}]} // Flatten}; \[IndentingNewLine]coeffList = 
            ymax*Complement[Range[\(-n\), n], {0}]/
                n; \[IndentingNewLine]basicTrajs = {Map[sol, coeffList], 
              orizz, equil}; \[IndentingNewLine]allTrajs = 
            If[shwArrsQ, 
                clipAndPlaceArrows[basicTrajs, {\(-1\), 1}, {\(-1\), 1}, 
                  wrongDirectionQ[mat], arwDnsty, opts], basicTrajs] /. 
              provisional \[Rule] Line; 
          Show[{If[shwFldQ, fld, Sequence @@ {}], Graphics[allTrajs]}, 
            PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}}, 
            FilterOptions[Plot, opts], 
            FilterOptions[Plot, Options[LinearPhasePlot2D]], 
            DisplayFunction \[Rule] $DisplayFunction]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Null matrix", "Subsection",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \(\(LinearPhasePlot2D[mat_?nullMatrixQ, 
          opts___Rule] := \[IndentingNewLine]Show[Graphics[equil], 
          PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}}, 
          FilterOptions[Plot, 
            opts], \[IndentingNewLine]If[\(WriteReport /. {opts}\) /. 
              Options[LinearPhasePlot2D], Print["\<Null matrix\>"], 
            Null]; \[IndentingNewLine]FilterOptions[Plot, 
            Options[LinearPhasePlot2D]], 
          DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Center (purely imaginary conjugated eigenvalues)", "Subsection",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \(\(LinearPhasePlot2D[mat_?centerQ, opts___Rule] := 
        Module[{sim, canon, xmax, ymax, wrtRptQ, shwFldQ, shwArrsQ, arwDnsty, 
            n, style, fld, symAxes, \[Theta]0, unitCirc, sol, coeffList, 
            basicTrajs, allTrajs, ax}, \[IndentingNewLine]{sim, canon} = 
            realCanonicalForm[mat]; \[IndentingNewLine]{xmax, ymax} = 
            N[inverseRange[sim]]; \[IndentingNewLine]{wrtRptQ, shwFldQ, 
              shwArrsQ, arwDnsty, n, 
              style} = \({WriteReport, ShowField, Oriented, \ ArrowDensity, 
                  1 + NumberOfTrajectories, NotableLineStyle} /. {opts}\) /. 
              Options[LinearPhasePlot2D]; \[IndentingNewLine]If[wrtRptQ, 
            Print["\<Center (periodic orbits)\>"], 
            Null]; \[IndentingNewLine]fld := 
            PlotVectorField[
              mat . {x, y}, {x, \(- .9\),  .9}, {y, \(- .9\),  .9}, 
              DisplayFunction \[Rule] 
                Identity]; \[IndentingNewLine]symAxes = \(Eigensystem[
                Transpose[sim] . 
                  sim]\)[\([2]\)]; \[IndentingNewLine]\[Theta]0 = 
            N[ArcTan @@ symAxes[\([1]\)]] + Pi/2; 
          unitCirc = 
            Line[Table[{Cos[\[Theta]], 
                    Sin[\[Theta]]}, {\[Theta], \[Theta]0, \[Theta]0 + 2  Pi - 
                      2  Pi/80. , 2  Pi/80. }]~
                Join~{{Cos[\[Theta]0], 
                    Sin[\[Theta]0]}}]; \[IndentingNewLine]sol[c_] := 
            Map[c*N[sim] . # &, 
              unitCirc, {2}]; \[IndentingNewLine]coeffList = 
            Max[xmax, ymax]*
              Range[2, n]^2/n^2; \[IndentingNewLine]basicTrajs = 
            Map[sol, coeffList]; \[IndentingNewLine]allTrajs = 
            If[shwArrsQ, 
              clipAndPlaceArrows[basicTrajs, {\(-1\), 1}, {\(-1\), 1}, 
                wrongDirectionQ[mat], arwDnsty, opts], basicTrajs]; 
          ax[i_] := {Dashing[{ .02,  .02}], style, 
                Map[N[sim] . # &, 
                  Line[Sqrt[2] 
                      Max[xmax, ymax]/
                        Sqrt[symAxes[\([i]\)] . 
                            symAxes[\([i]\)]] {\(-symAxes[\([i]\)]\), 
                        symAxes[\([i]\)]}], {2}]} // 
              Flatten; \[IndentingNewLine]Show[{If[shwFldQ, fld, 
                Sequence @@ {}], Graphics[{allTrajs, ax[1], ax[2], equil}]}, 
            FilterOptions[Plot, opts], 
            FilterOptions[Plot, Options[LinearPhasePlot2D]], 
            DisplayFunction \[Rule] $DisplayFunction]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Spiral (complex conjugate eigenvalues with nonvanishing real \
part)\
\>", "Subsection",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \(\(LinearPhasePlot2D[mat_?spiralQ, opts___Rule] := 
        Module[{sim, canon, xmax, ymax, \[Alpha], \[Beta], wrtRptQ, shwFldQ, 
            shwArrsQ, arwDnsty, n, style, fld, basicSpir, sol, coeffList, 
            basicTrajs, allTrajs, symAxes, 
            ax}, \[IndentingNewLine]{sim, canon} = 
            realCanonicalForm[mat]; {xmax, ymax} = 
            N[inverseRange[
                sim]]; \[IndentingNewLine]{\[Alpha], \[Beta]} = {canon[\([1, 
                  1]\)], canon[\([2, 1]\)]}; \[IndentingNewLine]{wrtRptQ, 
              shwFldQ, shwArrsQ, arwDnsty, n, 
              style} = \({WriteReport, ShowField, Oriented, \ ArrowDensity, 
                  2  NumberOfTrajectories, NotableLineStyle} /. {opts}\) /. 
              Options[LinearPhasePlot2D]; \[IndentingNewLine]If[wrtRptQ, 
            Print[If[\[Alpha] > 
                    0, "\<Repulsive\>", "\<Attractive\>"] <> "\< spirals\>"], 
            Null]; \[IndentingNewLine]fld := 
            PlotVectorField[
              mat . {x, y}, {x, \(- .9\),  .9}, {y, \(- .9\),  .9}, 
              DisplayFunction \[Rule] 
                Identity]; \[IndentingNewLine]basicSpir = \(ParametricPlot[
                Exp[\[Alpha]*\[Theta]] {Cos[\[Beta]*\[Theta]], 
                    Sin[\[Beta]*\[Theta]]}, 
                Evaluate[{\[Theta], Log[ .01  Min[xmax, ymax]]/\[Alpha], 
                    Log[Sqrt[xmax^2 + ymax^2]]/\[Alpha]}], 
                DisplayFunction \[Rule] Identity]\)[\([1, 1, 
                1]\)]; \[IndentingNewLine]sol[c_] := 
            Map[N[sim] . {{Cos[c], Sin[c]}, {\(-Sin[c]\), Cos[c]}} . # &, 
              basicSpir, {2}]; 
          coeffList = Range[n]*2  Pi/n; \[IndentingNewLine]basicTrajs = 
            Map[sol, coeffList]; \[IndentingNewLine]allTrajs = 
            If[shwArrsQ, 
              clipAndPlaceArrows[basicTrajs, {\(-1\), 1}, {\(-1\), 1}, 
                wrongDirectionQ[mat], arwDnsty, opts], basicTrajs]; 
          symAxes = \(Eigensystem[Transpose[sim] . sim]\)[\([2]\)]; 
          ax[i_] := {Dashing[{ .02,  .02}], style, 
                Map[N[sim] . # &, 
                  Line[Sqrt[2] 
                      Max[xmax, ymax]/
                        Sqrt[symAxes[\([i]\)] . 
                            symAxes[\([i]\)]] {\(-symAxes[\([i]\)]\), 
                        symAxes[\([i]\)]}], {2}]} // 
              Flatten; \[IndentingNewLine]Show[{If[shwFldQ, fld, 
                Sequence @@ {}], Graphics[{allTrajs, ax[1], ax[2], equil}]}, 
            FilterOptions[Plot, opts], 
            FilterOptions[Plot, Options[LinearPhasePlot2D]], 
            DisplayFunction \[Rule] $DisplayFunction]];\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Trig Interpolation curves", "Subsubtitle"],

Cell[CellGroupData[{

Cell["Open curve TrigInterpolation", "Section"],

Cell["A utility:", "Text"],

Cell[BoxData[
    \(\(trigFunctionsAndValueMatrix[conditionsStructure_List, timesList_List, 
          t_Symbol, periodLength_: \((2  Pi)\)] := 
        Module[{numberOfConditions, baseFunctions, f, 
            g}, \[IndentingNewLine]numberOfConditions = \(conditionsStructure \
// Flatten\) // Length; \[IndentingNewLine]baseFunctions[r_] = 
            Take[Flatten[
                Join[{1}, 
                  Table[{Cos[2  Pi*k*r/periodLength], 
                      Sin[2  Pi*k*r/periodLength]}, {k, 
                      Ceiling[numberOfConditions/2] + 1}]]], 
              numberOfConditions + 1]; \[IndentingNewLine]f[
              a_, {k_, j_:  1}] := \(\(Derivative[j - 1]\)[g]\)[
              timesList[\([k]\)]]; \[IndentingNewLine]{g[t], 
              Flatten[MapIndexed[f, conditionsStructure, {\(-1\)}]]} /. 
            g \[Rule] baseFunctions];\)\)], "Input",
  InitializationCell->True],

Cell["Cartesian one-dimensional case:", "Text"],

Cell[BoxData[{
    \(\(Options[
          TrigInterpolation] = {EvaluateOnCoefficients \[Rule] Identity, 
          Period \[Rule] Automatic};\)\), "\[IndentingNewLine]", 
    \(\(TrigInterpolation[
          pointList : {{_?NumericQ, _?NumericQ | {__?NumericQ}} .. }, 
          t_Symbol, opts___?OptionQ] := 
        Module[{funct, xlist, derivativesList, xmin, xmax, pl, periodLength, 
            derivativesListStructure, trigValueMatrix, 
            coeff}, \[IndentingNewLine]funct = \(EvaluateOnCoefficients /. \
{opts}\) /. Options[TrigInterpolation]; \[IndentingNewLine]xlist = 
            Map[First, pointList]; \[IndentingNewLine]derivativesList = 
            Map[Flatten[Rest[#]] &, pointList]; \[IndentingNewLine]{xmin, 
              xmax} = {Min[xlist], 
              Max[xlist]}; \[IndentingNewLine]pl = \(Period /. {opts}\) /. 
              Options[TrigInterpolation]; \[IndentingNewLine]periodLength = 
            Which[pl === Automatic, \((xmax - xmin)\)*3, 
              Element[N[pl], Reals] === True, pl, 
              True, \((xmax - 
                    xmin)\)*3]; \[IndentingNewLine]derivativesListStructure = 
            derivativesList /. _?NumericQ \[Rule] 
                1; \[IndentingNewLine]{baseFunctions, trigValueMatrix} = 
            trigFunctionsAndValueMatrix[derivativesListStructure, xlist, t, 
              periodLength]; \[IndentingNewLine]coeff = 
            Map[funct, 
              LinearSolve[trigValueMatrix, 
                Flatten[derivativesList]]]; \[IndentingNewLine]If[
            Head[coeff] === LinearSolve, Null, 
            coeff . baseFunctions]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(TrigInterpolation[pointList : {__?NumericQ}, t_Symbol, 
          opts___?OptionQ] := 
        TrigInterpolation[Transpose[{Range[Length[pointList]], pointList}], 
          t, opts];\)\)], "Input",
  InitializationCell->True],

Cell["Case of interpolating parametric curve in the plane:", "Text"],

Cell[BoxData[{
    \(\(Options[
          OpenCurveInterpolation] = {EvaluateOnCoefficients \[Rule] Identity, 
          ShowTimesListQ \[Rule] False, 
          Period \[Rule] Automatic};\)\), "\[IndentingNewLine]", 
    \(\(OpenCurveInterpolation[
          pointList : {\(({_?NumericQ, _?
                        NumericQ} | {{_?NumericQ, _?NumericQ} .. })\) .. }, 
          t_Symbol, opts___?OptionQ] := 
        Module[{stlQ, funct, x, y, conditionsStructure, conditionsPerPoint, 
            timesList, tmax, pl, periodLength, baseFunctions, 
            trigValueMatrix, coeffx, coeffy, 
            result}, \[IndentingNewLine]stlQ = \((\((\(ShowTimesListQ /. \
{opts}\) /. Options[ClosedCurveInterpolation])\) === 
                True)\); \[IndentingNewLine]funct = \(EvaluateOnCoefficients /. \
{opts}\) /. Options[ClosedCurveInterpolation]; \[IndentingNewLine]x = 
            pointList /. {a_?NumericQ, _} \[RuleDelayed] 
                a; \[IndentingNewLine]y = 
            pointList /. {_, b_?NumericQ} \[RuleDelayed] 
                b; \[IndentingNewLine]conditionsStructure = 
            x /. _?NumericQ \[Rule] 
                1; \[IndentingNewLine]conditionsPerPoint = 
            Map[Length[Flatten[#]] &, pointList]/
              2; \[IndentingNewLine]timesList = 
            FoldList[Plus, 0, ListConvolve[{1, 1}, conditionsPerPoint]]; 
          tmax = Last[
              timesList]; \[IndentingNewLine]pl = \(Period /. {opts}\) /. 
              Options[OpenCurveInterpolation]; \
\[IndentingNewLine]periodLength = 
            Which[pl === Automatic, tmax*3, Element[N[pl], Reals] === True, 
              pl, True, tmax*3]; \[IndentingNewLine]{baseFunctions, 
              trigValueMatrix} = 
            trigFunctionsAndValueMatrix[conditionsStructure, timesList, t, 
              periodLength]; \[IndentingNewLine]coeffx = 
            Map[funct, 
              LinearSolve[trigValueMatrix, 
                Flatten[x]]]; \[IndentingNewLine]coeffy = 
            Map[funct, 
              LinearSolve[trigValueMatrix, 
                Flatten[
                  y]]]; \[IndentingNewLine]result = \
\[IndentingNewLine]{baseFunctions . coeffx, 
              baseFunctions . coeffy}; \[IndentingNewLine]If[
            Or[Head[coeffx] === LinearSolve, Head[coeffy] === LinearSolve], 
            Null, {result, 
              If[stlQ, timesList, Sequence @@ {}]}]];\)\)}], "Input",
  InitializationCell->True],

Cell["\<\
Case of interpolating parametric curve in the the three-dimensional \
case:\
\>", "Text"],

Cell[BoxData[
    \(\(OpenCurveInterpolation[
          pointList : {\(({_?NumericQ, _?NumericQ, _?
                        NumericQ} | {{_?NumericQ, _?NumericQ, _?
                            NumericQ} .. })\) .. }, t_Symbol, 
          opts___?OptionQ] := 
        Module[{stlQ, funct, x, y, conditionsStructure, conditionsPerPoint, 
            timesList, tmax, pl, periodLength, baseFunctions, 
            trigValueMatrix, coeffx, coeffy, 
            result}, \[IndentingNewLine]stlQ = \((\((\(ShowTimesListQ /. \
{opts}\) /. Options[ClosedCurveInterpolation])\) === 
                True)\); \[IndentingNewLine]funct = \(EvaluateOnCoefficients /. \
{opts}\) /. Options[ClosedCurveInterpolation]; \[IndentingNewLine]x = 
            pointList /. {a_?NumericQ, __} \[RuleDelayed] 
                a; \[IndentingNewLine]y = 
            pointList /. {_, b_?NumericQ, _} \[RuleDelayed] 
                b; \[IndentingNewLine]z = 
            pointList /. {_, _, c_?NumericQ} \[RuleDelayed] 
                c; \[IndentingNewLine]conditionsStructure = 
            x /. _?NumericQ \[Rule] 
                1; \[IndentingNewLine]conditionsPerPoint = 
            Map[Length[Flatten[#]] &, pointList]/
              2; \[IndentingNewLine]timesList = 
            FoldList[Plus, 0, ListConvolve[{1, 1}, conditionsPerPoint]]; 
          tmax = Last[
              timesList]; \[IndentingNewLine]pl = \(Period /. {opts}\) /. 
              Options[OpenCurveInterpolation]; \
\[IndentingNewLine]periodLength = 
            Which[pl === Automatic, tmax*3, Element[N[pl], Reals] === True, 
              pl, True, tmax*3]; \[IndentingNewLine]{baseFunctions, 
              trigValueMatrix} = 
            trigFunctionsAndValueMatrix[conditionsStructure, timesList, t, 
              periodLength]; \[IndentingNewLine]coeffx = 
            Map[funct, 
              LinearSolve[trigValueMatrix, 
                Flatten[x]]]; \[IndentingNewLine]coeffy = 
            Map[funct, 
              LinearSolve[trigValueMatrix, 
                Flatten[y]]]; \[IndentingNewLine]coeffz = 
            Map[funct, 
              LinearSolve[trigValueMatrix, 
                Flatten[
                  z]]]; \[IndentingNewLine]result = \
\[IndentingNewLine]{baseFunctions . coeffx, baseFunctions . coeffy, 
              baseFunctions . coeffz}; \[IndentingNewLine]If[
            Or[Head[coeffx] === LinearSolve, Head[coeffy] === LinearSolve], 
            Null, {result, 
              If[stlQ, timesList, Sequence @@ {}]}]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Closed curve TrigInterpolation", "Section"],

Cell["Two-dimensional case:", "Text"],

Cell[BoxData[{
    \(\(Options[
          ClosedCurveInterpolation] = {EvaluateOnCoefficients \[Rule] 
            Identity, 
          ShowTimesListQ \[Rule] False};\)\), "\[IndentingNewLine]", 
    \(\(ClosedCurveInterpolation[
          pointList : {\(({_?NumericQ, _?
                        NumericQ} | {{_?NumericQ, _?NumericQ} .. })\) .. }, 
          t_Symbol, opts___?OptionQ] := 
        Module[{stlQ, funct, x, y, conditionsStructure, conditionsPerPoint, 
            timesList, r, f, g, baseFunctions, trigValueMatrix, coeffx, 
            coeffy, result}, \[IndentingNewLine]stlQ = \((\((\(ShowTimesListQ \
/. {opts}\) /. Options[ClosedCurveInterpolation])\) === 
                True)\); \[IndentingNewLine]funct = \(EvaluateOnCoefficients /. \
{opts}\) /. Options[ClosedCurveInterpolation]; \[IndentingNewLine]x = 
            pointList /. {a_?NumericQ, _} \[RuleDelayed] 
                a; \[IndentingNewLine]y = 
            pointList /. {_, b_?NumericQ} \[RuleDelayed] 
                b; \[IndentingNewLine]conditionsStructure = 
            x /. _?NumericQ \[Rule] 
                1; \[IndentingNewLine]conditionsPerPoint = 
            Map[Length[Flatten[#]] &, pointList]/
              2; \[IndentingNewLine]timesList = 
            2  Pi \((Drop[#, \(-1\)]/Last[#] &)\)[
                FoldList[Plus, 0, 
                  ListConvolve[{1, 1}, 
                    conditionsPerPoint, {1, 
                      1}]]]; \[IndentingNewLine]{baseFunctions, 
              trigValueMatrix} = 
            trigFunctionsAndValueMatrix[conditionsStructure, timesList, 
              t]; \[IndentingNewLine]coeffx = 
            Map[funct, 
              LinearSolve[trigValueMatrix, 
                Flatten[x]]]; \[IndentingNewLine]coeffy = 
            Map[funct, 
              LinearSolve[trigValueMatrix, 
                Flatten[
                  y]]]; \[IndentingNewLine]result = \
\[IndentingNewLine]{baseFunctions . coeffx, 
              baseFunctions . coeffy}; \[IndentingNewLine]If[
            Or[Head[coeffx] === LinearSolve, Head[coeffy] === LinearSolve], 
            Null, If[stlQ, {result, timesList}, result]]];\)\)}], "Input",
  InitializationCell->True],

Cell["Three-dimensional case:", "Text"],

Cell[BoxData[
    \(\(ClosedCurveInterpolation[
          pointList : {\(({_?NumericQ, _?NumericQ, _?
                        NumericQ} | {{_?NumericQ, _?NumericQ, _?
                            NumericQ} .. })\) .. }, t_Symbol, 
          opts___?OptionQ] := 
        Module[{stlQ, funct, x, y, conditionsStructure, conditionsPerPoint, 
            timesList, r, f, g, baseFunctions, trigValueMatrix, coeffx, 
            coeffy, result}, \[IndentingNewLine]stlQ = \((\((\(ShowTimesListQ \
/. {opts}\) /. Options[ClosedCurveInterpolation])\) === 
                True)\); \[IndentingNewLine]funct = \(EvaluateOnCoefficients /. \
{opts}\) /. Options[ClosedCurveInterpolation]; \[IndentingNewLine]x = 
            pointList /. {a_?NumericQ, __} \[RuleDelayed] 
                a; \[IndentingNewLine]y = 
            pointList /. {_, b_?NumericQ, _} \[RuleDelayed] 
                b; \[IndentingNewLine]z = 
            pointList /. {_, _, c_?NumericQ} \[RuleDelayed] 
                c; \[IndentingNewLine]conditionsStructure = 
            x /. _?NumericQ \[Rule] 
                1; \[IndentingNewLine]conditionsPerPoint = 
            Map[Length[Flatten[#]] &, pointList]/
              2; \[IndentingNewLine]timesList = 
            2  Pi \((Drop[#, \(-1\)]/Last[#] &)\)[
                FoldList[Plus, 0, 
                  ListConvolve[{1, 1}, 
                    conditionsPerPoint, {1, 
                      1}]]]; \[IndentingNewLine]{baseFunctions, 
              trigValueMatrix} = 
            trigFunctionsAndValueMatrix[conditionsStructure, timesList, 
              t]; \[IndentingNewLine]coeffx = 
            Map[funct, 
              LinearSolve[trigValueMatrix, 
                Flatten[x]]]; \[IndentingNewLine]coeffy = 
            Map[funct, 
              LinearSolve[trigValueMatrix, 
                Flatten[y]]]; \[IndentingNewLine]coeffz = 
            Map[funct, 
              LinearSolve[trigValueMatrix, 
                Flatten[
                  z]]]; \[IndentingNewLine]result = \
\[IndentingNewLine]{baseFunctions . coeffx, baseFunctions . coeffy, 
              baseFunctions . coeffz}; \[IndentingNewLine]If[
            Or[Head[coeffx] === LinearSolve, Head[coeffy] === LinearSolve], 
            Null, If[stlQ, {result, timesList}, result]]];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "A single function that combines ",
  StyleBox["OpenCurveInterpolation", "Input"],
  " and ",
  StyleBox["ClosedCurveInterpolation", "Input"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(checkDimensions[pointList_] := 
        MemberQ[{{2}, {3}}, 
          Union@Map[Length, Level[pointList, {\(-2\)}]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(ParametricTrigInterpolation[
        pointList : {\(({__?NumericQ} | {{__?NumericQ} .. })\) .. } /; 
          checkDimensions[pointList], t_Symbol, 
        opts___?OptionQ] := \[IndentingNewLine]If[
        TrueQ[ClosedCurve /. {opts}], 
        ClosedCurveInterpolation[pointList, t, 
          opts], \[IndentingNewLine]OpenCurveInterpolation[pointList, t, 
          opts]]\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["TrigInterpolation curve plot", "Section"],

Cell["One-dimensional cartesian curve case:", "Text"],

Cell[BoxData[{
    \(\(Options[TrigInterpolationPlot] = {ShowListPlot \[Rule] False, 
          ListPlotStyle \[Rule] PointSize[ .02], 
          ShowFormula \[Rule] False};\)\), "\[IndentingNewLine]", 
    \(\(TrigInterpolationPlot[pointList : {{_?NumericQ, __?NumericQ} .. }, 
          xmin_?NumericQ, xmax_?NumericQ, opts___?OptionQ] := 
        Module[{slpQ, sformQ, interpFunct, t, curve, listPl, 
            finalPlot}, \[IndentingNewLine]{slpQ, sformQ} = 
            Map[TrueQ, \({ShowListPlot, ShowFormula} /. {opts}\) /. 
                Options[
                  TrigInterpolationPlot]]; \[IndentingNewLine]interpFunct = 
            TrigInterpolation[pointList, t, 
              FilterOptions[TrigInterpolation, opts]]; \[IndentingNewLine]If[
            interpFunct === Null, Return[Null]]; \[IndentingNewLine]curve = 
            Plot[interpFunct, {t, xmin, xmax}, 
              DisplayFunction \[Rule] Identity, 
              Evaluate[
                FilterOptions[Plot, opts]]]; \[IndentingNewLine]listPl := 
            ListPlot[Map[Take[#, 2] &, pointList], 
              PlotStyle \[Rule] \((\(ListPlotStyle /. {opts}\) /. 
                    Options[TrigInterpolationPlot])\), 
              DisplayFunction \[Rule] 
                Identity]; \[IndentingNewLine]finalPlot := 
            Show[If[slpQ, {curve, listPl}, curve], 
              Evaluate[
                FilterOptions[Graphics, opts, 
                  DisplayFunction \[Rule] $DisplayFunction]]]; \
\[IndentingNewLine]If[
            sformQ, {finalPlot, 
              Evaluate[interpFunct /. t \[Rule] Slot[1]] &}, 
            finalPlot]];\)\)}], "Input",
  InitializationCell->True],

Cell["Parametric case, in either 2 and 3 dimensional space:", "Text"],

Cell[BoxData[{
    \(\(\(Options[TrigInterpolationParametricPlot] = 
        Join[{OrientedCurve \[Rule] False, ClosedCurve \[Rule] False, 
            FilledClosedCurve \[Rule] False, ShowListPlot \[Rule] False, 
            ListPlotStyle \[Rule] PointSize[ .02], ShowFormula \[Rule] False, 
            ShowTimesListQ \[Rule] False}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(TrigInterpolationParametricPlot[
          pointList : {\(({__?NumericQ} | {{__?NumericQ} .. })\) .. } /; 
            checkDimensions[pointList], 
          opts___?OptionQ] := \[IndentingNewLine]Module[{dimen, orntdQ, 
            clsdQ, filledclsdQ, slpQ, sformQ, stlstQ, paramCurve, tmax, 
            basicPlot, pointsPlot, 
            endPlot}, \[IndentingNewLine]dimen = \(Level[
                  pointList, {\(-2\)}] // First\) // 
              Length; \[IndentingNewLine]{orntdQ, clsdQ, filledclsdQ, slpQ, 
              sformQ, stlstQ} = 
            Map[TrueQ, \({OrientedCurve, ClosedCurve, FilledClosedCurve, 
                    ShowListPlot, ShowFormula, ShowTimesListQ} /. {opts}\) /. 
                Options[InterpolationParametricPlot]]; \[IndentingNewLine]If[
            filledclsdQ, clsdQ = True]; \[IndentingNewLine]If[
            Not@clsdQ, {paramCurve, tlst} = 
              OpenCurveInterpolation[pointList, t, 
                ShowTimesListQ \[Rule] True, 
                Evaluate[
                  FilterOptions[OpenCurveInterpolation, 
                    opts]]]]; \[IndentingNewLine]If[
            clsdQ, {paramCurve, tlst} = 
              ClosedCurveInterpolation[pointList, t, 
                ShowTimesListQ \[Rule] True, 
                Evaluate[
                  FilterOptions[ClosedCurveInterpolation, 
                    opts]]]]; \[IndentingNewLine]If[paramCurve === Null, 
            Return[Null]]; \[IndentingNewLine]tmax = 
            If[clsdQ, 2  Pi, 
              Last@tlst]; \[IndentingNewLine]\((basicPlot /; 
                dimen \[Equal] 2)\) := \(basicPlot = 
              OrientedParametricPlot[paramCurve, {t, 0, tmax}, 
                  DisplayFunction \[Rule] Identity, 
                  Evaluate[
                    If[orntdQ, Sequence @@ {}, HowManyArrows \[Rule] 0]], 
                  Evaluate[FilterOptions[OrientedParametricPlot, opts]]] /. 
                If[filledclsdQ, 
                  Line[pts_] \[RuleDelayed] {{Sequence @@ 
                          Flatten[{\(Graphics`FilledPlot`Fills /. {opts}\) /. \
{Graphics`FilledPlot`Fills \[Rule] GrayLevel[ .5]}}], Polygon[pts]}, 
                      Line[pts]}, {}]\); \[IndentingNewLine]\((basicPlot /; 
                dimen \[Equal] 3)\) := \(basicPlot = 
              OrientedParametricPlot3D[Evaluate[paramCurve], {t, 0, tmax}, 
                DisplayFunction \[Rule] Identity, 
                Evaluate[
                  If[orntdQ, Sequence @@ {}, HowManyArrows \[Rule] 0]], 
                Evaluate[
                  FilterOptions[OrientedParametricPlot3D, 
                    opts]]]\); \[IndentingNewLine]pointsPlot := \(If[
                dimen \[Equal] 2, Graphics, 
                Graphics3D]\)[{Sequence @@ 
                  Flatten[{\(ListPlotStyle /. {opts}\) /. 
                        Options[TrigInterpolationParametricPlot]}], 
                Map[Point[Take[Flatten[#], dimen]] &, 
                  pointList]}]; \[IndentingNewLine]endPlot := 
            Show[If[slpQ, {basicPlot, 
                  pointsPlot}, \[IndentingNewLine]basicPlot], \
\[IndentingNewLine]Evaluate[FilterOptions[Graphics, opts]], 
              DisplayFunction \[Rule] $DisplayFunction]; \
\[IndentingNewLine]If[
            sformQ, {endPlot, 
              Evaluate[First@paramCurve /. t \[Rule] Slot[1]] &}, 
            endPlot]];\)\)}], "Input",
  InitializationCell->True],

Cell[TextData[{
  "In 3D-space we provide a separate function, just for naming consistency, \
even if ",
  StyleBox["TrigInterpolationPlot", "Input"],
  " already does the job:"
}], "Text"],

Cell[BoxData[
    \(\(TrigInterpolationParametricPlot3D[
          pointList : {\(({_?NumericQ, _?NumericQ, _?
                        NumericQ} | {{_?NumericQ, _?NumericQ, _?
                            NumericQ} .. })\) .. }, 
          opts___] := \[IndentingNewLine]InterpolationParametricPlot[
          pointList, opts];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "The ",
  StyleBox["Draw", "Input"],
  " parallels to ",
  StyleBox["Plot", "Input"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(TrigInterpolationDraw[pointList : {{_?NumericQ, __?NumericQ} .. }, 
          xmin_?NumericQ, xmax_?NumericQ, opts___?OptionQ] := 
        Block[{$DisplayFunction = 
              Identity}, \[IndentingNewLine]\(TrigInterpolationPlot[
              pointList, xmin, xmax, ShowFormula \[Rule] False, 
              opts]\)[\([1]\)]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(TrigInterpolationParametricDraw[
          pointList : {\(({__?NumericQ} | {{__?NumericQ} .. })\) .. } /; 
            checkDimensions[pointList], opts___?OptionQ] := 
        Block[{$DisplayFunction = 
              Identity}, \[IndentingNewLine]\(TrigInterpolationParametricPlot[
              pointList, ShowFormula \[Rule] False, 
              opts]\)[\([1]\)]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(TrigInterpolationParametricDraw3D[
          pointList : {\(({_?NumericQ, _?NumericQ, _?
                          NumericQ} | {{_?NumericQ, _?NumericQ, _?
                              NumericQ} .. })\) .. } /; 
            checkDimensions[pointList], opts___?OptionQ] := 
        Block[{$DisplayFunction = 
              Identity}, \
\[IndentingNewLine]\(TrigInterpolationParametricPlot3D[pointList, 
              ShowFormula \[Rule] False, opts]\)[\([1]\)]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Level set polynomial TrigInterpolation", "Section"],

Cell["\<\
Given a set of points (and possibly of tangent vectors, \
acceleration vectors etc.) in the plain, PolynomialLevelSetInterpolation \
attempts to find a two-variable polynomial whose 0-level set interpolates the \
given points.\
\>", "Text"],

Cell[BoxData[
    \(\(Options[PolynomialLevelSetTrigInterpolation] = 
        Options[ClosedCurveInterpolation];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PolynomialLevelSetTrigInterpolation::"\<NonExactInput\>" = \
"\<PolynomialLevelSetInterpolation is designed only for exact (infinite \
precision) numeric input.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PolynomialLevelSetTrigInterpolation[
          pointList : {\(({_?NumericQ, _?
                          NumericQ} | {{_?NumericQ, _?NumericQ} .. })\) .. } /; 
            Precision[pointList] < Infinity, t_Symbol, x_Symbol, y_Symbol, 
          opts___Rule] := \((Message[
            PolynomialLevelSetInterpolation::"\<NonExactInput\>"]; 
          Null)\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PolynomialLevelSetTrigInterpolation[
          pointList : {\(({_?NumericQ, _?
                          NumericQ} | {{_?NumericQ, _?NumericQ} .. })\) .. } /; 
            Precision[pointList] \[Equal] Infinity, t_Symbol, x_Symbol, 
          y_Symbol, opts___Rule] := 
        Module[{closedQ, funct, parametricContour, maxDenom, poly, a, b, 
            simplifiedPoly}, \[IndentingNewLine]{closedQ, 
              funct} = \({ClosedCurve, EvaluateOnCoefficients} /. {opts}\) /. 
              Options[ClosedCurveInterpolation]; \
\[IndentingNewLine]parametricContour = 
            ParametricTrigInterpolation[pointList, t, 
              opts]; \[IndentingNewLine]If[parametricContour === Null, 
            Return[Null]]; \[IndentingNewLine]maxDenom := 
            Max[1, Cases[parametricContour, 
                Cos[Pi*t*Rational[_, n_]] | 
                    Sin[Pi*t*Rational[1, n_]] \[RuleDelayed] n, {0, 
                  Infinity}]]; 
          poly = Eliminate[
                Join[Thread[{x, y} == 
                        TrigExpand[
                          Take[Flatten[parametricContour], 2] /. 
                            If[TrueQ[closedQ], {}, 
                              t \[Rule] t*maxDenom/Pi]] /. {Cos[t] \[Rule] a, 
                        Sin[t] \[Rule] b}], {a^2 + b^2 \[Equal] 1}], {a, b}] /. 
              Equal \[Rule] Subtract; \[IndentingNewLine]simplifiedPoly = 
            Collect[poly, {x^\((_ : 1)\) y^\((_ : 1)\), x^\((_ : 1)\), 
                y^\((_ : 1)\)}, 
              funct]; \[IndentingNewLine]{parametricContour, 
            simplifiedPoly}];\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["LinearClipPlot3D", "Subsubtitle"],

Cell[BoxData[
    \(\(SetAttributes[LinearClipPlot3D, \ HoldRest];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[LinearClipPlot3D] = {PrepareForSlices \[Rule] False, 
          ReverseOrientation \[Rule] False, 
          ContourStyle \[Rule] Automatic};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LinearClipPlot3D[obj_SurfaceGraphics, other___] := 
        LinearClipPlot3D[Graphics3D[obj], other];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LinearClipPlot3D[obj_Graphics3D, 
          rel_ /; Or[
              MemberQ[{Less, LessEqual, Greater, GreaterEqual}, Head[rel]] && 
                Length[rel] > 2, Head[rel] === Inequality], var__Symbol, 
          opts___Rule] := 
        LinearClipPlot3D[obj, Evaluate@LogicalExpand[rel], var, 
            opts] //. {a___Rule, b_ \[Rule] c_, d___Rule, b_ \[Rule] f_, 
              g___Rule} \[RuleDelayed] {a, b \[Rule] c, d, g};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LinearClipPlot3D[obj_Graphics3D, rel_And, var__Symbol, opts___Rule] := 
        Show[Fold[
              LinearClipPlot3D[#1, #2, var, DisplayFunction \[Rule] Identity, 
                  opts] &, obj, 
              List @@ rel], \[IndentingNewLine]FilterOptions[Graphics3D, 
              opts], \[IndentingNewLine]Sequence @@ Rest[obj]] //. {a___Rule, 
              b_ \[Rule] c_, d___Rule, b_ \[Rule] f_, 
              g___Rule} \[RuleDelayed] {a, b \[Rule] c, d, g};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LinearClipPlot3D[obj_Graphics3D, 
            rel_ /; MemberQ[{Less, LessEqual, Greater, GreaterEqual}, 
                  Head[rel]] && Length[rel] \[Equal] 2, var__Symbol, 
            opts___Rule] /; \((PolynomialQ[Subtract @@ rel, {var}] && 
              Max[\((Exponent[Expand[Subtract @@ rel], #1] &)\) /@ {var}] === 
                1)\) := Module[{ratObj, strictRel, weakRel, strictNegRel, 
            weakNegRel, eqRel, interiorQ, weakInteriorQ, exteriorQ, 
            weakExteriorQ, onBoundaryQ, interiorQList, weakInteriorQList, 
            exteriorQList, weakExteriorQList, borderTouchingQ, flatOnPlaneQ, 
            toThrowQ, winnowed, inters, clipLine, removeDuplicatePts, 
            clipContour, beyondClipLine, beyondClipContour, prepareQ, 
            boundaryLine, crossPr, parallelPolygons, normalVectorToPolygon, 
            normalVectorToClipPlane, positivelyOrientedQ, 
            rulesForConnectingSegments, dontReverseQ, 
            removeDuplicateEndPoints, boundaryStyle, boundary, 
            withoutBoundary, 
            withClippedPolygons}, \[IndentingNewLine]ratObj = 
            Rationalize[obj, 1/10^6]; \[IndentingNewLine]If[
            Not[MatchQ[ratObj, Graphics3D[_List, ___]]], 
            MapAt[List, ratObj, 1]]; \[IndentingNewLine]strictRel = 
            Rationalize[
              rel /. \[InvisibleSpace]{LessEqual \[Rule] Less, 
                  GreaterEqual \[Rule] Greater}, 
              1/10^6]; \[IndentingNewLine]weakRel = 
            strictRel /. {Less \[Rule] LessEqual, 
                Greater \[Rule] 
                  GreaterEqual}; \[IndentingNewLine]strictNegRel = 
            strictRel /. {Less \[Rule] Greater, 
                Greater \[Rule] Less}; \[IndentingNewLine]weakNegRel = 
            strictNegRel /. {Less \[Rule] LessEqual, 
                Greater \[Rule] GreaterEqual}; \[IndentingNewLine]eqRel = 
            strictRel /. {Less \[Rule] Equal, 
                Greater \[Rule] Equal}; \[IndentingNewLine]interiorQ[
              pt_List] := 
            strictRel /. \[InvisibleSpace]Thread[{var} \[Rule] 
                  pt]; \[IndentingNewLine]weakInteriorQ[pt_List] := 
            weakRel /. \[InvisibleSpace]Thread[{var} \[Rule] 
                  pt]; \[IndentingNewLine]exteriorQ[pt_List] := 
            strictNegRel /. 
              Thread[{var} \[Rule] pt]; \[IndentingNewLine]weakExteriorQ[
              pt_List] := 
            weakNegRel /. \[InvisibleSpace]Thread[{var} \[Rule] pt]; 
          onBoundaryQ[pt_List] := 
            eqRel /. Thread[{var} \[Rule] 
                  pt]; \[IndentingNewLine]interiorQList[pts_List] := 
            interiorQ /@ pts; \[IndentingNewLine]weakInteriorQList[pts_List] := 
            weakInteriorQ /@ pts; \[IndentingNewLine]exteriorQList[pts_List] := 
            exteriorQ /@ pts; \[IndentingNewLine]weakExteriorQList[pts_List] := 
            weakExteriorQ /@ pts; 
          flatOnPlaneQ[pts_List] := 
            And[And @@ weakInteriorQList[pts], 
              And @@ weakExteriorQList[
                  pts]]; \[IndentingNewLine]borderTouchingQ[pts_List] := 
            And[Or @@ weakInteriorQList[pts], Or @@ weakExteriorQList[pts], 
              Not[flatOnPlaneQ[pts]]]; \[IndentingNewLine]toThrowQ[
              Polygon[pts_List]] := 
            Or[And @@ exteriorQList[pts]]; \[IndentingNewLine]winnowed = 
            ratObj /. \[InvisibleSpace]pol_Polygon?toThrowQ \[RuleDelayed] 
                Sequence @@ {}; \[IndentingNewLine]inters[pt1_List, 
              pt2_List] := 
            t\ pt1 + \((1 - t)\)\ pt2 /. \[InvisibleSpace]\(Solve[
                  eqRel /. \[InvisibleSpace]Thread[{var} \[Rule] 
                        t*pt1 + \((1 - t)\)\ pt2], t]\)[\([1]\)]; 
          clipLine[pt1_List?exteriorQ, pt2_List?exteriorQ] := Sequence @@ {}; 
          clipLine[pt1_List?interiorQ, pt2_List?weakExteriorQ] := {pt1, 
              inters[pt1, pt2]}; 
          clipLine[pt1_List?weakInteriorQ, pt2_List?exteriorQ] := {pt1, 
              inters[pt1, pt2]}; 
          clipLine[pt1_List?weakExteriorQ, 
              pt2_List?interiorQ] := {inters[pt1, pt2], pt2}; 
          clipLine[pt1_List?exteriorQ, 
              pt2_List?weakInteriorQ] := {inters[pt1, pt2], 
              pt2}; \[IndentingNewLine]clipLine[pt1_List?weakInteriorQ, 
              pt2_List?weakInteriorQ] := {pt1, 
              pt2}; \[IndentingNewLine]removeDuplicatePts = \(({a___, b_List, 
                  b_, c___} \[RuleDelayed] {a, b, 
                  c})\); \[IndentingNewLine]clipContour[pts_List] := 
            Flatten[Apply[clipLine, Partition[Append[pts, First[pts]], 2, 1], 
                  1], 1] //. 
              removeDuplicatePts; \[IndentingNewLine]beyondClipLine[
              pt1_List?interiorQ, pt2_List?interiorQ] := Sequence @@ {}; 
          beyondClipLine[pt1_List?weakInteriorQ, 
              pt2_List?exteriorQ] := {inters[pt1, pt2], 
              pt2}; \[IndentingNewLine]beyondClipLine[pt1_List?interiorQ, 
              pt2_List?weakExteriorQ] := {inters[pt1, pt2], pt2}; 
          beyondClipLine[pt1_List?exteriorQ, pt2_List?weakInteriorQ] := {pt1, 
              inters[pt1, pt2]}; 
          beyondClipLine[pt1_List?weakExteriorQ, pt2_List?interiorQ] := {pt1, 
              inters[pt1, pt2]}; 
          beyondClipLine[pt1_List?weakExteriorQ, 
              pt2_List?weakExteriorQ] := {pt1, 
              pt2}; \[IndentingNewLine]beyondClipContour[pts_List] := 
            Flatten[Apply[beyondClipLine, 
                  Partition[Append[pts, First[pts]], 2, 1], 1], 1] //. 
              removeDuplicatePts; \[IndentingNewLine]prepareQ = \
\(PrepareForSlices /. \[InvisibleSpace]{opts}\) /. \[InvisibleSpace]Options[
                LinearClipPlot3D]; 
          boundaryLine[clipCtr_List] := 
            Cases[Partition[clipCtr, 2, 
                1], {p__List?onBoundaryQ} \[RuleDelayed] 
                Line[{p}]]; \[IndentingNewLine]normalVectorToPolygon[
              polyPts_List] := 
            Cross @@ Map[
                Last[#] - First[#] &, {polyPts, 
                  RotateLeft[
                    polyPts]}]; \[IndentingNewLine]normalVectorToClipPlane = 
            Outer[D, {Subtract @@ rel}, {var}] // 
              First; \[IndentingNewLine]positivelyOrientedQ[polyPts_List, 
              boundaryPts_List] := 
            Positive[
              Det[{normalVectorToPolygon[polyPts], 
                  Last[boundaryPts] - First[boundaryPts], 
                  normalVectorToClipPlane}]]; \
\[IndentingNewLine]positivelyOrientedQ[polyPts_List, {}] := 
            False; \[IndentingNewLine]rulesForConnectingSegments = {\(({a___, 
                      Line[{b_List, c1_, c___}], d___, Line[{e___, e1_, b_}], 
                      f___} /; c1 =!= 
                      e1)\) \[RuleDelayed] \[IndentingNewLine]{Line[{e, e1, 
                      b, c1, c}], a, d, 
                  f}, \(({a___, Line[{c___, c1_, b_List}], d___, 
                      Line[{b_, e1_, e___}], f___} /; 
                    c1 =!= e1)\) \[RuleDelayed] {Line[{c, c1, b, e1, e}], a, 
                  d, f}}; \[IndentingNewLine]dontReverseQ = 
            Not@TrueQ[\(ReverseOrientation /. {opts}\) /. 
                  Options[
                    LinearClipPlot3D]]; \
\[IndentingNewLine]removeDuplicateEndPoints = 
            Polygon[{a_, b___, a_}] \[RuleDelayed] 
              Polygon[{a, 
                  b}]; \[IndentingNewLine]boundaryStyle = \(ContourStyle /. \
{opts}\) /. Options[LinearClipPlot3D]; \[IndentingNewLine]If[
            boundaryStyle === Automatic, 
            boundaryStyle = {}]; \[IndentingNewLine]crossPr[{a_, b_, 
                c_}, {e_, f_, g_}] = {\(-c\)\ f + b\ g, 
              c\ e - a\ g, \(-b\)\ e + 
                a\ f}; \[IndentingNewLine]parallelPolygons[{pt1_, pt2_, pt3_, 
                pts___}] := 
            With[{normal = crossPr[pt1 - pt2, pt2 - pt3]/10^10}, {Polygon[
                  Map[# + normal &, {pt1, pt2, pt3, pts}]], 
                Polygon[
                  Map[# - normal &, {pt1, pt2, pt3, 
                      pts}]]}]; \[IndentingNewLine]boundary = {}; \
\[IndentingNewLine]withoutBoundary := \(withoutBoundary = \(winnowed \
/. \[InvisibleSpace]{Polygon[
                        pts_List /; 
                          Length[pts] > 2 && 
                            flatOnPlaneQ[pts]] \[RuleDelayed] \((AppendTo[
                          boundary, parallelPolygons[pts]]; 
                        Polygon[pts])\), \[IndentingNewLine]Polygon[
                        pts_List?borderTouchingQ] \[RuleDelayed] 
                      Module[{clCon = clipContour[pts], 
                          bClCon = beyondClipContour[pts], 
                          bndLine}, \[IndentingNewLine]bndLine = 
                          Union[boundaryLine[
                                Join[clCon, bClCon] //. removeDuplicatePts] /. 
                              Line[segment_ /; 
                                    Not@positivelyOrientedQ[pts, 
                                        segment]] \[RuleDelayed] 
                                Line[Reverse[
                                    segment]]]; \[IndentingNewLine]AppendTo[
                          boundary, 
                          bndLine]; \[IndentingNewLine]Sequence @@ {Polygon[
                              clCon], Polygon[bClCon]}]}\) /. 
                removeDuplicateEndPoints\); \
\[IndentingNewLine]withClippedPolygons := 
            Show[{withoutBoundary; winnowed, 
                Graphics3D[
                  Join[{Sequence @@ 
                        Flatten[{If[FreeQ[boundary, Polygon], boundaryStyle, 
                              If[FreeQ[boundaryStyle, 
                                  colorSpecPattern], {boundaryStyle, 
                                  EdgeForm[], 
                                  SurfaceColor[
                                    GrayLevel[0]]}, {boundaryStyle, 
                                  EdgeForm[], 
                                  SurfaceColor[
                                    Last@Cases[boundaryStyle, 
                                        colorSpecPattern, {0, 
                                        Infinity}]]}]]}]}, 
                    Union[Flatten[boundary]] //. 
                      rulesForConnectingSegments]]}, 
              DisplayFunction \[Rule] Identity]; \[IndentingNewLine]Show[
            If[prepareQ, 
              withClippedPolygons, \(winnowed /. \[InvisibleSpace]Polygon[
                      pts_List?borderTouchingQ] \[RuleDelayed] 
                    Polygon[clipContour[pts]]\) /. removeDuplicateEndPoints], 
            FilterOptions[Graphics3D, opts, 
              Sequence @@ Rest[obj]]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SetAttributes[LinearClipDraw3D, HoldRest];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LinearClipDraw3D[obj_Graphics3D, 
            rel_ /; MemberQ[{Less, LessEqual, Greater, GreaterEqual}, 
                  Head[rel]] && Length[rel] \[Equal] 2, var__Symbol, 
            opts___Rule] /; \((PolynomialQ[Subtract @@ rel, {var}] && 
              Max[\((Exponent[Expand[Subtract @@ rel], #1] &)\) /@ {var}] === 
                1)\) := Block[{$DisplayFunction = 
              Identity}, \[IndentingNewLine]\(LinearClipPlot3D[obj, rel, var, 
              opts]\)[\([1]\)]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LinearClipDraw3D[obj_SurfaceGraphics, other___] := 
        LinearClipDraw3D[Graphics3D[obj], other];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LinearClipDraw3D[obj_Graphics3D, 
          rel_ /; Or[
              MemberQ[{Less, LessEqual, Greater, GreaterEqual}, Head[rel]] && 
                Length[rel] > 2, Head[rel] === Inequality], var__Symbol, 
          opts___Rule] := 
        Block[{$DisplayFunction = Identity}, \(LinearClipPlot3D[obj, 
              Evaluate@LogicalExpand[rel], var, 
              opts]\)[\([1]\)]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LinearClipDraw3D[obj_Graphics3D, rel_And, var__Symbol, opts___Rule] := 
        Block[{$DisplayFunction = Identity}, \(Fold[
              LinearClipPlot3D[#1, #2, var, DisplayFunction \[Rule] Identity, 
                  opts] &, obj, List @@ rel]\)[\([1]\)]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["SliceSurfacePlot3D", "Subsubtitle"],

Cell[BoxData[
    \(\(SetAttributes[SliceSurfacePlot3D, \ HoldRest];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[SliceSurfacePlot3D] = 
        Join[{Contours \[Rule] 11, SurfaceStyle \[Rule] {EdgeForm[]}, 
            ContourStyle \[Rule] Automatic, 
            ColorFunctionScaling \[Rule] True, OrientedCurve \[Rule] False, 
            ShowProjectedLevelSets \[Rule] False, ProjectAt \[Rule] 0, 
            ArrowDensity \[Rule] 1, ArrowPositions \[Rule] Automatic, 
            ReverseOrientation \[Rule] False, 
            DrawGraphics`DrawingArrows`HeadScaling3D \[Rule] Automatic, 
            DrawGraphics`DrawingArrows`HeadLength3D \[Rule] 1/10}, 
          Options[ParametricPlot3D]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SliceSurfacePlot3D[obj_SurfaceGraphics, other___] := 
        SliceSurfacePlot3D[Graphics3D[obj], other];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SliceSurfacePlot[obj_Graphics3D, linForm_, x_Symbol, y_Symbol, 
            z_Symbol, 
            opts___?OptionQ] /; \((PolynomialQ[linForm, {x, y, z}] && 
              Max[Map[Exponent[Expand[linForm], #] &, {x, y, z}]] === 1)\) := 
        Module[{projQ, zlev, sl, mshsty, ratObj, vertList, extremaOfLinForm, 
            linearFormExcursion, lnsty, colorScalingQ, sliceList, singleStep, 
            newGr, newLines, slicedGr, sliceLines, grad, gradNormalized, 
            squishedLinesAdded, plotWithoutArrows, arwDnsty, pos, orientedQ, 
            arw3Dcolor, maxLevelLineLength, howManyArrows, arrowPos, 
            normalizedArrowPos, hdscl3D, addArrows, 
            plotWithArrows}, \[IndentingNewLine]{projQ, 
              zlev} = \({ShowProjectedLevelSets, ProjectAt} /. {opts}\) /. 
              Options[SliceSurfacePlot]; \[IndentingNewLine]sl = \(Contours /. \
{opts}\) /. Options[SliceSurfacePlot]; \[IndentingNewLine]mshsty = 
            Flatten[\({SurfaceStyle} /. {opts}\) /. 
                Options[SliceSurfacePlot]]; \[IndentingNewLine]ratObj = 
            Rationalize[obj[\([1]\)], 
              1/10^6]; \[IndentingNewLine]triangulized = 
            ratObj /. Polygon[{pt1_List, pts___}] \[RuleDelayed] 
                Sequence @@ 
                  Map[Polygon[Join[{pt1}, #]] &, 
                    Partition[{pts}, 2, 1]]; \[IndentingNewLine]vertList = 
            Cases[ratObj, 
              Polygon[pts_List] \[RuleDelayed] Sequence @@ pts, {1, 
                Infinity}]; \[IndentingNewLine]extremaOfLinForm = \({Min[#], 
                  Max[#]} &\)[
              linForm /. 
                Map[Thread[{x, y, z} \[Rule] #] &, 
                  vertList]]; \[IndentingNewLine]linearFormExcursion = 
            Abs[Subtract @@ extremaOfLinForm]; \[IndentingNewLine]If[
            Chop@linearFormExcursion === 0, 
            Print["\<The object is flat in the direction of the slices\>"]; 
            Abort[]]; \[IndentingNewLine]{lnsty, 
              colorScalingQ} = \({ContourStyle, 
                  ColorFunctionScaling} /. {opts}\) /. 
              Options[SliceSurfacePlot]; \[IndentingNewLine]If[
            MatchQ[lnsty, Hue | GrayLevel | _Function], 
            If[TrueQ@colorScalingQ, 
              lnsty = Evaluate[
                    lnsty[\((# - First@extremaOfLinForm)\)/
                        linearFormExcursion]] &], 
            lnsty = \((Evaluate[lnsty] &)\)]; \[IndentingNewLine]sliceList = 
            Which[IntegerQ[sl] && sl > 0, 
              Drop[Rest[
                  Range @@ \((extremaOfLinForm~
                        Join~{Abs[
                              Subtract @@ extremaOfLinForm]/\((sl + 
                                1)\)})\)], \(-1\)], 
              MatchQ[sl, {val__?\((\((NumericQ[#] && 
                            FreeQ[N[#], Complex])\) &)\)}], 
              sl, \[IndentingNewLine]True, 
              Print["\<can't handle these contours\>"]; 
              Abort[]]; \[IndentingNewLine]sliceList = 
            Sort[sliceList, Less]; \[IndentingNewLine]contourLine[
              val_] := \(LinearClip[Graphics3D[triangulized], 
                linForm \[LessEqual] val, x, y, z, 
                DisplayFunction \[Rule] Identity, 
                ContourStyle \[Rule] lnsty[val], 
                PrepareForSlices \[Rule] True, 
                Evaluate@
                  FilterOptions[LinearClip, 
                    opts]]\)[\([1, \(-1\)]\)]; \[IndentingNewLine]sliceLines \
= Map[contourLine, 
              sliceList]; \[IndentingNewLine]grad = \(Outer[
                D, {linForm}, {x, y, 
                  z}]\)[\([1]\)]; \[IndentingNewLine]gradNormalized = 
            grad/Sqrt[grad . grad]; \[IndentingNewLine]squishedLinesAdded := 
            sliceLines /. \((hd : \((Line | Polygon)\))\)[
                  pts_] \[RuleDelayed] {hd[pts], 
                  hd[Map[# - \((gradNormalized . #)\) gradNormalized + 
                          zlev*grad/\((linForm /. 
                                  Thread[{x, y, z} \[Rule] grad])\) &, 
                      pts]]}; \[IndentingNewLine]plotWithoutArrows = 
            Graphics3D[{Join[mshsty, ratObj], 
                If[TrueQ@projQ, squishedLinesAdded, 
                  sliceLines]}]; \[IndentingNewLine]{arwDnsty, pos, 
              orientedQ, 
              arw3Dcolor} = \({ArrowDensity, ArrowPositions, OrientedCurve, 
                  Arrow3DColor} /. {opts}\) /. 
              Options[LevelPlot3D]; \[IndentingNewLine]If[
            Not[TrueQ[orientedQ]], 
            Return[Show[plotWithoutArrows, FilterOptions[Graphics3D, opts], 
                DisplayFunction \[Rule] $DisplayFunction, 
                BoxRatios \[Rule] Automatic, 
                Rest[List @@ obj]]]]; \[IndentingNewLine]If[
            MatchQ[arw3Dcolor, Hue | GrayLevel | _Function], 
            If[TrueQ@colorScalingQ, 
              arw3Dcolor = 
                Evaluate[
                    arw3Dcolor[\((# - First@extremaOfLinForm)\)/
                        linearFormExcursion]] &], 
            arw3Dcolor = \((Evaluate[
                    arw3Dcolor] &)\)]; \[IndentingNewLine]maxLevelLineLength := 
            Max @@ N[
                Cases[plotWithoutArrows, 
                  l_Line \[RuleDelayed] lineLength @@ l, Infinity]]; 
          howManyArrows[pts_] := 
            Round[arwDnsty*3 
                 lineLength[pts]/
                  maxLevelLineLength]; \[IndentingNewLine]arrowPos[
              pts_ /; pos === 
                  Automatic] := \[IndentingNewLine]\((Range[1, 2  # - 1, 2]/
                    Max[2  #, 1] &)\)[
              howManyArrows[pts]]; \[IndentingNewLine]arrowPos[
              pts_ /; pos =!= Automatic] := 
            Flatten[{pos}]; \[IndentingNewLine]normalizedArrowPos[
              pts_] := \((\((# - Min[#, 0])\)/\((Max[#, 1] - 
                        Min[#, 0])\) &)\)[
              arrowPos[pts]]; \[IndentingNewLine]hdscl3D = 
            automaticHeadScaling3D[plotWithoutArrows, opts, 
              Sequence @@ 
                Options[SliceSurfacePlot]]; \[IndentingNewLine]addArrows[
              pts_, linFormValue_] := {Line[pts], 
              insertArrows[pts, normalizedArrowPos[pts], hdscl3D, 
                Arrow3DColor \[Rule] arw3Dcolor[linFormValue], 
                PlotStyle \[Rule] lnsty[linFormValue], opts, 
                FilterOptions[DrawGraphics`DrawingArrows`Arrow3D, 
                  Options[
                    SliceSurfacePlot]]]}; \[IndentingNewLine]plotWithArrows = 
            plotWithoutArrows /. \[IndentingNewLine]If[
                TrueQ@projQ, \[IndentingNewLine]{Line[pts1_], 
                    Line[pts2_]} \[RuleDelayed] \((linFormValue = 
                      linForm /. 
                        Thread[{x, y, z} \[Rule] First[pts1]]; {addArrows[
                        pts1, linFormValue], 
                      addArrows[pts2, 
                        linFormValue]})\), \[IndentingNewLine]Line[
                    pts_] \[RuleDelayed] 
                  Sequence @@ 
                    addArrows[pts, 
                      linForm /. 
                        Thread[{x, y, z} \[Rule] 
                            First[pts]]]]; \[IndentingNewLine]Show[
            plotWithArrows, 
            FilterOptions[Graphics3D, opts, BoxRatios \[Rule] Automatic, 
              DisplayFunction \[Rule] $DisplayFunction, 
              Rest[List @@ obj]]]\[IndentingNewLine]];\)\)], "Input",
  CellOpen->False],

Cell[BoxData[
    \(\(SliceSurfacePlot3D[obj_Graphics3D, linForm_, x_Symbol, y_Symbol, 
            z_Symbol, 
            opts___?OptionQ] /; \((PolynomialQ[linForm, {x, y, z}] && 
              Max[Map[Exponent[Expand[linForm], #] &, {x, y, z}]] === 1)\) := 
        Module[{projQ, zlev, sl, mshsty, ratObj, vertList, extremaOfLinForm, 
            linearFormExcursion, lnsty, colorScalingQ, sliceList, 
            sliceLineList, centralVal, srf, cntr, sliceLines, grad, 
            gradNormalized, squishedLinesAdded, plotWithoutArrows, arwDnsty, 
            pos, orientedQ, arw3Dcolor, maxLevelLineLength, howManyArrows, 
            arrowPos, normalizedArrowPos, hdscl3D, addArrows, 
            plotWithArrows}, \[IndentingNewLine]{projQ, 
              zlev} = \({ShowProjectedLevelSets, ProjectAt} /. {opts}\) /. 
              Options[SliceSurfacePlot3D]; \[IndentingNewLine]sl = \(Contours \
/. {opts}\) /. Options[SliceSurfacePlot3D]; \[IndentingNewLine]mshsty = 
            Flatten[\({SurfaceStyle} /. {opts}\) /. 
                Options[SliceSurfacePlot3D]]; \[IndentingNewLine]ratObj = 
            Rationalize[obj[\([1]\)], 
              1/10^6]; \[IndentingNewLine]triangulized = 
            ratObj /. Polygon[{pt1_List, pts___}] \[RuleDelayed] 
                Sequence @@ 
                  Map[Polygon[Join[{pt1}, #]] &, 
                    Partition[{pts}, 2, 1]]; \[IndentingNewLine]vertList = 
            Cases[ratObj, 
              Polygon[pts_List] \[RuleDelayed] Sequence @@ pts, {1, 
                Infinity}]; \[IndentingNewLine]extremaOfLinForm = \({Min[#], 
                  Max[#]} &\)[
              linForm /. 
                Map[Thread[{x, y, z} \[Rule] #] &, 
                  vertList]]; \[IndentingNewLine]linearFormExcursion = 
            Abs[Subtract @@ extremaOfLinForm]; \[IndentingNewLine]If[
            Chop@linearFormExcursion === 0, 
            Print["\<The object is flat in the direction of the slices\>"]; 
            Abort[]]; \[IndentingNewLine]{lnsty, 
              colorScalingQ} = \({ContourStyle, 
                  ColorFunctionScaling} /. {opts}\) /. 
              Options[SliceSurfacePlot3D]; \[IndentingNewLine]If[
            MatchQ[lnsty, Hue | GrayLevel | _Function], 
            If[TrueQ@colorScalingQ, 
              lnsty = Evaluate[
                    lnsty[\((# - First@extremaOfLinForm)\)/
                        linearFormExcursion]] &], 
            lnsty = \((Evaluate[lnsty] &)\)]; \[IndentingNewLine]sliceList = 
            Which[IntegerQ[sl] && sl > 0, 
              Drop[Rest[
                  Range @@ \((extremaOfLinForm~
                        Join~{Abs[
                              Subtract @@ extremaOfLinForm]/\((sl + 
                                1)\)})\)], \(-1\)], 
              MatchQ[sl, {val__?\((\((NumericQ[#] && 
                            FreeQ[N[#], Complex])\) &)\)}], 
              sl, \[IndentingNewLine]True, 
              Print["\<can't handle these contours\>"]; 
              Abort[]]; \[IndentingNewLine]sliceList = 
            Sort[sliceList, 
              Less]; \[IndentingNewLine]sliceLineList = {}; \
\[IndentingNewLine]{Graphics3D[triangulized], 
              sliceList} //. {{gr_Graphics3D, 
                  valueList_List /; 
                    Length[valueList] \[GreaterEqual] 
                      2} \[RuleDelayed] \((centralVal = 
                    Floor[Length[valueList]/2]; {{srf, cntr} = 
                      LinearClipPlot3D[gr, 
                          linForm \[LessEqual] valueList[\([centralVal]\)], 
                          x, y, z, DisplayFunction \[Rule] Identity, 
                          PrepareForSlices \[Rule] True, 
                          ContourStyle \[Rule] 
                            lnsty[valueList[\([centralVal]\)]]] // 
                        First; \[IndentingNewLine]AppendTo[
                      sliceLineList, {valueList[\([centralVal]\)], 
                        cntr}]; \[IndentingNewLine]If[
                      centralVal > 1, {Graphics3D[srf], 
                        Take[valueList, centralVal - 1]}, 
                      Sequence @@ {}], \[IndentingNewLine]{srf, cntr} = 
                      LinearClipPlot3D[gr, 
                          linForm \[GreaterEqual] 
                            valueList[\([centralVal + 1]\)], x, y, z, 
                          DisplayFunction \[Rule] Identity, 
                          PrepareForSlices \[Rule] True, 
                          ContourStyle \[Rule] 
                            lnsty[valueList[\([centralVal + 1]\)]]] // 
                        First; \[IndentingNewLine]AppendTo[
                      sliceLineList, {valueList[\([centralVal + 1]\)], 
                        cntr}]; \[IndentingNewLine]If[
                      centralVal + 1 < Length[valueList], {Graphics3D[srf], 
                        Drop[valueList, centralVal + 1]}, 
                      Sequence @@ {}]})\), \[IndentingNewLine]{gr_Graphics3D, \
{value_}} \[RuleDelayed] \(({srf, cntr} = 
                    LinearClipPlot3D[gr, linForm \[LessEqual] value, x, y, z, 
                        DisplayFunction \[Rule] Identity, 
                        PrepareForSlices \[Rule] True, 
                        ContourStyle \[Rule] lnsty[value]] // First; 
                  AppendTo[sliceLineList, {value, cntr}]; 
                  Sequence @@ {})\)}; \[IndentingNewLine]sliceLines = \(Sort[
                sliceLineList, 
                First[#1] < 
                    First[#2] &]\)[\([All, \(-1\)]\)]; \
\[IndentingNewLine]grad = \(Outer[
                D, {linForm}, {x, y, 
                  z}]\)[\([1]\)]; \[IndentingNewLine]gradNormalized = 
            grad/Sqrt[grad . grad]; \[IndentingNewLine]squishedLinesAdded := 
            sliceLines /. \((hd : \((Line | Polygon)\))\)[
                  pts_] \[RuleDelayed] {hd[pts], 
                  hd[Map[# - \((gradNormalized . #)\) gradNormalized + 
                          zlev*grad/\((linForm /. 
                                  Thread[{x, y, z} \[Rule] grad])\) &, 
                      pts]]}; \[IndentingNewLine]plotWithoutArrows = 
            Graphics3D[{Join[mshsty, ratObj], 
                If[TrueQ@projQ, squishedLinesAdded, 
                  sliceLines]}]; \[IndentingNewLine]{arwDnsty, pos, 
              orientedQ, 
              arw3Dcolor} = \({ArrowDensity, ArrowPositions, OrientedCurve, 
                  Arrow3DColor} /. {opts}\) /. 
              Options[LevelPlot3D]; \[IndentingNewLine]If[
            Not[TrueQ[orientedQ]], 
            Return[Show[plotWithoutArrows, FilterOptions[Graphics3D, opts], 
                DisplayFunction \[Rule] $DisplayFunction, 
                BoxRatios \[Rule] Automatic, 
                Rest[List @@ obj]]]]; \[IndentingNewLine]If[
            MatchQ[arw3Dcolor, Hue | GrayLevel | _Function], 
            If[TrueQ@colorScalingQ, 
              arw3Dcolor = 
                Evaluate[
                    arw3Dcolor[\((# - First@extremaOfLinForm)\)/
                        linearFormExcursion]] &], 
            arw3Dcolor = \((Evaluate[
                    arw3Dcolor] &)\)]; \[IndentingNewLine]maxLevelLineLength := 
            Max @@ N[
                Cases[plotWithoutArrows, 
                  l_Line \[RuleDelayed] lineLength @@ l, Infinity]]; 
          howManyArrows[pts_] := 
            Round[arwDnsty*3 
                 lineLength[pts]/
                  maxLevelLineLength]; \[IndentingNewLine]arrowPos[
              pts_ /; pos === 
                  Automatic] := \[IndentingNewLine]\((Range[1, 2  # - 1, 2]/
                    Max[2  #, 1] &)\)[
              howManyArrows[pts]]; \[IndentingNewLine]arrowPos[
              pts_ /; pos =!= Automatic] := 
            Flatten[{pos}]; \[IndentingNewLine]normalizedArrowPos[
              pts_] := \((\((# - Min[#, 0])\)/\((Max[#, 1] - 
                        Min[#, 0])\) &)\)[
              arrowPos[pts]]; \[IndentingNewLine]hdscl3D = 
            automaticHeadScaling3D[plotWithoutArrows, opts, 
              Sequence @@ 
                Options[SliceSurfacePlot3D]]; \[IndentingNewLine]addArrows[
              pts_, linFormValue_] := {Line[pts], 
              insertArrows[pts, normalizedArrowPos[pts], hdscl3D, 
                Arrow3DColor \[Rule] arw3Dcolor[linFormValue], 
                PlotStyle \[Rule] lnsty[linFormValue], opts, 
                FilterOptions[DrawGraphics`DrawingArrows`Arrow3D, 
                  Options[
                    SliceSurfacePlot3D]]]}; \[IndentingNewLine]plotWithArrows \
= plotWithoutArrows /. \[IndentingNewLine]If[
                TrueQ@projQ, \[IndentingNewLine]{Line[pts1_], 
                    Line[pts2_]} \[RuleDelayed] \((linFormValue = 
                      linForm /. 
                        Thread[{x, y, z} \[Rule] First[pts1]]; {addArrows[
                        pts1, linFormValue], 
                      addArrows[pts2, 
                        linFormValue]})\), \[IndentingNewLine]Line[
                    pts_] \[RuleDelayed] 
                  Sequence @@ 
                    addArrows[pts, 
                      linForm /. 
                        Thread[{x, y, z} \[Rule] 
                            First[pts]]]]; \[IndentingNewLine]Show[
            plotWithArrows, 
            FilterOptions[Graphics3D, opts, BoxRatios \[Rule] Automatic, 
              DisplayFunction \[Rule] $DisplayFunction, 
              Rest[List @@ obj]]]\[IndentingNewLine]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SliceSurfaceDraw3D[obj_Graphics3D, linForm_, x_Symbol, y_Symbol, 
            z_Symbol, 
            opts___?OptionQ] /; \((PolynomialQ[linForm, {x, y, z}] && 
              Max[Map[Exponent[Expand[linForm], #] &, {x, y, z}]] === 1)\) := 
        Block[{$DisplayFunction = 
              Identity}, \[IndentingNewLine]\(SliceSurfacePlot3D[obj, 
              linForm, x, y, z, opts]\)[\([1]\)]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["LevelPlot3D", "Subsubtitle"],

Cell[BoxData[
    \(\(SetAttributes[LevelPlot3D, HoldAll];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[LevelPlot3D] = 
        Join[{Contours \[Rule] 11, SurfaceStyle \[Rule] {EdgeForm[]}, 
            ContourStyle \[Rule] Automatic, 
            ShowProjectedLevelSets \[Rule] False, ProjectAt \[Rule] 0, 
            OrientedCurve \[Rule] False, ArrowDensity \[Rule] 1, 
            ArrowPositions \[Rule] Automatic, 
            ReverseOrientation \[Rule] False, 
            DrawGraphics`DrawingArrows`HeadScaling3D \[Rule] Automatic, 
            DrawGraphics`DrawingArrows`HeadLength3D \[Rule] 1/30}, 
          Options[ParametricPlot3D]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LevelPlot3D[f_, {x_Symbol, xMin_, xMax_}, {y_Symbol, yMin_, yMax_}, 
          opts___] := 
        Module[{z}, \[IndentingNewLine]SliceSurfacePlot3D[
            Plot3D[f, {x, xMin, xMax}, {y, yMin, yMax}, 
              DisplayFunction \[Rule] Identity, 
              Evaluate[FilterOptions[Plot3D, opts]]], z, x, y, z, 
            opts]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LevelDraw3D[x__] := 
        Block[{$DisplayFunction = Identity}, \[IndentingNewLine]\(LevelPlot3D[
              x]\)[\([1]\)]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Tail end", "Subsubtitle"],

Cell[BoxData[
    \(\(End[];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Protect["\<`*\>"];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(EndPackage[];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(On[General::"\<spell1\>"]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(On[General::"\<spell\>"]\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Basic usage examples", "Subtitle"],

Cell["A parabola with arrow on it:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{\(x\^2\), ",", \({x, \(-1\), 1}\), ",", 
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["A circle with arrow on it:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot", "[", 
        RowBox[{\({Cos[x], Sin[x]}\), ",", \({x, 0, 3  \[Pi]/2}\), ",", 
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["A helix with arrow on it:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{\({Cos[x], Sin[x], x\/\[Pi]}\), ",", \({x, 0, 2  \[Pi]}\), 
          ",", 
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The contour lines of the function ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\) \[RightTeeArrow] x\^2 + y\^2\)]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(x\^2 + y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", 
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["\<\
Numerical solution and plot of a differential equation in the \
plane:\
\>", "Text"],

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {
                StyleBox[\(\(x'\)[t] \[Equal] x[t]\/10 - y[t]\),
                  GridBoxOptions->{ColumnAlignments->{Left}}]},
              {
                StyleBox[\(\(y'\)[t] \[Equal] y[t]\/10 + x[t]\),
                  GridBoxOptions->{ColumnAlignments->{Left}}]},
              {
                StyleBox[\(x[0] \[Equal] 1\),
                  GridBoxOptions->{ColumnAlignments->{Left}}]},
              {
                StyleBox[\(y[0] \[Equal] 0\),
                  GridBoxOptions->{ColumnAlignments->{Left}}]}
              },
            ColumnAlignments->{Left}], ")"}], ",", \({x, y}\), 
        ",", \({t, 0, 10}\), ",", 
        StyleBox[\(PlotSolution \[Rule] True\),
          FontColor->RGBColor[1, 0, 0]]}], "]"}]], "Input"],

Cell["\<\
Numerical solution and plot of a differential equation in 3D space:\
\
\>", "Text"],

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\(x''\)[t] \[Equal] \(-x[t]\) \((1 + x[t]\^2)\)\)},
              {\(\(y''\)[
                    t] \[Equal] \(-y[t]\) \((1 + x[t]\^2 - x[t]\^4)\)\)},
              {\(\(z'\)[t] \[Equal] 1\/3\)},
              {\(x[0] \[Equal] 1\)},
              {\(y[0] \[Equal] 0\)},
              {\(\(x'\)[0] \[Equal] 0\)},
              {\(\(y'\)[0] \[Equal] 1\)},
              {\(z[0] \[Equal] 0\)}
              },
            ColumnAlignments->{Left}], ")"}], ",", \({x, y, z}\), 
        ",", \({t, 0, 10}\), ",", 
        StyleBox[\(PlotSolution \[Rule] True\),
          FontColor->RGBColor[1, 0, 0]]}], "]"}]], "Input"],

Cell["Force lines of a vector field in the plane:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["PhasePlot",
          FontColor->RGBColor[1, 0, 0]], "[", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {\(1\/\(1 + x\^2\)\)},
                {\(\(-y\) + x\)}
                }], ")"}], ",", \({x, \(-1\), 1}\), ",", \({y, \(-1\), 1}\), 
          ",", \({\(-3\), 3}\)}], "]"}], ";"}]], "Input"],

Cell["Force lines of a vector field in 3D space:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["PhasePlot",
          FontColor->RGBColor[1, 0, 0]], "[", 
        RowBox[{
          RowBox[{
            RowBox[{"(", GridBox[{
                  {"1", "2", "3"},
                  {"4", "3", "2"},
                  {"3", "1", "2"}
                  }], ")"}], ".", 
            RowBox[{"(", GridBox[{
                  {"x"},
                  {"y"},
                  {"z"}
                  }], ")"}]}], ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \({z, \(-1\), 1}\), 
          ",", \({\(-2\), 2}\), ",", \(GridPoints \[Rule] 4\), 
          ",", \(PlotStyle \[Rule] RGBColor\)}], "]"}], ";"}]], "Input"],

Cell["\<\
Phase portrait of a linear autonomous differential equation in the \
plane:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["LinearPhasePlot2D",
          FontColor->RGBColor[1, 0, 0]], "[", 
        RowBox[{"(", GridBox[{
              {"1", \(1\/2\)},
              {\(1\/5\), "2"}
              }], ")"}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-level lines on the surface plot of the function ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\) \[RightTeeArrow] x\^2 - y\^2\)]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["LevelPlot3D",
          FontColor->RGBColor[1, 0, 0]], 
        "[", \(x\^2 - y\^2, {x, \(-1\), 1}, {y, \(-1\), 1}\), "]"}], 
      ";"}]], "Input"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-level lines, with arrows along them, on the surface plot of the function \
",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\) \[RightTeeArrow] x\^2 - y\^2\)]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["LevelPlot3D",
          FontColor->RGBColor[1, 0, 0]], "[", 
        RowBox[{\(x\^2 - y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", 
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The parametric spiral ",
  Cell[BoxData[
      \(TraditionalForm\`t \[RightTeeArrow] \((t\ cos\ 10  t, 
          t\ sin\ 10  t)\)\)]],
  " \"lifted\" on the surface plot of the function ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\) \[RightTeeArrow] 
        1\/\(1 + x\^2 + y\^2\)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["PlotCurveOnSurface3D",
          FontColor->RGBColor[1, 0, 0]], 
        "[", \({1\/\(1 + x\^2 + y\^2\), {x, \(-2\), 2}, {y, \(-2\), 
            2}}, {{t*Cos[10  t], t*Sin[10  t]}, {t, 0, 2}, 
          PlotPoints \[Rule] 100, Oriented \[Rule] True}\), "]"}], 
      ";"}]], "Input"],

Cell[TextData[{
  "The contour lines of the function ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\) \[RightTeeArrow] x\^2 - y\^2\)]],
  " \"lifted\" on the surface plot of the function ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\) \[RightTeeArrow] 
        1\/\(1 + x\^2 + y\^2\)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["PlotCurveOnSurface3D",
          FontColor->RGBColor[1, 0, 0]], 
        "[", \({1\/\(1 + x^2 + y^2\), {x, \(-2\), 2}, {y, \(-2\), 
            2}}, {x\^2 - y\^2, {x, \(-2\), 2}, {y, \(-2\), 2}, 
          Contours \[Rule] 7}\), "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The (oriented) contour lines of the function ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y, z)\) \[RightTeeArrow] z + y\^2\)]],
  " on the cylinder ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2 + z\^2 = 1\)]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["PlotCurveOnSurface3D",
          FontColor->RGBColor[1, 0, 0]], 
        "[", \({{Cos[v], u, Sin[v]}, {u, \(-1\), 1}, {v, \(-Pi\), Pi}, 
          PlotPoints \[Rule] {2, 41}}, {Sin[v] + u\^2, {u, \(-1\), 
            1}, {v, \(-Pi\), Pi}, Oriented \[Rule] True, 
          PlotPoints \[Rule] 35}\), "]"}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Advanced examples", "Subtitle"],

Cell["\<\
Evaluate the input cells below to see the package in action and \
learn its usage.\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["The ",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["Oriented", "Input",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" option for curves in the plane",
    FontColor->RGBColor[1, 0, 0]]
}], "Subsubtitle"],

Cell[TextData[{
  "The package adds new options to ",
  ButtonBox["Plot",
    ButtonStyle->"RefGuideLink"],
  " and ",
  ButtonBox["ParametricPlot",
    ButtonStyle->"RefGuideLink"],
  " making it easy to place arrow heads along the lines. The basic option is \
",
  StyleBox["OrientedCurve", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{\(x\^2\), ",", \({x, 0, 1}\), ",", 
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "By default the number of arrow placed on the curve is the ratio of the \
length of the curve to the length of the smallest ",
  ButtonBox["Rectangle",
    ButtonStyle->"RefGuideLink"],
  " that contains the curve, rounded up by excess. You can ask for a \
different number through the option ",
  StyleBox["HowManyArrows", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot", "[", 
        RowBox[{\({Cos[x], Sin[x]}\), ",", \({x, 0, 3  \[Pi]/2}\), 
          ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(HowManyArrows \[Rule] 3\),
            FontColor->RGBColor[1, 0, 0]], 
          ",", \(AspectRatio \[Rule] Automatic\)}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can change the appearance of the arrows with the options described in \
the ",
  ButtonBox["Graphics`Arrow`",
    ButtonStyle->"AddOnsLink"],
  " package documentation. For example, you can make the arrow heads bigger \
or smaller by setting ",
  StyleBox["HeadLength", "Input",
    Background->RGBColor[1, 1, 0]],
  " to a value larger or smaller than the default ",
  StyleBox["1/20", "Input"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot", "[", 
        RowBox[{\({Cos[x], Sin[x]}\), ",", \({x, 0, 3  \[Pi]/2}\), 
          ",", \(Oriented \[Rule] True\), 
          ",", \(AspectRatio \[Rule] Automatic\), ",", 
          StyleBox[\(HeadLength \[Rule] 1/10\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["\<\
The default placement of the arrows along the cuve is designed to \
get them equally spaced when the curve is a loop:\
\>", "Text"],

Cell[BoxData[
    \(\(ParametricPlot[{Cos[x], Sin[x]}, {x, 0, 2  \[Pi]}, 
        Oriented \[Rule] True, AspectRatio \[Rule] Automatic];\)\)], "Input"],

Cell["A more complicated curve:", "Text"],

Cell[BoxData[
    \(\(ParametricPlot[{Cos[x] + Sin[3  x]/3, Sin[x]}, {x, 0, 2  \[Pi]}, 
        Oriented \[Rule] True, HowManyArrows \[Rule] 4, 
        AspectRatio \[Rule] Automatic];\)\)], "Input"],

Cell[TextData[{
  "You can override the default placement of the arrows along the curve with \
",
  StyleBox["ArrowPositions", "Input",
    Background->RGBColor[1, 1, 0]],
  ". Values must be between 0 and 1, and will place arrow heads \
proportionally with respect to arc length (allow for distoriton the more ",
  StyleBox["AspectRatio", "Input"],
  " is far from ",
  StyleBox["Automatic", "Input"],
  ")."
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot", "[", 
        RowBox[{\({Cos[x], Sin[x]}\), ",", \({x, 0, 3  \[Pi]/2}\), 
          ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(ArrowPositions \[Rule] {1/4, 1/2, 1}\),
            FontColor->RGBColor[1, 0, 0]], 
          ",", \(AspectRatio \[Rule] Automatic\)}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can reverse the direction of the arrows without changing \
parameterization with the option ",
  StyleBox["ReverseOrientation", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot", "[", 
        RowBox[{\({Cos[x], Sin[x]}\), ",", \({x, 0, 3  \[Pi]/2}\), 
          ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(ReverseOrientation \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["More of one curve on the same plot is allowed:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              StyleBox["t",
                FontColor->RGBColor[1, 0, 0]], ",", 
              StyleBox[\(t/2\),
                FontColor->RGBColor[0, 0, 1]]}], "}"}], ",", \({t, 0, 1}\), 
          ",", \(Oriented \[Rule] True\), ",", 
          RowBox[{"HowManyArrows", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["1",
                  FontColor->RGBColor[1, 0, 0]], ",", 
                StyleBox["2",
                  FontColor->RGBColor[0, 0, 1]]}], "}"}]}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["Red",
                  FontColor->RGBColor[1, 0, 0]], ",", 
                StyleBox["Blue",
                  FontColor->RGBColor[0, 0, 1]]}], "}"}]}]}], "]"}], 
      ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              StyleBox[\({Cos[x], Sin[x]}\),
                FontColor->RGBColor[1, 0, 0]], ",", 
              StyleBox[\({2  Cos[x], 2  Sin[x]}\),
                FontColor->RGBColor[0, 1, 0]]}], "}"}], 
          ",", \({x, 0, 3  \[Pi]/2}\), ",", \(Oriented \[Rule] True\), 
          ",", \(HowManyArrows \[Rule] 2\), ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"{", 
                  StyleBox["Red",
                    FontColor->RGBColor[1, 0, 0]], "}"}], ",", 
                RowBox[{"{", 
                  StyleBox["Green",
                    FontColor->RGBColor[0, 1, 0]], "}"}]}], "}"}]}], 
          ",", \(AspectRatio \[Rule] Automatic\), ",", 
          RowBox[{"Prolog", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{"Blue", ",", \(PointSize[ .04]\), ",", 
                StyleBox[\(Point[{0, 0}]\),
                  FontColor->RGBColor[0, 0, 1]]}], "}"}]}]}], "]"}], 
      ";"}]], "Input"],

Cell[TextData[{
  "All the options can be given also to ",
  ButtonBox["Draw",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["ParametricDraw",
    ButtonStyle->"AddOnsLink"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Draw2D", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"Red", ",", 
              RowBox[{"ParametricDraw", "[", 
                RowBox[{
                  StyleBox[\({Cos[x], Sin[x]}\),
                    FontColor->RGBColor[1, 0, 0]], 
                  ",", \({x, 0, 3  \[Pi]/2}\), 
                  ",", \(Oriented \[Rule] True\)}], "]"}], ",", 
              "\[IndentingNewLine]", "Green", ",", 
              RowBox[{"ParametricDraw", "[", 
                RowBox[{
                  StyleBox[\({2  Cos[x], 2  Sin[x]}\),
                    FontColor->RGBColor[0, 1, 0]], ",", \({x, 0, 2  \[Pi]}\), 
                  ",", \(Oriented \[Rule] True\)}], "]"}], ",", 
              "\[IndentingNewLine]", "Blue", ",", \(PointSize[ .04]\), ",", 
              StyleBox[\(Point[{0, 0}]\),
                FontColor->RGBColor[0, 0, 1]]}], "}"}], ",", 
          "\[IndentingNewLine]", \(AspectRatio \[Rule] Automatic\)}], "]"}], 
      ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["The ",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["Oriented", "Input",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" option for curves in 3D-space",
    FontColor->RGBColor[1, 0, 0]]
}], "Subsubtitle"],

Cell[TextData[{
  "The package adds new options to ",
  ButtonBox["ParametricPlot3D",
    ButtonStyle->"RefGuideLink"],
  " making it easy to place arrow heads along lines in 3D-space. The main \
option is ",
  StyleBox["Oriented", "Input",
    Background->RGBColor[1, 1, 0]],
  ", exactly as in the plane:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{\({Cos[x], Sin[x], x/\[Pi]}\), ",", \({x, 0, 2  \[Pi]}\), ",",
           
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "By default the number of arrow placed on the curve is the ratio of the \
length of the curve to the length of the smallest ",
  ButtonBox["Cuboid",
    ButtonStyle->"RefGuideLink"],
  " that contains the curve, rounded up by excess. Just as in the plance, you \
can choose the number of arrows with ",
  StyleBox["HowManyArrows", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{\({Cos[x], Sin[x], x/\[Pi]}\), ",", \({x, 0, 2  \[Pi]}\), 
          ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(HowManyArrows \[Rule] 3\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "Consult the documentation of the package ",
  ButtonBox["Arrow3D",
    ButtonStyle->"AddOnsLink"],
  " to learn how to change the shape of 3D arrows.  Here by default, ",
  StyleBox["HeadLength3D", "Input",
    Background->RGBColor[1, 1, 0]],
  " is set to ",
  StyleBox["1/10", "Input"],
  " of the lenght of the largest edge of the smallest ",
  ButtonBox["Cuboid",
    ButtonStyle->"RefGuideLink"],
  " that encloses the curve (or curves, if there are more than one; the \
option ",
  StyleBox["HeadScaling3D", "Input"],
  " is set internally to that length by default; if you write ",
  StyleBox["HeadScaling3D\[Rule]Relative", "Input"],
  " it will be ignored; only numeric values are taken into account). You can \
give a different length:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{\({Cos[x], Sin[x], x/\[Pi]}\), ",", \({x, 0, 2  \[Pi]}\), 
          ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(HeadLength3D \[Rule] 1/5\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can dictate the exact placement of the arrows along the curve with ",
  StyleBox["ArrowPositions", "Input",
    Background->RGBColor[1, 1, 0]],
  ". Values must be between 0 and 1, and will place arrow heads \
proportionally with respect to arc length (allow for some distoriton when ",
  StyleBox["AspectRatio", "Input"],
  " or ",
  StyleBox["BoxRatios", "Input"],
  " is not set to ",
  StyleBox["Automatic", "Input"],
  ")."
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{\({Cos[x], Sin[x], x/\[Pi]}\), ",", \({x, 0, 2  \[Pi]}\), 
          ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(ArrowPositions \[Rule] {1/4, 1/2, 1}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The ",
  StyleBox["default",
    FontSlant->"Italic"],
  " ",
  StyleBox["Automatic", "Input"],
  " setting of ",
  StyleBox["ArrowPositions", "Input"],
  " is meant to give evenly spaced arrows when the curve is a loop:"
}], "Text"],

Cell[BoxData[
    \(\(ParametricPlot3D[{Cos[x] + Sin[3  x]/3, Sin[x], Sin[x]}, {x, 0, 
          2  \[Pi]}, Oriented \[Rule] True];\)\)], "Input"],

Cell[TextData[{
  "The option ",
  ButtonBox["PlotStyle",
    ButtonStyle->"RefGuideLink"],
  " sets the style for the curve. The arrow is colored the same way as the \
curve, unless an arrow color is independently assigned through the options ",
  StyleBox["Arrow3DColor", "Input",
    Background->RGBColor[1, 1, 0]],
  " (and, if you want to see the polygons making up the arrows, also ",
  StyleBox["Arrow3DEdgeForm", "Input",
    Background->RGBColor[1, 1, 0]],
  "). Arrows of different colors along one curve are not supported."
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{\({Cos[x], Sin[x], x/\[Pi]}\), ",", \({x, 0, 2  \[Pi]}\), 
          ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(PlotStyle \[Rule] Red\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["\<\
The 3D arrows are surface objects, as you realize in the following \
picture:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{\({Cos[x], Sin[x], x/\[Pi]}\), ",", \({x, 0, 2  \[Pi]}\), 
          ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(Arrow3DColor \[Rule] {}\),
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[",",
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[\(Arrow3DEdgeForm \[Rule] EdgeForm[Black]\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "Keep in mind that an ",
  StyleBox["Arrow3D", "Input"],
  " is a solid object whose appearance is affected by the ",
  StyleBox["AspectRatio", "Input"],
  " or ",
  StyleBox["BoxRatios", "Input"],
  " (",
  StyleBox["un",
    FontSlant->"Italic"],
  "like a 2D ",
  StyleBox["Arrow", "Input"],
  "). They look best when ",
  StyleBox["BoxRatios", "Input"],
  " are ",
  StyleBox["Automatic", "Input"],
  " (default) or almost so. Otherwise they may get flattened and stretched in \
the display, as in the following example:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{\({x, x/30, x}\), ",", \({x, 0, 2  \[Pi]}\), 
          ",", \(Oriented \[Rule] True\), ",", \(PlotPoints \[Rule] 2\), ",", 
          
          StyleBox[\(BoxRatios \[Rule] {1, 1, 1}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The same 3D objects as in the previous example, but displayed at the \
default ",
  StyleBox["BoxRatios", "Input"],
  StyleBox["\[Rule]Automatic", "Input"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(ParametricPlot3D[{x, x/30, x}, {x, 0, 2  \[Pi]}, 
        Oriented \[Rule] True, PlotPoints \[Rule] 2];\)\)], "Input"],

Cell[TextData[{
  "You can reverse the direction of the arrows without changing \
parameterization with the option ",
  StyleBox["ReverseOrientation\[Rule]True", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{\({Cos[x], Sin[x], x/\[Pi]}\), ",", \({x, 0, 2  \[Pi]}\), 
          ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(ReverseOrientation \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "More of one curve on the same plot is allowed, just as in ",
  StyleBox["ParametricPlot3D", "Input"],
  ". The ",
  StyleBox["HeadScaling3D", "Input"],
  " is again taken as the length of the largest edge of the smallest ",
  ButtonBox["Cuboid",
    ButtonStyle->"RefGuideLink"],
  " that encloses the curves. The options ",
  StyleBox["HowManyArrows", "Input"],
  ", ",
  StyleBox["PlotStyle", "Input"],
  " and  ",
  StyleBox["Arrow3DColor", "Input"],
  " accept lists as values. ",
  StyleBox["ArrowPositions", "Input"],
  " also accepts a list of lists as a value."
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              StyleBox[\({Cos[x], Sin[x], x}\),
                FontColor->RGBColor[1, 0, 0]], ",", 
              StyleBox[\({2  Cos[x], 2  Sin[x], Sin[x]}\),
                FontColor->RGBColor[0, 0, 1]]}], "}"}], 
          ",", \({x, 0, 2  \[Pi]}\), ",", \(Oriented \[Rule] True\), ",", 
          RowBox[{"HowManyArrows", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["2",
                  FontColor->RGBColor[1, 0, 0]], ",", 
                StyleBox["1",
                  FontColor->RGBColor[0, 0, 1]]}], "}"}]}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"{", 
                  StyleBox["Red",
                    FontColor->RGBColor[1, 0, 0]], "}"}], ",", 
                RowBox[{"{", 
                  StyleBox["Blue",
                    FontColor->RGBColor[0, 0, 1]], "}"}]}], "}"}]}]}], "]"}], 
      ";"}]], "Input"],

Cell["One more example:", "Text"],

Cell[BoxData[
    \(\(ParametricPlot3D[{Cos[t], Sin[t], Cos[t]^2}, {t, 0, 2  \[Pi]}, 
        Oriented \[Rule] True];\)\)], "Input"],

Cell[TextData[{
  "You can use the option ",
  StyleBox["Oriented", "Input"],
  " with ",
  ButtonBox["ParametricDraw3D",
    ButtonStyle->"AddOnsLink"],
  ": here is a ",
  "helix",
  " path around a cylinder:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Draw3DItems", "[", 
        RowBox[{
          RowBox[{"{", 
            
            RowBox[{\({EdgeForm[], 
                ParametricDraw3D[{Cos[t]/2, Sin[t]/2, z}, {t, 0, 
                    2  \[Pi]}, {z, 0, 6}, PlotPoints \[Rule] {17, 2}]}\), ",",
               "\[IndentingNewLine]", 
              RowBox[{
                StyleBox["ParametricDraw3D",
                  FontColor->RGBColor[1, 0, 0]], "[", 
                
                RowBox[{\({Cos[t], Sin[t], t/\[Pi]}\), 
                  ",", \({t, 0, 6  \[Pi]}\), ",", 
                  StyleBox[\(Oriented \[Rule] True\),
                    FontColor->RGBColor[1, 0, 0]], 
                  ",", \(HowManyArrows \[Rule] 9\), 
                  ",", \(HeadLength3D \[Rule] 1/20\)}], "]"}]}], "}"}], 
          ",", \(Boxed \[Rule] False\)}], "]"}], ";"}]], "Input"],

Cell["and a helix around a torus:", "Text"],

Cell[BoxData[
    \(\(Needs["\<Geometry`Rotations`\>"];\)\)], "Input"],

Cell[BoxData[{\(rot[u_, v_, \[Phi]_] = 
        Rotate3D[{u, 0, v}, \[Phi], 0, 0];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Draw3DItems", "[", 
        RowBox[{
          RowBox[{"{", 
            
            RowBox[{\({EdgeForm[], 
                ParametricDraw3D[
                  Evaluate[rot[2 + Cos[t]/2, Sin[t]/2, \[Phi]]], {\[Phi], 0, 
                    2  \[Pi]}, {t, 0, 2  \[Pi]}, 
                  PlotPoints \[Rule] {37, 13}]}\), ",", "\[IndentingNewLine]",
               
              RowBox[{
                StyleBox["ParametricDraw3D",
                  FontColor->RGBColor[1, 0, 0]], "[", 
                
                RowBox[{\(Evaluate@rot[2 + Cos[t], Sin[t], t/6]\), 
                  ",", \({t, 0, 12  \[Pi]}\), ",", \(PlotPoints \[Rule] 150\),
                   ",", 
                  StyleBox[\(Oriented \[Rule] True\),
                    FontColor->RGBColor[1, 0, 0]], 
                  ",", \(HowManyArrows \[Rule] 12\), 
                  ",", \(HeadLength3D \[Rule] 1/20\)}], "]"}]}], "}"}], 
          ",", \(Boxed \[Rule] False\), ",", \(ImageSize \[Rule] 300\)}], 
        "]"}], ";"}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["The ",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["Oriented", "Input",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" option for surfaces",
    FontColor->RGBColor[1, 0, 0]]
}], "Subsubtitle"],

Cell[TextData[{
  ButtonBox["Plot3D",
    ButtonStyle->"RefGuideLink"],
  " and ",
  ButtonBox["ParametrciPlot3D",
    ButtonStyle->"RefGuideLink"],
  " can be used to plot a ",
  StyleBox["surface",
    FontSlant->"Italic"],
  ". In that case the new option ",
  StyleBox["Oriented", "Input",
    Background->RGBColor[1, 1, 0]],
  " draws arrows along the contour of the surface:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot3D", "[", 
        RowBox[{\(\(-x^2\) + y^2\), ",", \({x, \(-1\)/3, 1}\), 
          ",", \({y, 0, 1}\), ",", 
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "By default the surface mesh is suppressed. The arrows and the contour are \
less visible if we reinstate the mesh (keep in mind that the mesh syntax is \
quite different for ",
  ButtonBox["Plot3D",
    ButtonStyle->"RefGuideLink"],
  " and ",
  ButtonBox["ParametricPlot3D",
    ButtonStyle->"RefGuideLink"],
  ")"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot3D", "[", 
        RowBox[{\(\(-x^2\) + y^2\), ",", \({x, \(-1\)/3, 1}\), 
          ",", \({y, 0, 1}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(MeshStyle \[Rule] Black\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"x", ",", "y", ",", \(\(-x^2\) + y^2\), ",", 
              StyleBox[\(EdgeForm[Black]\),
                FontColor->RGBColor[1, 0, 0]]}], "}"}], 
          ",", \({x, \(-1\)/3, 1}\), ",", \({y, 0, 1}\), 
          ",", \(Oriented \[Rule] True\)}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "Consult the documentation of the package ",
  ButtonBox["Arrow3D",
    ButtonStyle->"AddOnsLink"],
  " to learn how to change the shape of 3D arrows.  Here by default, ",
  StyleBox["HeadLength3D", "Input",
    Background->RGBColor[1, 1, 0]],
  " is set to ",
  StyleBox["1/10", "Input"],
  " of the length of the largesst edge of the smallest ",
  ButtonBox["Cuboid",
    ButtonStyle->"RefGuideLink"],
  " that encloses the edges. You can give a different length:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{\({x, y, \(-x^2\) + y^2}\), ",", \({x, \(-1\)/3, 1}\), 
          ",", \({y, 0, 1}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(HeadLength3D \[Rule] 1/4\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The color and thickness of the contour can be changed with ",
  ButtonBox["ContourStyle",
    ButtonStyle->"RefGuideLink"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot3D", "[", 
        RowBox[{\({x, y, \(-x^2\) + y^2}\), ",", \({x, \(-1\)/3, 1}\), 
          ",", \({y, 0, 1}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(ContourStyle \[Rule] {Red, Thickness[ .015]}\),
            FontColor->RGBColor[1, 0, 0]], 
          ",", \(HeadLength3D \[Rule] 1/6\)}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  " The number of arrows along each edge (ordered counterclockwise starting \
from the bottom, in the parameter space) can be assigned with ",
  StyleBox["HowManyArrows", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"x", ",", "y", ",", \(\(-x^2\) + y^2\), ",", 
              StyleBox[\(EdgeForm[Green]\),
                FontColor->RGBColor[0, 1, 0]]}], "}"}], 
          ",", \({x, \(-1\)/3, 1}\), ",", \({y, 0, 1}\), 
          ",", \(Oriented \[Rule] True\), ",", \(PlotPoints \[Rule] 25\), 
          ",", \(HeadLength3D \[Rule] 1/9\), ",", 
          StyleBox[\(HowManyArrows \[Rule] {1, 2, 3, 4}\),
            FontColor->RGBColor[1, 0, 0]], 
          ",", \(ContourStyle \[Rule] Red\)}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can dictate the positions of the arrows along each edge with ",
  StyleBox["ArrowPositions", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"x", ",", "y", ",", \(\(-x^2\) + y^2\), ",", 
              StyleBox[\(EdgeForm[Blue]\),
                FontColor->RGBColor[0, 0, 1]]}], "}"}], 
          ",", \({x, \(-1\)/3, 1}\), ",", \({y, 0, 1}\), 
          ",", \(Oriented \[Rule] True\), ",", \(HeadLength3D \[Rule] 1/5\), 
          ",", \(ContourStyle \[Rule] Thickness[ .02]\), ",", 
          StyleBox[\(ArrowPositions \[Rule] {{1/3}, {1/2}, {1/5}, {7/10}}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  ButtonBox["ContourStyle",
    ButtonStyle->"RefGuideLink"],
  " can also be different along the four edges. In particular, the value ",
  StyleBox["None", "Input"],
  " suppresses the edge line:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot3D", "[", 
        RowBox[{\(\(-x^2\) + y^2\), ",", \({x, \(-1\)/3, 1}\), 
          ",", \({y, 0, 1}\), ",", \(Oriented \[Rule] True\), ",", 
          
          StyleBox[\(ContourStyle \[Rule] {{None}, {Thickness[ .01]}, {None}, \
{None}}\),
            FontColor->RGBColor[1, 0, 0]], 
          ",", \(HowManyArrows \[Rule] {0, 1, 0, 0}\)}], "]"}], 
      ";"}]], "Input"],

Cell["You can have edges without arrows and arrows without edges:", "Text"],

Cell[BoxData[
    \(\(Plot3D[\(-x^2\) + y^2, {x, \(-1\)/3, 1}, {y, 0, 1}, 
        Oriented \[Rule] True, Mesh \[Rule] False, 
        ContourStyle \[Rule] {{None}, {Thickness[ .012]}, {None}, {}}, 
        HowManyArrows \[Rule] {0, 1, 2, 0}, 
        PlotRange \[Rule] All];\)\)], "Input"],

Cell["A perhaps more meaningfule example:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{\({r*Cos[t], r*Sin[t], r^2}\), ",", \({r, 0, 1}\), 
          ",", \({t, 0, 2  \[Pi]}\), ",", \(Oriented \[Rule] True\), ",", 
          
          StyleBox[\(ContourStyle \[Rule] {{None}, {Thickness[ .01], 
                  PermanentGreen}, {None}, {None}}\),
            FontColor->RGBColor[1, 0, 0]], 
          ",", \(PlotPoints \[Rule] {8, 21}\), 
          ",", \(HowManyArrows \[Rule] {0, 3, 0, 0}\)}], "]"}], 
      ";"}]], "Input"],

Cell[TextData[{
  "You can reverse the orientation of the contour with the option ",
  StyleBox["ReverseOrientation", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{\({x, y, \(-x^2\) + y^2}\), ",", \({x, \(-1\)/3, 1}\), 
          ",", \({y, 0, 1}\), ",", \(Oriented \[Rule] True\), ",", " ", 
          StyleBox[\(ReverseOrientation \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["You can reverse the orientation on an edge-by-edge basis:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot3D", "[", 
        RowBox[{\(\(-x^2\) + y^2\), ",", \({x, \(-1\)/3, 1}\), 
          ",", \({y, 0, 1}\), ",", \(Oriented \[Rule] True\), ",", " ", 
          
          StyleBox[\(ReverseOrientation \[Rule] {True, False, False, False}\),
            
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"x", ",", "y", ",", \(\(-x^2\) + y^2\), ",", 
              StyleBox[\(EdgeForm[Blue]\),
                FontColor->RGBColor[0, 0, 1]]}], "}"}], 
          ",", \({x, \(-1\)/3, 1}\), ",", \({y, 0, 1}\), 
          ",", \(Oriented \[Rule] True\), ",", " ", 
          
          StyleBox[\(ReverseOrientation \[Rule] {True, False, False, False}\),
            
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can give shading to the surface, as with the regular ",
  ButtonBox["Plot3D",
    ButtonStyle->"RefGuideLink"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot3D", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"y", ",", 
              StyleBox[\(Hue[\((x + y)\)/2]\),
                FontColor->RGBColor[1, 0, 0]]}], "}"}], 
          ",", \({x, \(-1\)/3, 1}\), ",", \({y, 0, 1}\), 
          ",", \(Oriented \[Rule] True\), ",", \(PlotPoints \[Rule] 5\)}], 
        "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot3D", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{\(\(-x^2\) + y^2\), ",", 
              StyleBox[\(RGBColor[\((x + 1/3)\) 3/4, y, 0]\),
                FontColor->RGBColor[1, 0, 0]]}], "}"}], 
          ",", \({x, \(-1\)/3, 1}\), ",", \({y, 0, 1}\), 
          ",", \(Oriented \[Rule] True\), ",", \(HeadLength3D \[Rule] 1/5\)}],
         "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The option ",
  StyleBox["Oriented", "Input"],
  ", and all the associated ones, can be given to ",
  ButtonBox["Draw2D",
    ButtonStyle->"AddOnsLink"],
  " too:"
}], "Text"],

Cell[BoxData[{\(Clear[x, y, f, 
        normalVec];\), "\[IndentingNewLine]", \(f = \(-x^2\) + 
          y^2;\), "\[IndentingNewLine]", \(normalVec = \(Outer[
            D, {z - f}, {x, y, z}]\)[\([1]\)];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Draw3DItems", "[", 
        RowBox[{
          RowBox[{"{", 
            
            RowBox[{\({Blue, PointSize[ .02], Point[{x, y, f}], EdgeForm[], 
                  SurfaceColor[Blue], Thickness[ .01], 
                  Arrow3D[{x, y, f}, {x, y, f} + normalVec, 
                    HeadWidth3D \[Rule]  .3, 
                    HeadLength3D \[Rule]  .2]} /. {x \[Rule] 1/2, 
                  y \[Rule] 1/2}\), ",", "\[IndentingNewLine]", 
              RowBox[{
                StyleBox["Draw3D",
                  FontColor->RGBColor[1, 0, 0]], "[", 
                RowBox[{
                "f", ",", \({x, \(-1\)/3, 1}\), ",", \({y, 0, 1}\), ",", 
                  StyleBox[\(Oriented \[Rule] True\),
                    FontColor->RGBColor[1, 0, 0]], 
                  ",", \(MeshStyle \[Rule] Gainsboro\)}], "]"}], ",", 
              "\[IndentingNewLine]", \(Text[
                DisplayForm@
                  GridBox[{{"\<normal\>"}, {"\<vector\>"}}], {x, y, f} + 
                    normalVec /. {x \[Rule] 1/2, y \[Rule] 1/2}, {\(-1\), 
                  0}]\)}], "}"}], ",", 
          "\[IndentingNewLine]", \(Boxed \[Rule] False\)}], "]"}], 
      ";"}]}], "Input"],

Cell["Some more examples:", "Text"],

Cell["A cylinder:", "Text"],

Cell[BoxData[
    \(\(With[{a = \(-\[Pi]\)/
                2 +  .6}, \[IndentingNewLine]ParametricPlot3D[{Cos[t], 
            Sin[t], u}, {t, a, a + 2  \[Pi] -  .3}, {u, 0, 1}, 
          PlotPoints \[Rule] {25, 2}, Oriented \[Rule] True, 
          Boxed \[Rule] False, Axes \[Rule] False]];\)\)], "Input"],

Cell["A cut-open sphere:", "Text"],

Cell[BoxData[
    \(\(With[{a = \(-\[Pi]\)/2 +  .7, b =  .7, 
          c =  .3}, \[IndentingNewLine]ParametricPlot3D[{Cos[t] Sin[u], 
            Sin[t] Sin[u], Cos[u]}, {t, a, a + 2  \[Pi] - b}, {u, 
            c, \[Pi] - c}, Oriented \[Rule] True, HowManyArrows \[Rule] 1, 
          ContourStyle \[Rule] Thickness[ .005], 
          ViewPoint -> {1.2, \ \(-3\), \ 1}, Boxed \[Rule] False, 
          Axes \[Rule] False]];\)\)], "Input"],

Cell["A cut-open M\[ODoubleDot]bius strip:", "Text"],

Cell[BoxData[
    \(\(Needs["\<Geometry`Rotations`\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(ParametricPlot3D[
        Rotate3D[Rotate3D[{0, 1, u}, 0, \[Phi]/2, 0, {0, 1, 0}], \[Phi], 0, 
          0], {u, \(-1\)/2, 1/2}, {\[Phi], 0, 2  \[Pi] -  .3}, 
        Oriented \[Rule] True, ContourStyle \[Rule] Thickness[ .005], 
        PlotPoints \[Rule] {2, 31}, Boxed \[Rule] False, 
        Axes \[Rule] False];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["The ",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["Oriented", "Input",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" option for ",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["ContourPlot", "Input",
    FontColor->RGBColor[1, 0, 0]]
}], "Subsubtitle"],

Cell[TextData[{
  "This package adds the option ",
  StyleBox["Oriented", "Input",
    Background->RGBColor[1, 1, 0]],
  " to ",
  ButtonBox["ContourPlot",
    ButtonStyle->"RefGuideLink"],
  " . When that is set to ",
  StyleBox["True", "Input"],
  ", arrows will be placed along the contour lines:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(x^2 + y^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", 
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The ",
  ButtonBox["ContourStyle",
    ButtonStyle->"RefGuideLink"],
  " option affects the color of the arrows too:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(x^2 + y^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(ContourStyle \[Rule] Red\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(x^2 + y^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(ContourStyle \[Rule] Table[{Hue[n/11]}, {n, 11}]\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can change the style of the arrows with the options described in the \
",
  ButtonBox["Graphics`Arrow`",
    ButtonStyle->"AddOnsLink"],
  " package documentation By default ",
  ButtonBox["HeadScaling",
    ButtonStyle->"AddOnsLink"],
  " is set to ",
  StyleBox["Automatic", "Input"],
  " (other settings will be ignored). You can make the arrow heads bigger or \
smaller by setting ",
  ButtonBox["HeadLength",
    ButtonStyle->"AddOnsLink"],
  " to a value larger or smaller than the default ",
  StyleBox["1/20", "Input"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(x^2 + y^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(HeadLength \[Rule] 1/30\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "By default the contour lines are oriented  so that the function is larger \
on the left of the curve, and smaller on the right. You reverse this \
behaviour with ",
  StyleBox["ReverseOrientation", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(x^2 + y^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(ReverseOrientation \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You have some control on how many arrows are drawn with the option ",
  StyleBox["ArrowDensity", "Input",
    Background->RGBColor[1, 1, 0]],
  ". The default value is 1."
}], "Text"],

Cell[BoxData[
    \(\(ContourPlot[x^2 + y^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
        Oriented \[Rule] True, ArrowDensity \[Rule] 2];\)\)], "Input"],

Cell["\<\
Contour lines in regions where the function is rather flat can get \
the algorithm a bit confused:\
\>", "Text"],

Cell[BoxData[
    \(\(ContourPlot[y*x^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
        Oriented \[Rule] True, Contours \[Rule] 9];\)\)], "Input"],

Cell[BoxData[
    \(\(ContourPlot[y*x^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
        Oriented \[Rule] True, Contours \[Rule] 9, 
        ArrowDensity \[Rule] 5];\)\)], "Input"],

Cell[TextData[{
  "The default settings are meant to give reasonably good results when ",
  ButtonBox["AspectRatio",
    ButtonStyle->"RefGuideLink"],
  " is ",
  StyleBox["Automatic", "Input"],
  " and the contours have radius of curvature not too small. Otherwise the \
arrows may not lie nicely along the curves. For example, the arrow shaft may \
become visible:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(x^2 + \((y/10)\)^2\), ",", \({x, \(-1\), 1}\), ",", 
          StyleBox[\({y, \(-10\), 10}\),
            FontColor->RGBColor[1, 0, 0]], ",", \(Oriented \[Rule] True\)}], 
        "]"}], ";"}]], "Input"],

Cell[TextData[{
  "Some option tweaking may come to help in such cases. For example, try to \
set ",
  StyleBox["ArrowShaftLength", "Input",
    Background->RGBColor[1, 1, 0]],
  " to a small enough value:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(x^2 + \((y/10)\)^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-10\), 10}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(ArrowShaftLength \[Rule] 1/10\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "To get a better understanding of what ",
  StyleBox["ArrowShaftLength", "Input"],
  " means, try setting it to a value comparable to the size of the graph:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(x^2 + y^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \(Oriented \[Rule] True\), 
          StyleBox[",",
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[\(ArrowShaftLength -> 1/2\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "If you set ",
  StyleBox["ArrowsAcrossSubdivisions", "Input",
    Background->RGBColor[1, 1, 0]],
  " to ",
  StyleBox["False", "Input"],
  " (the default is ",
  StyleBox["True", "Input"],
  "), you constrain the arrow shafts to be inside one of the straight line \
segments of which the line is made of. In practice, the arrows will be ",
  StyleBox["tangent",
    FontSlant->"Italic"],
  " to the line. This may not be so nice when the radius of curvature is \
comparable or smaller than the arrow head size. In the following case the \
radius of curvature is not too small, and the result looks the same as we got \
from just setting a small ",
  StyleBox["ArrowShaftLength", "Input"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(x^2 + \((y/10)\)^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-10\), 10}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(ArrowsAcrossSubdivisions \[Rule] False\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can add the direction field (not specially nice) with ",
  StyleBox["ShowField", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(x^2 + y^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(ShowField \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["Example: the trajectories of the pendulum system:", "Text"],

Cell[BoxData[
    \(\(ContourPlot[\(-Cos[x]\) + 
          y^2/2, {x, \(-\[Pi]\), \[Pi]}, {y, \(-\[Pi]\), \[Pi]}, 
        Oriented \[Rule] True];\)\)], "Input"],

Cell[TextData[{
  "Increasing the option ",
  ButtonBox["PlotPoints",
    ButtonStyle->"RefGuideLink"],
  " you can make the curves less jagged:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(\(-Cos[x]\) + y^2/2\), ",", \({x, \(-\[Pi]\), \[Pi]}\), 
          ",", \({y, \(-\[Pi]\), \[Pi]}\), ",", \(Oriented \[Rule] True\), 
          ",", 
          StyleBox[\(PlotPoints \[Rule] 30\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "By default ",
  ButtonBox["ContourShading",
    ButtonStyle->"RefGuideLink"],
  " is set to ",
  StyleBox["False", "Input"],
  " when ",
  StyleBox["Oriented", "Input"],
  " is ",
  StyleBox["True", "Input"],
  ", but you can change that:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(\(-Cos[x]\) + y^2/2\), ",", \({x, \(-\[Pi]\), \[Pi]}\), 
          ",", \({y, \(-\[Pi]\), \[Pi]}\), ",", \(Oriented \[Rule] True\), 
          ",", 
          StyleBox[\(ContourShading \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["With a color function that avoids deep blacks:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(\(-Cos[x]\) + y^2/2\), ",", \({x, \(-\[Pi]\), \[Pi]}\), 
          ",", \({y, \(-\[Pi]\), \[Pi]}\), ",", \(Oriented \[Rule] True\), 
          ",", 
          StyleBox[\(ContourShading \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[",",
            FontColor->RGBColor[1, 0, 0]], 
          
          StyleBox[\(ColorFunction \[Rule] \((GrayLevel[\((1 + 2  #)\)/
                      3] &)\)\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["A psychedelic effect:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(\(-Cos[x]\) + y^2/2\), ",", \({x, \(-\[Pi]\), \[Pi]}\), 
          ",", \({y, \(-\[Pi]\), \[Pi]}\), ",", \(Oriented \[Rule] True\), 
          ",", 
          StyleBox[\(ContourShading \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[",",
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[\(ColorFunction \[Rule] Hue\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "To catch a singular point you have to be careful with ",
  ButtonBox["PlotPoints",
    ButtonStyle->"RefGuideLink"],
  " and ",
  ButtonBox["Contours",
    ButtonStyle->"RefGuideLink"],
  ": (disregard the warning messages)"
}], "Text"],

Cell[BoxData[
    \(\(ContourPlot[x*y, {x, \(-1\), 1}, {y, \(-1\), 1}, 
        Oriented \[Rule] True];\)\)], "Input"],

Cell[BoxData[
    \(\(ContourPlot[x*y, {x, \(-1\), 1}, {y, \(-1\), 1}, 
        Oriented \[Rule] True, Contours \[Rule] 9];\)\)], "Input"],

Cell[TextData[{
  "This plot is better with ",
  StyleBox["ArrowDensity", "Input",
    Background->RGBColor[1, 1, 0]],
  " higher than the default value of 1:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ContourPlot", "[", 
        RowBox[{\(x*y\), ",", \({x, \(-1\), 1}\), ",", \({y, \(-1\), 1}\), 
          ",", \(Oriented \[Rule] True\), ",", \(Contours \[Rule] 9\), 
          ",", \(PlotPoints \[Rule] {21, 21}\), ",", 
          StyleBox[\(ArrowDensity \[Rule] 2\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The ",
  StyleBox["Oriented", "Input"],
  " option also works with ",
  ButtonBox["ContourDraw",
    ButtonStyle->"AddOnsLink"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Draw2D", "[", 
        RowBox[{
          RowBox[{"{", "\[IndentingNewLine]", 
            
            RowBox[{\(DensityDraw[x^2 + y^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
                Mesh \[Rule] False, PlotPoints \[Rule] 50, 
                ColorFunction \[Rule] \((GrayLevel[2  #/3 + 1/3] &)\)]\), ",",
               
              RowBox[{
                StyleBox["ContourDraw",
                  FontColor->RGBColor[1, 0, 0]], 
                "[", \(x^2 + y^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
                Oriented \[Rule] True\), "]"}], ",", "\[IndentingNewLine]", 
              "Red", ",", \(Text["\<center\>", {0, 0}, 
                Background \[Rule] Yellow]\)}], "}"}], ",", 
          "\[IndentingNewLine]", \(AspectRatio \[Rule] Automatic\), 
          ",", \(Frame \[Rule] True\)}], "]"}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["The ",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["PlotSolution", "Input",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" option for ",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["NDSolve", "Input",
    FontColor->RGBColor[1, 0, 0]]
}], "Subsubtitle"],

Cell[TextData[{
  ButtonBox["NDSolve",
    ButtonStyle->"RefGuideLink"],
  " gives a numeric solution to a system of differential equations. Plotting \
the solution however is a little tricky for a beginner. This package adds the \
new option ",
  StyleBox["PlotSolution", "Input",
    Background->RGBColor[1, 1, 0]],
  ", which makes a plot of the solution when there is one independent \
variable and at most 3 unknonwn functions."
}], "Text"],

Cell["A first-order planar system:", "Text"],

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {
                StyleBox[\(\(x'\)[t] \[Equal] x[t]/10 - y[t]\),
                  GridBoxOptions->{ColumnAlignments->{Left}}]},
              {
                StyleBox[\(\(y'\)[t] \[Equal] y[t]/10 + x[t]\),
                  GridBoxOptions->{ColumnAlignments->{Left}}]},
              {
                StyleBox[\(x[0] \[Equal] 1\),
                  GridBoxOptions->{ColumnAlignments->{Left}}]},
              {
                StyleBox[\(y[0] \[Equal] 0\),
                  GridBoxOptions->{ColumnAlignments->{Left}}]}
              },
            ColumnAlignments->{Left}], ")"}], ",", \({x, y}\), 
        ",", \({t, 0, 10}\), ",", 
        StyleBox[\(PlotSolution \[Rule] True\),
          FontColor->RGBColor[1, 0, 0]]}], "]"}]], "Input"],

Cell[TextData[{
  "The output is a list ",
  Cell[BoxData[
      \(TraditionalForm\`{NDSolve\ output, \ \[SkeletonIndicator]Graphics\
\[SkeletonIndicator]}\)]],
  "."
}], "Text"],

Cell[TextData[{
  "The option ",
  StyleBox["Oriented", "Input",
    Background->RGBColor[1, 1, 0]],
  " is ",
  StyleBox["True", "Input"],
  " by default when the unknown functions are two or three. You can turn the \
arrows off:"
}], "Text"],

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\(x'\)[t] \[Equal] x[t]/10 - y[t]\)},
              {\(\(y'\)[t] \[Equal] y[t]/10 + x[t]\)},
              {\(x[0] \[Equal] 1\)},
              {\(y[0] \[Equal] 0\)}
              },
            ColumnAlignments->{Left}], ")"}], ",", \({x, y}\), 
        ",", \({t, 0, 10}\), ",", \(PlotSolution \[Rule] True\), ",", 
        StyleBox[\(Oriented \[Rule] False\),
          FontColor->RGBColor[1, 0, 0]]}], "]"}]], "Input"],

Cell["A second-order planar system:", "Text"],

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\(x''\)[t] \[Equal] \(-x[t]\) \((1 + x[t]\^2)\)\)},
              {\(\(y''\)[
                    t] \[Equal] \(-y[t]\) \((1 + x[t]\^2 - x[t]\^4)\)\)},
              {\(x[0] \[Equal] 1\)},
              {\(y[0] \[Equal] 0\)},
              {\(\(x'\)[0] \[Equal] 0\)},
              {\(\(y'\)[0] \[Equal] 1\)}
              },
            ColumnAlignments->{Left}], ")"}], ",", \({x, y}\), 
        ",", \({t, 0, 10}\), ",", 
        StyleBox[\(PlotSolution \[Rule] True\),
          FontColor->RGBColor[1, 0, 0]]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "==", \(y[t]\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "==", \(\(- .01\)\ y[t] - Sin[x[t]]\)}], ",", \(x[0] == 0\), 
        ",", \(y[0] == 2.1\)}], "}"}]], "Input"],

Cell["The motion of a damped pendulum:", "Text"],

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {
                RowBox[{
                  RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], 
                  "==", \(y[t]\)}]},
              {
                RowBox[{
                  RowBox[{
                    SuperscriptBox["y", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], 
                  "==", \(\(- .03\)\ y[t] - Sin[x[t]]\)}]},
              {\(x[0] == 0\)},
              {\(y[0] == 2.1\)}
              },
            ColumnAlignments->{Left}], ")"}], ",", \({x, y}\), 
        ",", \({t, 0, 30}\), ",", 
        StyleBox[\(PlotSolution \[Rule] True\),
          FontColor->RGBColor[1, 0, 0]]}], "]"}]], "Input"],

Cell[TextData[{
  "In dimension 2 the color of the curve is controlled with ",
  ButtonBox["PlotStyle",
    ButtonStyle->"RefGuideLink"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\(x''\)[t] \[Equal] \(-x[t]\) \((1 + x[t]\^2)\)\)},
              {\(\(y''\)[
                    t] \[Equal] \(-y[t]\) \((1 + x[t]\^2 - x[t]\^4)\)\)},
              {\(x[0] \[Equal] 1\)},
              {\(y[0] \[Equal] 0\)},
              {\(\(x'\)[0] \[Equal] 0\)},
              {\(\(y'\)[0] \[Equal] 1\)}
              },
            ColumnAlignments->{Left}], ")"}], ",", \({x, y}\), 
        ",", \({t, 0, 10}\), ",", \(PlotSolution \[Rule] True\), ",", 
        StyleBox[\(PlotStyle \[Rule] Red\),
          FontColor->RGBColor[1, 0, 0]]}], "]"}]], "Input"],

Cell[TextData[{
  "You can give the same options as with ",
  ButtonBox["ParametricPlot",
    ButtonStyle->"RefGuideLink"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\(x'\)[t] \[Equal] y[t]\)},
              {\(\(y'\)[t] \[Equal] 1\)},
              {\(x[0] \[Equal] 0\)},
              {\(y[0] \[Equal] 0\)}
              },
            ColumnAlignments->{Left}], ")"}], ",", \({x, y}\), 
        ",", \({t, 0, 1}\), ",", \(PlotSolution \[Rule] True\), ",", 
        StyleBox[\(ArrowPositions \[Rule] {1/2, 1}\),
          FontColor->RGBColor[1, 0, 0]], ",", 
        StyleBox[\(PlotStyle \[Rule] Red\),
          FontColor->RGBColor[1, 0, 0]], ",", 
        StyleBox[\(Prolog \[Rule] {Red, PointSize[ .03], Point[{0, 0}]}\),
          FontColor->RGBColor[1, 0, 0]]}], "]"}]], "Input"],

Cell[TextData[{
  "A system in three unknown functions is displayed as a 3D curve with \
arrows. The arrow options are the same as for ",
  ButtonBox["ParametricPlot3D",
    ButtonStyle->"RefGuideLink"],
  ". with the ",
  StyleBox["Oriented", "Input",
    Background->RGBColor[1, 1, 0]],
  " option, described above:"
}], "Text"],

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\(x''\)[t] \[Equal] \(-x[t]\) \((1 + x[t]\^2)\)\)},
              {\(\(y''\)[
                    t] \[Equal] \(-y[t]\) \((1 + x[t]\^2 - x[t]\^4)\)\)},
              {\(\(z'\)[t] \[Equal] 1/3\)},
              {\(x[0] \[Equal] 1\)},
              {\(y[0] \[Equal] 0\)},
              {\(\(x'\)[0] \[Equal] 0\)},
              {\(\(y'\)[0] \[Equal] 1\)},
              {\(z[0] \[Equal] 0\)}
              },
            ColumnAlignments->{Left}], ")"}], ",", \({x, y, z}\), 
        ",", \({t, 0, 10}\), ",", 
        StyleBox[\(PlotSolution \[Rule] True\),
          FontColor->RGBColor[1, 0, 0]]}], "]"}]], "Input"],

Cell[TextData[{
  "Also in dimension 3 the style of the curve is controlled with ",
  ButtonBox["PlotStyle",
    ButtonStyle->"RefGuideLink"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\(x''\)[t] \[Equal] \(-x[t]\) \((1 + x[t]\^2)\)\)},
              {\(\(y''\)[
                    t] \[Equal] \(-y[t]\) \((1 + x[t]\^2 - x[t]\^4)\)\)},
              {\(\(z'\)[t] \[Equal] 1/3\)},
              {\(x[0] \[Equal] 1\)},
              {\(y[0] \[Equal] 0\)},
              {\(\(x'\)[0] \[Equal] 0\)},
              {\(\(y'\)[0] \[Equal] 1\)},
              {\(z[0] \[Equal] 0\)}
              },
            ColumnAlignments->{Left}], ")"}], ",", \({x, y, z}\), 
        ",", \({t, 0, 10}\), ",", \(PlotSolution \[Rule] True\), ",", 
        StyleBox[\(PlotStyle \[Rule] Red\),
          FontColor->RGBColor[1, 0, 0]]}], "]"}]], "Input"],

Cell[TextData[{
  ButtonBox["Lorenz equations",
    ButtonStyle->"MasterIndexLink"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\(x'\)[t] \[Equal] \(-3\)\ \((x[t] - y[t])\)\)},
              {\(\(y'\)[t] \[Equal] \(-x[t]\)\ z[t] + 26.5\ x[t] - y[t]\)},
              {\(\(z'\)[t] \[Equal] x[t]\ y[t] - z[t]\)},
              {\(x[0] \[Equal] z[0] \[Equal] 0\)},
              {\(y[0] \[Equal] 1\)}
              },
            ColumnAlignments->{Left}], ")"}], ",", \({x, y, z}\), 
        ",", \({t, 0, 9.1}\), ",", 
        StyleBox[\(PlotSolution \[Rule] True\),
          FontColor->RGBColor[1, 0, 0]], ",", \(PlotPoints \[Rule] 600\), 
        ",", \(ImageSize \[Rule] 300\), ",", \(HeadLength3D \[Rule] 1/30\)}], 
      "]"}]], "Input"],

Cell[TextData[{
  ButtonBox["R\[ODoubleDot]ssler equations"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\(x'\)[t] \[Equal] \(-y[t]\) - z[t]\)},
              {\(\(y'\)[t] \[Equal] x[t] +  .425\ y[t]\)},
              {\(\(z'\)[t] \[Equal] 2 - z[t]\ \((4 - x[t])\)\)},
              {\(x[0] \[Equal] \(-0.04\)\)},
              {\(y[0] \[Equal] \(-0.30\)\)},
              {\(z[0] \[Equal] 0.52\)}
              },
            ColumnAlignments->{Left}], ")"}], ",", \({x, y, z}\), 
        ",", \({t, 0, 25}\), ",", \(Method \[Rule] ExplicitRungeKutta\), ",", 
        
        StyleBox[\(PlotSolution \[Rule] True\),
          FontColor->RGBColor[1, 0, 0]], ",", \(PlotPoints \[Rule] 400\), 
        ",", \(PlotRange \[Rule] All\)}], "]"}]], "Input"],

Cell["\<\
A second-order scalar equation (the default for scalar equations is \
without arrows):\
\>", "Text"],

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\(x''\)[t] + \(x'\)[t]/2 \[Equal] \(-x[t]\)\)},
              {\(x[0] \[Equal] 1\)},
              {\(\(x'\)[0] \[Equal] 0\)}
              },
            ColumnAlignments->{Left}], ")"}], ",", "x", ",", \({t, 0, 10}\), 
        ",", \(PlotSolution \[Rule] True\), ",", \(PlotRange \[Rule] All\)}], 
      "]"}]], "Input"],

Cell["Same as above, but with arrows:", "Text"],

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\(x''\)[t] + \(x'\)[t]/2 \[Equal] \(-x[t]\)\)},
              {\(x[0] \[Equal] 1\)},
              {\(\(x'\)[0] \[Equal] 0\)}
              },
            ColumnAlignments->{Left}], ")"}], ",", "x", ",", \({t, 0, 10}\), 
        ",", \(PlotSolution \[Rule] True\), ",", 
        StyleBox[\(Oriented \[Rule] True\),
          FontColor->RGBColor[1, 0, 0]], ",", \(PlotRange \[Rule] All\), 
        ",", \(HowManyArrows \[Rule] 3\)}], "]"}]], "Input"],

Cell[TextData[{
  "With the option ",
  StyleBox["DrawSolution", "Input",
    Background->RGBColor[1, 1, 0]],
  " the output is of the form {NDsolve solution, graphics primitives of the \
plot}, and the display is inhibited:"
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{\({{sol}, pl}\), "=", 
        RowBox[{"NDSolve", "[", 
          RowBox[{
            RowBox[{"(", GridBox[{
                  {\(\(x'\)[t] \[Equal] x[t]/10 - y[t]\)},
                  {\(\(y'\)[t] \[Equal] y[t]/10 + x[t]\)},
                  {\(x[0] \[Equal] 1\)},
                  {\(y[0] \[Equal] 0\)}
                  },
                ColumnAlignments->{Left}], ")"}], ",", \({x, y}\), 
            ",", \({t, 0, 10}\), ",", 
            StyleBox[\(DrawSolution \[Rule] True\),
              FontColor->RGBColor[1, 0, 0]]}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(Draw2D[{Text["\<start\>", {1, 0}], 
          Text["\<end\>", {x[10], y[10]} /. sol], pl}];\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["PhasePlot", "Input",
  FontColor->RGBColor[1, 0, 0]]], "Subsubtitle"],

Cell[TextData[{
  StyleBox["PhasePlot", "Input",
    Background->RGBColor[1, 1, 0]],
  " draws trajectories of a 2D or 3D autonomous system of ordinary \
differential equations, placing arrows along the curves:"
}], "Text"],

Cell[BoxData[
    \(\(PhasePlot[{1\/\(1 + x\^2\), \(-y\) + x}, {x, \(-1\), 1}, {y, \(-1\), 
          1}, {\(-3\), 3}];\)\)], "Input"],

Cell[TextData[{
  "For a system of the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["{",
            SpanMaxSize->Infinity,
            GridBoxOptions->{ColumnAlignments->{Left}}], 
          StyleBox[GridBox[{
                {\(x' \((t)\) \[Equal] f(x(t), y(t))\)},
                {\(y' \((t)\) \[Equal] g(x(t), y(t))\)},
                {\(x\_min \[LessEqual] x \[LessEqual] x\_max\)},
                {\(y\_min \[LessEqual] y \[LessEqual] y\_max\)},
                {\(t\_min \[LessEqual] t \[LessEqual] t\_max\)}
                },
              ColumnAlignments->{Left}],
            GridBoxOptions->{ColumnAlignments->{Left}}]}], 
        TraditionalForm]]],
  " the syntax is ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(PhasePlot[{f[x, y], g[x, y]}, {x, x\_min, x\_max}, {y, 
              y\_min, y\_max}, {t\_min, t\_max}, options]\),
          "Input"], TraditionalForm]]],
  ". This is made to resemble the syntax of ",
  ButtonBox["PlotField",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Text"],

Cell["\<\
You can give the vector fiels as a column vector, instead of a row \
vector, to the same effect:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {\(1\/\(1 + x\^2\)\)},
                {\(\(-y\) + x\)}
                }], ")"}], ",", \({x, \(-1\), 1}\), ",", \({y, \(-1\), 1}\), 
          ",", \({\(-3\), 3}\)}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "When positioning the arrows along the solution curves, ",
  StyleBox["PhasePlot", "Input"],
  " only takes into accout the portion of the curves contained in the display \
area ",
  Cell[BoxData[
      FormBox[
        StyleBox[\({x, x\_min, x\_max}, {y, y\_min, y\_max}\),
          "Input"], TraditionalForm]]],
  ". Anything outside is clipped."
}], "Text"],

Cell["The pendulum system:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {"y"},
                {\(-Sin[x]\)}
                }], ")"}], ",", \({x, \(-2\) \[Pi], 2  \[Pi]}\), 
          ",", \({y, \(-2\), 2}\), ",", \({0, 2}\)}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "By default the starting points are a 5x5 rectangular grid. You can change \
the density of the grid with the option ",
  StyleBox["GridPoints", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {\(1/\((1 + x^2)\)\)},
                {\(\(-y\) + x\)}
                }], ")"}], ",", \({x, \(-1\), 1}\), ",", \({y, \(-1\), 1}\), 
          ",", \({\(-3\), 3}\), ",", 
          StyleBox[\(GridPoints \[Rule] 3\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can see the starting points with the option ",
  StyleBox["ShowListPlot", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{\({1/\((1 + x^2)\), \(-y\) + x}\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \({\(-3\), 3}\), 
          ",", \(GridPoints \[Rule] 3\), ",", 
          StyleBox[\(ShowListPlot \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can give an arbitrary set of starting points with the option ",
  StyleBox["InitialPoints", "Input",
    Background->RGBColor[1, 1, 0]],
  ". In the next example they are along a semi-circle, which seems to give a \
more nicely spaced-out plot:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{\({1/\((1 + x^2)\), \(-y\) + x}\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \({\(-3\), 2}\), ",", 
          
          StyleBox[\(InitialPoints \[Rule] 
              Table[{1 + Cos[\[Theta]], Sin[\[Theta]]}, {\[Theta], \[Pi]/2, 
                  3  \[Pi]/2, \[Pi]/12}]\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can color the curves with ",
  ButtonBox["PlotStyle",
    ButtonStyle->"RefGuideLink"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{\({1/\((1 + x^2)\), \(-y\) + x}\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \({\(-3\), 3}\), 
          ",", \(GridPoints \[Rule] 3\), ",", 
          StyleBox[\(PlotStyle \[Rule] Red\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {\(\(-x\) - y\)},
                {\(\(-y\) + x\)}
                }], ")"}], ",", \({x, \(-1\), 1}\), ",", \({y, \(-1\), 1}\), 
          ",", \({0, 2  \[Pi]}\), ",", \(GridPoints \[Rule] 2\), ",", 
          StyleBox[\(PlotStyle \[Rule] Red\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can assign a function to ",
  ButtonBox["PlotStyle",
    ButtonStyle->"RefGuideLink"],
  ". Every curve will get as style the function evaluated at the starting \
point:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{\({\(-x\) - y, \(-y\) + x}\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \({0, 2  \[Pi]}\), 
          ",", \(GridPoints \[Rule] 2\), ",", 
          
          StyleBox[\(PlotStyle \[Rule] 
              Function[{x, y}, RGBColor[x, y, 1/3]]\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "Actually, unless ",
  ButtonBox["ColorFunctionScaling",
    ButtonStyle->"RefGuideLink"],
  " is reset to ",
  ButtonBox["False",
    ButtonStyle->"RefGuideLink"],
  ", the ",
  Cell[BoxData[
      \(TraditionalForm\`x, y\)]],
  " values fed into ",
  ButtonBox["PlotStyle",
    ButtonStyle->"RefGuideLink"],
  " will be scaled to the display area. See the documentation for ",
  ButtonBox["DensityPlot",
    ButtonStyle->"RefGuideLink"],
  " and ",
  ButtonBox["ContourPlot",
    ButtonStyle->"RefGuideLink"],
  "."
}], "Text"],

Cell[TextData[{
  "You can give to ",
  ButtonBox["PlotStyle",
    ButtonStyle->"RefGuideLink"],
  " also a list of list of directives, that will be applied cyclically to the \
curves:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{\({\(-x\) - y, \(-y\) + x}\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \({0, 2  \[Pi]}\), 
          ",", \(GridPoints \[Rule] 2\), ",", 
          
          StyleBox[\(PlotStyle \[Rule] {{Red}, {Dashing[{ .02,  .02}]}, \
{Thickness[ .01]}, {Dashing[{ .01,  .01}], Blue}}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The arrows will inherit the color of the curve it is on. Other ",
  ButtonBox["Arrow",
    ButtonStyle->"AddOnsLink"],
  " options can only be set globally, and not on a curve-by-curve basis:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{\({\(-x\) - y, \(-y\) + x}\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \({0, 2  \[Pi]}\), 
          ",", \(GridPoints \[Rule] 2\), 
          ",", \(PlotStyle \[Rule] Function[{x, y}, RGBColor[x, y, 0]]\), ",",
           
          StyleBox[\(HeadLength \[Rule]  .1\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The points of ",
  StyleBox["ShowListPlot", "Input"],
  " inherit the color of the curve that starts from them:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{\({1, Sqrt[2]}\), ",", \({x, 0, 1}\), ",", \({y, 0, 1}\), 
          ",", \({0, 1}\), 
          ",", \(PlotStyle \[Rule] Function[{x, y}, RGBColor[x, y, 0]]\), ",",
           
          StyleBox[\(ShowListPlot \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can change their style otherwise with ",
  StyleBox["ListPlotStyle", "Input",
    Background->RGBColor[1, 1, 0]],
  ", that also accepts a function as value:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{\({1, Sqrt[2]}\), ",", \({x, 0, 1}\), ",", \({y, 0, 1}\), 
          ",", \({0, 1}\), ",", \(ShowListPlot \[Rule] True\), ",", 
          
          StyleBox[\(ListPlotStyle \[Rule] 
              Function[{x, y}, {RGBColor[x, y, 0], PointSize[ .04]}]\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{\({1, Sqrt[2]}\), ",", \({x, 0, 1}\), ",", \({y, 0, 1}\), 
          ",", \({0, 1}\), ",", \(ShowListPlot \[Rule] True\), ",", 
          StyleBox[\(ListPlotStyle \[Rule] {Red, PointSize[ .04]}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{\({1, Sqrt[2]}\), ",", \({x, 0, 1}\), ",", \({y, 0, 1}\), 
          ",", \({0, 1}\), 
          ",", \(PlotStyle \[Rule] Function[{x, y}, RGBColor[x, y, 0]]\), 
          ",", \(ShowListPlot \[Rule] True\), ",", 
          StyleBox[\(ListPlotStyle \[Rule] PointSize[ .04]\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  StyleBox["PhasePlot", "Input"],
  " can also draw a phase portrait of a 3D autonomous system, for example a \
linear system:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"(", GridBox[{
                  {"1", "2", "3"},
                  {"4", "3", "2"},
                  {"3", "1", "2"}
                  }], ")"}], ".", 
            RowBox[{"(", GridBox[{
                  {"x"},
                  {"y"},
                  {"z"}
                  }], ")"}]}], ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \({z, \(-1\), 1}\), 
          ",", \({\(-2\), 2}\), ",", \(GridPoints \[Rule] 3\), 
          ",", \(PlotStyle \[Rule] RGBColor\)}], "]"}], ";"}]], "Input"],

Cell["A stereogram of the same plot:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Show", "[", 
        RowBox[{
          RowBox[{"Block", "[", 
            
            RowBox[{\({$DisplayFunction = Identity}\), ",", 
              "\[IndentingNewLine]", 
              RowBox[{
                RowBox[{"gr", "=", 
                  RowBox[{"PhasePlot", "[", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"(", GridBox[{
                              {"1", "2", "3"},
                              {"4", "3", "2"},
                              {"3", "1", "2"}
                              }], ")"}], ".", 
                        RowBox[{"(", GridBox[{
                              {"x"},
                              {"y"},
                              {"z"}
                              }], ")"}]}], ",", \({x, \(-1\), 1}\), 
                      ",", \({y, \(-1\), 1}\), ",", \({z, \(-1\), 1}\), 
                      ",", \({\(-2\), 2}\), ",", \(GridPoints \[Rule] 3\), 
                      ",", \(PlotStyle \[Rule] RGBColor\)}], "]"}]}], ";", 
                "\[IndentingNewLine]", \(GraphicsArray[{Show[gr, 
                      ViewPoint \[Rule] {1.300, \ \(-2.400\), \ 2}, 
                      ViewCenter \[Rule] {1, 1, 1}/2], 
                    Show[gr, ViewPoint \[Rule] {1.6, \ \(-2.2\), \ 2}, 
                      ViewCenter \[Rule] {1, 1, 1}/2]}]\)}]}], "]"}], 
          ",", \(ImageSize \[Rule] 800\), 
          ",", \(GraphicsSpacing \[Rule]  .15\)}], "]"}], ";"}]], "Input"],

Cell["Another phase portrait in 3D:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"(", GridBox[{
                    {"0", "0", "0"},
                    {"0", \(-\(1\/2\)\), \(-1\)},
                    {"0", "1", \(-\(1\/2\)\)}
                    }], ")"}], ".", 
              RowBox[{"(", GridBox[{
                    {"x"},
                    {"y"},
                    {"z"}
                    }], ")"}]}], "+", 
            RowBox[{"(", GridBox[{
                  {"1"},
                  {"0"},
                  {"0"}
                  }], ")"}]}], ",", \({x, 0, 2  \[Pi]}\), 
          ",", \({y, \(-1\), 1}\), ",", \({z, \(-1\), 1}\), 
          ",", \({0, 2  \[Pi]}\), 
          ",", \(InitialPoints \[Rule] 
            Table[{ .1, Cos[t], Sin[t]}, {t, 0, 2  \[Pi], \[Pi]/3}]\), 
          ",", \(ImageSize \[Rule] 600\)}], "]"}], ";"}]], "Input"],

Cell["Same as above, but with colored curves:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PhasePlot", "[", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"(", GridBox[{
                    {"0", "0", "0"},
                    {"0", \(-\(1\/2\)\), \(-1\)},
                    {"0", "1", \(-\(1\/2\)\)}
                    }], ")"}], ".", 
              RowBox[{"(", GridBox[{
                    {"x"},
                    {"y"},
                    {"z"}
                    }], ")"}]}], "+", 
            RowBox[{"(", GridBox[{
                  {"1"},
                  {"0"},
                  {"0"}
                  }], ")"}]}], ",", \({x, 0, 2  \[Pi]}\), 
          ",", \({y, \(-1\), 1}\), ",", \({z, \(-1\), 1}\), 
          ",", \({0, 2  \[Pi]}\), 
          ",", \(InitialPoints \[Rule] 
            Table[{ .1, Cos[t], Sin[t]}, {t, 0, 2  \[Pi], \[Pi]/3}]\), ",", 
          StyleBox[\(PlotStyle \[Rule] RGBColor\),
            FontColor->RGBColor[1, 0, 0]], ",", \(ImageSize \[Rule] 600\)}], 
        "]"}], ";"}]], "Input"],

Cell[TextData[{
  StyleBox["PhaseDraw", "Input",
    Background->RGBColor[1, 1, 0]],
  " is the ",
  ButtonBox["DrawGraphics",
    ButtonStyle->"AddOnsLink"],
  " companion to ",
  StyleBox["PhasePlot", "Input"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Draw2D", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              RowBox[{"PhaseDraw", "[", 
                RowBox[{
                  RowBox[{"(", GridBox[{
                        {\(x*y \((1 - y)\)\)},
                        {\(\(-x\)*y \((1 - x)\)\)}
                        }], ")"}], ",", \({x, 0, 2}\), ",", \({y, 0, 2}\), 
                  ",", \({0, 3}\), 
                  ",", \(PlotStyle \[Rule] Function[{x, y}, Hue[x + y]]\)}], 
                "]"}], ",", \(Text["\<equilibrium\>", {1, 
                  1}, {0, \(-1.5\)}]\)}], "}"}], ",", \(Frame \[Rule] True\), 
          ",", \(AspectRatio \[Rule] Automatic\)}], "]"}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["LinearPhasePlot2D", "Input",
  FontColor->RGBColor[1, 0, 0]]], "Subsubtitle"],

Cell["\<\
LinearPhasePlot2D takes a two-by-two real matrix as argument, plus \
options.The matrix must be made of exact numbers, not of floating-point \
numbers.\
\>", "Text"],

Cell[TextData[{
  "The function ",
  "LinearPhasePlot2D",
  " accepts all ",
  StyleBox["Plot", "Input"],
  " options, but it ignores ",
  StyleBox["PlotRange", "Input"],
  ". "
}], "Text"],

Cell[TextData[{
  "With the option ",
  StyleBox["NotableLineStyle", "Input",
    Background->RGBColor[1, 1, 0]],
  " you can control how the following special lines are drawn: the \
eigenspaces when the eigenvalues are real, and the symmetry axes of the \
ellipse image of the unit circle when the eigenvalues are complex."
}], "Text"],

Cell[TextData[{
  "With the option ",
  StyleBox["NumberOfTrajectories", "Input",
    Background->RGBColor[1, 1, 0]],
  " you can control how many trajectories are drawn. The default value is ",
  StyleBox["5", "Input"],
  ", which was found to be reasonable. If you want less trajectories try a \
value of 4 or 3; if you want more try 6 or 7."
}], "Text"],

Cell[TextData[{
  "With the option ",
  StyleBox["WriteReport", "Input",
    Background->RGBColor[1, 1, 0]],
  " set to ",
  StyleBox["True", "Input"],
  " (the default) you get a classification of the kind of equilibrium the \
origin is."
}], "Text"],

Cell["Try out the following examples:", "Text"],

Cell["Repulsive node:", "Text"],

Cell[BoxData[
    \(\(LinearPhasePlot2D[{{1, 0}, {0, 2}}];\)\)], "Input"],

Cell["With 2-dimensional input form:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LinearPhasePlot2D", "[", 
        RowBox[{"(", GridBox[{
              {"1", "0"},
              {"0", "2"}
              }], ")"}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LinearPhasePlot2D", "[", 
        RowBox[{"(", GridBox[{
              {"1", \(1\/2\)},
              {\(1\/5\), "2"}
              }], ")"}], "]"}], ";"}]], "Input"],

Cell["Same as above, with the field:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LinearPhasePlot2D", "[", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {"1", \(1\/2\)},
                {\(1\/5\), "2"}
                }], ")"}], ",", 
          StyleBox[\(ShowField \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "Same as above, with eigenspaces colored ",
  StyleBox["greeen",
    FontColor->RGBColor[0, 1, 0]],
  " instead of the defaule ",
  StyleBox["red",
    FontColor->RGBColor[1, 0, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LinearPhasePlot2D", "[", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {"1", \(1\/2\)},
                {\(1\/5\), "2"}
                }], ")"}], ",", 
          StyleBox[\(NotableLineStyle \[Rule] Green\),
            FontColor->RGBColor[0, 1, 0]]}], "]"}], ";"}]], "Input"],

Cell["\<\
By turning off the insertion of arrow along the curves (as distinct \
from the grid-arrows of the field) the computation is faster:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LinearPhasePlot2D", "[", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {"1", \(1\/2\)},
                {\(1\/5\), "2"}
                }], ")"}], ",", 
          StyleBox[\(Oriented \[Rule] False\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["Saddle:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LinearPhasePlot2D", "[", 
        RowBox[{"(", GridBox[{
              {\(-1\), "0"},
              {"1", "1"}
              }], ")"}], "]"}], ";"}]], "Input"],

Cell["Saddle with the field:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LinearPhasePlot2D", "[", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {\(-1\), "0"},
                {"1", "1"}
                }], ")"}], ",", 
          StyleBox[\(ShowField \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["One null eigenvalue, the other one positive:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"With", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"m", "=", 
              RowBox[{"(", GridBox[{
                    {"1", "2"},
                    {"3", "4"}
                    }], ")"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"LinearPhasePlot2D", "[", 
            RowBox[{"m", ".", 
              RowBox[{"(", GridBox[{
                    {"1", "0"},
                    {"0", "0"}
                    }], ")"}], ".", \(Inverse[m]\)}], "]"}]}], "]"}], 
      ";"}]], "Input"],

Cell["Improper node:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LinearPhasePlot2D", "[", 
        RowBox[{"(", GridBox[{
              {"2", "1"},
              {\(-1\), "4"}
              }], ")"}], "]"}], ";"}]], "Input"],

Cell["Identity matrix:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LinearPhasePlot2D", "[", 
        RowBox[{"-", 
          RowBox[{"(", GridBox[{
                {"1", "0"},
                {"0", "1"}
                }], ")"}]}], "]"}], ";"}]], "Input"],

Cell["Two null eigenvalues:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"With", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"m", "=", 
              RowBox[{"(", GridBox[{
                    {"1", "2"},
                    {"3", "4"}
                    }], ")"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"LinearPhasePlot2D", "[", 
            RowBox[{"m", ".", 
              RowBox[{"(", GridBox[{
                    {"0", "1"},
                    {"0", "0"}
                    }], ")"}], ".", \(Inverse[m]\)}], "]"}]}], "]"}], 
      ";"}]], "Input"],

Cell["Null matrix:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LinearPhasePlot2D", "[", 
        RowBox[{"(", GridBox[{
              {"0", "0"},
              {"0", "0"}
              }], ")"}], "]"}], ";"}]], "Input"],

Cell["Center:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"With", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"m", "=", 
              RowBox[{"(", GridBox[{
                    {"1", "2"},
                    {"3", "1"}
                    }], ")"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"LinearPhasePlot2D", "[", 
            RowBox[{"m", ".", 
              RowBox[{"(", GridBox[{
                    {"0", "1"},
                    {\(-1\), "0"}
                    }], ")"}], ".", \(Inverse[m]\)}], "]"}]}], "]"}], 
      ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"With", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"m", "=", 
              RowBox[{"(", GridBox[{
                    {"1", "2"},
                    {"3", "1"}
                    }], ")"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"LinearPhasePlot2D", "[", 
            RowBox[{"m", ".", 
              RowBox[{"(", GridBox[{
                    {"0", "1"},
                    {\(-1\), "0"}
                    }], ")"}], ".", \(Inverse[m]\)}], "]"}]}], "]"}], 
      ";"}]], "Input"],

Cell["\<\
Spiral (it seems to take more time to compute than the other \
examples):\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LinearPhasePlot2D", "[", 
        RowBox[{"(", GridBox[{
              {\(1\/2\), \(-1\)},
              {"1", \(1\/2\)}
              }], ")"}], "]"}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["LevelPlot3D", "Input"]], "Subsubtitle",
  FontColor->RGBColor[1, 0, 0]],

Cell[TextData[{
  "With ",
  StyleBox["LevelPlot3D", "Input",
    Background->RGBColor[1, 1, 0]],
  " you can draw level sets of a function (it takes a while for a default \
mesh). The basic syntax is the same as for ",
  ButtonBox["Plot3D",
    ButtonStyle->"RefGuideLink"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["LevelPlot3D",
          FontColor->RGBColor[1, 0, 0]], 
        "[", \(x\^2 - y\^2, {x, \(-1\), 1}, {y, \(-1\), 1}\), "]"}], 
      ";"}]], "Input"],

Cell["\<\
The computation is rather slow.  Try a rougher mesh for faster \
results:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["LevelPlot3D",
          FontColor->RGBColor[1, 0, 0]], 
        "[", \(x\^2 - y\^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
        PlotPoints \[Rule] 5\), "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The default ",
  StyleBox["SurfaceStyle", "Input",
    Background->RGBColor[1, 1, 0]],
  " is ",
  StyleBox["EdgeForm[]", "Input"],
  ", that suppresses the edges of the polygons. You can revert to the usual \
behaviour of ",
  ButtonBox["Plot3D",
    ButtonStyle->"RefGuideLink"],
  " in the following way, but you may agree it's not a good idea:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{\(x\^2 - y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", 
          StyleBox[\(SurfaceStyle \[Rule] {}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "With the option ",
  ButtonBox["Contours",
    ButtonStyle->"RefGuideLink"],
  " you can control the level sets to be drawn the same way as you do with ",
  ButtonBox["ContourPlot",
    ButtonStyle->"RefGuideLink"],
  ". If you set it to an integer, the level sets will be equally spaced \
between the supremum and the infimum of the function on the domain. The \
default is ",
  StyleBox["Contours->11", "Input"],
  ". ",
  ButtonBox["Contours",
    ButtonStyle->"RefGuideLink"],
  " can also be an explicit list of values."
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{\(x\^2 - y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", 
          StyleBox[\(Contours \[Rule] 3\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{\(x\^2 - y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", 
          StyleBox[\(Contours \[Rule] {0, 1/6}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can choose a style for the level lines with ",
  ButtonBox["ContourStyle",
    ButtonStyle->"RefGuideLink"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{\(x\^2 - y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", 
          StyleBox[\(ContourStyle \[Rule] Red\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "Within ",
  StyleBox["LevelPlot3D", "Input"],
  ", beside fixed directives, ",
  ButtonBox["ContourStyle",
    ButtonStyle->"RefGuideLink"],
  " accepts a ",
  StyleBox["function",
    FontSlant->"Italic"],
  " as value. For each contour the function will be evaluated at the \
corresponding ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ", and that will be the style of that contour. Actually, not exactly the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " value, rather the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " value scaled linearly to range between 0 and\[NonBreakingSpace]1, if ",
  ButtonBox["ColorFunctionScaling",
    ButtonStyle->"RefGuideLink"],
  " is set to the default ",
  StyleBox["True", "Input"],
  "."
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{\(x\^2 - y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", 
          StyleBox[\(ContourStyle \[Rule] Hue\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{\(x\^2 - y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", 
          
          StyleBox[\(ContourStyle \[Rule] \(({GrayLevel[1 - #], 
                    Dashing[{ .01,  .02}], Thickness[ .01]} &)\)\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "With the option ",
  StyleBox["ShowProjectedLevelSets", "Input",
    Background->RGBColor[1, 1, 0]],
  " set to ",
  StyleBox["True", "Input"],
  " the level lines are shown both on the surface and projected onto a \
horizontal plane:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{\(x\^2 + y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", 
          StyleBox[\(ShowProjectedLevelSets \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The horizontal plane is by default at ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  ". You can choose a different value of ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " with the option ",
  StyleBox["ProjectAt", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{\(x\^2 - y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), 
          ",", \(ShowProjectedLevelSets \[Rule] True\), ",", 
          StyleBox[\(ProjectAt \[Rule] 1\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "With the option ",
  StyleBox["Oriented", "Input",
    Background->RGBColor[1, 1, 0]],
  " set to ",
  StyleBox["True", "Input"],
  ", arrows will be placed along the contour lines, oriented so that the \
higher ground will be to the left hand side of the curve, seen from above:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{\(x\^2 - y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", 
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can adjust the arrow size with ",
  StyleBox["HeadLength3D", "Input",
    Background->RGBColor[1, 1, 0]],
  " and other options from ",
  ButtonBox["Arrow3D",
    ButtonStyle->"AddOnsLink"],
  ", Here by default, ",
  StyleBox["HeadLength3D", "Input",
    Background->RGBColor[1, 1, 0]],
  " is set to ",
  StyleBox["1/10", "Input"],
  " of the lenght of the largest edge of the smallest ",
  ButtonBox["Cuboid",
    ButtonStyle->"RefGuideLink"],
  " that encloses the contours:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{\(x\^2 - y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(HeadLength3D \[Rule] 1/20\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can reverse the arrow orientation with ",
  StyleBox["ReverseOrientation", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{\(x\^2 - y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(ReverseOrientation \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "Any colors from ",
  ButtonBox["ContourStyle",
    ButtonStyle->"RefGuideLink"],
  " will be applied to the arrows, too, unless a separate ",
  StyleBox["Arrow3DColor", "Input",
    Background->RGBColor[1, 1, 0]],
  " option is explicitly given, if for any reason you want to try:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{\(x\^2 - y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(ContourStyle \[Rule] Hue\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{\(x\^2 - y\^2\), ",", \({x, \(-1\), 1}\), 
          ",", \({y, \(-1\), 1}\), ",", \(Oriented \[Rule] True\), ",", 
          StyleBox[\(ContourStyle \[Rule] Hue\),
            FontColor->RGBColor[1, 0, 0]], ",", 
          StyleBox[\(Arrow3DColor \[Rule] \((Hue[1 - #] &)\)\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "There are ",
  StyleBox["\"pathological cases\"",
    FontSlant->"Italic"],
  " to keep in mind. In flat areas the level lines are not lines any more. \
The output in these cases can be confusing at first sight: the level line \
expands into triangles. First an example with a spaced-out grid to show the \
triangles better:"
}], "Text"],

Cell[BoxData[
    \(\(LevelPlot3D[y*x\^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
        PlotPoints \[Rule] 5, PlotRange \[Rule] All];\)\)], "Input"],

Cell[BoxData[
    \(\(LevelPlot3D[y*x\^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
        PlotPoints \[Rule] 5, PlotRange \[Rule] All, 
        ShowProjectedLevelSets \[Rule] True, 
        ProjectAt \[Rule] \(-1.5\)];\)\)], "Input"],

Cell["\<\
then an example with a normally spaced grid, where the flat \
triangles are small but still noticeable:\
\>", "Text"],

Cell[BoxData[
    \(\(LevelPlot3D[y*x\^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
        ContourStyle \[Rule] Hue];\)\)], "Input"],

Cell[TextData[{
  "Sometimes the function can be larger ",
  StyleBox["on both sides",
    FontSlant->"Italic"],
  " of a level line.  In this case arrows pointing in opposite direction get \
superimposed on each other:"
}], "Text"],

Cell[BoxData[
    \(\(LevelPlot3D[x\^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
        Oriented \[Rule] True, Contours \[Rule] {0}, 
        PlotPoints \[Rule] {11, 2}, PlotRange \[Rule] All];\)\)], "Input"],

Cell["The two \"pathologies\" together:", "Text"],

Cell[BoxData[
    \(\(LevelPlot3D[y*x^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
        Oriented \[Rule] True, Contours \[Rule] 1, PlotPoints \[Rule] 7, 
        PlotRange \[Rule] All];\)\)], "Input"],

Cell[TextData[{
  "When ",
  StyleBox["ShowProjectedLevelSets", "Input"],
  " is ",
  StyleBox["True", "Input"],
  ", also the ",
  ButtonBox["ContourStyle",
    ButtonStyle->"RefGuideLink"],
  " and the arrows will be projected:"
}], "Text"],

Cell[BoxData[
    \(\(LevelPlot3D[x + y, {x, \(-1\), 1}, {y, \(-1\), 1}, 
        PlotPoints \[Rule] 2, Oriented \[Rule] True, 
        ContourStyle \[Rule] Hue, ShowProjectedLevelSets \[Rule] True, 
        ProjectAt \[Rule] \(-3\)];\)\)], "Input"],

Cell[TextData[{
  "You can give shading to the surface, too, just as in ",
  ButtonBox["Plot3D",
    ButtonStyle->"RefGuideLink"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LevelPlot3D", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{\(y - x\), ",", 
              StyleBox[\(Hue[\((x + y)\)/4]\),
                FontColor->RGBColor[1, 0, 0]]}], "}"}], 
          ",", \({x, \(-1\), 1}\), ",", \({y, \(-1\), 1}\), 
          ",", \(Oriented \[Rule] True\), ",", \(PlotPoints \[Rule] 5\)}], 
        "]"}], ";"}]], "Input"],

Cell[TextData[{
  "As an example, here are the trajectories of the ",
  StyleBox["pendulum",
    FontSlant->"Italic"],
  " system, plotted on the energy surface: first a quick-and-dirty version:"
}], "Text"],

Cell[BoxData[
    \(\(LevelPlot3D[\(-Cos[x]\) + y\^2\/2, {x, \(-\[Pi]\), 
          3  \[Pi]}, {y, \(-2\), 2.5}, Oriented \[Rule] True, 
        PlotPoints \[Rule] 5, Contours \[Rule] 3, 
        HeadLength3D \[Rule] 1/25];\)\)], "Input"],

Cell["and then a slower, smoother plot:", "Text"],

Cell[BoxData[
    \(\(LevelPlot3D[\(-Cos[x]\) + y\^2\/2, {x, \(-\[Pi]\), 
          3  \[Pi]}, {y, \(-2\), 2.5}, Oriented \[Rule] True, 
        PlotPoints \[Rule] 30, Contours \[Rule] 8, HeadLength3D \[Rule] 1/25, 
        PlotLabel \[Rule] "\<Pendulum Phase Portrait\>", 
        AxesLabel \[Rule] {"\<\[Theta]\>", "\<v\>", "\<E\>"}, 
        Ticks \[Rule] {PiScale[\(-\[Pi]\), 3  \[Pi]], Automatic, 
            Automatic}];\)\)], "Input"],

Cell[TextData[{
  "There is also ",
  StyleBox["LevelDraw3D", "Input",
    Background->RGBColor[1, 1, 0]],
  ", the ",
  ButtonBox["Draw",
    ButtonStyle->"AddOnsLink"],
  " companion to ",
  StyleBox["LevelPlot3D", "Input"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Draw3DItems", "[", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              StyleBox["LevelDraw3D",
                FontColor->RGBColor[1, 0, 0]], 
              "[", \(x\^2 - y\^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
              Oriented \[Rule] True, Contours \[Rule] 3, 
              ContourStyle \[Rule] Hue, ArrowDensity \[Rule]  .5\), "]"}], 
            ",", \(Text["\<saddle\>", {1/2, 1/2, 1}, {0, \(-1\)}]\), 
            ",", \(SurfaceColor[Black]\), ",", \(Thickness[ .01]\), 
            ",", \(Arrow3D[{1/2, 1/2, 1}, {0, 0, 0}, HeadScaling3D \[Rule] 2, 
              HeadLength3D \[Rule] 1/10]\)}], "}"}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  StyleBox["LevelPlot3D", "Input"],
  " has the same purpose as the function ",
  ButtonBox["DrawContourLines",
    ButtonStyle->"AddOnsLink"],
  " from the ",
  ButtonBox["DrawGraphics",
    ButtonStyle->"AddOnsLink"],
  " package, but its inner workings are quite different. ",
  StyleBox["LevelPlot3D", "Input"],
  " first ",
  ButtonBox["Rationalize",
    ButtonStyle->"RefGuideLink"],
  "s the surface, then computes the intersections of the horizontal planes \
with every triangle the surface is made of , using exact rational \
arithmetics. This way the contour lines are perfectly embedded within the \
surface; they will be visible from every ",
  ButtonBox["ViewPoint",
    ButtonStyle->"RefGuideLink"],
  ", because they don't hover above, or below, the surface, much the less do \
they cross it. There ",
  StyleBox["is",
    FontSlant->"Italic"],
  " a draw-back however: ",
  StyleBox["LevelPlot3D", "Input"],
  " is slower. Compare anyway the following plots with the one from the ",
  ButtonBox["DrawContourLines",
    ButtonStyle->"AddOnsLink"],
  " documentation example:"
}], "Text"],

Cell[BoxData[{
    \(\(energy = v\^2/2 + 1/r\^2 - 4/r;\)\), "\[IndentingNewLine]", 
    \(\(Draw3DItems[\[IndentingNewLine]{LevelDraw3D[
            energy, {r, 0.1, 1}, {v, \(-5\), 5}, 
            Contours \[Rule] Join[Range[\(-3\), 2, 1/2], {3, 4, 5, 6, 7}], 
            PlotPoints \[Rule] {10, 31}, 
            ContourStyle \[Rule] White], \[IndentingNewLine]LevelDraw3D[
            energy, {r, 1, 7}, {v, \(-5\), 5}, 
            Contours \[Rule] Join[Range[\(-3\), 2, 1/2], {3, 4, 5, 6, 7}], 
            PlotPoints \[Rule] {30, 31}, 
            ContourStyle \[Rule] 
              White]}, \[IndentingNewLine]PlotRange \[Rule] {All, 
            All, {\(-4\), 8}}, \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 
            0.5}, \[IndentingNewLine]Axes \[Rule] 
          True, \[IndentingNewLine]AxesLabel \[Rule] {r, 
            v, "\<E\>"}, \[IndentingNewLine]AxesEdge \[Rule] {{\(-1\), \
\(-1\)}, {1, \(-1\)}, {\(-1\), \(-1\)}}, 
        ViewPoint -> {1.348, \ \(-0.997\), \ 2.939}, 
        Background \[Rule] 
          GrayLevel[
            0.2], \[IndentingNewLine]TextStyle \[Rule] {FontFamily \[Rule] \
"\<Helvetica\>", FontSize \[Rule] 12, FontWeight \[Rule] "\<Bold\>"}, 
        PlotRegion \[Rule] {{0.05, 0.95}, {0, 
              1}}, \[IndentingNewLine]PlotLabel \[Rule] "\<Keplerian Radial \
Phase Portrait\>", \[IndentingNewLine]ImageSize \[Rule] 400];\)\)}], "Input"],

Cell[TextData[{
  "A variation on the theme, with oriented trajectories: (to make sure the \
arrows are of the same size in the two halfs of the plot we set an explicit \
",
  StyleBox["HeadScaling3D", "Input"],
  ")"
}], "Text"],

Cell[BoxData[{
    \(\(energy = v\^2/2 + 1/r\^2 - 4/r;\)\), "\[IndentingNewLine]", 
    \(\(Draw3DItems[\[IndentingNewLine]{LevelDraw3D[
            energy, {r, 0.1, 1}, {v, \(-5\), 5}, 
            Contours \[Rule] 
              Union[Range[\(-3\), 0, 1/2], Range[\(-1\), 7, 2]], 
            PlotPoints \[Rule] {10, 31}, Oriented \[Rule] True, 
            ArrowDensity \[Rule]  .5, HeadScaling3D \[Rule] 10, 
            HeadLength3D \[Rule] 1/25], \[IndentingNewLine]LevelDraw3D[
            energy, {r, 1, 7}, {v, \(-5\), 5}, 
            Contours \[Rule] 
              Union[Range[\(-3\), 0, 1/2], Range[\(-1\), 7, 2]], 
            PlotPoints \[Rule] {30, 31}, Oriented \[Rule] True, 
            ArrowDensity \[Rule]  .5, HeadScaling3D \[Rule] 10, 
            HeadLength3D \[Rule] 
              1/25]}, \[IndentingNewLine]PlotRange \[Rule] {All, 
            All, {\(-4\), 8}}, \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 
            0.5}, \[IndentingNewLine]Axes \[Rule] True, 
        ImageSize \[Rule] 500, 
        ViewPoint \[Rule] {3, \ \(-1\), \ 4}];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["SliceSurfacePlot3D", "Input"]], "Subsubtitle",
  FontColor->RGBColor[1, 0, 0]],

Cell[TextData[{
  "The function ",
  StyleBox["SliceSurfacePlot3D", "Input",
    Background->RGBColor[1, 1, 0]],
  " is more general than ",
  StyleBox["LevelPlot3D", "Input"],
  ", because you can give an arbitrary surface and slice it in an arbitrary \
direction. You give a take a pre-computed surface and specify a linear \
expression in ",
  Cell[BoxData[
      \(TraditionalForm\`x, y, z\)]],
  ": ",
  StyleBox["SliceSurfacePlot3D", "Input"],
  " will draw the level lines of the linear function over any polygon of the \
surface. The options are mostly the same as with ",
  StyleBox["LevelPlot3D", "Input"],
  "."
}], "Text"],

Cell[TextData[{
  "Here we draw the level lines of the linear form ",
  Cell[BoxData[
      \(TraditionalForm\`x - 2  y + z\)]],
  " over an ellipsoid:"
}], "Text"],

Cell[BoxData[{\(mySurface = 
        ParametricPlot3D[{4  Cos[u] Cos[v], 3  Sin[u] Cos[v], 2  Sin[v]}, {u, 
            0, 2  \[Pi]}, {v, \(-\[Pi]\)/2, \[Pi]/2}, Ticks \[Rule] None, 
          PlotPoints \[Rule] {25, 15}];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"SliceSurfacePlot3D", "[", 
        RowBox[{"mySurface", ",", 
          StyleBox[\(x - 2  y + z\),
            FontColor->RGBColor[1, 0, 0]], ",", "x", ",", "y", ",", "z"}], 
        "]"}], ";"}]}], "Input"],

Cell[TextData[{
  "The option ",
  ButtonBox["Contours",
    ButtonStyle->"RefGuideLink"],
  " directs how many (or exactly which) level lines will be drawn: here is \
the same ellipsoid sliced with 2 level lines of the form ",
  Cell[BoxData[
      \(TraditionalForm\`x + z\)]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SliceSurfacePlot3D", "[", 
        RowBox[{
        "mySurface", ",", \(x + z\), ",", "x", ",", "y", ",", "z", ",", 
          StyleBox[\(Contours \[Rule] 2\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The option ",
  ButtonBox["ContourStyle",
    ButtonStyle->"RefGuideLink"],
  " can be given to govern the style of the contour lines:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SliceSurfacePlot3D", "[", 
        RowBox[{
        "mySurface", ",", \(x + z\), ",", "x", ",", "y", ",", "z", 
          ",", \(Contours \[Rule] 2\), ",", 
          StyleBox[\(ContourStyle \[Rule] Red\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "With the option ",
  StyleBox["Oriented\[Rule]True", "Input",
    Background->RGBColor[1, 1, 0]],
  ", arrows will be placed along the level lines:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SliceSurfacePlot3D", "[", 
        RowBox[{
        "mySurface", ",", \(x - z\), ",", "x", ",", "y", ",", "z", 
          ",", \(Contours \[Rule] 2\), ",", " ", 
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The default orientation of the arrows can be reversed either by giving the \
opposite linear form, or by setting ",
  StyleBox["ReverseOrientation\[Rule]True", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SliceSurfacePlot3D", "[", 
        RowBox[{
        "mySurface", ",", \(x - z\), ",", "x", ",", "y", ",", "z", 
          ",", \(Contours \[Rule] 2\), ",", " ", \(Oriented \[Rule] True\), 
          ",", 
          StyleBox[\(ReverseOrientation \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The size of the arrows can be controlled with ",
  StyleBox["HeadLength3D", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SliceSurfacePlot3D", "[", 
        RowBox[{
        "mySurface", ",", \(x - z\), ",", "x", ",", "y", ",", "z", 
          ",", \(Contours \[Rule] 2\), ",", " ", \(Oriented \[Rule] True\), 
          ",", 
          StyleBox[\(HeadLength3D \[Rule] 1/5\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can increase the number of arrows by setting ",
  StyleBox["ArrowDensity", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(SliceSurfacePlot3D[mySurface, x + 2  y - z, x, y, z, 
        Oriented \[Rule] True, ArrowDensity \[Rule] 2];\)\)], "Input"],

Cell[TextData[{
  "With the option ",
  StyleBox["ShowProjectedLevelSets", "Input",
    Background->RGBColor[1, 1, 0]],
  " you can get a separate plot of the level lines orthogonally projected on \
a single level line of the linear form. The level set on which the lines are \
projected is by default 0, but can be set with the option ",
  StyleBox["ProjectAt", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SliceSurfacePlot3D", "[", 
        RowBox[{
        "mySurface", ",", \(x + 2  y - z\), ",", "x", ",", "y", ",", "z", 
          ",", \(ContourStyle \[Rule] Hue\), ",", 
          StyleBox[\(ShowProjectedLevelSets \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[",",
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[\(ProjectAt \[Rule] 15\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["LinearClipPlot3D", "Input"]], "Subsubtitle",
  FontColor->RGBColor[1, 0, 0]],

Cell[TextData[{
  "The function ",
  StyleBox["LinearClipPlot3D", "Input",
    Background->RGBColor[1, 1, 0]],
  " is mainly an engine for ",
  StyleBox["SliceSurfacePlot3D", "Input"],
  ", but it can be used independently. It draws the intersection of a surface \
with a half-space. See also the functions ",
  ButtonBox["TrimPolygons",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["RaiseTo3D",
    ButtonStyle->"AddOnsLink"],
  " from ",
  ButtonBox["DrawGraphics",
    ButtonStyle->"AddOnsLink"],
  " for an alternative approach."
}], "Text"],

Cell["Start with a paraboloid:", "Text"],

Cell[BoxData[
    \(\(paraboloid = 
        ParametricPlot3D[
          r {Cos[t], Sin[t], r}, {r, 0, 1}, {t, 0, 2  \[Pi]}];\)\)], "Input"],

Cell["The paraboloid cut by a plane:", "Text"],

Cell[BoxData[
    \(\(Show[{paraboloid, \[IndentingNewLine]Plot3D[
            x\/4 + y\/3 + 1\/3, {x, \(-1\), 1}, {y, \(-1\), 1}, 
            PlotPoints \[Rule] 2, 
            DisplayFunction \[Rule] Identity]}];\)\)], "Input"],

Cell["The part of the paraboloid above the plane:", "Text"],

Cell[BoxData[
    \(\(LinearClipPlot3D[paraboloid, z \[GreaterEqual] \ x\/4 + y\/3 + 1\/3, 
        x, y, z];\)\)], "Input"],

Cell["The part of the paraboloid below the plane:", "Text"],

Cell[BoxData[
    \(\(LinearClipPlot3D[paraboloid, z \[LessEqual] x\/4 + y\/3 + 1\/3, x, y, 
        z];\)\)], "Input"],

Cell[TextData[{
  "Instead of a single inequality you can give an ",
  StyleBox["And", "Input"],
  " combination, to intersect the surface with more than one half-space:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LinearClipPlot3D", "[", 
        RowBox[{"paraboloid", ",", 
          RowBox[{
            StyleBox[
              FractionBox[
                StyleBox["y",
                  FontColor->RGBColor[1, 0, 0]], "2"],
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["\[LessEqual]",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["z",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["\[LessEqual]",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[\(x\/4 + y\/3 + 1\/3\),
              FontColor->RGBColor[1, 0, 0]]}], ",", "x", ",", "y", ",", "z"}],
         "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LinearClipPlot3D", "[", 
        RowBox[{"paraboloid", ",", 
          
          StyleBox[\(x - y \[GreaterEqual] \(-\(1\/4\)\) \[And] 
              2  z \[LessEqual] \(-x\) + y + 1\),
            FontColor->RGBColor[1, 0, 0]], ",", "x", ",", "y", ",", "z"}], 
        "]"}], ";"}]], "Input"],

Cell[TextData[{
  "There is also ",
  StyleBox["LinearClipDraw3D", "Input",
    Background->RGBColor[1, 1, 0]],
  ", the ",
  ButtonBox["DrawGraphics",
    ButtonStyle->"AddOnsLink"],
  " companion to ",
  StyleBox["LinearClipPlot3D", "Input"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Draw3DItems", "[", 
        RowBox[{"{", 
          RowBox[{\(SurfaceColor[Red]\), ",", 
            RowBox[{
              StyleBox["LinearClipDraw3D",
                FontColor->RGBColor[1, 0, 0]], "[", \(paraboloid, 
              z \[LessEqual] \ x\/4 + y\/3 + 1\/3, x, y, z\), "]"}], ",", 
            "\[IndentingNewLine]", \(SurfaceColor[Green]\), ",", 
            RowBox[{
              StyleBox["LinearClipDraw3D",
                FontColor->RGBColor[1, 0, 0]], "[", \(paraboloid, 
              z \[GreaterEqual] x\/4 + y\/3 + 1\/3, x, y, z\), "]"}]}], "}"}],
         "]"}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PlotCurveOnSurface3D", "Input"],
  " (for parametric curves)"
}], "Subsubtitle",
  FontColor->RGBColor[1, 0, 0]],

Cell["\<\
The na\[IDoubleDot]ve way of plotting a curve over a 3D surface, \
with the curve that submarines behind the surface:\
\>", "Text"],

Cell[BoxData[{\(f[u_, v_] = {4  Cos[u] Cos[v], 3  Sin[u] Cos[v], 
          2  Sin[v]};\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["surface",
          FontColor->RGBColor[0, 0, 1]], 
        "=", \(ParametricPlot3D[
          Evaluate[f[u, v]~Join~{EdgeForm[]}], {u, 0, 
            2  \[Pi]}, {v, \(-\[Pi]\)/2, \[Pi]/2}, 
          PlotPoints \[Rule] {51, 41}, Ticks \[Rule] None, 
          PlotRange \[Rule] {{\(-4\), 4}, {\(-3\), 3}, {\(-2\), 2}}]\)}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["curve",
          FontColor->RGBColor[1, 0, 0]], 
        "=", \(ParametricPlot3D[
          Evaluate[f[t*Cos[30  t] - \[Pi]/2, t*Sin[30  t] + \[Pi]/6]], {t, 0, 
            1}, PlotPoints \[Rule] 150, Ticks \[Rule] None, 
          PlotRange \[Rule] {{\(-4\), 4}, {\(-3\), 3}, {\(-2\), 2}}]\)}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Show", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              StyleBox["surface",
                FontColor->RGBColor[0, 0, 1]], ",", 
              StyleBox["curve",
                FontColor->RGBColor[1, 0, 0]]}], "}"}], 
          ",", \(Ticks \[Rule] None\)}], "]"}], ";"}]}], "Input"],

Cell[BoxData[
    \(\($FormatType = TraditionalForm;\)\)], "Input"],

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{{Show[surface, PlotLabel \[Rule] "\<surface\>", 
                DisplayFunction \[Rule] Identity], 
              Show[curve, PlotLabel \[Rule] "\<curve\>", 
                DisplayFunction \[Rule] Identity]}, {Show[{surface, curve}, 
                PlotLabel \[Rule] "\<surface and curve\>", 
                DisplayFunction \[Rule] Identity], Null}}], 
        ImageSize \[Rule] 500];\)\)], "Input"],

Cell[TextData[{
  "With ",
  StyleBox["PlotCurveOnSurface3D", "Input",
    Background->RGBColor[1, 1, 0]],
  " the curve shows all the way (it takes a while to compute):"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{
          
          StyleBox[\({{4  Cos[u] Cos[v], 3  Sin[u] Cos[v], 2  Sin[v]}, {u, 0, 
                2  \[Pi]}, {v, \(-\[Pi]\)/2, \[Pi]/2}, 
              PlotPoints \[Rule] {51, 41}}\),
            FontColor->RGBColor[0, 0, 1]], ",", 
          
          StyleBox[\({{t*Cos[30  t] - \[Pi]/2, t*Sin[30  t] + \[Pi]/6}, {t, 
                0, 1}, PlotPoints \[Rule] 100}\),
            FontColor->RGBColor[1, 0, 0]], ",", \(Ticks \[Rule] None\)}], 
        "]"}], ";"}]], "Input"],

Cell[TextData[{
  "With the option ",
  StyleBox["Oriented", "Input",
    Background->RGBColor[1, 1, 0]],
  " you get arrows along the curve:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{
          
          StyleBox[\({{4  Cos[u] Cos[v], 3  Sin[u] Cos[v], 2  Sin[v]}, {u, 0, 
                2  \[Pi]}, {v, \(-\[Pi]\)/2, \[Pi]/2}, 
              PlotPoints \[Rule] {51, 41}}\),
            FontColor->RGBColor[0, 0, 1]], ",", 
          
          StyleBox[\({{t*Cos[30  t] - \[Pi]/2, t*Sin[30  t] + \[Pi]/6}, {t, 
                0, 1}, PlotPoints \[Rule] 100, Oriented \[Rule] True, 
              HowManyArrows \[Rule] 6}\),
            FontColor->RGBColor[1, 0, 0]], ",", \(Ticks \[Rule] None\)}], 
        "]"}], ";"}]], "Input"],

Cell[TextData[{
  "To get a non-jagged look for the curve you need to set rather higher ",
  ButtonBox["PlotPoints",
    ButtonStyle->"RefGuideLink"],
  " for both surface and curve, and be prepared to wait longer..."
}], "Text"],

Cell["The syntax is:", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["PlotCurveOnSurface3D",
        "Input"], 
      StyleBox["[",
        "Input"], 
      StyleBox["\[IndentingNewLine]",
        "Input"], 
      RowBox[{
        StyleBox[\({content\ of\ what\ you\ would\ write\ into\ Plot3D\ or\ \
ParametricPlot3D\ to\ get\ the\ surface\ only}\),
          "Input",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[",",
          "Input",
          FontColor->RGBColor[0, 0, 1]], 
        RowBox[{
          StyleBox["{",
            "Input",
            FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
            StyleBox["content",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["of",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["what",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["you",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["would",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["write",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["into",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["ParametricPlot",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["to",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["describe",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["the",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["curve",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["in",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["the",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["2",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["dimensional",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["parameter",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["space",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["of",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["the",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["surface",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]]}], 
          StyleBox["}",
            "Input",
            FontColor->RGBColor[1, 0, 0]]}], 
        StyleBox[",",
          "Input"], 
        StyleBox["\[IndentingNewLine]",
          "Input"], 
        StyleBox[\(optional\ Graphics3D\ options\),
          "Input"]}], 
      StyleBox["]",
        "Input"]}]], "Input",
  Evaluatable->False],

Cell[TextData[{
  "You can do it the ",
  ButtonBox["Plot3D",
    ButtonStyle->"RefGuideLink"],
  " way:"
}], "Text"],

Cell[BoxData[{
    RowBox[{\(f = 
          1\/\(1 + \((x + 1)\)\^2 + y\^2\) - 
            1\/\(1 + \((x - 1)\)\^2 + y\^2\);\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{
          StyleBox[\({f, {x, \(-2\), 2}, {y, \(-2\), 2}, PlotPoints -> 50}\),
            FontColor->RGBColor[0, 0, 1]], ",", 
          
          StyleBox[\({{t*Cos[10  t], t*Sin[10  t]}, {t, 0, 2}, 
              PlotPoints \[Rule] 100, Oriented \[Rule] True}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]}], "Input"],

Cell["\<\
The motion of  the pendulum with friction, drawn on the energy \
function graph\
\>", "Text"],

Cell[BoxData[{
    \(\({sol, plot2D} = 
        NDSolve[{\(x'\)[t] \[Equal] 
              y[t], \(y'\)[t] \[Equal] \(-Sin[x[t]]\) - y[t]/6, 
            x[0] \[Equal] \(-\[Pi]\)/2, y[0] \[Equal] 0}, {x, y}, {t, 0, 20}, 
          PlotSolution \[Rule] True, 
          HowManyArrows \[Rule] 4];\)\), "\[IndentingNewLine]", 
    \(\(PlotCurveOnSurface3D[{y^2/2 - Cos[x], {x, \(-\[Pi]\)/2 // N, 
            1.2}, {y, \(-1\), 1.3}}, 
        Evaluate[{{x[t], y[t]} /. sol[\([1]\)], {t, 0, 20}, 
            Oriented \[Rule] True, PlotPoints \[Rule] 100, 
            HowManyArrows \[Rule] 4}]];\)\)}], "Input"],

Cell["You can also draw more than one curve on the same surface:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{
          
          StyleBox[\({{\((3 + Cos[u])\) Cos[v], \((3 + Cos[u])\) Sin[v], 
                Sin[u]}, {u, 0, 2  \[Pi]}, {v, 0, 2  \[Pi]}, 
              PlotPoints \[Rule] {15, 41}}\),
            FontColor->RGBColor[0, 0, 1]], ",", 
          RowBox[{"Evaluate", "[", 
            RowBox[{"Sequence", "@@", 
              RowBox[{"Table", "[", 
                RowBox[{
                  
                  StyleBox[\({{Cos[\[Theta]] t + \[Pi]/4, 
                        Sin[\[Theta]] t - \[Pi]/4}, {t, \(-4\), 4}, 
                      PlotPoints \[Rule] 5, 
                      PlotStyle \[Rule] {Thickness[ .002], Hue[\[Theta]]}}\),
                    FontColor->RGBColor[1, 0, 0]], 
                  ",", \({\[Theta], 0, \[Pi], \[Pi]/6}\)}], "]"}]}], "]"}], 
          ",", \(Boxed \[Rule] False\), ",", \(Axes \[Rule] False\)}], "]"}], 
      ";"}]], "Input"],

Cell[TextData[{
  "With the ",
  StyleBox["Oriented", "Input"],
  " option you get arrows along the curve:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{
          
          StyleBox[\({{x, y, x^2 - y^2}, {x, \(-1.5\), 1.5}, {y, \(-1.5\), 
                1.5}, PlotPoints \[Rule] 21}\),
            FontColor->RGBColor[0, 0, 1]], ",", 
          
          StyleBox[\({{Cos[t], Sin[t]}, {t, 0, 2  \[Pi]}, 
              Oriented \[Rule] True, PlotPoints \[Rule] 100, 
              HowManyArrows \[Rule] 4, HeadLength3D \[Rule] 1/5}\),
            FontColor->RGBColor[1, 0, 0]], ",", \(PlotRange \[Rule] All\)}], 
        "]"}], ";"}]], "Input"],

Cell[TextData[{
  StyleBox["DrawCurveOnSurface3D", "Input",
    Background->RGBColor[1, 1, 0]],
  ", the ",
  ButtonBox["DrawGraphics",
    ButtonStyle->"AddOnsLink"],
  " companion to ",
  StyleBox["PlotCurveOnSurface3D", "Input"],
  ", is also provided. You can even combine ",
  StyleBox["DrawCurveOnSurface3D", "Input"],
  " with ",
  StyleBox["SliceSurfacePlot3D", "Input"],
  ", to show how the energy of a pendulum with friction decreases with time:"
}], "Text"],

Cell[BoxData[{
    RowBox[{\({sol, plot2D} = 
          NDSolve[{\(x'\)[t] \[Equal] 
                y[t], \(y'\)[t] \[Equal] \(-Sin[x[t]]\) - y[t]/6, 
              x[0] \[Equal] \(-\[Pi]\)/2, y[0] \[Equal] 0}, {x, y}, {t, 0, 
              20}, PlotSolution \[Rule] True, HowManyArrows \[Rule] 4];\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\({surface, curve}\), "=", 
          RowBox[{
            StyleBox["DrawCurveOnSurface3D",
              FontColor->RGBColor[1, 0, 0]], 
            "[", \({y^2/2 - Cos[x], {x, \(-\[Pi]\)/2 // N, 1.2}, {y, \(-1\), 
                1.3}}, Evaluate[{{x[t], y[t]} /. sol[\([1]\)], {t, 0, 20}, 
                Oriented \[Rule] True, PlotPoints \[Rule] 100, 
                HowManyArrows \[Rule] 4}]\), "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Draw3DItems", "[", 
        RowBox[{"{", 
          RowBox[{"curve", ",", 
            RowBox[{
              StyleBox["SliceSurfaceDraw3D",
                FontColor->RGBColor[1, 0, 0]], "[", \(Graphics3D[surface], z, 
              x, y, z, ContourStyle \[Rule] White\), "]"}]}], "}"}], "]"}], 
      ";"}]}], "Input"],

Cell[TextData[{
  "An elaborate illustration, combining ",
  StyleBox["DrawCurveOnSurface3D", "Input"],
  " and ",
  StyleBox["TrigInterpolationParametricDraw", "Input"],
  " (described elsewhere in this file):"
}], "Text"],

Cell[BoxData[{
    \(\(Clear[t];\)\), "\[IndentingNewLine]", 
    \(parCurve = {{t*Cos[t], t*Sin[t]}/\((3  \[Pi])\), {t, 0, 3  \[Pi]}, 
        Oriented \[Rule] True, HeadScaling3D \[Rule] 2, 
        PlotPoints \[Rule] 50, HowManyArrows \[Rule] 4}; 
    Block[{r = 1 + 1/8, $FormatType = TraditionalForm}, 
      Draw3DItems[{{Thickness[ .006], 
            Line[{{\(-3\), 0, 0}, {\(-1.5\), 0, 
                  0}}]}, \[IndentingNewLine]Text[
            StyleForm[\[DoubleStruckCapitalR], FontSize \[Rule] 14], {\(-3\), 
              0, 0}, {\(-1\), 
              2}], \[IndentingNewLine]TrigInterpolationParametricDraw[{{\(-2.\
2\), 1/4, 1/4}, {{\(- .3\), 1, 1/4}, {1, \(-1\), \(-1\)}/2}}, 
            Oriented \[Rule] True, ArrowPositions \[Rule] 1, 
            HeadScaling3D \[Rule] 3], \[IndentingNewLine]Text[
            StyleForm[\[CurlyPhi], FontSize \[Rule] 14], {\(-1.3\), 0, 
              1.4}], \[IndentingNewLine]Text[
            DisplayForm[
              StyleForm[
                GridBox[{{"\<parametric curve\>"}, {"\<in the plane\>"}}], 
                FontFamily \[Rule] Times]], {\(-3\), 
              1.5,  .6}], \[IndentingNewLine]DrawCurveOnSurface3D[{{x, y, 0, 
                EdgeForm[GrayLevel[ .5], Thickness[0]]}, {x, \(-1\), 
                1}, {y, \(-1\), 1}, PlotPoints \[Rule] 25}, 
            Evaluate[parCurve]], \[IndentingNewLine]Text[
            StyleForm[\[DoubleStruckCapitalR]\^2, 
              FontSize \[Rule] 14], {\(-1\), \(-1\), 0}, {\(-1\), 
              2}], \[IndentingNewLine]TrigInterpolationParametricDraw[{{0, 1, 
                1/4}, {{2.5, 1, 1}, {1, \(-1\), \(-1\)}/2}}, 
            Oriented \[Rule] True, ArrowPositions \[Rule] 1, 
            HeadScaling3D \[Rule] 3], \[IndentingNewLine]Text[
            StyleForm[\[Psi], FontSize \[Rule] 14], {1.3, 1, 
              1.5}], \[IndentingNewLine]DrawCurveOnSurface3D[{{u + 
                  3, \(-u^2\) + v^2 - u*v/2, v, 
                EdgeForm[GrayLevel[ .5], Thickness[0]]}, {u, \(-1\), 
                1}, {v, \(-1\), 1}, PlotPoints \[Rule] 25}, 
            Evaluate[parCurve]], \[IndentingNewLine]Text[
            StyleForm[\[DoubleStruckCapitalR]\^3, 
              FontSize \[Rule] 14], {3 - 
                r, \(-r\), \(-r\)}, {1.5, \(-2\)}], \[IndentingNewLine]Text[
            DisplayForm[
              StyleForm[
                GridBox[{{"\<parametric surface\>"}, {"\<in space\>"}}], 
                FontFamily \[Rule] Times]], {2.8, 1.5, 
              1.5}], \[IndentingNewLine]Line[{{3 - r, \(-r\), 
                  z}, {3 + r, \(-r\), z}, {3 + r, r, z}, {3 - r, r, 
                  z}, {3 - r, \(-r\), 
                  z}}] /. \[IndentingNewLine]{{z \[Rule] \(-1\)}, {z \[Rule] 
                  1}}, \[IndentingNewLine]Table[
            Line[{{x, y, \(-1\)}, {x, y, 1}}], {x, 3 - r, 3 + r, 
              2  r}, {y, \(-r\), r, 
              2  r}], \[IndentingNewLine]TrigInterpolationParametricDraw[{{\(-\
2.2\), \(-1\)/4, \(-1\)/4}, {{2.5, \(-1\), \(-1\)}, {1, 1, 1}/2}}, 
            Oriented \[Rule] True, ArrowPositions \[Rule] 1, 
            HeadScaling3D \[Rule] 3], \[IndentingNewLine]Text[
            StyleForm[\[Psi]\[EmptySmallCircle]\[CurlyPhi], 
              FontSize \[Rule] 14], {0, \(-1\), \(-1.3\)}], 
          Text[DisplayForm[
              StyleForm[
                GridBox[{{"\<parametric curve\>"}, {"\<on surface\>"}}], 
                FontFamily \[Rule] 
                  Times]], {\(-1\), \(-1.5\), \(-1.6\)}]}, \
\[IndentingNewLine]ImageSize \[Rule] 600, Boxed \[Rule] False, 
        ViewPoint -> {1, \ \(-3\), \ 2}]];\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PlotCurveOnSurface3D", "Input"],
  " (for contour curves)"
}], "Subsubtitle",
  FontColor->RGBColor[1, 0, 0]],

Cell[TextData[{
  StyleBox["PlotCurveOnSurface3D", "Input",
    Background->RGBColor[1, 1, 0]],
  " can also draw the contour lines of a scalar function over a 3D surface. \
In the following example the surface is the saddle ",
  Cell[BoxData[
      \(TraditionalForm\`z = x\^2 - y\^2\)]],
  " and the scalar function is ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2 + y\^2\)]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{
          StyleBox[\({x^2 - y^2, {x, \(-1\), 1}, {y, \(-1\), 1}}\),
            FontColor->RGBColor[0, 0, 1]], ",", "\[IndentingNewLine]", 
          StyleBox[\({x^2 + y^2, {x, \(-1\), 1}, {y, \(-1\), 1}}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "It works internally by \"lifting\" the contours made by ",
  ButtonBox["ContourPlot",
    ButtonStyle->"RefGuideLink"],
  " and adapting them to the triangulation of the surface. The syntax is:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["PlotCurveOnSurface3D",
        "Input"], 
      StyleBox["[",
        "Input"], 
      StyleBox["\[IndentingNewLine]",
        "Input"], 
      RowBox[{
        StyleBox[\({content\ of\ what\ you\ would\ write\ into\ Plot3D\ or\ \
ParametricPlot3D\ to\ get\ the\ surface\ only}\),
          "Input",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[",",
          "Input",
          FontColor->RGBColor[0, 0, 1]], 
        RowBox[{
          StyleBox["{",
            "Input",
            FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
            StyleBox["content",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["of",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["what",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["you",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["would",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["write",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["into",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["ContourPlot",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["to",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["describe",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["the",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["contours",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["in",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["the",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["2",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["dimensional",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["parameter",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["space",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["of",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["the",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["surface",
              "Input",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]]}], 
          StyleBox["}",
            "Input",
            FontColor->RGBColor[1, 0, 0]]}], 
        StyleBox[",",
          "Input"], 
        StyleBox["\[IndentingNewLine]",
          "Input"], 
        StyleBox[\(optional\ Graphics3D\ options\),
          "Input"]}], 
      StyleBox["]",
        "Input"]}]], "Input",
  Evaluatable->False],

Cell["The contour lines can be oriented:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{
          StyleBox[\({x^2 - y^2, {x, \(-1\), 1}, {y, \(-1\), 1}}\),
            FontColor->RGBColor[0, 0, 1]], ",", "\[IndentingNewLine]", 
          
          StyleBox[\({x^2 + y^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
              Contours \[Rule] 3, Oriented \[Rule] True}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{
          
          StyleBox[\({{Cos[u], v, Sin[u]}, {u, 0, 2  \[Pi]}, {v, \(-1\), 1}, 
              PlotPoints -> {50, 2}}\),
            FontColor->RGBColor[0, 0, 1]], ",", "\[IndentingNewLine]", 
          
          StyleBox[\({Sin[u] + v^2, {u, 0, 2  \[Pi]}, {v, \(-1\), 1}, 
              Oriented \[Rule] True, PlotPoints \[Rule] {31, 31}}\),
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[",",
            FontColor->RGBColor[1, 0, 
            0]], \(ViewPoint \[Rule] {1, \ \(-2.5\), \ 1.5}\), 
          ",", \(Boxed \[Rule] False\), ",", \(Axes \[Rule] False\)}], "]"}], 
      ";"}]], "Input"],

Cell[TextData[{
  "You can draw the contour lines of two or more scalar functions on the same \
surface, and make them of different colors with the option ",
  ButtonBox["ContourStyle",
    ButtonStyle->"RefGuideLink"],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{
          StyleBox[\({x^2 - y^2, {x, \(-1\), 1}, {y, \(-1\), 1}}\),
            FontColor->RGBColor[0, 0, 1]], ",", "\[IndentingNewLine]", 
          
          StyleBox[\({x^2 + y^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
              ContourStyle \[Rule] Red}\),
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[",",
            FontColor->RGBColor[1, 0, 0]], 
          
          StyleBox[\({x*y, {x, \(-1\), 1}, {y, \(-1\), 1}, 
              ContourStyle \[Rule] Blue}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can give different ",
  ButtonBox["ContourStyle",
    ButtonStyle->"RefGuideLink"],
  "s to the various contour lines of a single scalar function:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{
          StyleBox[\({x^2 - y^2, {x, \(-1\), 1}, {y, \(-1\), 1}}\),
            FontColor->RGBColor[0, 0, 1]], ",", "\[IndentingNewLine]", 
          
          StyleBox[\({x^2 + y^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
              PlotPoints \[Rule] {5, 5}, 
              ContourStyle \[Rule] Table[{Hue[i/11]}, {i, 11}]}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "One more example: contour lines of ",
  Cell[BoxData[
      \(TraditionalForm\`x\ y\ z\)]],
  " over a half sphere:"
}], "Text"],

Cell[BoxData[{\(Needs["\<Geometry`Rotations`\>"];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Module", "[", 
        RowBox[{\({x, y, z}\), ",", "\[IndentingNewLine]", 
          
          RowBox[{\({x, y, z} = Rotate3D[{1, 0, 0}, \[Phi], \[Theta], 0]\), 
            ";", "\[IndentingNewLine]", 
            RowBox[{"PlotCurveOnSurface3D", "[", 
              RowBox[{
                RowBox[{"{", 
                  
                  StyleBox[\({x, y, z}, {\[Phi], 0, 
                      Pi}, {\[Theta], \(-Pi\)/2, Pi/2}\),
                    FontColor->RGBColor[0, 0, 1]], 
                  StyleBox["}",
                    FontColor->RGBColor[0, 0, 1]]}], ",", 
                "\[IndentingNewLine]", 
                
                StyleBox[\({x*y*z, {\[Phi], 0, Pi}, {\[Theta], \(-Pi\)/2, 
                      Pi/2}, ContourStyle \[Rule] 
                      Table[{Hue[i/11]}, {i, 11}]}\),
                  FontColor->RGBColor[1, 0, 0]]}], "]"}]}]}], "]"}], 
      ";"}]}], "Input"],

Cell["The contour lines can be oriented:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Module", "[", 
        RowBox[{\({x, y, z}\), ",", "\[IndentingNewLine]", 
          
          RowBox[{\({x, y, z} = Rotate3D[{1, 0, 0}, \[Phi], \[Theta], 0]\), 
            ";", "\[IndentingNewLine]", 
            RowBox[{"PlotCurveOnSurface3D", "[", 
              RowBox[{
                RowBox[{"{", 
                  
                  StyleBox[\({x, y, z}, {\[Phi], 0, 
                      Pi}, {\[Theta], \(-Pi\)/2, Pi/2}\),
                    FontColor->RGBColor[0, 0, 1]], 
                  StyleBox["}",
                    FontColor->RGBColor[0, 0, 1]]}], ",", 
                "\[IndentingNewLine]", 
                
                StyleBox[\({x*y*z, {\[Phi], 0, Pi}, {\[Theta], \(-Pi\)/2, 
                      Pi/2}, ContourStyle \[Rule] 
                      Table[{Hue[i/11]}, {i, 11}], Oriented -> True}\),
                  FontColor->RGBColor[1, 0, 0]]}], "]"}]}]}], "]"}], 
      ";"}]], "Input"],

Cell["\<\
You can have contour curves and parametric curves at the same time:\
\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PlotCurveOnSurface3D", "[", 
        RowBox[{
          StyleBox[\({x^2 - y^2, {x, \(-1\), 1}, {y, \(-1\), 1}}\),
            FontColor->RGBColor[0, 0, 1]], ",", "\[IndentingNewLine]", 
          
          StyleBox[\({x^2 + y^2, {x, \(-1\), 1}, {y, \(-1\), 1}, 
              ContourStyle \[Rule] Red}\),
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[",",
            FontColor->RGBColor[1, 0, 0]], 
          
          StyleBox[\({{t, \(-t^2\)}, {t, \(-1\), 1}, PlotStyle \[Rule] Blue, 
              Oriented -> True}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The command ",
  StyleBox["PlotCurveOnSurface3D", "Input"],
  " sorts out from the input syntax whether you are asking for a parametric \
curve or for contour lines."
}], "Text"],

Cell[TextData[{
  StyleBox["PlotCurveOnSurface3D", "Input"],
  " can make plots very similar-looking to the ones you get from ",
  StyleBox["LevelPlot3D", "Input"],
  " and ",
  StyleBox["SliceSurfacePlot3D", "Input"],
  ", and it's up to you to choose which one to use for your purposes. \
Internally, they make totally different calculations. From the final user \
point of view, perhaps the main difference is that the contour lines made by \
",
  StyleBox["LevelPlot3D", "Input"],
  " and ",
  StyleBox["SliceSurfacePlot3D", "Input"],
  " are exactly planar, even for rough surface grids, while with ",
  StyleBox["PlotCurveOnSurface3D", "Input"],
  " you may need to crank up ",
  ButtonBox["PlotPoints",
    ButtonStyle->"RefGuideLink"],
  " in both the surface and the curves to get rid of jaggies."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Trig Interpolation curves",
  FontColor->RGBColor[1, 0, 0]]], "Subsubtitle"],

Cell[TextData[{
  "I have written some utilities to help me draw pictures of \
\"generic-looking\" smooth functions or curves in the plane, and blob-like \
shapes. I was not satisfied with ",
  Cell[BoxData[
      FormBox[
        ButtonBox["Graphics`Spline",
          ButtonStyle->"AddOnsLink"], TraditionalForm]]],
  ", because that way you can just spot the junctions, even if they are \
technically smooth. So I turned to trigonometric functions instead of \
polynomials to see what happened."
}], "Text"],

Cell[CellGroupData[{

Cell["TrigInterpolation parametric curves in the plane", "Section"],

Cell[TextData[{
  "The basic function is ",
  StyleBox["TrigInterpolationParametricPlot", "Input",
    Background->RGBColor[1, 1, 0]],
  ", which takes a list of points and connects them with a curve:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["TrigInterpolationParametricPlot",
          FontColor->RGBColor[1, 0, 0]], 
        "[", \({{0, 0}, {1, 1}, {3, 0}, {1, 0}} // N\), "]"}], ";"}]], "Input"],

Cell[TextData[{
  "Just for checking, let us see the points through with we interpolate, with \
the option ",
  StyleBox["ShowListPlot", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(TrigInterpolationParametricPlot[{{0, 0}, {1, 1}, {3, 0}, {1, 0}} // 
          N, ShowListPlot \[Rule] True];\)\)], "Input"],

Cell[TextData[{
  "To every interpolation point ",
  StyleBox["{x,y}", "Input"],
  " you can impose a velocity vector ",
  StyleBox["{vx,vy}", "Input"],
  ", a second order derivative vector ",
  StyleBox["{ax,ay}", "Input"],
  ", etc., by writing ",
  StyleBox["{{x,y},{vx,vy},{ax,ay}...}", "Input"],
  " instead of ",
  StyleBox["{x,y}", "Input"]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                StyleBox[\({{0, 0}, {\(-1\), 0}}\),
                  FontColor->RGBColor[1, 0, 0]], ",", \({1, 1}\), 
                ",", \({3, 0}\), ",", \({1, 0}\)}], "}"}], "//", "N"}], 
          ",", \(ShowListPlot \[Rule] True\), ",", \(Frame \[Rule] True\), 
          ",", \(Axes \[Rule] False\)}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "Trig functions are periodic. Hence they are specially suited to make \
closed curves (loops). You get that with the option ",
  StyleBox["ClosedCurve", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{\({{0, 0}, {1, 1}, {3, 0}, {1, 0}} // N\), ",", 
          StyleBox[\(ClosedCurve \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can change the appearace of the curve with ",
  StyleBox["PlotStyle", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{\({{0, 0}, {1, 1}, {3, 0}, {1, 0}} // N\), ",", 
          StyleBox[\(PlotStyle \[Rule] Red\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{\({{0, 0}, {1, 1}, {3, 0}, {1, 0}} // N\), 
          ",", \(ClosedCurve \[Rule] True\), ",", \(Axes \[Rule] False\), ",",
           
          StyleBox[\(PlotStyle \[Rule] Red\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The option ",
  StyleBox["Oriented", "Input",
    Background->RGBColor[1, 1, 0]],
  " adds arrows to the curve:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{\({{0, 0}, {1, 1}, {3, 0}, {1, 0}} // N\), ",", 
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{\({{0, 0}, {1, 1}, {3, 0}, {1, 0}} // N\), 
          ",", \(ClosedCurve \[Rule] True\), ",", 
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]], ",", \(Axes \[Rule] None\)}], 
        "]"}], ";"}]], "Input"],

Cell[TextData[{
  "You can fill the closed curve with ",
  StyleBox["FilledClosedCurve", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(TrigInterpolationParametricPlot[{{0, 0}, {1, 1}, {2, 0}, {1, 0}} // 
          N, FilledClosedCurve \[Rule] True];\)\)], "Input"],

Cell[TextData[{
  "You can use the ",
  StyleBox[ButtonBox["AxesFront"], "Input",
    Background->RGBColor[1, 1, 0]],
  " and ",
  StyleBox["Fills", "Input",
    Background->RGBColor[1, 1, 0]],
  " options from ",
  Cell[BoxData[
      FormBox[
        ButtonBox["FilledPlot",
          ButtonStyle->"AddOnsLink"], TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{\({{0, 0}, {1, 1}, {2, 0}, {1, 0}} // N\), 
          ",", \(FilledClosedCurve \[Rule] True\), ",", 
          StyleBox[\(AxesFront \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]], ",", 
          StyleBox[\(Fills \[Rule] AureolineYellow\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{\({{0, 0}, {1, 1}, {2, 0}, {1, 0}} // N\), 
          ",", \(FilledClosedCurve \[Rule] True\), ",", 
          StyleBox[\(AxesFront \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]], ",", 
          StyleBox[\(Fills \[Rule] AureolineYellow\),
            FontColor->RGBColor[1, 0, 0]], ",", \(Oriented \[Rule] True\), 
          ",", \(PlotStyle \[Rule] {Blue, Thickness[ .01]}\), 
          ",", \(HeadLength \[Rule] 1/10\)}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{\({{{0, 0}, {0, 0}, {0, 1}}, {1, 1}, {0, 1}} // N\), 
          ",", \(FilledClosedCurve \[Rule] True\), 
          ",", \(ShowListPlot \[Rule] True\), ",", 
          StyleBox[\(AxesFront \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[",",
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[\(Fills \[Rule] CornflowerBlue\),
            FontColor->RGBColor[1, 0, 0]], 
          ",", \(PlotStyle \[Rule] {OrangeRed, Dashing[{ .01,  .02}], 
              Thickness[ .01]}\)}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "With ",
  StyleBox["ListPlotStyle", "Input",
    Background->RGBColor[1, 1, 0]],
  " you can decide the look of the interpolation points:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{\({{0, 0}, {1, 1}, {3, 0}, {1, 0}} // N\), 
          ",", \(ClosedCurve \[Rule] True\), ",", \(Oriented \[Rule] True\), 
          ",", \(HowManyArrows \[Rule] 3\), ",", 
          StyleBox[\(ShowListPlot \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]], ",", 
          StyleBox[\(ListPlotStyle \[Rule] {Red, PointSize[ .04]}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["TrigInterpolation parametric curves in 3D-space", "Section"],

Cell[TextData[{
  "You get interpolating curves in 3D-space just by giving ",
  StyleBox["triples",
    FontSlant->"Italic"],
  " as interpolating points:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"{", 
              StyleBox[\({0, 0, 0}, {\(-1\), 1, 1}, {0, 2, 0}, {1, 2, 0}\),
                FontColor->RGBColor[1, 0, 0]], "}"}], "//", "N"}], 
          ",", \(ShowListPlot \[Rule] True\)}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The option ",
  StyleBox["ClosedCurve", "Input",
    Background->RGBColor[1, 1, 0]],
  " makes, well, a closed curve:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{\({{0, 0, 0}, {\(-1\), 1, 1}, {0, 2, 0}, {1, 2, 0}} // N\), 
          ",", 
          StyleBox[\(ClosedCurve \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]], ",", \(ShowListPlot \[Rule] True\),
           ",", \(Ticks \[Rule] None\)}], "]"}], ";"}]], "Input"],

Cell[TextData[{
  "The option ",
  StyleBox["Oriented", "Input",
    Background->RGBColor[1, 1, 0]],
  " places an arrow along the curve, whether it is open or closed:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{\({{0, 0, 0}, {\(-1\), 1, 1}, {0, 2, 0}, {1, 2, 0}} // N\), 
          ",", \(ClosedCurve \[Rule] True\), ",", 
          StyleBox[\(Oriented \[Rule] True\),
            FontColor->RGBColor[1, 0, 0]], ",", \(Ticks \[Rule] None\)}], 
        "]"}], ";"}]], "Input"],

Cell[TextData[{
  "In 3D-space you change the style of the interpolating line with ",
  StyleBox["PlotStyle", "Input",
    Background->RGBColor[1, 1, 0]],
  ": and the position of the arrow with ",
  StyleBox["ArrowPositions", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{\({{0, 0, 0}, {1, 1, 1}, {2, 0, 1}, {1, 0, 0}} // N\), ",", 
          StyleBox[\(PlotStyle \[Rule] Blue\),
            FontColor->RGBColor[1, 0, 0]], ",", 
          StyleBox[\(ArrowPositions \[Rule] 1\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{\({{0, 0, 0}, {\(-1\), 1, 1}, {0, 2, 0}, {1, 2, 0}} // N\), 
          ",", \(ClosedCurve \[Rule] True\), ",", \(Oriented \[Rule] True\), 
          ",", \(HowManyArrows \[Rule] 3\), ",", \(HeadLength3D \[Rule] 1/5\),
           ",", \(Ticks \[Rule] None\), ",", 
          StyleBox[\(PlotStyle \[Rule] {Red, Thickness[ .01]}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationParametricPlot", "[", 
        RowBox[{\({{0, 0, 0}, {0, 1, 1}, {1, 1, 1}, {1, 0, 1}}\), 
          ",", \(Oriented \[Rule] True\), 
          ",", \(ShowTimesListQ \[Rule] True\), 
          ",", \(ArrowPositions \[Rule] {1/2, 1}\), 
          ",", \(PlotRange \[Rule] All\), ",", 
          StyleBox[\(PlotStyle \[Rule] {Red, Thickness[ .01]}\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["TrigInterpolation cartesian plots", "Section"],

Cell[TextData[{
  "Instead of a parametric curve in the plane, we can make a cartesian plot \
of a one-variable-to-one-variable function with ",
  StyleBox["TrigInterpolationPlot", "Input",
    Background->RGBColor[1, 1, 0]],
  ": as arguments it takes the list of points, the minimum and maximum \
x-values of the plot, and options:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["TrigInterpolationPlot",
          FontColor->RGBColor[1, 0, 0]], 
        "[", \({{0, 0}, {1, 1}, {2, 1}} // N, \(-2\), 5, 
        ShowListPlot \[Rule] True\), "]"}], ";"}]], "Input"],

Cell[TextData[{
  "Here the the data follow the syntax ",
  Cell[BoxData[
      \(TraditionalForm\`{{x\_1, f\_1, d\ f\_1, 
          d\ d\ f\_1, \[Ellipsis]}, \[Ellipsis]}\)]],
  "  as in ",
  ButtonBox["InterpolatingPolynomial",
    ButtonStyle->"RefGuideLink"],
  ": "
}], "Text"],

Cell[BoxData[
    \(\(TrigInterpolationPlot[{{0, 0, 0}, {1, 1}, {2, 1}}, \(-2\), 5, 
        ShowListPlot \[Rule] True];\)\)], "Input"],

Cell[TextData[{
  "The option ",
  StyleBox["Period", "Input",
    Background->RGBColor[1, 1, 0]],
  " imposes the period of the interpolation function:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TrigInterpolationPlot", "[", 
        RowBox[{\({{0, 0}, {1, 1}, {2, 1}} // N\), ",", \(-4\), ",", "8", 
          ",", \(ShowListPlot \[Rule] True\), ",", 
          StyleBox[\(Period \[Rule] 10\),
            FontColor->RGBColor[1, 0, 0]]}], "]"}], ";"}]], "Input"],

Cell["\<\
Beware that some period values may be incompatible with the data.\
\
\>", "Text"],

Cell[BoxData[
    \(TrigInterpolationPlot[{{1, 1}, {2, 2}}, 0, 4, 
      Period \[Rule] 1]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["\"Drawing paper\" companions", "Section"],

Cell[TextData[{
  "There are also the ",
  ButtonBox["Draw",
    ButtonStyle->"AddOnsLink"],
  " parallels to the ",
  StyleBox["Plot", "Input"],
  " commands:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Draw2D", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{"Red", ",", 
                  RowBox[{
                    StyleBox["TrigInterpolationParametricDraw",
                      FontColor->RGBColor[1, 0, 0]], 
                    "[", \({{1, 1}, {2, 0}, {4, 1}} // N, 
                    ClosedCurve \[Rule] True\), "]"}]}], "}"}], ",", 
              RowBox[{"{", 
                RowBox[{"SapGreen", ",", 
                  RowBox[{
                    StyleBox["TrigInterpolationDraw",
                      FontColor->RGBColor[1, 0, 0]], 
                    "[", \({{0, \(-1\)}, {1, 0}, {2, 1}} // N, \(-1\), 5\), 
                    "]"}]}], "}"}], 
              ",", \({Blue, PointSize[ .03], Point[{2, 1}]}\), ",", 
              RowBox[{
                StyleBox["TrigInterpolationParametricDraw",
                  FontColor->RGBColor[1, 0, 0]], 
                "[", \({{{0, 0}, {0, 1}/5}, {{1, 1}, {2, \(-1\)}/2}} // N, 
                Oriented \[Rule] True, ArrowPositions \[Rule] 1, 
                HeadLength \[Rule] 1/15\), "]"}], 
              ",", \(Text[Here, {0, 0}, {0, 1}]\)}], "}"}], 
          ",", \(PlotRange \[Rule] All\), 
          ",", \(Background \[Rule] PaleTurquoise\)}], "]"}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["TrigInterpolation formulas", "Section"],

Cell[TextData[{
  "Are you curious to see the trigonometric functions whose graph you are \
plotting? Use the ",
  StyleBox["ShowFormula", "Input",
    Background->RGBColor[1, 1, 0]],
  " option: the ouput will become a list of the form ",
  Cell[BoxData[
      \(TraditionalForm\`{\[SkeletonIndicator]Graphics\[SkeletonIndicator], 
        formula}\)]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{"TrigInterpolationParametricPlot", "[", 
      RowBox[{\({{0, 0}, {1, 1}, {3, 0}, {1, 0}} // N\), 
        ",", \(ClosedCurve \[Rule] True\), ",", 
        StyleBox[\(ShowFormula \[Rule] True\),
          FontColor->RGBColor[1, 0, 0]], ",", \(Oriented \[Rule] True\), 
        ",", \(HowManyArrows \[Rule] 3\), ",", \(Axes \[Rule] None\)}], 
      "]"}]], "Input"],

Cell[TextData[{
  "From ",
  StyleBox["exact",
    FontSlant->"Italic"],
  " starting points you get an ",
  StyleBox["exact",
    FontSlant->"Italic"],
  " formula. Beware that the time and memory needed to calculate (and to \
display) an exact interpolation formula can be substantial:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["TrigInterpolationPlot",
        FontColor->RGBColor[1, 0, 0]], "[", 
      RowBox[{\({{0, 0}, {1, 1}, {2, 1}}\), ",", \(-2\), ",", "5", ",", 
        StyleBox[\(ShowFormula \[Rule] True\),
          FontColor->RGBColor[1, 0, 0]]}], "]"}]], "Input"],

Cell[TextData[{
  "You can get the formulas alone, without plotting, with the commands ",
  StyleBox["TrigInterpolation", "Input",
    Background->RGBColor[1, 1, 0]],
  " and ",
  StyleBox["ParametricTrigInterpolation", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[{\(Clear[t];\), "\[IndentingNewLine]", 
    RowBox[{
      StyleBox["TrigInterpolation",
        FontColor->RGBColor[1, 0, 0]], "[", 
      RowBox[{\({{0, 0}, {1, 1}, {2, 1}}\), ",", 
        StyleBox["t",
          FontColor->RGBColor[1, 0, 0]]}], "]"}]}], "Input"],

Cell[BoxData[{\(Clear[t];\), "\[IndentingNewLine]", 
    RowBox[{
      StyleBox["ParametricTrigInterpolation",
        FontColor->RGBColor[1, 0, 0]], "[", \({{0, 0}, {1, 1}, {2, 1}}, t\), 
      "]"}]}], "Input"],

Cell[TextData[{
  "You can try to get an interpolating formula with a different period from \
the default by setting the option ",
  StyleBox["Period", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[{\(Clear[t];\), "\[IndentingNewLine]", 
    RowBox[{"TrigInterpolation", "[", 
      RowBox[{\({{0, 0}, {1, 1}, {2, 1}}\), ",", "t", ",", 
        StyleBox[\(Period \[Rule] 10\),
          FontColor->RGBColor[1, 0, 0]]}], "]"}]}], "Input"],

Cell[TextData[{
  "Of course you can ",
  ButtonBox["Simplify",
    ButtonStyle->"RefGuideLink"],
  " the output formula, but then the trigonometric functions may not be \
nicely collected any more. To simplify the coefficients only, instead of the \
formula as a whole, try the option ",
  StyleBox["EvaluateOnCoefficients", "Input",
    Background->RGBColor[1, 1, 0]],
  ":"
}], "Text"],

Cell[BoxData[{\(Clear[t];\), "\[IndentingNewLine]", 
    RowBox[{"TrigInterpolation", "[", 
      RowBox[{\({{0, 0}, {1, 1}, {2, 1}}\), ",", "t", 
        ",", \(Period \[Rule] 10\), ",", 
        StyleBox[\(EvaluateOnCoefficients \[Rule] FullSimplify\),
          FontColor->RGBColor[1, 0, 0]]}], "]"}]}], "Input"],

Cell[TextData[{
  "A plane curve given by trigonometric interpolation is always the zero set \
of a two-variable polynomial. The function ",
  StyleBox["PolynomialLevelSetTrigInterpolation", "Input",
    Background->RGBColor[1, 1, 0]],
  " gives both the curve and the polynomial:"
}], "Text"],

Cell[BoxData[
    \(PolynomialLevelSetTrigInterpolation[{{0, 0}, {2, 0}, {1, 1}}, t, x, y, 
      ClosedCurve \[Rule] False]\)], "Input"],

Cell[BoxData[
    \(PolynomialLevelSetTrigInterpolation[{{0, 0}, {2, 0}, {1, 1}}, t, x, y, 
      ClosedCurve \[Rule] True]\)], "Input"],

Cell["\<\
This picture shows that the starting points (in red) do lie on a \
level set (contour) of the polynomial:\
\>", "Text"],

Cell[BoxData[{
    \(\(pts = {{0, 0}, {2, 0}, {1, 1}, {0, 1}};\)\), "\[IndentingNewLine]", 
    \({c, poly} = 
      PolynomialLevelSetTrigInterpolation[pts, t, x, y, 
        ClosedCurve \[Rule] True]\)}], "Input"],

Cell[BoxData[
    \(\(Draw2D[{\[IndentingNewLine]ContourDraw[
            ArcTan[poly], {x, \(-1\), 3}, {y, \(-1\), 3}, 
            Contours \[Rule] 
              ArcTan[{\(-10\), \(-5\), \(-2\), \(-1\), \(-1\)/2, \(-1\)/
                    8, \(-1\)/16, 0, 1/2, 1, 320/256, 343/256}], 
            PlotPoints \[Rule] 33], \[IndentingNewLine]PointSize[ .02], Red, 
          ListDraw[pts]}, \[IndentingNewLine]AspectRatio \[Rule] Automatic, 
        Frame \[Rule] True];\)\)], "Input"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 742}},
AutoGeneratedPackage->None,
WindowSize->{901, 707},
WindowMargins->{{Automatic, 31}, {Automatic, 6}},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 31, 0, 88, "Title"],
Cell[1810, 55, 515, 17, 32, "Text"],
Cell[2328, 74, 172, 5, 32, "Text"],
Cell[2503, 81, 700, 24, 50, "Text"],
Cell[3206, 107, 317, 9, 32, "Text"],
Cell[3526, 118, 287, 5, 50, "Text"],
Cell[3816, 125, 1149, 32, 86, "Text"],
Cell[4968, 159, 422, 8, 68, "Text"],

Cell[CellGroupData[{
Cell[5415, 171, 379, 8, 19, "Input",
  CellOpen->False],
Cell[5797, 181, 481, 13, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6315, 199, 64, 0, 28, "Subsubtitle"],
Cell[6382, 201, 393, 12, 50, "Text"],
Cell[6778, 215, 527, 13, 68, "Text"],
Cell[7308, 230, 107, 2, 27, "Input"],
Cell[7418, 234, 508, 14, 68, "Text"],
Cell[7929, 250, 87, 1, 27, "Input"],
Cell[8019, 253, 244, 6, 32, "Text"],
Cell[8266, 261, 61, 1, 27, "Input"],
Cell[8330, 264, 1438, 34, 140, "Text"],
Cell[9771, 300, 914, 26, 68, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[10722, 331, 39, 0, 30, "Subsubtitle"],
Cell[10764, 333, 669, 15, 86, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[11470, 353, 96, 4, 54, "Subtitle"],
Cell[11569, 359, 155, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[11749, 368, 60, 0, 28, "Subsubtitle"],
Cell[11812, 370, 86, 2, 27, "Input",
  InitializationCell->True],
Cell[11901, 374, 87, 2, 27, "Input",
  InitializationCell->True],
Cell[11991, 378, 250, 4, 43, "Input",
  InitializationCell->True],
Cell[12244, 384, 144, 3, 43, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[12413, 391, 98, 3, 38, "Subsection"],
Cell[12514, 396, 428, 7, 91, "Input",
  InitializationCell->True],
Cell[12945, 405, 633, 9, 139, "Input",
  InitializationCell->True],
Cell[13581, 416, 802, 12, 171, "Input",
  InitializationCell->True],
Cell[14386, 430, 339, 5, 75, "Input",
  InitializationCell->True],
Cell[14728, 437, 378, 6, 91, "Input",
  InitializationCell->True],
Cell[15109, 445, 499, 7, 107, "Input",
  InitializationCell->True],
Cell[15611, 454, 515, 8, 107, "Input",
  InitializationCell->True],
Cell[16129, 464, 424, 7, 91, "Input",
  InitializationCell->True],
Cell[16556, 473, 366, 6, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[16959, 484, 143, 4, 30, "Subsection"],
Cell[17105, 490, 373, 6, 91, "Input",
  InitializationCell->True],
Cell[17481, 498, 422, 7, 91, "Input",
  InitializationCell->True],
Cell[17906, 507, 673, 11, 139, "Input",
  InitializationCell->True],
Cell[18582, 520, 291, 5, 75, "Input",
  InitializationCell->True],
Cell[18876, 527, 243, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[19156, 537, 39, 0, 30, "Subsection"],
Cell[19198, 539, 324, 5, 91, "Input",
  InitializationCell->True],
Cell[19525, 546, 356, 6, 91, "Input",
  InitializationCell->True],
Cell[19884, 554, 304, 5, 75, "Input",
  InitializationCell->True],
Cell[20191, 561, 364, 6, 91, "Input",
  InitializationCell->True],
Cell[20558, 569, 458, 8, 107, "Input",
  InitializationCell->True],
Cell[21019, 579, 204, 4, 59, "Input",
  InitializationCell->True],
Cell[21226, 585, 691, 11, 155, "Input",
  InitializationCell->True],
Cell[21920, 598, 219, 4, 59, "Input",
  InitializationCell->True],
Cell[22142, 604, 272, 5, 75, "Input",
  InitializationCell->True],
Cell[22417, 611, 223, 4, 59, "Input",
  InitializationCell->True],
Cell[22643, 617, 437, 7, 107, "Input",
  InitializationCell->True],
Cell[23083, 626, 264, 5, 75, "Input",
  InitializationCell->True],
Cell[23350, 633, 280, 5, 75, "Input",
  InitializationCell->True],
Cell[23633, 640, 295, 6, 75, "Input",
  InitializationCell->True],
Cell[23931, 648, 394, 6, 107, "Input",
  InitializationCell->True],
Cell[24328, 656, 377, 6, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[24742, 667, 94, 3, 30, "Subsection"],
Cell[24839, 672, 400, 7, 91, "Input",
  InitializationCell->True],
Cell[25242, 681, 225, 4, 59, "Input",
  InitializationCell->True],
Cell[25470, 687, 379, 7, 91, "Input",
  InitializationCell->True],
Cell[25852, 696, 224, 4, 59, "Input",
  InitializationCell->True],
Cell[26079, 702, 99, 2, 27, "Input",
  InitializationCell->True],
Cell[26181, 706, 208, 4, 59, "Input",
  InitializationCell->True],
Cell[26392, 712, 330, 6, 75, "Input",
  InitializationCell->True],
Cell[26725, 720, 224, 4, 59, "Input",
  InitializationCell->True],
Cell[26952, 726, 95, 2, 27, "Input",
  InitializationCell->True],
Cell[27050, 730, 205, 4, 59, "Input",
  InitializationCell->True],
Cell[27258, 736, 281, 5, 75, "Input",
  InitializationCell->True],
Cell[27542, 743, 240, 4, 59, "Input",
  InitializationCell->True],
Cell[27785, 749, 488, 7, 107, "Input",
  InitializationCell->True],
Cell[28276, 758, 288, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[28601, 768, 136, 5, 30, "Subsection"],
Cell[28740, 775, 551, 9, 123, "Input",
  InitializationCell->True],
Cell[29294, 786, 259, 5, 59, "Input",
  InitializationCell->True],
Cell[29556, 793, 103, 2, 27, "Input",
  InitializationCell->True],
Cell[29662, 797, 235, 4, 59, "Input",
  InitializationCell->True],
Cell[29900, 803, 185, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[30122, 812, 46, 0, 30, "Subsection"],
Cell[30171, 814, 446, 7, 107, "Input",
  InitializationCell->True],
Cell[30620, 823, 291, 5, 75, "Input",
  InitializationCell->True],
Cell[30914, 830, 364, 6, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[31315, 841, 100, 4, 30, "Subsection"],
Cell[31418, 847, 594, 9, 123, "Input",
  InitializationCell->True],
Cell[32015, 858, 212, 4, 43, "Input",
  InitializationCell->True],
Cell[32230, 864, 354, 6, 91, "Input",
  InitializationCell->True],
Cell[32587, 872, 283, 5, 75, "Input",
  InitializationCell->True],
Cell[32873, 879, 251, 4, 59, "Input",
  InitializationCell->True],
Cell[33127, 885, 348, 6, 75, "Input",
  InitializationCell->True],
Cell[33478, 893, 447, 8, 107, "Input",
  InitializationCell->True],
Cell[33928, 903, 213, 4, 59, "Input",
  InitializationCell->True],
Cell[34144, 909, 244, 4, 59, "Input",
  InitializationCell->True],
Cell[34391, 915, 277, 5, 75, "Input",
  InitializationCell->True],
Cell[34671, 922, 51, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[34759, 928, 26, 0, 30, "Subsection"],
Cell[34788, 930, 88, 2, 27, "Input",
  InitializationCell->True],
Cell[34879, 934, 157, 3, 43, "Input",
  InitializationCell->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[35085, 943, 34, 0, 30, "Subsubtitle"],
Cell[35122, 945, 45, 0, 32, "Text"],
Cell[35170, 947, 177, 5, 27, "Input",
  InitializationCell->True],
Cell[35350, 954, 126, 3, 32, "Text"],
Cell[35479, 959, 154, 3, 27, "Input",
  InitializationCell->True],
Cell[35636, 964, 220, 5, 32, "Text"],
Cell[35859, 971, 1006, 19, 187, "Input",
  InitializationCell->True],
Cell[36868, 992, 32, 0, 32, "Text"],
Cell[36903, 994, 141, 3, 27, "Input",
  InitializationCell->True],
Cell[37047, 999, 143, 3, 32, "Text"],
Cell[37193, 1004, 337, 6, 59, "Input",
  InitializationCell->True],
Cell[37533, 1012, 136, 3, 27, "Input",
  InitializationCell->True],
Cell[37672, 1017, 3230, 60, 523, "Input",
  InitializationCell->True],
Cell[40905, 1079, 59, 0, 32, "Text"],
Cell[40967, 1081, 211, 4, 43, "Input",
  InitializationCell->True],
Cell[41181, 1087, 90, 1, 32, "Text"],
Cell[41274, 1090, 871, 17, 155, "Input",
  InitializationCell->True],
Cell[42148, 1109, 424, 16, 50, "Text"],
Cell[42575, 1127, 271, 7, 43, "Input",
  InitializationCell->True],
Cell[42849, 1136, 748, 14, 139, "Input",
  InitializationCell->True],
Cell[43600, 1152, 164, 4, 32, "Text"],
Cell[43767, 1158, 1129, 23, 203, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[44933, 1186, 35, 0, 30, "Subsubtitle"],
Cell[44971, 1188, 330, 6, 59, "Input",
  InitializationCell->True],
Cell[45304, 1196, 97, 2, 27, "Input",
  InitializationCell->True],
Cell[45404, 1200, 666, 13, 107, "Input",
  InitializationCell->True],
Cell[46073, 1215, 2042, 37, 363, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[48152, 1257, 45, 0, 30, "Subsubtitle"],
Cell[48200, 1259, 107, 2, 27, "Input",
  InitializationCell->True],
Cell[48310, 1263, 682, 13, 123, "Input",
  InitializationCell->True],
Cell[48995, 1278, 2116, 37, 411, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[51148, 1320, 55, 0, 30, "Subsubtitle"],
Cell[51206, 1322, 109, 2, 27, "Input",
  InitializationCell->True],
Cell[51318, 1326, 873, 15, 171, "Input",
  InitializationCell->True],
Cell[52194, 1343, 469, 9, 75, "Input",
  InitializationCell->True],
Cell[52666, 1354, 568, 12, 139, "Input",
  InitializationCell->True],
Cell[53237, 1368, 3250, 55, 571, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[56524, 1428, 43, 0, 30, "Subsubtitle"],

Cell[CellGroupData[{
Cell[56592, 1432, 51, 0, 69, "Section"],
Cell[56646, 1434, 431, 11, 50, "Text"],
Cell[57080, 1447, 580, 11, 75, "Input",
  InitializationCell->True],
Cell[57663, 1460, 367, 10, 50, "Text"],
Cell[58033, 1472, 606, 12, 107, "Input",
  InitializationCell->True],
Cell[58642, 1486, 346, 10, 50, "Text"],
Cell[58991, 1498, 352, 7, 75, "Input",
  InitializationCell->True],
Cell[59346, 1507, 310, 9, 50, "Text"],
Cell[59659, 1518, 441, 8, 91, "Input",
  InitializationCell->True],
Cell[60103, 1528, 244, 7, 32, "Text"],
Cell[60350, 1537, 264, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[60651, 1547, 39, 0, 39, "Section"],
Cell[60693, 1549, 255, 7, 32, "Text"],
Cell[60951, 1558, 970, 16, 155, "Input",
  InitializationCell->True],
Cell[61924, 1576, 168, 4, 32, "Text"],
Cell[62095, 1582, 88, 1, 27, "Input"],
Cell[62186, 1585, 587, 11, 107, "Input"],
Cell[62776, 1598, 583, 11, 107, "Input"],
Cell[63362, 1611, 314, 10, 50, "Text"],
Cell[63679, 1623, 249, 5, 43, "Input",
  InitializationCell->True],
Cell[63931, 1630, 247, 8, 32, "Text"],
Cell[64181, 1640, 214, 4, 43, "Input",
  InitializationCell->True],
Cell[64398, 1646, 646, 23, 68, "Text"],
Cell[65047, 1671, 106, 2, 27, "Input",
  InitializationCell->True],
Cell[65156, 1675, 584, 10, 139, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[65777, 1690, 24, 0, 39, "Section"],
Cell[65804, 1692, 87, 3, 32, "Text"],
Cell[65894, 1697, 110, 2, 27, "Input",
  InitializationCell->True],
Cell[66007, 1701, 185, 6, 32, "Text"],
Cell[66195, 1709, 668, 11, 139, "Input",
  InitializationCell->True],
Cell[66866, 1722, 660, 10, 139, "Input",
  InitializationCell->True],
Cell[67529, 1734, 8148, 146, 1243, "Input"],
Cell[75680, 1882, 65, 0, 32, "Text"],
Cell[75748, 1884, 11247, 202, 1707, "Input",
  InitializationCell->True],
Cell[86998, 2088, 61, 0, 32, "Text"],
Cell[87062, 2090, 2902, 49, 443, "Input",
  InitializationCell->True],
Cell[89967, 2141, 110, 2, 27, "Input",
  InitializationCell->True],
Cell[90080, 2145, 581, 10, 123, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[90710, 2161, 57, 0, 30, "Subsubtitle"],
Cell[90770, 2163, 261, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[91068, 2172, 37, 0, 30, "Subsubtitle"],
Cell[91108, 2174, 99, 2, 27, "Input",
  InitializationCell->True],
Cell[91210, 2178, 251, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[91498, 2187, 42, 0, 30, "Subsubtitle"],
Cell[91543, 2189, 669, 12, 139, "Input",
  InitializationCell->True],
Cell[92215, 2203, 824, 15, 155, "Input",
  InitializationCell->True],
Cell[93042, 2220, 794, 14, 139, "Input",
  InitializationCell->True],
Cell[93839, 2236, 380, 7, 75, "Input",
  InitializationCell->True],
Cell[94222, 2245, 1613, 29, 315, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[95872, 2279, 77, 0, 30, "Subsubtitle"],
Cell[95952, 2281, 424, 15, 32, "Text"],
Cell[96379, 2298, 335, 6, 59, "Input",
  InitializationCell->True],
Cell[96717, 2306, 39, 0, 32, "Text"],
Cell[96759, 2308, 442, 7, 75, "Input",
  InitializationCell->True],
Cell[97204, 2317, 212, 5, 32, "Text"],
Cell[97419, 2324, 311, 5, 59, "Input"],
Cell[97733, 2331, 363, 7, 59, "Input",
  InitializationCell->True],
Cell[98099, 2340, 313, 5, 59, "Input"],
Cell[98415, 2347, 365, 7, 59, "Input",
  InitializationCell->True],
Cell[98783, 2356, 315, 5, 59, "Input"],
Cell[99101, 2363, 375, 7, 59, "Input",
  InitializationCell->True],
Cell[99479, 2372, 317, 5, 59, "Input"],
Cell[99799, 2379, 377, 7, 59, "Input",
  InitializationCell->True],
Cell[100179, 2388, 369, 7, 59, "Input",
  InitializationCell->True],
Cell[100551, 2397, 369, 7, 59, "Input",
  InitializationCell->True],
Cell[100923, 2406, 162, 3, 27, "Input",
  InitializationCell->True],
Cell[101088, 2411, 73, 0, 32, "Text"],
Cell[101164, 2413, 162, 2, 27, "Input"],
Cell[101329, 2417, 194, 4, 27, "Input",
  InitializationCell->True],
Cell[101526, 2423, 213, 3, 43, "Input"],
Cell[101742, 2428, 197, 4, 27, "Input",
  InitializationCell->True],
Cell[101942, 2434, 152, 3, 27, "Input",
  InitializationCell->True],
Cell[102097, 2439, 152, 3, 27, "Input",
  InitializationCell->True],
Cell[102252, 2444, 120, 3, 32, "Text"],
Cell[102375, 2449, 2885, 52, 475, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[105297, 2506, 58, 0, 30, "Subsubtitle"],
Cell[105358, 2508, 392, 7, 59, "Input",
  InitializationCell->True],
Cell[105753, 2517, 2270, 42, 315, "Input",
  InitializationCell->True],
Cell[108026, 2561, 1064, 18, 187, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[109127, 2584, 34, 0, 30, "Subsubtitle"],
Cell[109164, 2586, 118, 2, 27, "Input",
  InitializationCell->True],
Cell[109285, 2590, 64, 0, 32, "Text"],
Cell[109352, 2592, 877, 15, 155, "Input",
  InitializationCell->True],
Cell[110232, 2609, 66, 0, 32, "Text"],
Cell[110301, 2611, 780, 13, 139, "Input",
  InitializationCell->True],
Cell[111084, 2626, 54, 0, 32, "Text"],
Cell[111141, 2628, 832, 17, 139, "Input",
  InitializationCell->True],
Cell[111976, 2647, 181, 3, 43, "Input",
  InitializationCell->True],
Cell[112160, 2652, 234, 5, 59, "Input",
  InitializationCell->True],
Cell[112397, 2659, 1785, 30, 347, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[114219, 2694, 32, 0, 30, "Subsubtitle"],
Cell[114254, 2696, 714, 12, 107, "Input",
  InitializationCell->True],
Cell[114971, 2710, 119, 2, 27, "Input",
  InitializationCell->True],
Cell[115093, 2714, 1133, 18, 235, "Input",
  InitializationCell->True],
Cell[116229, 2734, 6374, 113, 939, "Input",
  InitializationCell->True],
Cell[122606, 2849, 525, 9, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[123168, 2863, 40, 0, 30, "Subsubtitle"],

Cell[CellGroupData[{
Cell[123233, 2867, 48, 0, 56, "Section"],
Cell[123284, 2869, 58, 0, 32, "Text"],
Cell[123345, 2871, 130, 3, 27, "Input",
  InitializationCell->True],
Cell[123478, 2876, 132, 3, 27, "Input",
  InitializationCell->True],
Cell[123613, 2881, 123, 3, 27, "Input",
  InitializationCell->True],
Cell[123739, 2886, 142, 3, 27, "Input",
  InitializationCell->True],
Cell[123884, 2891, 61, 0, 32, "Text"],
Cell[123948, 2893, 796, 14, 155, "Input",
  InitializationCell->True],
Cell[124747, 2909, 52, 0, 32, "Text"],
Cell[124802, 2911, 179, 4, 27, "Input",
  InitializationCell->True],
Cell[124984, 2917, 144, 3, 27, "Input",
  InitializationCell->True],
Cell[125131, 2922, 133, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[125301, 2930, 59, 0, 36, "Section"],
Cell[125363, 2932, 154, 5, 32, "Text"],
Cell[125520, 2939, 165, 4, 27, "Input",
  InitializationCell->True],
Cell[125688, 2945, 57, 0, 32, "Text"],
Cell[125748, 2947, 139, 3, 27, "Input",
  InitializationCell->True],
Cell[125890, 2952, 64, 0, 32, "Text"],
Cell[125957, 2954, 163, 3, 27, "Input",
  InitializationCell->True],
Cell[126123, 2959, 481, 8, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[126641, 2972, 54, 0, 36, "Section"],
Cell[126698, 2974, 63, 0, 32, "Text"],
Cell[126764, 2976, 157, 3, 27, "Input",
  InitializationCell->True],
Cell[126924, 2981, 155, 3, 27, "Input",
  InitializationCell->True],
Cell[127082, 2986, 180, 3, 43, "Input",
  InitializationCell->True],
Cell[127265, 2991, 223, 5, 43, "Input",
  InitializationCell->True],
Cell[127491, 2998, 197, 4, 43, "Input",
  InitializationCell->True],
Cell[127691, 3004, 207, 4, 43, "Input",
  InitializationCell->True],
Cell[127901, 3010, 178, 4, 27, "Input",
  InitializationCell->True],
Cell[128082, 3016, 178, 4, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[128297, 3025, 41, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[128363, 3029, 62, 1, 46, "Subsection"],
Cell[128428, 3032, 526, 10, 75, "Input",
  InitializationCell->True],
Cell[128957, 3044, 202, 5, 27, "Input",
  InitializationCell->True],
Cell[129162, 3051, 163, 3, 27, "Input",
  InitializationCell->True],
Cell[129328, 3056, 247, 5, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[129612, 3066, 111, 1, 30, "Subsection"],
Cell[129726, 3069, 3007, 49, 491, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[132770, 3123, 126, 4, 30, "Subsection"],
Cell[132899, 3129, 2645, 42, 395, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[135581, 3176, 98, 1, 30, "Subsection"],
Cell[135682, 3179, 2552, 44, 395, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[138271, 3228, 143, 4, 30, "Subsection"],
Cell[138417, 3234, 2709, 45, 411, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[141163, 3284, 98, 1, 30, "Subsection"],
Cell[141264, 3287, 1731, 29, 251, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[143032, 3321, 101, 1, 30, "Subsection"],
Cell[143136, 3324, 2255, 36, 363, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[145428, 3365, 65, 1, 30, "Subsection"],
Cell[145496, 3368, 551, 10, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[146084, 3383, 102, 1, 30, "Subsection"],
Cell[146189, 3386, 2563, 46, 427, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[148789, 3437, 130, 4, 30, "Subsection"],
Cell[148922, 3443, 2714, 47, 411, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[151697, 3497, 48, 0, 30, "Subsubtitle"],

Cell[CellGroupData[{
Cell[151770, 3501, 47, 0, 69, "Section"],
Cell[151820, 3503, 26, 0, 32, "Text"],
Cell[151849, 3505, 912, 16, 171, "Input",
  InitializationCell->True],
Cell[152764, 3523, 47, 0, 32, "Text"],
Cell[152814, 3525, 1668, 29, 283, "Input",
  InitializationCell->True],
Cell[154485, 3556, 248, 5, 43, "Input",
  InitializationCell->True],
Cell[154736, 3563, 68, 0, 32, "Text"],
Cell[154807, 3565, 2447, 46, 427, "Input",
  InitializationCell->True],
Cell[157257, 3613, 99, 3, 32, "Text"],
Cell[157359, 3618, 2554, 48, 443, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[159950, 3671, 49, 0, 39, "Section"],
Cell[160002, 3673, 37, 0, 32, "Text"],
Cell[160042, 3675, 2196, 42, 395, "Input",
  InitializationCell->True],
Cell[162241, 3719, 39, 0, 32, "Text"],
Cell[162283, 3721, 2325, 44, 411, "Input",
  InitializationCell->True],
Cell[164611, 3767, 178, 6, 32, "Text"],
Cell[164792, 3775, 183, 4, 43, "Input",
  InitializationCell->True],
Cell[164978, 3781, 439, 9, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[165454, 3795, 47, 0, 39, "Section"],
Cell[165504, 3797, 53, 0, 32, "Text"],
Cell[165560, 3799, 1680, 31, 299, "Input",
  InitializationCell->True],
Cell[167243, 3832, 69, 0, 32, "Text"],
Cell[167315, 3834, 3825, 69, 747, "Input",
  InitializationCell->True],
Cell[171143, 3905, 189, 5, 32, "Text"],
Cell[171335, 3912, 369, 7, 91, "Input",
  InitializationCell->True],
Cell[171707, 3921, 121, 6, 32, "Text"],
Cell[171831, 3929, 397, 7, 75, "Input",
  InitializationCell->True],
Cell[172231, 3938, 432, 8, 75, "Input",
  InitializationCell->True],
Cell[172666, 3948, 527, 10, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[173230, 3963, 57, 0, 39, "Section"],
Cell[173290, 3965, 250, 5, 50, "Text"],
Cell[173543, 3972, 155, 3, 27, "Input",
  InitializationCell->True],
Cell[173701, 3977, 229, 4, 59, "Input",
  InitializationCell->True],
Cell[173933, 3983, 425, 8, 75, "Input",
  InitializationCell->True],
Cell[174361, 3993, 1667, 30, 331, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[176077, 4029, 39, 0, 30, "Subsubtitle"],
Cell[176119, 4031, 109, 2, 27, "Input",
  InitializationCell->True],
Cell[176231, 4035, 214, 4, 43, "Input",
  InitializationCell->True],
Cell[176448, 4041, 166, 3, 27, "Input",
  InitializationCell->True],
Cell[176617, 4046, 502, 9, 91, "Input",
  InitializationCell->True],
Cell[177122, 4057, 538, 9, 75, "Input",
  InitializationCell->True],
Cell[177663, 4068, 10824, 189, 1563, "Input",
  InitializationCell->True],
Cell[188490, 4259, 107, 2, 27, "Input",
  InitializationCell->True],
Cell[188600, 4263, 552, 9, 107, "Input",
  InitializationCell->True],
Cell[189155, 4274, 166, 3, 27, "Input",
  InitializationCell->True],
Cell[189324, 4279, 452, 9, 91, "Input",
  InitializationCell->True],
Cell[189779, 4290, 326, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[190142, 4300, 41, 0, 30, "Subsubtitle"],
Cell[190186, 4302, 111, 2, 27, "Input",
  InitializationCell->True],
Cell[190300, 4306, 657, 11, 107, "Input",
  InitializationCell->True],
Cell[190960, 4319, 170, 3, 27, "Input",
  InitializationCell->True],
Cell[191133, 4324, 7536, 138, 19, "Input",
  CellOpen->False],
Cell[198672, 4464, 9525, 171, 1419, "Input",
  InitializationCell->True],
Cell[208200, 4637, 460, 8, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[208697, 4650, 34, 0, 30, "Subsubtitle"],
Cell[208734, 4652, 101, 2, 27, "Input",
  InitializationCell->True],
Cell[208838, 4656, 615, 11, 107, "Input",
  InitializationCell->True],
Cell[209456, 4669, 408, 8, 75, "Input",
  InitializationCell->True],
Cell[209867, 4679, 194, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[210098, 4688, 31, 0, 30, "Subsubtitle"],
Cell[210132, 4690, 71, 2, 27, "Input",
  InitializationCell->True],
Cell[210206, 4694, 83, 2, 27, "Input",
  InitializationCell->True],
Cell[210292, 4698, 78, 2, 27, "Input",
  InitializationCell->True],
Cell[210373, 4702, 86, 2, 27, "Input",
  InitializationCell->True],
Cell[210462, 4706, 85, 2, 27, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[210596, 4714, 40, 0, 54, "Subtitle"],
Cell[210639, 4716, 44, 0, 30, "Text"],
Cell[210686, 4718, 226, 5, 31, "Input"],
Cell[210915, 4725, 42, 0, 30, "Text"],
Cell[210960, 4727, 252, 5, 27, "Input"],
Cell[211215, 4734, 41, 0, 30, "Text"],
Cell[211259, 4736, 273, 6, 40, "Input"],
Cell[211535, 4744, 159, 5, 30, "Text"],
Cell[211697, 4751, 276, 6, 31, "Input"],
Cell[211976, 4759, 94, 3, 30, "Text"],
Cell[212073, 4764, 853, 20, 93, "Input"],
Cell[212929, 4786, 93, 3, 30, "Text"],
Cell[213025, 4791, 723, 17, 151, "Input"],
Cell[213751, 4810, 59, 0, 30, "Text"],
Cell[213813, 4812, 376, 10, 49, "Input"],
Cell[214192, 4824, 58, 0, 30, "Text"],
Cell[214253, 4826, 692, 19, 57, "Input"],
Cell[214948, 4847, 99, 3, 30, "Text"],
Cell[215050, 4852, 267, 8, 59, "Input"],
Cell[215320, 4862, 222, 7, 30, "Text"],
Cell[215545, 4871, 208, 6, 31, "Input"],
Cell[215756, 4879, 249, 8, 30, "Text"],
Cell[216008, 4889, 335, 8, 31, "Input"],
Cell[216346, 4899, 332, 10, 36, "Text"],
Cell[216681, 4911, 344, 8, 64, "Input"],
Cell[217028, 4921, 319, 9, 36, "Text"],
Cell[217350, 4932, 312, 7, 44, "Input"],
Cell[217665, 4941, 255, 8, 30, "Text"],
Cell[217923, 4951, 382, 8, 49, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[218342, 4964, 37, 0, 54, "Subtitle"],
Cell[218382, 4966, 106, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[218513, 4973, 235, 7, 53, "Subsubtitle"],
Cell[218751, 4982, 355, 12, 32, "Text"],
Cell[219109, 4996, 221, 5, 31, "Input"],
Cell[219333, 5003, 404, 10, 50, "Text"],
Cell[219740, 5015, 348, 7, 43, "Input"],
Cell[220091, 5024, 437, 12, 50, "Text"],
Cell[220531, 5038, 348, 7, 43, "Input"],
Cell[220882, 5047, 141, 3, 32, "Text"],
Cell[221026, 5052, 151, 2, 27, "Input"],
Cell[221180, 5056, 41, 0, 32, "Text"],
Cell[221224, 5058, 199, 3, 43, "Input"],
Cell[221426, 5063, 421, 11, 50, "Text"],
Cell[221850, 5076, 361, 7, 43, "Input"],
Cell[222214, 5085, 213, 6, 32, "Text"],
Cell[222430, 5093, 305, 6, 27, "Input"],
Cell[222738, 5101, 62, 0, 32, "Text"],
Cell[222803, 5103, 936, 25, 27, "Input"],
Cell[223742, 5130, 1131, 27, 59, "Input"],
Cell[224876, 5159, 201, 8, 32, "Text"],
Cell[225080, 5169, 1019, 22, 75, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[226136, 5196, 234, 7, 42, "Subsubtitle"],
Cell[226373, 5205, 319, 9, 50, "Text"],
Cell[226695, 5216, 272, 6, 27, "Input"],
Cell[226970, 5224, 411, 10, 50, "Text"],
Cell[227384, 5236, 306, 6, 27, "Input"],
Cell[227693, 5244, 777, 19, 68, "Text"],
Cell[228473, 5265, 307, 6, 27, "Input"],
Cell[228783, 5273, 463, 12, 50, "Text"],
Cell[229249, 5287, 319, 6, 27, "Input"],
Cell[229571, 5295, 252, 9, 32, "Text"],
Cell[229826, 5306, 146, 2, 27, "Input"],
Cell[229975, 5310, 546, 12, 68, "Text"],
Cell[230524, 5324, 304, 6, 27, "Input"],
Cell[230831, 5332, 101, 3, 32, "Text"],
Cell[230935, 5337, 482, 10, 43, "Input"],
Cell[231420, 5349, 555, 18, 50, "Text"],
Cell[231978, 5369, 339, 7, 27, "Input"],
Cell[232320, 5378, 193, 6, 32, "Text"],
Cell[232516, 5386, 140, 2, 27, "Input"],
Cell[232659, 5390, 224, 6, 32, "Text"],
Cell[232886, 5398, 314, 6, 27, "Input"],
Cell[233203, 5406, 600, 17, 68, "Text"],
Cell[233806, 5425, 1084, 27, 43, "Input"],
Cell[234893, 5454, 33, 0, 32, "Text"],
Cell[234929, 5456, 132, 2, 27, "Input"],
Cell[235064, 5460, 223, 9, 32, "Text"],
Cell[235290, 5471, 880, 20, 75, "Input"],
Cell[236173, 5493, 43, 0, 32, "Text"],
Cell[236219, 5495, 70, 1, 27, "Input"],
Cell[236292, 5498, 1157, 25, 107, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[237486, 5528, 224, 7, 42, "Subsubtitle"],
Cell[237713, 5537, 393, 13, 32, "Text"],
Cell[238109, 5552, 271, 6, 27, "Input"],
Cell[238383, 5560, 346, 10, 50, "Text"],
Cell[238732, 5572, 305, 6, 27, "Input"],
Cell[239040, 5580, 400, 9, 27, "Input"],
Cell[239443, 5591, 496, 13, 50, "Text"],
Cell[239942, 5606, 324, 6, 27, "Input"],
Cell[240269, 5614, 160, 5, 32, "Text"],
Cell[240432, 5621, 380, 7, 43, "Input"],
Cell[240815, 5630, 249, 6, 32, "Text"],
Cell[241067, 5638, 632, 13, 43, "Input"],
Cell[241702, 5653, 178, 5, 32, "Text"],
Cell[241883, 5660, 618, 12, 43, "Input"],
Cell[242504, 5674, 225, 6, 32, "Text"],
Cell[242732, 5682, 422, 10, 43, "Input"],
Cell[243157, 5694, 75, 0, 32, "Text"],
Cell[243235, 5696, 290, 5, 43, "Input"],
Cell[243528, 5703, 51, 0, 32, "Text"],
Cell[243582, 5705, 524, 11, 59, "Input"],
Cell[244109, 5718, 180, 5, 32, "Text"],
Cell[244292, 5725, 336, 6, 27, "Input"],
Cell[244631, 5733, 73, 0, 32, "Text"],
Cell[244707, 5735, 365, 8, 43, "Input"],
Cell[245075, 5745, 556, 13, 43, "Input"],
Cell[245634, 5760, 152, 5, 32, "Text"],
Cell[245789, 5767, 398, 10, 27, "Input"],
Cell[246190, 5779, 432, 10, 43, "Input"],
Cell[246625, 5791, 194, 7, 32, "Text"],
Cell[246822, 5800, 1451, 29, 171, "Input"],
Cell[248276, 5831, 35, 0, 32, "Text"],
Cell[248314, 5833, 27, 0, 32, "Text"],
Cell[248344, 5835, 309, 5, 59, "Input"],
Cell[248656, 5842, 34, 0, 32, "Text"],
Cell[248693, 5844, 441, 7, 75, "Input"],
Cell[249137, 5853, 52, 0, 32, "Text"],
Cell[249192, 5855, 70, 1, 27, "Input"],
Cell[249265, 5858, 353, 6, 59, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[249655, 5869, 286, 9, 42, "Subsubtitle"],
Cell[249944, 5880, 312, 10, 31, "Text"],
Cell[250259, 5892, 274, 6, 27, "Input"],
Cell[250536, 5900, 148, 5, 31, "Text"],
Cell[250687, 5907, 309, 6, 27, "Input"],
Cell[250999, 5915, 333, 6, 43, "Input"],
Cell[251335, 5923, 568, 17, 48, "Text"],
Cell[251906, 5942, 308, 6, 27, "Input"],
Cell[252217, 5950, 279, 7, 47, "Text"],
Cell[252499, 5959, 316, 6, 27, "Input"],
Cell[252818, 5967, 202, 5, 31, "Text"],
Cell[253023, 5974, 148, 2, 27, "Input"],
Cell[253174, 5978, 122, 3, 30, "Text"],
Cell[253299, 5983, 140, 2, 27, "Input"],
Cell[253442, 5987, 173, 3, 27, "Input"],
Cell[253618, 5992, 379, 9, 47, "Text"],
Cell[254000, 6003, 283, 6, 27, "Input"],
Cell[254286, 6011, 218, 6, 31, "Text"],
Cell[254507, 6019, 325, 6, 27, "Input"],
Cell[254835, 6027, 187, 4, 31, "Text"],
Cell[255025, 6033, 371, 8, 27, "Input"],
Cell[255399, 6043, 726, 18, 66, "Text"],
Cell[256128, 6063, 334, 6, 27, "Input"],
Cell[256465, 6071, 166, 5, 31, "Text"],
Cell[256634, 6078, 307, 6, 27, "Input"],
Cell[256944, 6086, 65, 0, 30, "Text"],
Cell[257012, 6088, 161, 3, 27, "Input"],
Cell[257176, 6093, 157, 5, 31, "Text"],
Cell[257336, 6100, 343, 7, 27, "Input"],
Cell[257682, 6109, 270, 11, 31, "Text"],
Cell[257955, 6122, 349, 7, 27, "Input"],
Cell[258307, 6131, 62, 0, 30, "Text"],
Cell[258372, 6133, 577, 13, 43, "Input"],
Cell[258952, 6148, 37, 0, 30, "Text"],
Cell[258992, 6150, 511, 11, 43, "Input"],
Cell[259506, 6163, 255, 8, 31, "Text"],
Cell[259764, 6173, 118, 2, 27, "Input"],
Cell[259885, 6177, 138, 2, 27, "Input"],
Cell[260026, 6181, 171, 5, 31, "Text"],
Cell[260200, 6188, 379, 7, 43, "Input"],
Cell[260582, 6197, 165, 7, 31, "Text"],
Cell[260750, 6206, 874, 18, 107, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[261661, 6229, 286, 9, 42, "Subsubtitle"],
Cell[261950, 6240, 445, 10, 50, "Text"],
Cell[262398, 6252, 44, 0, 32, "Text"],
Cell[262445, 6254, 851, 20, 73, "Input"],
Cell[263299, 6276, 178, 6, 32, "Text"],
Cell[263480, 6284, 243, 8, 32, "Text"],
Cell[263726, 6294, 528, 12, 73, "Input"],
Cell[264257, 6308, 45, 0, 32, "Text"],
Cell[264305, 6310, 638, 15, 111, "Input"],
Cell[264946, 6327, 475, 13, 27, "Input"],
Cell[265424, 6342, 48, 0, 32, "Text"],
Cell[265475, 6344, 844, 22, 73, "Input"],
Cell[266322, 6368, 155, 5, 32, "Text"],
Cell[266480, 6375, 670, 15, 139, "Input"],
Cell[267153, 6392, 141, 5, 32, "Text"],
Cell[267297, 6399, 726, 16, 97, "Input"],
Cell[268026, 6417, 330, 9, 50, "Text"],
Cell[268359, 6428, 722, 17, 143, "Input"],
Cell[269084, 6447, 160, 5, 32, "Text"],
Cell[269247, 6454, 754, 17, 175, "Input"],
Cell[270004, 6473, 102, 4, 32, "Text"],
Cell[270109, 6479, 720, 15, 115, "Input"],
Cell[270832, 6496, 79, 3, 32, "Text"],
Cell[270914, 6501, 752, 16, 133, "Input"],
Cell[271669, 6519, 110, 3, 32, "Text"],
Cell[271782, 6524, 428, 10, 57, "Input"],
Cell[272213, 6536, 47, 0, 32, "Text"],
Cell[272263, 6538, 555, 12, 79, "Input"],
Cell[272821, 6552, 237, 6, 32, "Text"],
Cell[273061, 6560, 731, 16, 94, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[273829, 6581, 93, 1, 40, "Subsubtitle"],
Cell[273925, 6584, 223, 5, 31, "Text"],
Cell[274151, 6591, 134, 2, 42, "Input"],
Cell[274288, 6595, 1046, 28, 108, "Text"],
Cell[275337, 6625, 120, 3, 30, "Text"],
Cell[275460, 6630, 317, 8, 49, "Input"],
Cell[275780, 6640, 379, 10, 47, "Text"],
Cell[276162, 6652, 36, 0, 30, "Text"],
Cell[276201, 6654, 306, 8, 41, "Input"],
Cell[276510, 6664, 225, 6, 31, "Text"],
Cell[276738, 6672, 411, 10, 41, "Input"],
Cell[277152, 6684, 159, 5, 31, "Text"],
Cell[277314, 6691, 360, 7, 27, "Input"],
Cell[277677, 6700, 280, 6, 47, "Text"],
Cell[277960, 6708, 444, 9, 43, "Input"],
Cell[278407, 6719, 128, 5, 31, "Text"],
Cell[278538, 6726, 356, 7, 27, "Input"],
Cell[278897, 6735, 440, 10, 41, "Input"],
Cell[279340, 6747, 205, 6, 31, "Text"],
Cell[279548, 6755, 413, 9, 43, "Input"],
Cell[279964, 6766, 547, 20, 48, "Text"],
Cell[280514, 6788, 197, 6, 31, "Text"],
Cell[280714, 6796, 445, 9, 43, "Input"],
Cell[281162, 6807, 223, 5, 31, "Text"],
Cell[281388, 6814, 440, 9, 43, "Input"],
Cell[281831, 6825, 143, 4, 31, "Text"],
Cell[281977, 6831, 372, 8, 43, "Input"],
Cell[282352, 6841, 193, 5, 31, "Text"],
Cell[282548, 6848, 399, 8, 43, "Input"],
Cell[282950, 6858, 341, 6, 43, "Input"],
Cell[283294, 6866, 420, 8, 43, "Input"],
Cell[283717, 6876, 155, 4, 31, "Text"],
Cell[283875, 6882, 633, 17, 57, "Input"],
Cell[284511, 6901, 46, 0, 30, "Text"],
Cell[284560, 6903, 1517, 32, 156, "Input"],
Cell[286080, 6937, 45, 0, 30, "Text"],
Cell[286128, 6939, 923, 25, 99, "Input"],
Cell[287054, 6966, 55, 0, 30, "Text"],
Cell[287112, 6968, 1021, 27, 99, "Input"],
Cell[288136, 6997, 230, 9, 31, "Text"],
Cell[288369, 7008, 727, 16, 61, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[289133, 7029, 101, 1, 40, "Subsubtitle"],
Cell[289237, 7032, 175, 4, 30, "Text"],
Cell[289415, 7038, 189, 8, 31, "Text"],
Cell[289607, 7048, 336, 7, 47, "Text"],
Cell[289946, 7057, 356, 8, 47, "Text"],
Cell[290305, 7067, 251, 8, 31, "Text"],
Cell[290559, 7077, 47, 0, 30, "Text"],
Cell[290609, 7079, 31, 0, 30, "Text"],
Cell[290643, 7081, 73, 1, 27, "Input"],
Cell[290719, 7084, 46, 0, 30, "Text"],
Cell[290768, 7086, 198, 6, 41, "Input"],
Cell[290969, 7094, 208, 6, 59, "Input"],
Cell[291180, 7102, 46, 0, 30, "Text"],
Cell[291229, 7104, 331, 9, 59, "Input"],
Cell[291563, 7115, 218, 8, 30, "Text"],
Cell[291784, 7125, 339, 9, 59, "Input"],
Cell[292126, 7136, 155, 3, 30, "Text"],
Cell[292284, 7141, 331, 9, 59, "Input"],
Cell[292618, 7152, 23, 0, 30, "Text"],
Cell[292644, 7154, 201, 6, 41, "Input"],
Cell[292848, 7162, 38, 0, 30, "Text"],
Cell[292889, 7164, 324, 9, 41, "Input"],
Cell[293216, 7175, 60, 0, 30, "Text"],
Cell[293279, 7177, 565, 16, 74, "Input"],
Cell[293847, 7195, 30, 0, 30, "Text"],
Cell[293880, 7197, 201, 6, 41, "Input"],
Cell[294084, 7205, 32, 0, 30, "Text"],
Cell[294119, 7207, 230, 7, 41, "Input"],
Cell[294352, 7216, 37, 0, 30, "Text"],
Cell[294392, 7218, 565, 16, 74, "Input"],
Cell[294960, 7236, 28, 0, 30, "Text"],
Cell[294991, 7238, 198, 6, 41, "Input"],
Cell[295192, 7246, 23, 0, 30, "Text"],
Cell[295218, 7248, 568, 16, 74, "Input"],
Cell[295789, 7266, 568, 16, 74, "Input"],
Cell[296360, 7284, 97, 3, 30, "Text"],
Cell[296460, 7289, 211, 6, 59, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[296708, 7300, 95, 1, 40, "Subsubtitle"],
Cell[296806, 7303, 293, 9, 31, "Text"],
Cell[297102, 7314, 208, 6, 31, "Input"],
Cell[297313, 7322, 97, 3, 30, "Text"],
Cell[297413, 7327, 232, 6, 31, "Input"],
Cell[297648, 7335, 379, 11, 47, "Text"],
Cell[298030, 7348, 278, 6, 31, "Input"],
Cell[298311, 7356, 556, 15, 48, "Text"],
Cell[298870, 7373, 273, 6, 31, "Input"],
Cell[299146, 7381, 280, 6, 31, "Input"],
Cell[299429, 7389, 149, 5, 31, "Text"],
Cell[299581, 7396, 279, 6, 31, "Input"],
Cell[299863, 7404, 782, 25, 66, "Text"],
Cell[300648, 7431, 279, 6, 31, "Input"],
Cell[300930, 7439, 374, 8, 50, "Input"],
Cell[301307, 7449, 266, 8, 31, "Text"],
Cell[301576, 7459, 290, 6, 31, "Input"],
Cell[301869, 7467, 313, 11, 31, "Text"],
Cell[302185, 7480, 331, 7, 31, "Input"],
Cell[302519, 7489, 311, 8, 47, "Text"],
Cell[302833, 7499, 276, 6, 31, "Input"],
Cell[303112, 7507, 514, 16, 48, "Text"],
Cell[303629, 7525, 312, 6, 31, "Input"],
Cell[303944, 7533, 160, 5, 31, "Text"],
Cell[304107, 7540, 318, 6, 31, "Input"],
Cell[304428, 7548, 312, 8, 31, "Text"],
Cell[304743, 7558, 311, 6, 31, "Input"],
Cell[305057, 7566, 424, 8, 50, "Input"],
Cell[305484, 7576, 356, 8, 48, "Text"],
Cell[305843, 7586, 143, 2, 31, "Input"],
Cell[305989, 7590, 226, 4, 50, "Input"],
Cell[306218, 7596, 127, 3, 30, "Text"],
Cell[306348, 7601, 124, 2, 31, "Input"],
Cell[306475, 7605, 232, 6, 32, "Text"],
Cell[306710, 7613, 201, 3, 50, "Input"],
Cell[306914, 7618, 49, 0, 30, "Text"],
Cell[306966, 7620, 194, 3, 27, "Input"],
Cell[307163, 7625, 242, 9, 31, "Text"],
Cell[307408, 7636, 249, 4, 43, "Input"],
Cell[307660, 7642, 148, 5, 31, "Text"],
Cell[307811, 7649, 412, 10, 27, "Input"],
Cell[308226, 7661, 207, 5, 32, "Text"],
Cell[308436, 7668, 238, 4, 65, "Input"],
Cell[308677, 7674, 49, 0, 30, "Text"],
Cell[308729, 7676, 442, 7, 82, "Input"],
Cell[309174, 7685, 244, 10, 31, "Text"],
Cell[309421, 7697, 705, 14, 87, "Input"],
Cell[310129, 7713, 1118, 29, 100, "Text"],
Cell[311250, 7744, 1398, 24, 269, "Input"],
Cell[312651, 7770, 229, 6, 31, "Text"],
Cell[312883, 7778, 1086, 19, 157, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[314006, 7802, 102, 1, 40, "Subsubtitle"],
Cell[314111, 7805, 634, 17, 65, "Text"],
Cell[314748, 7824, 164, 5, 30, "Text"],
Cell[314915, 7831, 485, 9, 59, "Input"],
Cell[315403, 7842, 297, 9, 31, "Text"],
Cell[315703, 7853, 270, 6, 27, "Input"],
Cell[315976, 7861, 166, 5, 31, "Text"],
Cell[316145, 7868, 316, 7, 27, "Input"],
Cell[316464, 7877, 179, 5, 31, "Text"],
Cell[316646, 7884, 318, 7, 27, "Input"],
Cell[316967, 7893, 241, 6, 31, "Text"],
Cell[317211, 7901, 371, 8, 27, "Input"],
Cell[317585, 7911, 157, 5, 31, "Text"],
Cell[317745, 7918, 364, 8, 27, "Input"],
Cell[318112, 7928, 160, 5, 31, "Text"],
Cell[318275, 7935, 146, 2, 27, "Input"],
Cell[318424, 7939, 425, 10, 48, "Text"],
Cell[318852, 7951, 497, 11, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[319386, 7967, 100, 1, 40, "Subsubtitle"],
Cell[319489, 7970, 555, 17, 48, "Text"],
Cell[320047, 7989, 40, 0, 30, "Text"],
Cell[320090, 7991, 139, 3, 27, "Input"],
Cell[320232, 7996, 46, 0, 30, "Text"],
Cell[320281, 7998, 230, 4, 62, "Input"],
Cell[320514, 8004, 59, 0, 30, "Text"],
Cell[320576, 8006, 124, 2, 42, "Input"],
Cell[320703, 8010, 59, 0, 30, "Text"],
Cell[320765, 8012, 119, 2, 42, "Input"],
Cell[320887, 8016, 182, 4, 31, "Text"],
Cell[321072, 8022, 768, 20, 42, "Input"],
Cell[321843, 8044, 336, 8, 42, "Input"],
Cell[322182, 8054, 262, 10, 31, "Text"],
Cell[322447, 8066, 645, 14, 76, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[323129, 8085, 140, 4, 42, "Subsubtitle"],
Cell[323272, 8091, 141, 3, 30, "Text"],
Cell[323416, 8096, 1250, 30, 107, "Input"],
Cell[324669, 8128, 67, 1, 27, "Input"],
Cell[324739, 8131, 454, 8, 91, "Input"],
Cell[325196, 8141, 182, 5, 31, "Text"],
Cell[325381, 8148, 573, 13, 59, "Input"],
Cell[325957, 8163, 154, 5, 31, "Text"],
Cell[326114, 8170, 636, 14, 59, "Input"],
Cell[326753, 8186, 229, 5, 31, "Text"],
Cell[326985, 8193, 30, 0, 30, "Text"],
Cell[327018, 8195, 5510, 172, 91, "Input",
  Evaluatable->False],
Cell[332531, 8369, 117, 5, 31, "Text"],
Cell[332651, 8376, 594, 13, 94, "Input"],
Cell[333248, 8391, 103, 3, 30, "Text"],
Cell[333354, 8396, 608, 11, 75, "Input"],
Cell[333965, 8409, 74, 0, 30, "Text"],
Cell[334042, 8411, 967, 21, 91, "Input"],
Cell[335012, 8434, 119, 4, 31, "Text"],
Cell[335134, 8440, 581, 13, 59, "Input"],
Cell[335718, 8455, 469, 13, 48, "Text"],
Cell[336190, 8470, 1224, 26, 123, "Input"],
Cell[337417, 8498, 223, 6, 31, "Text"],
Cell[337643, 8506, 3630, 63, 530, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[341310, 8574, 137, 4, 42, "Subsubtitle"],
Cell[341450, 8580, 399, 11, 47, "Text"],
Cell[341852, 8593, 364, 7, 43, "Input"],
Cell[342219, 8602, 225, 5, 31, "Text"],
Cell[342447, 8609, 5510, 172, 91, "Input",
  Evaluatable->False],
Cell[347960, 8783, 50, 0, 30, "Text"],
Cell[348013, 8785, 433, 9, 43, "Input"],
Cell[348449, 8796, 712, 16, 59, "Input"],
Cell[349164, 8814, 237, 6, 31, "Text"],
Cell[349404, 8822, 643, 15, 59, "Input"],
Cell[350050, 8839, 182, 5, 31, "Text"],
Cell[350235, 8846, 482, 10, 43, "Input"],
Cell[350720, 8858, 147, 5, 30, "Text"],
Cell[350870, 8865, 1015, 22, 91, "Input"],
Cell[351888, 8889, 50, 0, 30, "Text"],
Cell[351941, 8891, 969, 22, 75, "Input"],
Cell[352913, 8915, 93, 3, 30, "Text"],
Cell[353009, 8920, 652, 15, 59, "Input"],
Cell[353664, 8937, 197, 5, 31, "Text"],
Cell[353864, 8944, 818, 19, 81, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[354719, 8968, 100, 1, 42, "Subsubtitle"],
Cell[354822, 8971, 510, 11, 68, "Text"],

Cell[CellGroupData[{
Cell[355357, 8986, 67, 0, 69, "Section"],
Cell[355427, 8988, 213, 5, 32, "Text"],
Cell[355643, 8995, 215, 5, 27, "Input"],
Cell[355861, 9002, 199, 6, 32, "Text"],
Cell[356063, 9010, 146, 2, 27, "Input"],
Cell[356212, 9014, 360, 11, 50, "Text"],
Cell[356575, 9027, 499, 11, 43, "Input"],
Cell[357077, 9040, 233, 6, 32, "Text"],
Cell[357313, 9048, 264, 5, 27, "Input"],
Cell[357580, 9055, 155, 5, 32, "Text"],
Cell[357738, 9062, 261, 5, 27, "Input"],
Cell[358002, 9069, 347, 7, 43, "Input"],
Cell[358352, 9078, 143, 5, 32, "Text"],
Cell[358498, 9085, 261, 5, 27, "Input"],
Cell[358762, 9092, 344, 7, 43, "Input"],
Cell[359109, 9101, 151, 5, 32, "Text"],
Cell[359263, 9108, 151, 2, 27, "Input"],
Cell[359417, 9112, 352, 13, 32, "Text"],
Cell[359772, 9127, 417, 8, 43, "Input"],
Cell[360192, 9137, 557, 10, 59, "Input"],
Cell[360752, 9149, 642, 13, 59, "Input"],
Cell[361397, 9164, 169, 5, 32, "Text"],
Cell[361569, 9171, 506, 9, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[362112, 9185, 66, 0, 39, "Section"],
Cell[362181, 9187, 167, 5, 32, "Text"],
Cell[362351, 9194, 359, 8, 43, "Input"],
Cell[362713, 9204, 149, 5, 32, "Text"],
Cell[362865, 9211, 368, 7, 43, "Input"],
Cell[363236, 9220, 180, 5, 32, "Text"],
Cell[363419, 9227, 362, 7, 43, "Input"],
Cell[363784, 9236, 289, 8, 32, "Text"],
Cell[364076, 9246, 372, 7, 43, "Input"],
Cell[364451, 9255, 495, 8, 59, "Input"],
Cell[364949, 9265, 475, 9, 59, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[365461, 9279, 52, 0, 39, "Section"],
Cell[365516, 9281, 346, 7, 50, "Text"],
Cell[365865, 9290, 244, 6, 27, "Input"],
Cell[366112, 9298, 282, 9, 32, "Text"],
Cell[366397, 9309, 135, 2, 27, "Input"],
Cell[366535, 9313, 165, 5, 32, "Text"],
Cell[366703, 9320, 309, 6, 43, "Input"],
Cell[367015, 9328, 91, 3, 32, "Text"],
Cell[367109, 9333, 103, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[367249, 9340, 47, 0, 39, "Section"],
Cell[367299, 9342, 172, 7, 32, "Text"],
Cell[367474, 9351, 1354, 29, 139, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[368865, 9385, 45, 0, 39, "Section"],
Cell[368913, 9387, 372, 10, 50, "Text"],
Cell[369288, 9399, 390, 7, 43, "Input"],
Cell[369681, 9408, 300, 9, 50, "Text"],
Cell[369984, 9419, 291, 6, 27, "Input"],
Cell[370278, 9427, 282, 8, 32, "Text"],
Cell[370563, 9437, 279, 6, 43, "Input"],
Cell[370845, 9445, 213, 4, 43, "Input"],
Cell[371061, 9451, 214, 6, 32, "Text"],
Cell[371278, 9459, 252, 4, 43, "Input"],
Cell[371533, 9465, 388, 10, 50, "Text"],
Cell[371924, 9477, 315, 5, 43, "Input"],
Cell[372242, 9484, 293, 6, 50, "Text"],
Cell[372538, 9492, 137, 2, 27, "Input"],
Cell[372678, 9496, 136, 2, 27, "Input"],
Cell[372817, 9500, 129, 3, 32, "Text"],
Cell[372949, 9505, 215, 4, 43, "Input"],
Cell[373167, 9511, 488, 8, 107, "Input"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

